/* *******************************************************************
** Copyright (c) 2002-2011 Seiji Kaneko. All rights reserved.
** Copyright (c) 1991-1999 Unicode Inc. All rights reserved.
** Copyright (C) 2000, earthian_at_tama.or.jp, All right reserved.
** Copyright (c) 1995-2005 International Business Machines 
**		 Corporation and others
** Everyone is permitted to use this program in source and binary
** form, with or without modification if and only if the following
** conditions are met:
** 1. Redistributions of source code must retain the above copyright
**   notice, copyright notice written in source code, additional list
**   of conditions and the following disclaimer.
** 2. Redistributions in machine readable form must reproduce the 
**   above copyright notice and the following disclaimer in the
**   documentation or other material provided with the distribution.
** 3. Neither the name of the copyright holders nor the names of its 
**   contributors may be used to endorse or promote products derived
**   from this software without specific prior written permission.
**********************************************************************
** Disclaimer: This software is provided and distributed AS IS, 
**	without any implicit or explicit warranties, and not
**	guaranteed to be error-free. In no event shall the author be
**	liable for any direct, indirect or incidental damages,
**	including, but not limited to, loss of data, use or profits
**	responsibility for any direct or indirect damages or results
**	arising by using whole or a part of this software.
**********************************************************************
** dyn_table.c: dynamic loading area
** $Id: dyn_table.c,v 1.101 2013/07/22 13:42:44 seiji Exp seiji $
**
**********************************************************************
*/

#include <sys/types.h>
#include <stddef.h>
#include <stdio.h>
#include <stdlib.h>
#include "skf.h"
#include "skf_fileio.h"
#include "convert.h"
#include "oconv.h"

#include "in_code_table.h"

#define GBK_1_LEN	846	/* GB2312 + some vertical symbol   */
#define GBK_2_LEN	6768	/* GB2312 Chinese		   */
#define GBK_3_LEN	6080	/* UCS Hanzi (U-4e02 - 72db) */
#define GBK_4_LEN	8140	/* UCS Hanzi (U-72dc - 9fa5) */
#define GBK_5_LEN	192

#define HKSCS_FA_LEN	1140	/* f940 - fefe			   */
#define HKSCS_88_LEN	4750	/* 8840 - a0fe			   */
#define HKSCS_C6_LEN	570	/* c640 - c8fe			   */

#define BIG5UAO_FA_LEN  950	/* fa40 - fefe			   */

#define	SKF_IN_CODE_FILE "in_table_defs.h"
#define SKF_OUT_CODE_FILE "out_table_defs.h"
#define SKF_ALT_TABLE_FILE "output.txt"

#define FORMAT_SKF	0	/* Default: for skf 		*/
#define FORMAT_SKFL	1	/* Default: !dynamic_loading	*/
#define FORMAT_GNU	10	/* GNU iconv			*/
#define FORMAT_ICU	20	/* IBM icu			*/
#define FORMAT_CITRUS	30	/* Citrus iconv			*/
#define FORMAT_MOZ	40	/* Mozilla			*/

#if defined(OUTPUT_DYNAMIC_TABLE) || !defined(DYNAMIC_LOADING) || defined(SWIG_EXT)
extern int cns11643_defined_code ;    /* cns11643-1,2,3 is defined */

void	gb2k_table_gen();
void	gb2k_otbl_gen();
void	gbk_table_gen();
void	gbk_otbl_fix();
void	big5p_table_gen();
void	big5a_table_gen();
void	big52_table_gen();
void	gb2312_otbl_fix();
void	cp932_table_gen();
void	cp943_table_gen();
void	x213n_table_gen();
void	cp932_fix_tbl();
void	cp932w_fix_tbl();
void	cp943_fix_tbl();
void	hku_table_gen();
void	big5p_otbl_fix();
void	big5a_otbl_fix();
void	o_x213_1nfix();
void	sjis_cell_fix_tbl();
void	ntt_table_setup();
void	uhc_otbl_fix();
void	keish_table_gen();
void	x0208nj_table_gen();
void	emoticon_table_gen();
void	emoti_ntt_otbl_gen();
void	emoti_sb_otbl_gen();
void	emoti_au_otbl_gen();
void	emoticon_otbl_gen();
void	set_out_table();
#else
void	emoticon_table_gen();
void	emoticon_otbl_gen();
#endif

/* --------------------------------------------------------------- */
#if defined(OUTPUT_DYNAMIC_TABLE) || !defined(DYNAMIC_LOADING) || defined(SWIG_EXT)
skf_ucode uni_t_keis59[KEIS_TBL_LEN] = {	/* 59a1 - 80fe	   */
/* 59xx */ 0x4e02,0x4e08,0x2000b, 0x2000b,0x4e12,0x4e12,0x0000,
    0x3402,0x4e23,0x4e23,0x0000, 0x4e85,0x3427,0x3005,0x4e42,
    0x4e44,0x4e47,0x4e75,0x5f0d, 0x4ea4,0x342a,0x4ead,0x4eae,
    0x4eb6,0x9f4a,0x8c6a,0x8944, 0x9f4b,0x9f4b,0x4eb9,0x4eb9,
    0x4eca,0x4ee1,0x3430,0x201cd, 0x0000,0x4efd,0x4f00,0x4f00,
    0x4efc,0x4ef1,0x4f15,0x4f56, 0x4f3b,0x4f42,0x4f39,0x3446,

    0x4f02,0x3441,0x4f35,0x4f4b, 0x4f3e,0x4f71,0x4f2d,0x4f7e,
    0x4f97,0x4f94,0x4f9a,0x4f92, 0x4f93,0x4f81,0x4f9f,0x4f6e,
    0x4f8a,0x3450,0xfa30,0x4fe6, 0x4fc9,0x4fb1,0x4fcd,0x4fb2,
    0x4fe2,0x4ff1,0x4fcb,0x4fd8, 0x4fbe,0x4fcc,0x4fde,0x501b,
    0x5018,0x5022,0x501c,0x501e, 0x5027,0x4ffc,0x4ffd,0x3467,
    0x500e,0x501d,0x4fff,0x3464, 0x4ff1,0x5030,0x3468,
/* 5axx */
    	   0x5040,0x5077,0x505f, 0x5085,0x5042,0x5042,0x5046,
    0x5057,0x5063,0x5066,0x5079, 0x5070,0x50a5,0x5086,0x50a2,
    0x5094,0x517c,0x5084,0x5093, 0x509f,0x6703,0x6703,0x6703,
    0x6703,0x50bd,0x50b3,0x508e, 0x50cc,0xfa31,0x50f4,0x50e1,
    0x50d9,0x50d8,0x50cf,0x50d3, 0x50f1,0x5107,0x50ef,0x5114,
    0x512c,0x512d,0x514a,0x514a, 0x514a,0x5151,0xfa32,0x5c2d,

    0x5157,0x515f,0x5164,0x5164, 0x5c73,0x4eca,0x5177,0x8207,
    0x8208,0x517c,0x8207,0x5dfd, 0x8207,0x5189,0x0000,0x723e,
    0x723e,0x519d,0x51a6,0x6c4e, 0x51be,0x51bf,0x51bc,0x0000,
    0x51e3,0x51e1,0x51ee,0x5e7c, 0x5220,0x5224,0x528e,0x8fa7,
    0x529c,0x52a6,0x52a4,0x0000, 0x351a,0x52b6,0x52c6,0x52ca,
    0x52ca,0x52c9,0x52d1,0x52e2, 0x52d9,0x52d8,0x52d6,
/* 5bxx */ /* Note: 6b77 and f98c looks same. Took 6b77  */
    	   0x52db,0x52e4,0xfa34, 0x52e5,0x52ea,0x52f1,0x8fa8,
    0x52fb,0x52fb,0x5305,0x5307, 0x0000,0x5315,0x352b,0x5324,
    0x8352,0x5342,0x353a,0x534b, 0xfa35,0x5c2d,0x5e78,0x684c,
    0x535a,0x5359,0x535a,0x536c, 0x5372,0x5377,0x5377,0x537d,
    0x5388,0x0000,0x20a38,0x0000, 0x5393,0x20a64,0x53a9,0x6b77,
    0x56b4,0x53b2,0x2062d,0x53b8, 0x53bd,0x590b,0x20af3,0x355b,

    0x53da,0x53db,0x53de,0xfa0e, 0x58e1,0x53f1,0x5433,0x6213,
    0x0000,0x20bb7,0x548a,0x549c, 0x5464,0x5496,0x5489,0x54c6,
    0x54a1,0x54a9,0x5471,0x54ff, 0x54f2,0x54e0,0x555d,0x5561,
    0x5500,0x5553,0x5553,0x5584, 0x5584,0x5586,0x5586,0xfa36,
    0x55a9,0x5581,0x559c,0x5597, 0x5599,0x55c3,0x58fd,0x58fd,
    0x58fd,0xfa37,0x5610,0x563b, 0x5644,0x566f,0x5672,
/* 5cxx */
    	   0x569d,0xfa38,0x569d, 0x569e,0x5694,0x56ad,0x56ce,
    0x56ec,0x570e,0x5711,0x5716, 0x571a,0x2123d,0x5721,0x5723,
    0x5734,0x5746,0x5759,0x21261, 0x3634,0x5762,0x5765,0x5e78,
    0x25e2e,0x57ac,0x2131b,0xfa0f, 0x57bd,0x57c8,0x57cc,0x57f5,
    0x57ed,0x0000,0x583f,0x0000, 0x585a,0x5819,0x584f,0xfa10,
    0xfa10,0x57f8,0x5859,0x5859, 0x5897,0x588a,0x588f,0x5887,

    0x588c,0x589e,0xfa3a,0x58b2, 0x589c,0x58d4,0x58e5,0x58fc,
    0x58fd,0x5609,0x5900,0x5906, 0x590c,0x5917,0x3688,0x21584,
    0x591b,0x685d,0x5933,0x594c, 0x5953,0x5951,0x595b,0x595f,
    0x595d,0x5963,0x2164f,0x5967, 0x6f01,0x596d,0x5972,0x0000,
    0x5975,0x598c,0x0000,0x599f, 0x59a4,0x59c8,0x59c3,0x59ba,
    0x59e4,0x59dd,0x59de,0x5a1c, 0x5a23,0x5a0e,0x5a1b,
/* 5dxx */
    	   0x5a67,0x5a5e,0x5a45, 0x5a6c,0x5a48,0x5a67,0x5a9f,
    0x5a9e,0x5a84,0x36f7,0x5a9b, 0x5abe,0x5ab3,0x5b09,0x5ac1,
    0x5ae9,0x5b05,0x5b4b,0x5b56, 0x5b66,0x5b76,0x5b73,0x5b78,
    0x5b75,0x6585,0x219c3,0x5baf, 0x5bb2,0x3758,0x5bb6,0x5bb1,
    0x5bb3,0x5bc0,0x5bc0,0x3761, 0x5bc7,0x752f,0x5bd8,0x5bec,
    0x5bec,0x5bec,0x5be7,0x8218, 0x5bf3,0x5c08,0x5c0b,0x5c0b,

    0x5c0a,0x5c19,0x5c1e,0x5c2d, 0x378d,0x5c4f,0x53a6,0xfa3b,
    0x5c8f,0x5c8a,0x5c91,0x5c92, 0x5c88,0x5cba,0x5ca6,0x5cb5,
    0x37bb,0x5cad,0x5cbc,0x5ccb, 0x5cc9,0x5ccc,0x5cf5,0x5cf4,
    0x5d27,0x5d27,0x5d2b,0x5d23, 0xfa11,0x5d34,0x5d43,0x5d42,
    0x5d53,0x5d61,0x21ed5,0x5d8c, 0x21ec5,0x3800,0x5d69,0x5db9,
    0x5d8a,0x5da0,0x5d94,0x5d92, 0x5d9a,0x3810,0x5d9f,
/* 5exx */
    	   0x5da7,0x5dab,0x5db8, 0x5dcc,0x5db9,0x5dcb,0x5dd0,
    0x5dd6,0x34db,0x5dfb,0x5df8, 0x4e55,0x4e55,0x2207a,0x5e0d,
    0x220e1,0x5e3d,0x5e58,0x5e64, 0x5e73,0x5e75,0x8332,0x5e80,
    0x5e92,0x5ea8,0x5eac,0x5ebb, 0x5ea7,0x5ea7,0x3888,0x5ebe,
    0x5eb3,0x5eb8,0x5eca,0x9ebd, 0x5ee3,0x5ee3,0x5ee0,0x0000,
    0x389c,0x5ef6,0x5ef9,0x5efd, 0x5f07,0x5f5e,0x5f10,0x5f0e,

    0x22397,0x5f1c,0x5f21,0x5f34, 0x5f3a,0x0000,0x5f4c,0x5f4c,
    0x5f45,0x5f4c,0x5f63,0x5f65, 0x5f6f,0x224c1,0x5f78,0x0000,
    0x5f8d,0x5f89,0x38e2,0x5fa4, 0x5fb5,0x5fb5,0x5fb7,0x5fb7,
    0x5fc9,0x5fc7,0x5ffa,0x5fce, 0x5fe9,0x6033,0x5fde,0x5fde,
    0x5fe2,0x3917,0x6071,0x0000, 0x391a,0x6054,0x608a,0xfa3d,
    0x605d,0x6085,0x392b,0x0000, 0x6093,0x6075,0x607f,
/* 5fxx */
    	   0x60bb,0x60c5,0x60d5, 0x60b0,0x60de,0x6097,0x60a5,
    0x6098,0x60e0,0x6120,0x6113, 0x6109,0x60f2,0x613d,0x6111,
    0x3960,0x6137,0x613c,0x6130, 0x3963,0x6139,0x60e0,0x6108,
    0x612b,0x6165,0x3972,0x2278d, 0x616c,0x611b,0x6198,0x6167,
    0x6167,0xfa3f,0x61ad,0x61bc, 0x6193,0x61dd,0x61ed,0xfa40,
    0x8302,0x8302,0x5f67,0x39b6, 0x621c,0x6222,0x6229,0x0000,

    0x6236,0x623f,0x624d,0x6273, 0x62d0,0x62cb,0x62a6,0x6304,
    0x6346,0x6339,0x634d,0x6377, 0x6368,0x6374,0x39fd,0x63b2,
    0x63be,0x63c4,0x63f5,0x3a17, 0x3a17,0x63c1,0x0000,0x6409,
    0x6428,0x6424,0x6460,0x6460, 0x64cd,0x6455,0x649d,0x6499,
    0x64b9,0x64da,0x64ce,0x64ca, 0x652c,0x5909,0x6546,0xfa41,
    0x654e,0x6550,0x655f,0x655e, 0x6572,0x6578,0x6583,
/* 60xx */
    	   0x6586,0x0000,0x658a, 0x2307d,0x65a6,0x65c5,0x65e1,
    0x3ad6,0x65f6,0x66f4,0x65f5, 0x65f2,0x6602,0x6602,0x6609,
    0x6611,0x6615,0x0000,0x6600, 0x660b,0x6608,0x663b,0x6634,
    0x6630,0x6624,0x6624,0x661e, 0x662e,0x6639,0x662e,0x6622,
    0x6621,0x65fa,0x6633,0x6607, 0x661e,0x663a,0x3ae0,0x66fa,
    0x6607,0x6648,0x6648,0x664c, 0x6651,0x6649,0x6640,0x6607,

    0x664e,0x6665,0x6663,0x66fb, 0x665b,0x6667,0x6657,0x6659,
    0x231c4,0x3af4,0x66fc,0x665a, 0x6677,0xfa12,0x0000,0x23209,
    0x666b,0x6673,0x231f5,0x666a, 0xfa43,0x668e,0x6699,0x668a,
    0x6692,0x669c,0x66a0,0x669a, 0x669f,0x0000,0x66b2,0x66bf,
    0x66c6,0x66bb,0x66c8,0x3b1a, 0x3b22,0x3b26,0x66e0,0x66da,
    0x6631,0x66fe,0x80d7,0x80e0, 0x670e,0x0000,0x80d6,
/* 61xx */
    	   0x43ee,0x80e4,0x8107, 0x6713,0x6719,0x6717,0x6717,
    0x8135,0x43f8,0x671b,0x671b, 0x43ef,0x69ba,0x6743,0x233c5,
    0x6747,0x6755,0x6766,0x6781, 0x233cc,0x233c8,0x6780,0x6798,
    0x6747,0x678e,0x67d7,0x67bb, 0x67d9,0x67d7,0x67bd,0x0000,
    0x0000,0x67bc,0x6852,0x67f3, 0x6852,0x6881,0x6844,0x67d3,
    0x6821,0x6849,0x67ff,0x67f3, 0x67f3,0xfa44,0x68a2,0x5de3,

    0x3b74,0x6adb,0x6884,0x67f3, 0x6875,0x6879,0x68b2,0x688f,
    0x687c,0x68da,0x0000,0x68c8, 0x68c8,0x68fd,0x6949,0x68cf,
    0xfa13,0x0000,0x6967,0x696e, 0x3b88,0x690a,0x3b78,0x68f0,
    0x6957,0x6968,0x69cc,0x6986, 0x698a,0x6962,0x6945,0x69e2,
    0x0000,0x6991,0x69b2,0x69b7, 0x69c0,0x69ad,0x6a58,0x69d9,
    0xfa14,0x6a0b,0x23583,0x0000, 0x69c7,0x2363a,0x69d7,
/* 62xx */
    	   0x6a3a,0x69c1,0x0000, 0x69e2,0x6a11,0x69e3,0x69ff,
    0x6a2a,0x6a2a,0x6a4e,0x6a3d, 0x6a9c,0x6a9c,0x6a46,0x6a52,
    0x6a45,0x3be2,0x6a73,0x6a7e, 0x6a80,0x6ad4,0x6adb,0x6aac,
    0x6ae4,0x6ae2,0x6ace,0x6acc, 0x6ad5,0x6ade,0x6b04,0x91cb,
    0x6b0a,0x6b35,0x6b2b,0x6b4a, 0x6b56,0x6b65,0x6b72,0x6b73,
    0x6b73,0x6b73,0x6b85,0x6baf, 0x3c7c,0x6bbe,0x23ad4,0x6bcf,

    0x6bd6,0x6bf1,0x6c10,0x6c11, 0x6c13,0x6c3f,0x6c5c,0x6c4b,
    0x6c86,0x6c6f,0x23ca8,0x6c72, 0x6c76,0x6ceb,0x6ce0,0x6ce9,
    0x6cc2,0x6c6d,0x6cda,0x6cd6, 0x6d04,0x6d2e,0x6d39,0x6cfb,
    0x6cf4,0x6d69,0xfa45,0x6d87, 0x6d82,0x6d65,0x6d96,0x6dda,
    0x6d89,0x3cdf,0x6d6f,0x6d8d, 0x6d25,0x6d81,0x6df5,0x6d2f,
    0x6d70,0x23cfe,0x23cfe,0x6ed9, 0x6dac,0x6df8,0x6dfb,
/* 63xx */
    	   0x6de9,0x6de5,0x6e38, 0x6dcf,0x6dcf,0x6df2,0x6dd0,
    0x6deb,0x6dce,0x6e36,0x6db5, 0x6e34,0x6e27,0x6e27,0x6e2f,
    0xfa46,0x6e51,0x6e53,0x6f06, 0x6e5c,0x6e40,0x6e90,0x6e39,
    0x6e3c,0x0000,0x6e5e,0x23e32, 0x6c52,0x6dfc,0x6df5,0x6e5b,
    0x6e74,0x6eab,0x6e9d,0x6eb1, 0x6ec7,0x6ea2,0x6eb1,0x6e80,
    0x6ebf,0x6f3e,0x6e99,0xfa47, 0x7aaa,0x6eff,0x6eff,0x6eff,

    0x6eff,0x6eff,0x6eff,0x6f33, 0x6f11,0x6f3b,0x6eff,0x6eff,
    0x6f88,0x6fb3,0x6f61,0x6fab, 0x6f11,0x6f92,0x6fa7,0x6fb5,
    0x6faf,0x6fa4,0x6ff1,0x701e, 0x6ff5,0x6fef,0x6fda,0x6fe0,
    0x7007,0x6eff,0x6eff,0x7005, 0x6eff,0x7007,0x7027,0x7027,
    0x7027,0x7028,0x7027,0x6ffe, 0x701e,0x6e08,0x705d,0x7069,
    0x7085,0x7098,0x708f,0x7086, 0x70a4,0x70ab,0x70bb,
/* 64xx */
    	   0x70dc,0x70d8,0x70d3, 0x0000,0x7104,0x710f,0x710f,
    0x711e,0x710f,0x712f,0x517c, 0xfa48,0x715c,0x7146,0x7147,
    0x7156,0x7152,0x7152,0x7192, 0x71c1,0x7180,0x7155,0x7199,
    0x7199,0xfa15,0xfa15,0xfa15, 0x7188,0x71c1,0x7188,0x71cb,
    0x71c1,0x71ba,0x71fe,0x7200, 0x7209,0x91c7,0x58ee,0xf9fa,
    0x5c06,0x5c06,0x7247,0x7247, 0x72b1,0x731b,0xfa16,0x7336,

    0x7324,0x7350,0x7377,0x7385, 0x7386,0x738e,0x739e,0x73a8,
    0x73a5,0x739f,0x739c,0x73c9, 0x73cf,0x73cb,0x73bc,0x73bd,
    0x73c6,0x73bf,0x73d9,0x73e9, 0x73d6,0x73e3,0x73e7,0x73f9,
    0x73d2,0x0000,0x3ec6,0x7407, 0x73f5,0x73f5,0x7401,0x73f4,
    0x73fd,0x7404,0x7422,0x0000, 0xfa4a,0x7426,0x742a,0x7439,
    0x742e,0x741b,0x741a,0x742b, 0x7429,0x0000,0x743c,
/* 65xx */
    	   0x742d,0x249fd,0x7443, 0x7457,0x6e2b,0x744b,0x0000,
    0x7462,0x7489,0x7472,0x7471, 0x7480,0x7487,0x7489,0x3ee8,
    0x74a3,0x7498,0x749f,0x7499, 0x749a,0x74bf,0x74e0,0x74e3,
    0x74fa,0x7501,0x750d,0x751a, 0x7521,0x7522,0x0000,0x7540,
    0x7554,0x753e,0x7571,0x756f, 0x75e4,0x7619,0x762d,0x7664,
    0x766d,0x34b5,0x7682,0x7695, 0x7693,0x76a2,0x769c,0x769e,

    0x769e,0x769b,0x76a6,0x76a7, 0x76a9,0x76b6,0x76c1,0x76c8,
    0xfa17,0x76df,0x76e3,0x76f4, 0x7706,0x771f,0x771f,0x772b,
    0x7712,0x771e,0x771e,0x772d, 0x7739,0x773b,0x7746,0x774d,
    0x771e,0x775c,0x775b,0x4050, 0x7774,0x7772,0x405f,0x4071,
    0x77cc,0x77de,0x4093,0x0000, 0x6998,0x4096,0x52af,0x7821,
    0x7814,0x7814,0x784e,0x7851, 0x786e,0x785e,0x7863,
/* 66xx */
    	   0x7864,0x7860,0x0000, 0xfa4b,0x787a,0x787b,0x789e,
    0x78cc,0x78e6,0x40dd,0x78fb, 0x78fa,0x7926,0x7930,0x7925,
    0xfa18,0x25609,0x7940,0x7940, 0xfa4c,0xfa4e,0xfa4d,0x7962,
    0x795a,0x795c,0xfa51,0xfa19, 0xfa50,0xfa4f,0x796e,0x7957,
    0x7958,0x7962,0xfa1a,0x2567f, 0x4105,0x7971,0x4106,0xfa61,
    0x797a,0x0000,0x0000,0x797f, 0x81fa,0x7994,0x7979,0xfa52,

    0x7994,0xfa53,0x7993,0xfa1b, 0x799b,0x79a7,0x79ae,0x79b0,
    0x79b0,0x9f92,0x79ca,0x79cc, 0x79d6,0x79de,0x79e2,0x79da,
    0x79f1,0x0000,0x4147,0x79f8, 0x7a02,0x7a11,0x7a2b,0x0000,
    0x7a3d,0x4163,0x4165,0xfa54, 0x7a39,0x7a45,0x9fa2,0x7a57,
    0x7a60,0x7a5f,0x7a6a,0x7a67, 0x7a70,0x7a74,0x7a7a,0xfa55,
    0x7a91,0x7a99,0x7a96,0x7aa0, 0x7ac3,0x9083,0x7ad1,
/* 67xx */
    	   0x0000,0x7ae7,0x7ae4, 0x7aeb,0x7aeb,0xfa1c,0x7ae9,
    0x7ae8,0x0000,0x7af1,0x7afd, 0x7b08,0x7b0b,0x7b27,0x7b53,
    0x7b40,0x7b3f,0x7b6d,0x7b64, 0x7b8f,0x7bc0,0xfa56,0x7b9e,
    0x7bad,0x7bbd,0x7be1,0x7bd9, 0x7c17,0x7bc4,0x7bdd,0x7c11,
    0x7bc4,0x7c0f,0x7b86,0x7c13, 0x7c09,0x7c31,0x7c1b,0x7c54,
    0x7c60,0x7c89,0x6549,0x7c99, 0xfa1d,0x7cb7,0x7cd8,0x42af,

    0x7d08,0x7d03,0x7d09,0x7d00, 0x7d1d,0x7d0d,0x7d0b,0x7d0f,
    0x7d14,0x7d13,0x7d47,0x7d37, 0x0000,0x7d48,0x7d3e,0x7d4d,
    0x7d79,0x7d5c,0x7d5c,0x25ffd, 0x7d53,0x7d54,0x7d8b,0x7d9b,
    0x7d93,0x7d8d,0x7dc4,0x7da0, 0x7db7,0x7db5,0x7da1,0x7db6,
    0x7dc3,0x7dd6,0xfa57,0x7deb, 0x7e01,0x7de3,0x7ded,0x7e11,
    0x7e41,0x7e2b,0x7e52,0x7e52, 0x7e6a,0x7e8a,0x7e8a,
/* 68xx */
    	   0x7e7d,0x7e7f,0x7e92, 0x530b,0x7f47,0x7f44,0x7f54,
    0xfa5a,0x7f91,0x7f99,0x7f8e, 0x7f8e,0x7f95,0x7fa1,0x7fa9,
    0x7faf,0x7fb2,0xfa1e,0x7fc1, 0x7fd4,0x7fe0,0x7fe6,0x7fee,
    0x7ff0,0x7ffc,0xfa5b,0x8014, 0x8020,0x8024,0x8039,0x8060,
    0x8054,0x8056,0x8073,0x8070, 0x5367,0x81e4,0xfa5c,0x0000,
    0x8207,0x8240,0x826e,0x827f, 0x8296,0x8283,0x828a,0x8299,

    0x82a7,0x82a8,0x82be,0x8307, 0x82b1,0x82b3,0x8299,0x82d6,
    0x82e4,0x830a,0x8301,0x82f3, 0x8343,0x8362,0x833d,0x82e5,
    0x82e5,0x8302,0x837f,0x8302, 0x44b9,0x82f1,0x82f1,0x8333,
    0x0000,0x44be,0x8352,0x8352, 0x8352,0x8352,0x8352,0x83ef,
    0x8378,0x83a3,0x837f,0x839e, 0x8398,0x83ef,0x83c1,0x83df,
    0x83f6,0x845b,0x8352,0x8323, 0x83c7,0x840d,0x8352,
/* 69xx */
    	   0x8413,0x83c0,0x8448, 0x844f,0x843b,0x83c5,0x83ca,
    0x845f,0x842b,0x83df,0x8470, 0xfa5f,0x84ee,0x84dc,0x84b4,
    0x8429,0x0000,0x8431,0x8449, 0x8449,0x84a6,0x8533,0x8517,
    0x8513,0x85cf,0x856b,0x8570, 0x854f,0x852d,0x8553,0x8559,
    0x858f,0x81c8,0x8563,0x85c7, 0x8586,0x0000,0x85ab,0x0000,
    0x85be,0x85b0,0x85b0,0x85e4, 0x8613,0x8612,0x8604,0x8618,

    0xfa20,0x8653,0x865b,0x865c, 0x8663,0x0000,0x0000,0xfa21,
    0x873e,0x87d2,0x8807,0x880d, 0x8821,0x8859,0x885e,0x885e,
    0x8879,0x27657,0x88ef,0x8944, 0xfa60,0x798e,0x88f5,0x8906,
    0x891c,0x891c,0x88f5,0x893d, 0x79ae,0x4674,0x0000,0x8988,
    0x898a,0x8990,0x89a0,0x899a, 0x89ba,0x89c0,0x89bd,0x89d2,
    0x24c04,0x89d4,0x89e5,0x89da, 0x89f4,0x8a15,0x8a12,
/* 6axx */
    	   0x8a11,0x8a22,0x8a4e, 0x8a56,0x8a37,0x8a47,0x8a1d,
    0x8a65,0x8a72,0x8a79,0x8aa7, 0x8a8f,0x8abe,0x8ad7,0x8acb,
    0x46ed,0xfa62,0x8af8,0x8adf, 0x8af6,0x8af6,0x8aed,0x8aff,
    0x8b39,0xfa63,0x8b1c,0x8b46, 0x8b4c,0x8b6a,0x8b53,0x8b54,
    0x8b71,0x8b74,0x8b93,0x8b7f, 0x4722,0x8c54,0x8c5a,0x8c61,
    0x8c70,0x8c9f,0x8ca4,0x8ce2, 0x8cba,0x8cb9,0xfa64,0x8cf4,

    0x8cf0,0x8cf2,0x8cef,0x8ce2, 0xfa65,0x8d12,0x8d1c,0x8d77,
    0x8d76,0xfa23,0x8dab,0x8dda, 0x8e48,0x8e64,0x8e8d,0x0000,
    0x8ec7,0x8ecf,0x282c2,0x8f1d, 0x8f38,0x8f54,0x8fa1,0x8fbb,
    0x8fbe,0x8fbc,0x8fc4,0xfa24, 0x8fd1,0xfa24,0x8fea,0x8fee,
    0x8fe8,0x8ff6,0x9022,0x9027, 0x9025,0x901a,0x900c,0x9039,
    0x9039,0x9032,0xfa25,0x9060, 0x9033,0xfa25,0x9044,
/* 6bxx */
    	   0x9060,0x0000,0x9067, 0x906e,0x9081,0x0000,0x908a,
    0x9089,0x9089,0x9089,0x9066, 0x907c,0x96a8,0x9089,0x9089,
    0x9089,0x9089,0x9089,0x9089, 0x908a,0x908a,0x908a,0x908a,
    0x908a,0x908a,0x907d,0x908a, 0x9089,0x961d,0x90a0,0x90a6,
    0x90a6,0x90a6,0x90a6,0x90a3, 0x90a2,0x90b0,0x90c4,0x90ce,
    0x90db,0x90ab,0x90fd,0x9109, 0x9119,0x9109,0x9109,0x90d2,

    0x286ba,0x9127,0x90d2,0x9137, 0x913a,0x91b5,0x91cd,0x91d9,
    0x91d7,0x91da,0x91de,0x91ec, 0x91ed,0x91f1,0x91f0,0x91e5,
    0x91e4,0x91ee,0x91f0,0x91f2, 0x9201,0x9206,0x9228,0x920a,
    0x9210,0x9210,0x9216,0x491e, 0x9251,0x9239,0x9240,0x924e,
    0x924a,0x9259,0x923a,0x923c, 0x9242,0x9256,0x9267,0x9260,
    0x9233,0x9235,0x9231,0x9238, 0x923e,0x9265,0x4922,
/* 6cxx */
    	   0x926e,0x9252,0x9288, 0x9292,0x9278,0x92a7,0x927d,
    0x9277,0x9289,0x9282,0x92ba, 0x92d7,0x92e5,0x92b6,0x92d8,
    0x92e0,0x92e7,0x92ce,0x92d0, 0x92d5,0x92d5,0x93d7,0xfa27,
    0x92d9,0x92cc,0x92db,0x92f9, 0x931f,0x9327,0x9321,0x931e,
    0x9304,0x92ff,0xfa28,0x9325, 0x931d,0x9302,0x9329,0x9348,
    0x9348,0x934a,0x9370,0x936b, 0x9357,0x92fb,0x939a,0x9349,

    0x935a,0x935f,0x935e,0x936f, 0x0000,0x9373,0x93bb,0x93b0,
    0x0000,0x9388,0x93ad,0x93a8, 0x93c5,0x939f,0x93df,0x93de,
    0x93c6,0x93db,0x93cd,0x93e6, 0x93ea,0x940f,0x93f8,0x93de,
    0x9400,0x93f6,0x9408,0x9416, 0x9418,0x93fb,0x9433,0x9431,
    0x9445,0x9448,0x9442,0x9453, 0x945f,0x946b,0x946d,0x958e,
    0x9592,0x95ac,0x8abe,0x95bc, 0x0000,0x49b0,0x9633,
/* 6dxx */
    	   0x9670,0xf9dc,0x49de, 0xfa29,0x969d,0x96af,0x96c7,
    0x9d8f,0x96d1,0x96de,0xfa68, 0x96ea,0x96ef,0x9743,0x9749,
    0x974f,0x9751,0x9755,0x975c, 0x975c,0x9760,0x97a8,0x97b8,
    0x97c3,0x97c6,0xfa69,0x980e, 0x980a,0x9819,0x983d,0x99a5,
    0x985e,0x9857,0x9865,0x51ec, 0x98bf,0xfa2a,0xfa2b,0x9905,
    0x9927,0xfa2c,0x9921,0x9957, 0x999e,0x999f,0x99a3,0x99ac,

    0x99b9,0x99bc,0x99e6,0x9a08, 0x9ad9,0x9a4d,0x9a24,0x9a15,
    0x9a4a,0x9a4e,0x9ad7,0x4be8, 0x9adc,0x9adf,0x9aef,0x29d4b,
    0x9b72,0x9b75,0x9b8f,0x9bab, 0x9bb1,0x9bb1,0x9bc9,0x9bbb,
    0x9bdb,0x9bf2,0x9c00,0x9c48, 0x9ce5,0x9d07,0x9d0b,0x9d09,
    0x4cbd,0x9d6c,0x9d6b,0x9dc4, 0x9db4,0x9e1b,0x9e81,0x9e8c,
    0x9ea9,0x9eaa,0x9ead,0x9ebd, 0x6469,0x9ebf,0x9ec3,
/* 6exx */
    	   0x9ed1,0x9edb,0x9ee8, 0x9efd,0x9f4a,0x9f8d,0x9f8d,
    0x9f8d,0x9f8e,0x9f91,0x9f94, 0x9e19,0x0000,0x0000,0x0000,
    0x4fe0,0x5026,0x50c5,0x50ca, 0x5132,0x5154,0x51a4,0x51cb,
    0x525d,0x537f,0x53a9,0x66fc, 0x555e,0x5544,0x5533,0x5653,
    0x5642,0x564c,0x5632,0x5699, 0x8b71,0x56c1,0x56ca,0x580b,
    0x5835,0x5861,0x5858,0x51a4, 0x5c28,0x5c5b,0x5c60,0x5c62,

    0x5df7,0x5e54,0x5e96,0x5ed0, 0x5edf,0x5f38,0x6062,0x6097,
    0x6108,0x6357,0x6372,0x6369, 0x63d6,0x6414,0x6406,0x6451,
    0x64b0,0x651d,0x6522,0x66c1, 0x66d9,0x67f5,0x67b4,0x689b,
    0x688e,0x696b,0x6994,0x6991, 0x69f6,0x6a94,0x6af3,0x6b1d,
    0x6e23,0x9061,0x6f23,0x6f97, 0x6f51,0x7006,0x7026,0x701e,
    0x7015,0x7058,0x7130,0x714e, 0x7149,0x7337,0x73ca,
/* 6fxx */
           0x2262,0x2211,0x220f, 0x2250,0x2afd,0x2226,0x2280,
    0x2281,0x0000,0x2288,0x2289, 0x2284,0x2285,0x225f,0x2243,
    0x2245,0x2213,0x2276,0x2a8f, 0x0000,0x25b1,0x2248,0x230a,
    0x222e,0x2224,0x22bf,0x2237, 0x2221,0x33d2,0x33d1, 0,

    0x33d0, 0, 0, 0, 0, 0, 0, 0,
    0, 0, 0x339e, 0x339d, 0x339c, 0x339b, 0x339a, 0x33a2,
    0x33a1,0x33a0,0x339f,0x33a5, 0x33a4,0x33a3,0x3398,0x3397,
    0x3396,0x338f,0x338e,0x338d, 0x3384,0x3383,0x3382,0x33b8,

    0x33b7,0x33b6,0x33b5,0x33be, 0x33bd,0x338c,0x338b,0x338a,
    0, 0, 0x33c1, 0x33c0, 0, 0, 0x33b3, 0x33b2,
/*    0x33b1,0x33b0,0x3387,0x3386, 0x3385, 0, 0, 0x32ce, :* Need Unicode 4.0*/
    0x33b1,0x33b0,0x3387,0x3386, 0x3385, 0, 0, 0,
    0x3391,0x3390,0x33c4,0x0000, 0x2109,0x212a,0x33ad,
/* 70xx */
           0x33db,0x3371,0x33a9, 0x33d4,0x3013,0x33d6,0x33cb,
    0x33c5,0x33d0,0x33d3,0x3013, 0x33cf,0x3013,0x33d5,0x3013,
    0x3374,0x3013,0x3013,0x33dd, 0x3013,0x3013,0x33c8,0x3013,
    0x33d9,0x3013,0x33c3,0x33c9, 0x3013,0x3373,0x3376,0x3013,
    0x3013,0x3013,0x3013,0x3013, 0x3013,0x3013,0x3013,0x3013,
    0x3013,0x3013,0x2127,0x3013, 0x3013,0x3013,0x3013,0x3349,

    0x3322,0x3314,0x3305,0x334d, 0x3316,0x3318,0x3315,0x3327,
    0x3303,0x3336,0x334a,0x3357, 0x330d,0x333f,0x3339,0x333b,
    0x332b,0x3323,0x3326,0x3340, 0x3346,0x3335,0x3324,0x21d0,
    0x21cc,0x21c4,0x2194,0x219d, 0x2199,0x2197,0x2198,0x2196,
    0x2936,0x303d,0x2667,0x2661, 0x2664,0x2662,0x2663,0x2665,
    0x2660,0x2666,0x25c1,0x25b7, 0x25c0,0x25b6,0x261e,
/* 71xx */
    	   0x261c,0x261b,0x261a, 0x3020,0x3020,0x3036,0x3013,
    0x21e8,0x21e6,0x21e7,0x21e9, 0x27a1,0x21e6,0x21e7,0x21e9,
    0x260f,0x3013,0x3004,0x2297, 0x2295,0x2296,0x2298,0x2205,
    0x25c9,0x22a0,0x3013,0x3013, 0x29c8,0x3013,0x3013,0x3013,
    0x3013,0x0031,0x0032,0x0033, 0x0034,0x0035,0x0036,0x0037,
    0x0038,0x0039,0x0030,0x0000, 0x0000,0x0000,0x0000,0x0000,

    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,
/* 72xx */
	   0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x33c7,0x33cd,0x32cf,
    0x2121,0x2121,0x0000,0x0000, 0x33c2,0x33d8,0x2116,0x33cc,
    0x0000,0x2105,0x2100,0x0000, 0x652f,0x672c,0x4ee5,0x4ee5,
    0x4ee5,0x4ee5,0x4ee5,0x672a, 0x4e0a,0x4e0b,0x5f53,0x5f53,

    0x5bfe,0x524d,0x5e74,0x671f, 0x5e74,0x7d2f,0x5358,0x5927,
    0x5927,0x77ed,0x9ad8,0x9ad8, 0x4e2d,0x5c0f,0x767a,0x767a,
    0x5354,0x533b,0x533b,0x5354, 0x4fe1,0x4fe1,0x52b4,0x5546,
    0x5171,0x751f,0x4e8b,0x798f, 0x8fb2,0x68ee,0x5546,0x57fa,
    0x5343,0x4e07,0x5186,0x5186, 0x5104,0x337e,0x337d,0x337c,
    0x337e,0x337d,0x337c,0x337f, 0x5ea7,0x6cd5,0x6cd5,
/* 73xx */
	   0x4eba, 0x4eba,0x793e, 0x793e,0x793e, 0x4eba,0x79d2, 
    0x5206,0x6642, 0x65e5,0x6708, 0x5e74,0x308a, 0x3089,0x3067,
    0x304b,0x3232, 0x5408,0x323e, 0x533b,0x3236, 0x3233,0x5b97,
    0x323b,0x76f8, 0x323d,0x323f, 0x6ce8,0x3239, 0x76f4,0x323a,
    0x3230,0x322a, 0x322b,0x322c, 0x322d,0x322e, 0x322f,0x96fb,
    0x3240,0x3234, 0x32b0,0x3243, 0x3238,0x323c, 0x3242,0x3235,

    0x3231,0x0029, 0x6ce8,0x32ab, 0x329e,0x3292, 0x3293,0x32ac,
    0x32ae,0x3291, 0x3296,0x32a9, 0x32af,0x3294, 0x32aa,0x3298,
    0x32b0,0x32ad, 0x3299,0x329d, 0x3239,0x5378, 0x8ca9,0x52a0,
    0x88fd,0x76f4, 0x32a4,0x32a5, 0x32a6,0x32a7, 0x32a8,0x63a7,
    0x96fb,0x329f, 0x32a3,0x526f, 0x32a2,0x8acb, 0x6e08,0x32a1,
    0x337b,0x337b, 0x0000,0x0000, 0x0000,0x0000, 0x0000,
/* 74xx */
	   0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x2160,0x2161,0x2162, 0x2163,0x2164,0x2165,0x2166,
    0x2167,0x2168,0x2169,0x216a, 0x216b,0x0000,0x0000,0x0000,
    0x0000,0x2170,0x2171,0x2172, 0x2173,0x2174,0x2175,0x2176,
    0x2177,0x2178,0x2179,0x217a, 0x217b,0x0000,0x0000,0x0000,

    0x0000,0x2160,0x2161,0x2162, 0x2163,0x2164,0x2165,0x2166,
    0x2167,0x2168,0x2169,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x2170,0x2171,0x2172, 0x2173,0x2174,0x2175,0x2176,
    0x2177,0x2178,0x2179,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x3220,0x3221,0x3222, 0x3223,0x3224,0x3225,0x3226,
    0x3227,0x3228,0x3229,0x0000, 0x0000,0x0000,0x0000,
/* 75xx */
	   0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x2474,0x2475,0x2476, 0x2477,0x2478,0x2479,0x247a,
    0x247b,0x247c,0x247d,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0041,0x0042,0x0043, 0x0044,0x0045,0x0046,0x0047,
    0x0048,0x0049,0x004a,0x004b, 0x004c,0x004d,0x004e,0x004f,

    0x0050,0x0051,0x0052,0x0053, 0x0054,0x0055,0x0056,0x0057,
    0x0058,0x0059,0x005a,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x249c,0x249d,0x249e, 0x249f,0x24a0,0x24a1,0x24a2,
    0x24a3,0x24a4,0x24a5,0x24a6, 0x24a7,0x24a8,0x24a9,0x24aa,
    0x24ab,0x24ac,0x24ad,0x24ae, 0x24af,0x24b0,0x24b1,0x24b2,
    0x24b3,0x24b4,0x24b5,0x0000, 0x0000,0x0000,0x0000,
/* 76xx */
	   0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x2460,0x2461,0x2462, 0x2463,0x2464,0x2465,0x2466,
    0x2467,0x2468,0x2469,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x24b6,0x24b7,0x24b8, 0x24b9,0x24ba,0x24bb,0x24bc,
    0x24bd,0x24be,0x24bf,0x24c0, 0x24c1,0x24c2,0x24c3,0x24c4,

    0x24c5,0x24c6,0x24c7,0x24c8, 0x24c9,0x24ca,0x24cb,0x24cc,
    0x24cd,0x24ce,0x24cf,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x24d0,0x24d1,0x24d2, 0x24d3,0x24d4,0x24d5,0x24d6,
    0x24d7,0x24d8,0x24d9,0x24da, 0x24db,0x24dc,0x24dd,0x24de,
    0x24df,0x24e0,0x24e1,0x24e2, 0x24e3,0x24e4,0x24e5,0x24e6,
    0x24e7,0x24e8,0x24e9,0x0000, 0x0000,0x0000,0x0000,
/* 77xx */
	   0x246a,0x246b,0x246c, 0x246d,0x246e,0x246f,0x2470,
    0x2471,0x2472,0x2473,0x3251, 0x3252,0x3253,0x3254,0x3255,
    0x3256,0x3257,0x3258,0x3259, 0x325a,0x325b,0x325c,0x325d,
    0x325e,0x325f,0x32b1,0x32b2, 0x32b3,0x32b4,0x32b5,0x32b6,
    0x32b7,0x32b8,0x32b9,0x32ba, 0x32bb,0x32bc,0x32bd,0x32be,
    0x32bf,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,

    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,
/* 78xx */
           0x30a2,0x30a4,0x30a6, 0x30a8,0x30aa,0x30ab,0x30ad,
    0x30af,0x30b1,0x30b3,0x30b5, 0x30b7,0x30b9,0x30bb,0x30bd,
    0x30bf,0x30c1,0x30c4,0x30c6, 0x30c8,0x30ca,0x30cb,0x30cc,
    0x30cd,0x30ce,0x30cf,0x30d2, 0x30d5,0x30d8,0x30db,0x30de,
    0x30df,0x30e0,0x30e1,0x30e2, 0x30e4,0x30e6,0x30e8,0x30e9,
    0x30ea,0x30eb,0x30ec,0x30ed, 0x30ef,0x30f0,0x30f1,0x30f2,

    0x30f3,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,
/* 79xx */
    0x32d0,0x32d1,0x32d2,0x32d3, 0x32d4,0x32d5,0x32d6,0x32d7,
    0x32d8,0x32d9,0x32da,0x32db, 0x32dc,0x32dd,0x32de,0x32df,
    0x32e0,0x32e1,0x32e2,0x32e3, 0x32e4,0x32e5,0x32e6,0x32e7,
    0x32e8,0x32e9,0x32ea,0x32eb, 0x32ec,0x32ed,0x32ee,0x32ef,
    0x32f0,0x32f1,0x32f2,0x32f3, 0x32f4,0x32f5,0x32f6,0x32f7,
    0x32f8,0x32f9,0x32fa,0x32fb, 0x32fc,0x32fd,0x32fe,

    0x30f3,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,
/* 7axx */
    0x0000,0x3042,0x0000,0x3044,0x0000,0x3046,0x0000,0x3048,
    0x0000,0x304a,0x304b,0x0000,0x304d,0x0000,0x304f,0x0000,
    0x3051,0x0000,0x3053,0x0000,0x3055,0x0000,0x3057,0x0000,
    0x3059,0x0000,0x305b,0x0000,0x305d,0x0000,0x305f,0x0000,
    0x3061,0x0000,0x0000,0x3064,0x0000,0x3066,0x0000,0x3068,
    0x0000,0x306a,0x306b,0x306c,0x306d,0x306e,0x306f,0x0000,
    0x0000,0x3072,0x0000,0x0000,0x3075,0x0000,0x0000,0x3078,
    0x0000,0x0000,0x307b,0x0000,0x0000,0x307e,0x307f,0x3080,
    0x3081,0x3082,0x0000,0x3084,0x0000,0x3086,0x0000,0x3088,
    0x3089,0x308a,0x308b,0x308c,0x308d,0x0000,0x308f,0x3090,
    0x3091,0x3092,0x3093,0x0000,0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
/* 7bxx */
    0x0000,0x3042,0x0000,0x3044,0x0000,0x3046,0x0000,0x3048,
    0x0000,0x304a,0x304b,0x0000,0x304d,0x0000,0x304f,0x0000,
    0x3051,0x0000,0x3053,0x0000,0x3055,0x0000,0x3057,0x0000,
    0x3059,0x0000,0x305b,0x0000,0x305d,0x0000,0x305f,0x0000,
    0x3061,0x0000,0x0000,0x3064,0x0000,0x3066,0x0000,0x3068,
    0x0000,0x306a,0x306b,0x306c,0x306d,0x306e,0x306f,0x0000,
    0x0000,0x3072,0x0000,0x0000,0x3075,0x0000,0x0000,0x3078,
    0x0000,0x0000,0x307b,0x0000,0x0000,0x307e,0x307f,0x3080,
    0x3081,0x3082,0x0000,0x3084,0x0000,0x3086,0x0000,0x3088,
    0x3089,0x308a,0x308b,0x308c,0x308d,0x0000,0x308f,0x3090,
    0x3091,0x3092,0x3093,0x0000,0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
/* 7cxx */
    0x0000,0x3042,0x0000,0x3044,0x0000,0x3046,0x0000,0x3048,
    0x0000,0x304a,0x304b,0x0000,0x304d,0x0000,0x304f,0x0000,
    0x3051,0x0000,0x3053,0x0000,0x3055,0x0000,0x3057,0x0000,
    0x3059,0x0000,0x305b,0x0000,0x305d,0x0000,0x305f,0x0000,
    0x3061,0x0000,0x0000,0x3064,0x0000,0x3066,0x0000,0x3068,
    0x0000,0x306a,0x306b,0x306c,0x306d,0x306e,0x306f,0x0000,
    0x0000,0x3072,0x0000,0x0000,0x3075,0x0000,0x0000,0x3078,
    0x0000,0x0000,0x307b,0x0000,0x0000,0x307e,0x307f,0x3080,
    0x3081,0x3082,0x0000,0x3084,0x0000,0x3086,0x0000,0x3088,
    0x3089,0x308a,0x308b,0x308c,0x308d,0x0000,0x308f,0x3090,
    0x0000,0x3092,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
/* 7dxx */
	   0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,

    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,
/* 7exx */
    0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x304b,0x0000,0x0000,0x0000,0x0000,0x0000,
    0x3051,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
    0x3059,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
    0x3061,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
    0x0000,0x306a,0x306b,0x0000,0x0000,0x306e,0x306f,0x0000,
    0x0000,0x3072,0x0000,0x0000,0x0000,0x0000,0x0000,0x3078,
    0x0000,0x0000,0x307b,0x0000,0x0000,0x307e,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
/* 7fxx */
	   0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,

    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,
/* 80xx */
	   0x750d,0x7511,0x75e9, 0x787c,0x7947,0x79b1,0x7a31,
    0x9f9d,0x7a97,0x9083,0x7b99, 0x7bb8,0x7c1e,0x7c3e,0x7c7e,
    0x7d9b,0x7d9f,0x5fbd,0x7e43, 0x7e6b,0x7e61,0x7f50,0x8028,
    0x805f,0x8073,0x8072,0x8070, 0x807e,0x8141,0x817f,0x82d2,
    0x8338,0x8375,0x83bd,0x83df, 0x840a,0x847a,0x8523,0x84ec,
    0x8513,0x85a9,0x85af,0x85f7, 0x8680,0x87d2,0x87ec,0x880e,

    0x881f,0x8956,0x89af,0x8afa, 0x8b0e,0x8ced,0x8ec0,0x8fc2,
    0x8fbf,0x8fe6,0x8fe9,0x9017, 0x9019,0x9041,0x903c,0x905c,
    0x9058,0x7941,0x912d,0x914b, 0x91ac,0x91b1,0x9306,0x9453,
    0x9699,0x9771,0x976d,0x9784, 0x9830,0x985a,0x98f4,0x990c,
    0x9a52,0x9bd6,0x9c52,0x9d60, 0x9dd7,0x9e7c,0x9ea9,0x9eb4,
    0x9eb5,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000
};

unsigned short uni_t_jef43[JEF_TBL_LEN] = {
	 0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x4fa0, 0x50c5,0x5026,0x5132,0x0000,

  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x514e,0x5154, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x914b,0x0000,0x0000, 0x0000,0x0000,0x5195,0x0000,
  0x51a4,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,
/* 44xx */
	 0x0000,0x0000,0x0000,0x0000,0x51b4,0x51cb,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x5265,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	 0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x537f,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x53a9,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x53db,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
/* 46xx */
	 0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
/* 47xx */
	 0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x559d,0x5516,0x5618,0x5642, 0x565b,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x5c2d,0x585a,0x586b,0x5835, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,
	 0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x5858,
  0x580b,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
/* 49xx */
	 0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x5acc,0x5a9b,0x5a29,0x5abe,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	 0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x5bc3,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x5c51,0x5c61,0x5c60,0x5c4f,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
/* 4bxx */
	 0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x5df7,0x5dfd,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	 0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x5ee0,0x5edf,0x5e96,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
/* 4dxx */
	 0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x5fbd,0x6167,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	 0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x6062,0x6108,0x6097,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x6249,0x0000,0x0000,0x0000,0x0000,
	 0x62f3,0x6372,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x62d0,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
/* 50xx */
	 0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x6505,0x0000,0x0000, 0x0000,0x0000,0x0000,0x647a,
  0x64b0,0x63bb,0x63c3,0x63b4, 0x6357,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x6602,0x0000,0x0000,
	 0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x66a0,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x6666,0x66d9,
/* 52xx */
	 0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x671e,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x817f,0x6813,0x68a2,0x68da,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	 0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x67f5,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
/* 54xx */
	 0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x69d9,0x6b1d,0x6e20,0x6adb,
  0x698a,0x6753,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	 0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x6ce1,0x6e1a,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
/* 56xx */
	 0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	 0x0000,0x0000,0x0000,0x0000,0x0000,0x6f97,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x6e9d,0x6fef,
  0x6deb,0x6ea2,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
/* 58xx */
  	 0x0000,0x0000,0x0000,0x0000,0x7104,0x710f,0x0000,
  0x0000,0x71fe,0x707c,0x714e,0x717d,0x7149,0x0000,0x91c7,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x724c,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x7259,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x7337,0x0000,0x0000,0x0000,0x0000,0x0000,
	 0x7422,0x6813,0x68da,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
/* 5axx */
	 0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x73ce,0x73d2,0x7462,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x7511,0x7504,
  0x7501,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x7652,0x75e9,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	 0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x7693,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x77a5,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x77e9,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
/* 5cxx */
	 0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x787c,0x7930,0x7947,
  0x7941,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0xfa19,0x0000,0xfa1a,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0xfa1b,0x0000,0x7994,0x0000,
  0x799b,0x0000,0x0000,0x0000,0x7977,0x79b0,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x999e,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	 0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x79e4,0x7a17,
  0x7a31,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x7a7f,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x7ad1,0x0000,0x0000,
  0x0000,0x7ae7,0x0000,0x0000,0x7aeb,0xfa1c,0x0000,0x0000,
  0x0000,0x0000,0x7b08,0x7bad,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
/* 5exx */
	 0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x7baa,0x7bb8,0x7bc7,0x7c3e,0x7b99,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0xfa1d,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x7c7e,0x7c90,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	 0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x7e52,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x7e8a,0x0000,0x0000,0x7e4b,
  0x7e4d,0x7d9b,0x7d9f,0x7dae,0x7db7,0x0000,0x0000,0x0000,
  0x7f47,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x7fa1,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x7fd4,0x7fe0,
/* 60xx */
	 0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x7ff0,0x7feb,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x822e,
	 0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x82a6,0x8328,0x845b,0x85a9,0x85af,
  0x85f7,0x848b,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x834a,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
/* 62xx */
	 0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x83df,0x853d,0x8511,
  	 0x7e6d,0x83b1,0x84ee, 0x84ec,0x82d2,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x8749, 0x86f8,0x874b,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,

  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x87d2,0xfa21,
 
  0x8807,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x8910,0x8956,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x88f5,0x0000,0x0000, 0x0000,0x0000,0x0000,
/* 64xx */
	 0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x890a,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x89af,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x8afa,0x8a6e,0x8b0e,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	 0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x8b2c,0x8ade,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
/* 66xx */
	 0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x8ced,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x8d73,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x8dda,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x8eaf,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	 0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x8fea,0x901d,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
/* 68xx */
	 0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x9127,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0xf9dc,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x9699,0x0000, 0x969d,0x0000,0x0000,0x0000,
  0x0000,0x90a3,0x0000,0x96af, 0x0000,0x0000,0x912d,0x9115,
  0xfa29,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  	 0x91a4,0x9197,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x9306,0x939a,0x9453, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
/* 6axx */
	 0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	 0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x8000,
/* 6cxx */
	 0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x9733,0x973b,0x974f,0x0000,
  0x9743,0x974d,0x0000,0x9751,0x0000,0x9755,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x9784,0x9774,0x9798,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x9857, 0x0000,0x0000,0x0000,0x9865,
  0x0000,0x0000,0x0000,0x983b, 0x985b,0x982c,0x0000,
	 0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x98f4,0x990c,0x9957,0x9910, 0x8755,0x9905,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x9a28,0x0000,0x0000,0x0000,0x0000,0x0000,
/* 6exx */
	 0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x9c2f,
  0x9bd6,0x9c48,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x9b75,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x9b8f,0x0000,0x0000,0x9bb1,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x9c00,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x9c52,0x9bf2,0x9b72,0x9bbb,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x9d07,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  	 0x9d6b,0x0000,0x9d70,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x9e19,0x0000,
  0x9d0e,0x9d60,0xfa2d,0x0000,0x0000,0x9e78,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x9eb9,0x9eba,0x9eaa,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x6a2e,0x0000,0x0000,0x9ed1,0x0000,
  0x9edb,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
/* 70xx */
	 0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x55b0,0x54e8,
  0x564c,0x5544,0x56a2,0x5539, 0x5533,0x5632,0x64e2,0x633d,
  0x6369,0x6406,0x0000,0x6a3d, 0x69cc,0x6962,0x6adb,0x67ca,
  0x6994,0x67a6,0x67b4,0x689b, 0x688d,0x68c8,0x6766,0x68cf,
  0xfa13,0xfa14,0x69e2,0x6a30, 0x6c72,0x7026,0x6eba,0x6d9c,
  0x701e,0x7058,0x6e8c,0x7015, 0x6f23,0x6e6e,0x6d6f,0x6df2,
  0x7114,0x70bb,0x0000,0xfa15, 0x7962,0xfa18,0x8375,0x8362,
  0x8448,0x84b4,0xfa20,0x9065, 0x906e,0x907c,0x8fc2,0x8fe6,
  0x9017,0x9061,0x9019,0x903c, 0x8fc4,0x9041,0x8fbf,0x905c,
  0x9058,0xfa24,0x9067,0x9038, 0x8fe9,0x0000,0x0000,
	 0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
/* 72xx */
	 0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	 0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
/* 74xx */
	 0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	 0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
/* 76xx */
  	 0xffe4,0xff07,0xff02, 0x0000,0x0000,0x0000,0xffe2,
  0x2235,0x2252,0x2261,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x339c,0x339d,0x339e,0x0000,
  0x33a1,0x0000,0x0000,0x0000, 0x338e,0x338f,0x33c4,0x0000,
  0x3351,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,

  0x0000,0x212b,0x0000,0x2030, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x334d,0x3349,0x3322, 0x3314,0x0000,0x3318,0x0000,
  0x3327,0x3303,0x3336,0x3326, 0x3323,0x332b,0x330d,0x3357,
  0x0000,0x334a,0x0000,0x333b, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x33cd,0x0000,0x2121,0x0000,
  0x0000,0x0000,0x2116,0x0000, 0x0000,0x0000,0x0000,
	 0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x2460,0x2461,0x2462,0x2463,0x2464,0x2465,0x2466,
  0x2467,0x2468,0x2469,0x246a,0x246b,0x246c,0x246d,0x246e,
  0x246f,0x2470,0x2471,0x2472,0x2473,0x0000,0x2160,0x2161,
  0x2162,0x2163,0x2164,0x2165,0x2166,0x2167,0x2168,0x2169,
  0x216a,0x216b,0x0000,0x2170,0x2171,0x2172,0x2173,0x2174,
  0x2175,0x2176,0x2177,0x2178,0x2179,0x217a,0x217b,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
/* 78xx */
	 0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x3239,0x0000,0x0000,0x0000,0x3232,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x3231,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	 0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
/* 7axx */
	 0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	 0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
/* 7cxx */
	 0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x2537,0x250c,0x2510,0x2518, 0x2514,0x252c,0x2534,0x251c,
  0x2524,0x253c,0x2520,0x252f, 0x2528,0x2542,0x253f,0x0000,
  0x0000,0x2500,0x2502,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x250f,0x2513,
  0x251b,0x2517,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x2533,0x253b,0x2523, 0x252b,0x254b,0x2501,0x2503,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,
	 0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
/* 7exx */
	 0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
         0x2538,0x251d,0x2530, 0x2525,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x2208,0x220b,0x2286,0x2287, 0x2282,0x2283,0x222a,0x2229,
  0x2227,0x2228,0x21d2,0x21d4, 0x2200,0x2203,0x2220,0x22a5,
  0x2312,0x2202,0x2207,0x226a, 0x226b,0x221a,0x223d,0x221d,
  0x222b,0x222c,0x266f,0x266d, 0x266a,0x2020,0x2021,0x00b6,
  0x25ef,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000
};

unsigned short x9010_a_uni_byte[128] = {
  0x0000,0x0001,0x0002,0x0003,0x0004,0x0005,0x0006,0x0007,
  0x0008,0x0009,0x000a,0x000b,0x000c,0x000d,0x000e,0x000f,
  0x0010,0x0011,0x0012,0x0013,0x0014,0x0015,0x0016,0x0017,
  0x0018,0x0019,0x001a,0x001b,0x001c,0x001d,0x001e,0x001f,
  0x0020,0x0000,0x0022,0x00a3,0x0024,0x0025,0x0026,0x0027,
  0x007b,0x007d,0x002a,0x002b,0x002c,0x002d,0x002e,0x002f,
  0x0030,0x0031,0x0032,0x0033,0x0034,0x0035,0x0036,0x0037,
  0x0038,0x0039,0x003a,0x003b,0x2440,0x003d,0x2441,0x003f,
  0x0000,0x0041,0x0042,0x0043,0x0044,0x0045,0x0046,0x0047,
  0x0048,0x0049,0x004a,0x004b,0x004c,0x004d,0x004e,0x004f,
  0x0050,0x0051,0x0052,0x0053,0x0054,0x0055,0x0056,0x0057,
  0x0058,0x0059,0x005a,0x0000,0x00a5,0x2442,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x007c,0x0000,0x0000,0x007f
};

unsigned short x9010_ba_uni_byte[128] = {
  0x0000,0x0001,0x0002,0x0003,0x0004,0x0005,0x0006,0x0007,
  0x0008,0x0009,0x000a,0x000b,0x000c,0x000d,0x000e,0x000f,
  0x0010,0x0011,0x0012,0x0013,0x0014,0x0015,0x0016,0x0017,
  0x0018,0x0019,0x001a,0x001b,0x001c,0x001d,0x001e,0x001f,
  0x0020,0x0000,0x0000,0x00a3,0x00a4,0x005c,0x0000,0x00a7,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000
};

unsigned short x9010_e13_uni_byte[128] = {
  0x0000,0x0001,0x0002,0x0003,0x0004,0x0005,0x0006,0x0007,
  0x0008,0x0009,0x000a,0x000b,0x000c,0x000d,0x000e,0x000f,
  0x0010,0x0011,0x0012,0x0013,0x0014,0x0015,0x0016,0x0017,
  0x0018,0x0019,0x001a,0x001b,0x001c,0x001d,0x001e,0x001f,
  0x0020,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0030,0x0031,0x0032,0x0033,0x0034,0x0035,0x0036,0x0037,
  0x0038,0x0039,0x2446,0x2447,0x2448,0x2449,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000
};

unsigned short uni_t_ibm930[11970] = {
/* codelimit: 11970 */
/* 0x4100(i:0) */
  0x03b1,0x03b2,0x03b3,0x03b4, 0x03b5,0x03b6,0x03b7,0x03b8,
  0x03b9,0x03ba,0x03bb,0x03bc, 0x03bd,0x03be,0x03bf,0x03c0,
  0x03c1,0x03c3,0x03c4,0x03c5, 0x03c6,0x03c7,0x03c8,0x03c9,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0391,0x0392,0x0393,0x0394, 0x0395,0x0396,0x0397,0x0398,
  0x0399,0x039a,0x039b,0x039c, 0x039d,0x039e,0x039f,0x03a0,
  0x03a1,0x03a3,0x03a4,0x03a5, 0x03a6,0x03a7,0x03a8,0x03a9,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0430,
  0x0431,0x0432,0x0433,0x0434, 0x0435,0x0451,0x0436,0x0437,
  0x0438,0x0439,0x043a,0x043b, 0x043c,0x043d,0x043e,0x043f,
  0x0440,0x0441,0x0442,0x0443, 0x0444,0x0445,0x0446,0x0447,
  0x0448,0x0449,0x044a,0x044b, 0x044c,0x044d,0x044e,0x044f,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x2170,0x2171,0x2172,0x2173, 0x2174,0x2175,0x2176,0x2177,
  0x2178,0x2179,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0410,
  0x0411,0x0412,0x0413,0x0414, 0x0415,0x0401,0x0416,0x0417,
  0x0418,0x0419,0x041a,0x041b, 0x041c,0x041d,0x041e,0x041f,
  0x0420,0x0421,0x0422,0x0423, 0x0424,0x0425,0x0426,0x0427,
  0x0428,0x0429,0x042a,0x042b, 0x042c,0x042d,0x042e,0x042f,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x2160,0x2161,0x2162,0x2163, 0x2164,0x2165,0x2166,0x2167,
  0x2168,0x2169,0x0000,0x0000, 0x0000,0x0000,
/* 0x4241(i:190) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0xffe1,0xff0e,0xff1c, 0xff08,0xff0b,0xff5c,0xff06,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0xff01,0xffe5,0xff0a, 0xff09,0xff1b,0xffe2,0xff0d,
  0xff0f,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0xffe4,0xff0c,0xff05, 0xff3f,0xff1e,0xff1f,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xff40,0xff1a,0xff03,0xff20, 0xff07,0xff1d,0xff02,0x0000,
  0xff41,0xff42,0xff43,0xff44, 0xff45,0xff46,0xff47,0xff48,
  0xff49,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xff4a,0xff4b,0xff4c,0xff4d, 0xff4e,0xff4f,0xff50,0xff51,
  0xff52,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xffe3,0xff53,0xff54,0xff55, 0xff56,0xff57,0xff58,0xff59,
  0xff5a,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0xff5b,
  0xff21,0xff22,0xff23,0xff24, 0xff25,0xff26,0xff27,0xff28,
  0xff29,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0xff5d,
  0xff2a,0xff2b,0xff2c,0xff2d, 0xff2e,0xff2f,0xff30,0xff31,
  0xff32,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0xff04,
  0x0000,0xff33,0xff34,0xff35, 0xff36,0xff37,0xff38,0xff39,
  0xff3a,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0xff10,
  0xff11,0xff12,0xff13,0xff14, 0xff15,0xff16,0xff17,0xff18,
  0xff19,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x4341(i:380) */
  0x3002,0x300c,0x300d,0x3001, 0x30fb,0x30f2,0x30a1,0x30a3,
  0x30a5,0xffe0,0x2220,0x22a5, 0x2312,0x2202,0x2207,0x0000,
  0x30a7,0x30a9,0x30e3,0x30e5, 0x30e7,0x30c3,0x30ee,0x30fc,
  0x30f5,0x30f6,0x2261,0x2252, 0x226a,0x226b,0x221a,0x223d,
  0x221d,0x222b,0x222c,0x2208, 0x220b,0x2286,0x2287,0x2282,
  0x2283,0x222a,0x2229,0x2227, 0x2228,0x21d2,0x21d4,0x2200,
  0x2203,0x212b,0x2030,0x266f, 0x266d,0x266a,0x2020,0x2021,
  0x00b6,0x25ef,0x0000,0x2500, 0x2502,0x250c,0x2510,0x0000,
  0x30a2,0x30a4,0x30a6,0x30a8, 0x30aa,0x30ab,0x30ad,0x30af,
  0x30b1,0x30b3,0x0000,0x30b5, 0x30b7,0x30b9,0x30bb,0x30bd,
  0x30bf,0x30c1,0x30c4,0x30c6, 0x30c8,0x30ca,0x30cb,0x30cc,
  0x30cd,0x30ce,0x0000,0x0000, 0x30cf,0x30d2,0x30d5,0x0000,
  0xff5e,0x30d8,0x30db,0x30de, 0x30df,0x30e0,0x30e1,0x30e2,
  0x30e4,0x30e6,0x0000,0x30e8, 0x30e9,0x30ea,0x30eb,0x2518,
  0x2514,0x251c,0x252c,0x2524, 0x2534,0x253c,0x2501,0x2503,
  0x250f,0x30ec,0x30ed,0x30ef, 0x30f3,0x309b,0x309c,0x30ac,
  0x30ae,0x30b0,0x30b2,0x30b4, 0x30b6,0x30b8,0x30ba,0x30bc,
  0x30be,0x30c0,0x30c2,0x30c5, 0x30c7,0x30c9,0x30d0,0x30d3,
  0x30d6,0x30d9,0x30dc,0x30f4, 0x30d1,0x30d4,0x30d7,0x30da,
  0x30dd,0x30f0,0x30f1,0x30fd, 0x30fe,0x0000,0x0000,0xff3c,
  0x2513,0x251b,0x2517,0x2523, 0x2533,0x252b,0x253b,0x254b,
  0x2520,0x252f,0x2528,0x2537, 0x253f,0x251d,0x2530,0x2525,
  0x2538,0x2542,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x4441(i:570) */
  0x0000,0x300e,0x300f,0xff3b, 0xff3d,0x3092,0x3041,0x3043,
  0x3045,0x2015,0x00b1,0x2260, 0x221e,0x2103,0x0000,0x00b4,
  0x3047,0x3049,0x3083,0x3085, 0x3087,0x3063,0x308e,0x0000,
  0x0000,0x2010,0x3003,0x4edd, 0x3005,0x3006,0x3007,0x00a8,
  0x2018,0x201c,0x3014,0x3008, 0x300a,0x3010,0x2266,0x2234,
  0x2642,0x00a7,0x203b,0x3012, 0x3231,0x2116,0x2121,0xff3e,
  0x2019,0x201d,0x3015,0x3009, 0x300b,0x3011,0x2267,0x2235,
  0x2640,0x00d7,0x00f7,0x2225, 0x3013,0x2025,0x2026,0x0000,
  0x3042,0x3044,0x3046,0x3048, 0x304a,0x304b,0x304d,0x304f,
  0x3051,0x3053,0x0000,0x3055, 0x3057,0x3059,0x305b,0x305d,
  0x305f,0x3061,0x3064,0x3066, 0x3068,0x306a,0x306b,0x306c,
  0x306d,0x306e,0x0000,0x0000, 0x306f,0x3072,0x3075,0x0000,
  0x0000,0x3078,0x307b,0x307e, 0x307f,0x3080,0x3081,0x3082,
  0x3084,0x3086,0x0000,0x3088, 0x3089,0x308a,0x308b,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x308c,0x308d,0x308f, 0x3093,0x0000,0x0000,0x304c,
  0x304e,0x3050,0x3052,0x3054, 0x3056,0x3058,0x305a,0x305c,
  0x305e,0x3060,0x3062,0x3065, 0x3067,0x3069,0x3070,0x3073,
  0x3076,0x3079,0x307c,0x0000, 0x3071,0x3074,0x3077,0x307a,
  0x307d,0x3090,0x3091,0x309d, 0x309e,0x0000,0x0000,0x25cb,
  0x25cf,0x25b3,0x25b2,0x25ce, 0x2606,0x2605,0x25c7,0x25c6,
  0x25a1,0x25a0,0x25bd,0x25bc, 0x00b0,0x2032,0x2033,0x2192,
  0x2190,0x2191,0x2193,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x4541(i:760) */
  0x4e00,0x4e8c,0x4e09,0x56db, 0x4e94,0x516d,0x4e03,0x516b,
  0x4e5d,0x5341,0x767e,0x5343, 0x4e07,0x5104,0x90fd,0x9053,
  0x5e9c,0x770c,0x5e02,0x533a, 0x753a,0x6751,0x6771,0x897f,
  0x5357,0x5317,0x5927,0x4e2d, 0x5c0f,0x4e0a,0x4e0b,0x5e74,
  0x6708,0x65e5,0x7530,0x5b50, 0x5c71,0x672c,0x5ddd,0x85e4,
  0x91ce,0x5de5,0x696d,0x6728, 0x4e95,0x90ce,0x5cf6,0x96c4,
  0x9ad8,0x5ca1,0x592b,0x539f, 0x4eac,0x4f50,0x6b63,0x677e,
  0x6a5f,0x548c,0x88fd,0x7537, 0x7f8e,0x5409,0x5d0e,0x77f3,
  0x8c37,0x96fb,0x9577,0x6cbb, 0x6ca2,0x91d1,0x65b0,0x53e3,
  0x6a4b,0x4e45,0x798f,0x6240, 0x5e73,0x5185,0x56fd,0x5316,
  0x962a,0x5bae,0x4eba,0x4f5c, 0x90e8,0x6e05,0x6b21,0x7fa9,
  0x751f,0x4ee3,0x51fa,0x6c34, 0x68ee,0x5149,0x52a0,0x5408,
  0x795e,0x6797,0x91cd,0x884c, 0x4fe1,0x660e,0x6d77,0x5b89,
  0x5e78,0x4fdd,0x592a,0x5bcc, 0x6c5f,0x9234,0x524d,0x77e5,
  0x6b66,0x4f0a,0x662d,0x5206, 0x52dd,0x7528,0x5e83,0x9020,
  0x6c17,0x6210,0x898b,0x5229, 0x4f1a,0x5b66,0x5ca9,0x7523,
  0x9593,0x5730,0x81ea,0x826f, 0x95a2,0x611b,0x653f,0x5c3e,
  0x8a08,0x6587,0x624b,0x7236, 0x65b9,0x4e8b,0x6238,0x54c1,
  0x559c,0x6e21,0x5f18,0x53e4, 0x8fba,0x5009,0x9244,0x4e4b,
  0x5834,0x6d0b,0x57ce,0x6d25, 0x7acb,0x5ea6,0x5348,0x4eca,
  0x5f66,0x8a2d,0x901a,0x52d5, 0x5f8c,0x5948,0x5b9a,0x6c60,
  0x5c4b,0x6d5c,0x7406,0x5742, 0x5b9f,0x82f1,0x7684,0x53f8,
  0x79c0,0x6a2a,0x540d,0x5b5d, 0x7af9,0x535a,0x529b,0x5eab,
  0x8449,0x6804,0x6c38,0x5668, 0x7389,0x591a,
/* 0x4641(i:950) */
  0x8cc0,0x771f,0x6075,0x9759, 0x5186,0x8302,0x654f,0x8c4a,
  0x5175,0x6cd5,0x767a,0x9752, 0x5897,0x6599,0x5fe0,0x8cc7,
  0x6642,0x7269,0x8eca,0x5fb3, 0x8981,0x5bfe,0x585a,0x79cb,
  0x767d,0x6cb3,0x702c,0x6cb9, 0x9686,0x8535,0x5f53,0x4fca,
  0x5fd7,0x6625,0x793e,0x99ac, 0x5165,0x5efa,0x6839,0x6749,
  0x9032,0x8208,0x6d66,0x7cbe, 0x540c,0x6027,0x7c73,0x8005,
  0x52a9,0x679d,0x8fd1,0x76f4, 0x76ee,0x6765,0x753b,0x76f8,
  0x9ed2,0x4e38,0x8239,0x7531, 0x58eb,0x7b2c,0x718a,0x7d19,
  0x5065,0x68b0,0x82b3,0x571f, 0x6709,0x5bb6,0x7dda,0x7d4c,
  0x8abf,0x5929,0x671f,0x7f6e, 0x6d45,0x6589,0x5f0f,0x5f62,
  0x9762,0x7a2e,0x8f38,0x5916, 0x5143,0x4f53,0x9e7f,0x5fa1,
  0x5973,0x5eb7,0x4e16,0x52c7, 0x5800,0x597d,0x5150,0x5bfa,
  0x92fc,0x7279,0x57fc,0x9054, 0x5411,0x53d6,0x7b49,0x667a,
  0x56de,0x9580,0x904b,0x5099, 0x601d,0x963f,0x4e0d,0x9808,
  0x5168,0x5bff,0x5584,0x677f, 0x98ef,0x8c9e,0x73fe,0x98df,
  0x7d44,0x985e,0x516c,0x6750, 0x9999,0x5546,0x7d50,0x8868,
  0x77e2,0x6f5f,0x79c1,0x5236, 0x90a6,0x6cbc,0x7cf8,0x5b8f,
  0x7b56,0x6ce2,0x54e1,0x6570, 0x958b,0x6e96,0x6a39,0x8cbb,
  0x660c,0x5f37,0x7814,0x53cb, 0x5b87,0x82e5,0x83ca,0x6301,
  0x82b1,0x5f15,0x7d00,0x8352, 0x5225,0x4fee,0x8d8a,0x4f4f,
  0x85ac,0x6bdb,0x9060,0x554f, 0x5965,0x578b,0x5fc3,0x767b,
  0x65e9,0x67f3,0x6d69,0x8cea, 0x52d9,0x6cc9,0x5e38,0x5b88,
  0x57fa,0x7ba1,0x6cf0,0x4f38, 0x6700,0x4ee5,0x6b4c,0x88d5,
  0x8d64,0x8db3,0x898f,0x6d41, 0x8aa0,0x6607,
/* 0x4741(i:1140) */
  0x5dde,0x7167,0x5869,0x9001, 0x96c5,0x672b,0x54f2,0x5cb8,
  0x4e5f,0x5c90,0x521d,0x8328, 0x5247,0x6bd4,0x80fd,0x8a71,
  0x6295,0x8ee2,0x83c5,0x9023, 0x4ed6,0x6c11,0x7d66,0x9152,
  0x7e41,0x4fa1,0x6e80,0x671d, 0x4ed8,0x6761,0x7121,0x8003,
  0x697d,0x4e3b,0x610f,0x6226, 0x5207,0x5264,0x7247,0x7d30,
  0x6e08,0x7a32,0x5e03,0x91cc, 0x5c5e,0x7ae0,0x5909,0x4f55,
  0x685c,0x5f7c,0x67fb,0x76ca, 0x58f2,0x4ec1,0x6df1,0x53f0,
  0x9ce5,0x9db4,0x652f,0x6574, 0x89d2,0x5609,0x5473,0x885b,
  0x8b70,0x5727,0x7387,0x8def, 0x706b,0x961c,0x8f1d,0x70b9,
  0x4e0e,0x6e1b,0x7551,0x9280, 0x7a7a,0x4ea4,0x7fbd,0x534a,
  0x53ce,0x592e,0x7dcf,0x8a18, 0x6674,0x69cb,0x969b,0x6885,
  0x5370,0x8a00,0x6817,0x8eab, 0x66f8,0x514b,0x7d20,0x96c6,
  0x7bc0,0x5148,0x6edd,0x6c7a, 0x6559,0x7d14,0x67f4,0x63a5,
  0x661f,0x7740,0x7559,0x6620, 0x5df1,0x754c,0x5177,0x656c,
  0x7fa4,0x9806,0x5171,0x6d3b, 0x91cf,0x6307,0x89e3,0x5ba4,
  0x679c,0x5404,0x671b,0x9632, 0x7d04,0x61b2,0x967d,0x4e80,
  0x56f3,0x4e88,0x8272,0x7a0e, 0x690d,0x53ef,0x6052,0x4f4d,
  0x5178,0x5fc5,0x7d9a,0x6025, 0x5728,0x57a3,0x541b,0x5ef6,
  0x5d8b,0x4f01,0x6803,0x670d, 0x71b1,0x5272,0x5354,0x6b69,
  0x53f2,0x512a,0x658e,0x623f, 0x5b97,0x683c,0x8fb0,0x7b20,
  0x5712,0x8af8,0x8107,0x5553, 0x8ce2,0x5f25,0x98a8,0x5f97,
  0x6613,0x6253,0x982d,0x65ed, 0x6bb5,0x52e2,0x7136,0x56e3,
  0x984d,0x843d,0x914d,0x7a0b, 0x8fbb,0x543e,0x611f,0x5bdb,
  0x53cd,0x7a14,0x9700,0x6e90, 0x6c96,0x984c,
/* 0x4841(i:1330) */
  0x8fbc,0x8349,0x7b97,0x76db, 0x8fb2,0x90a3,0x7701,0x69d8,
  0x6bbf,0x5c11,0x4ecb,0x53d7, 0x97f3,0x7de8,0x59d4,0x5e84,
  0x4fc2,0x72b6,0x793a,0x5e97, 0x5a9b,0x682a,0x6ecb,0x68a8,
  0x7e04,0x53f3,0x5de6,0x53ca, 0x9078,0x5c45,0x60c5,0x7df4,
  0x70ad,0x9928,0x9271,0x6a21, 0x6b8a,0x7e3e,0x4e9c,0x7e4a,
  0x4ef2,0x5857,0x6d88,0x8853, 0x691c,0x6717,0x5b85,0x529f,
  0x5c1a,0x8cbf,0x60a6,0x8102, 0x7be0,0x4f73,0x7d21,0x51a8,
  0x6851,0x78ba,0x7267,0x4e26, 0x5024,0x89b3,0x8cb4,0x7dad,
  0x7d71,0x5bbf,0x4e21,0x7cd6, 0x89aa,0x9332,0x6f84,0x65bd,
  0x5bb9,0x98db,0x5c40,0x7950, 0x904e,0x6c0f,0x6539,0x76e4,
  0x7a4d,0x6e0b,0x5dfb,0x6df3, 0x5fdc,0x4e89,0x8ecd,0x88c5,
  0x9178,0x7e54,0x67d3,0x5e1d, 0x7dbf,0x7c89,0x822a,0x7532,
  0x5468,0x4ed9,0x5f85,0x4f4e, 0x7dd1,0x8efd,0x9ebb,0x6176,
  0x52b4,0x78ef,0x4e39,0x80b2, 0x9650,0x5c0e,0x653e,0x6643,
  0x5ea7,0x4ef6,0x60f3,0x9a13, 0x4ed5,0x4f7f,0x8f2a,0x9854,
  0x756a,0x5f35,0x805e,0x4f9b, 0x6e6f,0x6eb6,0x6821,0x9285,
  0x92f3,0x878d,0x9756,0x5199, 0x5b8c,0x6e2f,0x935b,0x591c,
  0x5145,0x9f8d,0x7db1,0x83f1, 0x901f,0x52c9,0x5237,0x8d77,
  0x6469,0x53c2,0x55b6,0x7a42, 0x63a8,0x8fd4,0x8077,0x6b62,
  0x4f1d,0x5e79,0x7403,0x6a29, 0x5c55,0x5e61,0x845b,0x5ead,
  0x975e,0x53f7,0x5358,0x6b73, 0x62e1,0x51e6,0x8a9e,0x6628,
  0x57df,0x6df5,0x518d,0x50cd, 0x79d1,0x9b5a,0x7aef,0x9014,
  0x6848,0x5b57,0x8ad6,0x517c, 0x53c8,0x632f,0x6280,0x5fb9,
  0x672d,0x7cfb,0x5f93,0x51b7, 0x614b,0x5cf0,
/* 0x4941(i:1520) */
  0x5931,0x539a,0x5074,0x6ce8, 0x6e2c,0x9803,0x4e57,0x8a66,
  0x576a,0x8429,0x515a,0x6c7d, 0x5b9d,0x606d,0x6a0b,0x6e29,
  0x6577,0x8aac,0x82b8,0x544a, 0x6b74,0x822c,0x98fe,0x793c,
  0x5c06,0x96e3,0x7802,0x5224, 0x5f79,0x5f71,0x66fd,0x5e2f,
  0x9678,0x938c,0x8ac7,0x5f70, 0x60aa,0x6a19,0x7533,0x5bb3,
  0x6bcd,0x88dc,0x5e4c,0x58f0, 0x9664,0x7b39,0x5a66,0x4e7e,
  0x7af6,0x829d,0x725b,0x8cb7, 0x79fb,0x785d,0x8336,0x52b9,
  0x990a,0x52f2,0x80a5,0x8b19, 0x7089,0x590f,0x5802,0x67cf,
  0x6255,0x5e30,0x713c,0x786b, 0x8001,0x7a76,0x5be9,0x91dd,
  0x65ad,0x5c04,0x5dee,0x5d50, 0x6298,0x8010,0x5ba3,0x59cb,
  0x5f8b,0x6b8b,0x666f,0x8c61, 0x90f7,0x5353,0x96e2,0x85ab,
  0x6b7b,0x8015,0x64cd,0x4eae, 0x4e91,0x90e1,0x52e4,0x6c42,
  0x8cab,0x5b98,0x59bb,0x88cf, 0x773c,0x4f2f,0x7aaf,0x7bc9,
  0x968e,0x63db,0x6842,0x99c5, 0x68b6,0x5747,0x8ca1,0x547d,
  0x738b,0x84b2,0x90c1,0x78e8, 0x7b11,0x66f2,0x6975,0x5831,
  0x63d0,0x8a3c,0x96ea,0x9055, 0x88c1,0x9996,0x75c5,0x6850,
  0x4f59,0x74e6,0x4ee4,0x5439, 0x732a,0x672a,0x525b,0x8ca0,
  0x4f34,0x5100,0x542b,0x9069, 0x8fc4,0x5c3b,0x5dcc,0x7b54,
  0x8ffd,0x8a0e,0x4e08,0x925b, 0x71c3,0x8ab2,0x70ba,0x9662,
  0x679a,0x76ae,0x8b77,0x7dbe, 0x96e8,0x6211,0x5bc4,0x837b,
  0x62bc,0x7d0d,0x76e3,0x7e2b, 0x964d,0x572d,0x7adc,0x7bc4,
  0x6bba,0x8c9d,0x698e,0x9047, 0x6f14,0x5360,0x8feb,0x5287,
  0x624d,0x6566,0x7d1a,0x7d42, 0x6bce,0x7d79,0x7e2e,0x666e,
  0x7965,0x500b,0x5c02,0x99d2, 0x8a55,0x7560,
/* 0x4a41(i:1710) */
  0x5b58,0x8089,0x50be,0x5e2b, 0x6db2,0x4f8b,0x81e3,0x81f3,
  0x56e0,0x7d99,0x5df2,0x899a, 0x6e9d,0x6d17,0x8aad,0x8996,
  0x731b,0x5de8,0x7db2,0x888b, 0x4efb,0x5bc6,0x8896,0x6cc1,
  0x8457,0x8f03,0x6bc5,0x97ff, 0x8ca9,0x5e45,0x82e6,0x63aa,
  0x5f81,0x78c1,0x821e,0x52aa, 0x7aaa,0x5999,0x6297,0x8f14,
  0x7fd2,0x4fc3,0x54c9,0x967a, 0x66f4,0x8b1b,0x5e72,0x5fa9,
  0x8a2a,0x6d3e,0x7763,0x6483, 0x8b58,0x614e,0x5a5a,0x8d85,
  0x71d0,0x983c,0x72e9,0x583a, 0x5dfe,0x8a8d,0x67c4,0x7de0,
  0x4f11,0x77ed,0x4f0f,0x5bc5, 0x629c,0x5c3c,0x533b,0x6dc0,
  0x81fc,0x96d1,0x904a,0x6d6e, 0x93e1,0x5c64,0x98fc,0x524a,
  0x6dfb,0x8584,0x968a,0x56fa, 0x5883,0x7766,0x9805,0x4e73,
  0x8c46,0x8a31,0x7dd2,0x8ff0, 0x6d6a,0x4f9d,0x6b6f,0x6b27,
  0x62c5,0x511f,0x9769,0x5374, 0x9aa8,0x6775,0x887f,0x5305,
  0x7570,0x8d70,0x864e,0x5cef, 0x8cde,0x5ff5,0x725f,0x7686,
  0x609f,0x80cc,0x59eb,0x8131, 0x5e0c,0x8a17,0x9676,0x82d7,
  0x74b0,0x84b8,0x50d5,0x96f2, 0x7248,0x7834,0x6dd1,0x6e09,
  0x67ff,0x6f54,0x5915,0x500d, 0x72ac,0x9ec4,0x7b46,0x9b3c,
  0x6563,0x53bb,0x8a98,0x91dc, 0x9818,0x6fc3,0x65c5,0x501f,
  0x7f8a,0x6f64,0x9031,0x5f3e, 0x63f4,0x9038,0x8b66,0x7be4,
  0x7206,0x6843,0x72ec,0x65cf, 0x82a6,0x5ba2,0x6960,0x9ea6,
  0x52df,0x6790,0x639b,0x7d75, 0x9855,0x5df3,0x5805,0x8acb,
  0x95a3,0x8863,0x8ca8,0x5b63, 0x5e8a,0x5449,0x786c,0x7d2b,
  0x8ca2,0x5352,0x7d76,0x8cb8, 0x7070,0x547c,0x6545,0x6676,
  0x73b2,0x56f2,0x7bb1,0x58a8, 0x7a81,0x66ae,
/* 0x4b41(i:1900) */
  0x8087,0x59ff,0x8840,0x56f0, 0x7b51,0x6df7,0x5f01,0x934b,
  0x9000,0x4fe3,0x675f,0x4fbf, 0x8cc3,0x526f,0x63a1,0x5442,
  0x8907,0x698a,0x5e2d,0x5a18, 0x7518,0x514d,0x5e7e,0x50b5,
  0x5bdd,0x68d2,0x745e,0x69fb, 0x5fae,0x55e3,0x8a70,0x5bf8,
  0x5824,0x8358,0x5f13,0x5e95, 0x706f,0x751a,0x7d05,0x60e3,
  0x7e70,0x5012,0x5238,0x83ef, 0x5373,0x5f31,0x6a2b,0x9cf4,
  0x53cc,0x6d32,0x4eab,0x4e92, 0x842c,0x8a8c,0x65e2,0x6f01,
  0x80a9,0x9df9,0x8b72,0x7b52, 0x9589,0x6d74,0x63a2,0x6590,
  0x5bd2,0x6319,0x8ab0,0x76df, 0x99a8,0x7a74,0x8236,0x8846,
  0x8061,0x6557,0x5922,0x9644, 0x88ab,0x9326,0x7b4b,0x62b5,
  0x5371,0x5e81,0x5bdf,0x4f75, 0x58c1,0x7058,0x7dca,0x5438,
  0x73e0,0x52d8,0x5208,0x78d0, 0x6b23,0x6838,0x4e43,0x690e,
  0x8377,0x6ed1,0x98f2,0x8170, 0x8857,0x8ef8,0x798e,0x83dc,
  0x8fce,0x7e01,0x5510,0x4ea8, 0x8a33,0x9162,0x5efb,0x606f,
  0x4e86,0x664b,0x6368,0x5217, 0x8056,0x51fd,0x7642,0x821f,
  0x9685,0x50cf,0x662f,0x4f3c, 0x4e59,0x6a3d,0x4e71,0x523a,
  0x8acf,0x6a58,0x66ff,0x670b, 0x653b,0x9732,0x5ec3,0x8a13,
  0x5782,0x604b,0x866b,0x95d8, 0x60a9,0x4e01,0x63cf,0x6fc0,
  0x659c,0x8cac,0x8305,0x7ca7, 0x6050,0x96f7,0x5fcd,0x640d,
  0x5b54,0x900f,0x62d3,0x59b9, 0x7159,0x51ac,0x79f0,0x552f,
  0x5275,0x6697,0x80f8,0x4e98, 0x4ecf,0x51cd,0x9d5c,0x5144,
  0x7a93,0x67f1,0x5841,0x7c21, 0x8861,0x5c31,0x68da,0x91e7,
  0x9df2,0x63ee,0x6575,0x84ee, 0x523b,0x6b32,0x7c98,0x5982,
  0x969c,0x8987,0x7c9f,0x9006, 0x62db,0x66dc,
/* 0x4c41(i:2090) */
  0x6355,0x6982,0x50ac,0x623b, 0x5fd8,0x63da,0x75db,0x627f,
  0x616e,0x8266,0x7c95,0x716e, 0x96c7,0x7f6a,0x5426,0x5200,
  0x83d3,0x5211,0x594f,0x9d28, 0x574a,0x66c7,0x9858,0x820e,
  0x6614,0x733f,0x50b7,0x6551, 0x5eb8,0x5b6b,0x55ac,0x5feb,
  0x6388,0x8caf,0x676f,0x5951, 0x5a01,0x71e5,0x5de3,0x8c6a,
  0x6271,0x81f4,0x5c3a,0x5f92, 0x9045,0x7384,0x7149,0x79d8,
  0x796d,0x9003,0x83cc,0x5fb4, 0x5b8d,0x6279,0x64ae,0x7d18,
  0x723e,0x5bee,0x65e7,0x8d08, 0x9e78,0x52e7,0x5d07,0x9f62,
  0x6069,0x536f,0x6681,0x9663, 0x5e3d,0x62b1,0x722a,0x6e4a,
  0x93ae,0x79e6,0x53e5,0x809d, 0x88fe,0x53b3,0x6c88,0x6e7f,
  0x5141,0x9091,0x6f6e,0x84c4, 0x85ea,0x8129,0x6bd2,0x663c,
  0x7f72,0x73c2,0x5f1f,0x790e, 0x60b2,0x72ed,0x58ee,0x8179,
  0x8e8d,0x5c65,0x5de7,0x6c37, 0x6de1,0x862d,0x72af,0x8e0a,
  0x7c92,0x8218,0x8033,0x63a7, 0x9291,0x5019,0x8155,0x8a69,
  0x8edf,0x66b4,0x8133,0x7591, 0x6b20,0x6669,0x90f5,0x4e32,
  0x73ea,0x693f,0x7687,0x707d, 0x7d3a,0x6148,0x8607,0x99ff,
  0x59c9,0x7832,0x7815,0x907f, 0x80a1,0x5c3f,0x66a2,0x9418,
  0x6d44,0x5e55,0x5854,0x7b95, 0x8de1,0x4ea1,0x8c5a,0x81e8,
  0x89e6,0x9670,0x5263,0x74f6, 0x9a5a,0x6012,0x520a,0x7434,
  0x9801,0x907a,0x5504,0x7956, 0x5230,0x54b2,0x8a34,0x96a3,
  0x4ff3,0x9283,0x91e3,0x7d39, 0x9688,0x4f51,0x7d61,0x5dba,
  0x9bae,0x5f80,0x795d,0x8597, 0x8da3,0x7c60,0x5c0a,0x7565,
  0x85a9,0x63d6,0x9e97,0x7d22, 0x5375,0x9aea,0x9042,0x6b3d,
  0x7d0b,0x6392,0x80aa,0x7de9, 0x9f3b,0x99c6,
/* 0x4d41(i:2280) */
  0x6d78,0x6731,0x5531,0x6398, 0x7825,0x5cb3,0x5de1,0x92ad,
  0x98fd,0x9810,0x6ce3,0x6b64, 0x5321,0x6b53,0x5e8f,0x7ae5,
  0x502b,0x6e56,0x62bd,0x8276, 0x6a9c,0x4e18,0x57f7,0x752b,
  0x7c97,0x82eb,0x9802,0x811a, 0x73cd,0x8f9b,0x5c0b,0x63e1,
  0x7372,0x8150,0x80e1,0x5b99, 0x76d7,0x6291,0x65ec,0x8a3a,
  0x5947,0x65e8,0x6e7e,0x6696, 0x55ab,0x8f09,0x92ed,0x9396,
  0x4eee,0x755c,0x6f38,0x8f9e, 0x7981,0x5c01,0x62e0,0x9be8,
  0x91c8,0x6276,0x65cb,0x8e0f, 0x8b21,0x699b,0x6216,0x5a92,
  0x90b8,0x50da,0x79df,0x6c41, 0x5270,0x9175,0x8b39,0x685d,
  0x5875,0x819c,0x5b9c,0x8a89, 0x8a72,0x9d8f,0x6377,0x5974,
  0x8aa4,0x52b1,0x6962,0x5c48, 0x9ce9,0x673a,0x75b2,0x6d1e,
  0x4f0d,0x7e6d,0x7b48,0x7fcc, 0x65e6,0x59a5,0x79e9,0x6212,
  0x6ede,0x770b,0x8ca7,0x65bc, 0x885d,0x6adb,0x5c4a,0x8074,
  0x9084,0x8ecc,0x65d7,0x57f9, 0x708e,0x6f06,0x5e7c,0x77ac,
  0x4ff5,0x5949,0x81ed,0x9b45, 0x7ffc,0x8178,0x69fd,0x6cca,
  0x69c7,0x79d2,0x8b1d,0x9ed9, 0x81d3,0x7a3c,0x7968,0x6f5c,
  0x63b2,0x8ddd,0x6383,0x6e9c, 0x5e33,0x61f8,0x76bf,0x642c,
  0x7db4,0x6247,0x6458,0x6816, 0x5f69,0x9022,0x7a1a,0x82b9,
  0x70c8,0x9a12,0x6163,0x6fef, 0x53eb,0x9d3b,0x62fe,0x60a0,
  0x9591,0x6d99,0x6162,0x9298, 0x635c,0x9707,0x8972,0x683d,
  0x51e1,0x9b54,0x608c,0x5b22, 0x99c4,0x7126,0x8a73,0x971c,
  0x7396,0x67d4,0x60a3,0x4e11, 0x4ef0,0x8cdb,0x8cb0,0x7912,
  0x9774,0x8986,0x5146,0x57dc, 0x99d0,0x80c3,0x8338,0x78a7,
  0x86cd,0x7f85,0x5049,0x8247, 0x690b,0x7c4d,
/* 0x4e41(i:2470) */
  0x53ea,0x5f26,0x6e25,0x6881, 0x9375,0x5dfd,0x5347,0x9727,
  0x643a,0x75c7,0x6fa4,0x73a9, 0x77e9,0x9451,0x8b5c,0x808c,
  0x674e,0x4ead,0x582f,0x7573, 0x8ed2,0x6ce5,0x9320,0x8ff7,
  0x7d33,0x72c2,0x8217,0x7422, 0x82c5,0x9a30,0x773a,0x5f84,
  0x9673,0x64ad,0x920d,0x74dc, 0x60c7,0x86ed,0x4ffa,0x52a3,
  0x6a3a,0x7720,0x5320,0x61b6, 0x5674,0x8776,0x6cbf,0x505c,
  0x602a,0x8466,0x6b96,0x6dbc, 0x97d3,0x968f,0x6876,0x60d1,
  0x5378,0x64a4,0x51a0,0x9154, 0x5df4,0x629e,0x5e63,0x929a,
  0x7693,0x6c5a,0x6597,0x50e7, 0x7c82,0x5f6b,0x6ce1,0x5f6c,
  0x5ac1,0x6f2c,0x852d,0x6442, 0x5750,0x58c7,0x8cfc,0x8a5e,
  0x7a7f,0x689d,0x7e26,0x7a40, 0x7344,0x8aeb,0x4fd7,0x7a63,
  0x8036,0x7def,0x80c6,0x8aed, 0x731f,0x8fea,0x4f0e,0x758b,
  0x518a,0x6734,0x5fd9,0x61c7, 0x65af,0x9cf3,0x5eca,0x9262,
  0x68df,0x6cb8,0x80f4,0x57cb, 0x6c99,0x96a0,0x5b64,0x58f1,
  0x68c4,0x5410,0x982c,0x8a87, 0x4e5e,0x6167,0x9bab,0x90aa,
  0x55b0,0x82bd,0x596a,0x66f3, 0x8299,0x5893,0x719f,0x6284,
  0x67d1,0x9063,0x5acc,0x6c57, 0x7ce7,0x5851,0x64b2,0x58ca,
  0x830e,0x5968,0x5302,0x5a46, 0x8702,0x6065,0x72d9,0x89a7,
  0x6689,0x66f9,0x5d6f,0x5bb0, 0x96bc,0x636e,0x60dc,0x7948,
  0x51dd,0x8606,0x5ec9,0x7554, 0x596e,0x6b04,0x4f43,0x7b94,
  0x67da,0x62dd,0x628a,0x971e, 0x62ed,0x6ec5,0x508d,0x67b6,
  0x80e4,0x9ebf,0x5eb5,0x638c, 0x85cd,0x9867,0x52c5,0x6016,
  0x68cb,0x61d0,0x5751,0x8f29, 0x5faa,0x81a8,0x7d62,0x71c8,
  0x54c0,0x69cc,0x6b3e,0x65ac, 0x63c3,0x4f46,
/* 0x4f41(i:2660) */
  0x7b1b,0x6b86,0x88f8,0x5203, 0x732e,0x6687,0x7d17,0x57f4,
  0x570f,0x618e,0x970a,0x7c3f, 0x8b00,0x7881,0x8ce0,0x548b,
  0x7b87,0x745b,0x7c11,0x8870, 0x5398,0x5448,0x6cf3,0x6f22,
  0x53f6,0x88b4,0x5301,0x7a6b, 0x8695,0x586b,0x5d29,0x88c2,
  0x62d2,0x4e1e,0x5036,0x96c0, 0x7363,0x8a3b,0x5176,0x7199,
  0x7fe0,0x8888,0x7e1e,0x4e4f, 0x84cb,0x6f2b,0x5859,0x936c,
  0x53e9,0x865a,0x9149,0x86ef, 0x5e06,0x5507,0x902e,0x6795,
  0x846c,0x5ba5,0x82a5,0x8431, 0x6d8c,0x63fa,0x4ea5,0x51c6,
  0x6328,0x7f70,0x5b5f,0x5dbd, 0x99c8,0x53ec,0x7985,0x8a54,
  0x7962,0x88df,0x5b09,0x4fb5, 0x4f91,0x9b8e,0x5192,0x96f0,
  0x6daf,0x622f,0x8490,0x8cdc, 0x5075,0x5ce0,0x4e14,0x4f83,
  0x7c54,0x84d1,0x77b3,0x8aee, 0x5ce8,0x62f6,0x663b,0x8a93,
  0x8526,0x8a95,0x65fa,0x6714, 0x53d4,0x62ab,0x8ce6,0x88f3,
  0x5be7,0x868a,0x668e,0x582a, 0x6170,0x696f,0x9f13,0x7a92,
  0x7893,0x6a7f,0x9017,0x9266, 0x7d10,0x7bc7,0x6ef4,0x821c,
  0x5c3d,0x62cd,0x85c1,0x6f02, 0x6e67,0x6691,0x85a6,0x637a,
  0x821b,0x4f8d,0x5091,0x8a02, 0x62ec,0x9bc9,0x7a3d,0x7c9b,
  0x50c5,0x9019,0x708a,0x7c8b, 0x64ec,0x665f,0x6562,0x732b,
  0x5339,0x67a0,0x55a7,0x6d2a, 0x7a3f,0x64e6,0x79a7,0x67d8,
  0x7b26,0x96bb,0x6311,0x72a0, 0x5c6f,0x7026,0x97ee,0x60df,
  0x8afe,0x8b04,0x8494,0x9bd6, 0x82af,0x932c,0x6606,0x9640,
  0x5bc2,0x86c7,0x7949,0x8017, 0x6919,0x7092,0x963b,0x7c7e,
  0x59d3,0x5b5c,0x7d1b,0x91d8, 0x6a80,0x85e9,0x6905,0x6c93,
  0x502d,0x4ea6,0x7fc1,0x61a4, 0x8cca,0x9665,
/* 0x5041(i:2850) */
  0x93d1,0x53f1,0x598a,0x8eac, 0x62d8,0x6867,0x71d5,0x7b67,
  0x504f,0x67d0,0x82d1,0x978d, 0x748b,0x80ba,0x7336,0x514e,
  0x8105,0x90ca,0x584a,0x67fe, 0x6ff1,0x5ffd,0x76c6,0x9a0e,
  0x507d,0x9694,0x5ef7,0x7bb8, 0x904d,0x6c4e,0x85fb,0x819d,
  0x67af,0x564c,0x5606,0x8c8c, 0x56da,0x73ed,0x8cc4,0x8fc5,
  0x96f6,0x6c50,0x8944,0x8f3f, 0x7d5e,0x60e8,0x72fc,0x7d9c,
  0x8463,0x5cfb,0x5446,0x5d16, 0x6ca1,0x81b3,0x58fa,0x5bb4,
  0x8108,0x541f,0x8cbc,0x6182, 0x78a9,0x6fe1,0x91a4,0x76f2,
  0x6020,0x76fe,0x84c9,0x7f36, 0x4ec7,0x755d,0x7a17,0x84ec,
  0x75f4,0x4f3a,0x676d,0x7460, 0x62f3,0x6f20,0x79e4,0x87f9,
  0x6094,0x6234,0x66ab,0x820c, 0x8499,0x723a,0x5fcc,0x6109,
  0x70cf,0x7261,0x7a50,0x5098, 0x9aed,0x5d69,0x601c,0x6667,
  0x99b4,0x5e7b,0x643e,0x5830, 0x53c9,0x7a9f,0x990c,0x9b42,
  0x8f5f,0x7aae,0x5b9b,0x68a2, 0x6249,0x7984,0x9dfa,0x5451,
  0x932f,0x8ac4,0x5f90,0x8df3, 0x5a2f,0x80de,0x6d29,0x7a4f,
  0x84bc,0x9d2b,0x9010,0x6d38, 0x916a,0x6fc1,0x9905,0x6bbb,
  0x5eb6,0x91b8,0x5076,0x6f0f, 0x4e19,0x540f,0x9675,0x6c72,
  0x51b4,0x5631,0x9f20,0x66a6, 0x5f0a,0x75ab,0x51f8,0x674f,
  0x8df5,0x6c70,0x8a6b,0x757f, 0x5cac,0x6841,0x8cd3,0x9bdb,
  0x8475,0x6893,0x840c,0x72db, 0x7577,0x8568,0x783a,0x847a,
  0x5f10,0x831c,0x6813,0x6e1a, 0x9daf,0x51f9,0x7980,0x4e99,
  0x5ee3,0x908a,0x80af,0x59a8, 0x77db,0x8d74,0x8a1f,0x673d,
  0x533f,0x8a0a,0x5618,0x6756, 0x53d9,0x4f10,0x7409,0x5a41,
  0x4ff8,0x79b0,0x9838,0x8e2a, 0x9d60,0x8f44,
/* 0x5141(i:3040) */
  0x65a5,0x75be,0x906d,0x867b, 0x60bc,0x51b6,0x5937,0x7d2f,
  0x916c,0x69ae,0x7ce0,0x792a, 0x5d14,0x64c1,0x58ec,0x589c,
  0x8d66,0x66d9,0x61f2,0x912d, 0x6e58,0x9435,0x965b,0x7272,
  0x5f6a,0x5e9a,0x8f1b,0x5b95, 0x5c39,0x9013,0x834f,0x7cce,
  0x620a,0x90ed,0x691b,0x6e15, 0x65db,0x66fe,0x4e9f,0x55aa,
  0x7a83,0x83e9,0x8b83,0x846d, 0x83f0,0x7f50,0x918d,0x9190,
  0x758e,0x95a5,0x81e7,0x75e2, 0x61a9,0x8a50,0x95b2,0x53a8,
  0x59f6,0x9813,0x7891,0x7c17, 0x6b3a,0x57e0,0x620e,0x83d6,
  0x8ad2,0x75d4,0x927e,0x59dc, 0x5289,0x9087,0x6ffe,0x7473,
  0x5c09,0x9d6c,0x84fc,0x7cdf, 0x7bad,0x8a6e,0x594e,0x56ca,
  0x819a,0x7947,0x6636,0x53e1, 0x7887,0x58cc,0x9397,0x6e13,
  0x5256,0x828b,0x9e9f,0x9583, 0x658c,0x9e93,0x7345,0x6e26,
  0x9d07,0x5983,0x7dac,0x96c1, 0x61be,0x6762,0x9ece,0x90a8,
  0x9187,0x9f0e,0x7c38,0x51f1, 0x8599,0x524c,0x540e,0x7901,
  0x655e,0x6668,0x5ce1,0x7566, 0x76c8,0x8679,0x531d,0x5506,
  0x7926,0x8912,0x77ef,0x7cc0, 0x570b,0x515c,0x7e8a,0x535c,
  0x8a60,0x65a7,0x8766,0x5766, 0x6ae8,0x87fb,0x5e16,0x7aea,
  0x8d73,0x771e,0x737a,0x66e0, 0x9410,0x816b,0x7b08,0x91fc,
  0x5737,0x6fe4,0x856a,0x7e55, 0x9957,0x87ba,0x694a,0x818f,
  0x5eff,0x891c,0x72d0,0x9846, 0x9edb,0x8d99,0x5dd6,0x62b9,
  0x64ab,0x4f76,0x613f,0x68af, 0x5f14,0x800c,0x92f8,0x7bc1,
  0x52fe,0x664f,0x9177,0x51f6, 0x97a0,0x839e,0x647a,0x9c3a,
  0x67f5,0x7c4f,0x685f,0x9b6f, 0x9f4b,0x7ffb,0x9348,0x4ff6,
  0x9e92,0x9197,0x96db,0x5be6, 0x6ccc,0x7cfe,
/* 0x5241(i:3230) */
  0x9453,0x6822,0x66b9,0x5bd4, 0x98f4,0x8ae6,0x8154,0x7827,
  0x74bd,0x6ed3,0x9288,0x5a20, 0x5b8b,0x86f8,0x760d,0x865c,
  0x6641,0x91c9,0x5589,0x7a4e, 0x59e5,0x6042,0x932b,0x5b5a,
  0x849c,0x5c91,0x96cd,0x62d9, 0x675c,0x6787,0x5e7d,0x8650,
  0x9eb9,0x5cb1,0x80ce,0x7a00, 0x8abc,0x5700,0x8096,0x7d72,
  0x9211,0x8098,0x907c,0x7761, 0x8737,0x9075,0x817a,0x7c3e,
  0x6ea2,0x965e,0x7e90,0x72d7, 0x58fd,0x60b3,0x9786,0x7e88,
  0x587e,0x6e20,0x84dc,0x6961, 0x77ad,0x5197,0x652a,0x6777,
  0x5dcd,0x6101,0x932e,0x5954, 0x6367,0x798d,0x7aff,0x80d6,
  0x58b3,0x6168,0x6ac3,0x7483, 0x9b92,0x660a,0x642d,0x5118,
  0x6763,0x809b,0x9c10,0x4fc9, 0x6953,0x7a1c,0x52ff,0x6055,
  0x768e,0x817f,0x5642,0x5f6d, 0x7194,0x70bb,0x7436,0x8000,
  0x874b,0x55da,0x7435,0x7690, 0x96eb,0x66dd,0x751c,0x633d,
  0x6ec9,0x7c64,0x7ca5,0x6d35, 0x935c,0x7027,0x5e25,0x701d,
  0x54bd,0x611a,0x6973,0x6c6a, 0x559a,0x6d19,0x96cc,0x5be1,
  0x59fb,0x697c,0x914c,0x7709, 0x8500,0x7a46,0x7872,0x92e4,
  0x8ced,0x7cfa,0x9d1b,0x814e, 0x9ac4,0x68a0,0x6dcb,0x5918,
  0x83b1,0x5629,0x9b41,0x6897, 0x70b3,0x9771,0x9419,0x67a2,
  0x6802,0x7895,0x68a7,0x50d6, 0x80b1,0x5ef8,0x82d4,0x797a,
  0x67ca,0x7e4d,0x69cd,0x51c4, 0x723d,0x6829,0x99b3,0x5f3c,
  0x8f61,0x682b,0x6155,0x6591, 0x8fb1,0x7e1b,0x9798,0x9952,
  0x8877,0x5b2c,0x6631,0x4fa0, 0x6939,0x6afb,0x5bb5,0x7ac8,
  0x5026,0x5944,0x9059,0x7b25, 0x7b4f,0x8e74,0x8543,0x5858,
  0x8b0e,0x5039,0x8654,0x97f6, 0x7569,0x72f8,
/* 0x5341(i:3420) */
  0x4ef7,0x9d89,0x5016,0x51cc, 0x62cc,0x91c6,0x8755,0x649a,
  0x88f4,0x91e6,0x6854,0x695a, 0x6c40,0x7b6c,0x6741,0x77d7,
  0x8823,0x5384,0x8eaf,0x7280, 0x8c6b,0x788d,0x7165,0x8207,
  0x68b1,0x8d04,0x9077,0x701e, 0x8fe6,0x810a,0x81bf,0x89dc,
  0x68b3,0x6adf,0x92ea,0x95c7, 0x7957,0x7a20,0x53a9,0x8e5f,
  0x786f,0x79b9,0x5f27,0x5ed6, 0x6853,0x93ac,0x919c,0x691a,
  0x5806,0x64b0,0x7e4b,0x7d8f, 0x68f2,0x6ea5,0x82db,0x9192,
  0x5243,0x8eb0,0x9081,0x721b, 0x7dcb,0x7656,0x59ac,0x6fe0,
  0x8b28,0x80a2,0x5544,0x6070, 0x5f4a,0x68c8,0x633a,0x9438,
  0x9b4f,0x81e5,0x6a17,0x70dd, 0x69a7,0x614c,0x920e,0x9310,
  0x9bad,0x52d7,0x925e,0x92f9, 0x5993,0x7696,0x66fb,0x5769,
  0x73ca,0x7678,0x6a1f,0x7e9c, 0x9811,0x8cd1,0x5840,0x6349,
  0x871c,0x62d0,0x60b4,0x6b89, 0x86ee,0x5764,0x581d,0x8549,
  0x7235,0x7652,0x983b,0x8237, 0x5351,0x5c24,0x59be,0x5815,
  0x901d,0x69b4,0x834a,0x9ea9, 0x976b,0x8086,0x53ad,0x6068,
  0x4fae,0x76c3,0x6a05,0x689b, 0x937e,0x99d5,0x91c7,0x5c16,
  0x585e,0x61a7,0x9699,0x4fdf, 0x8278,0x9c52,0x5f45,0x6108,
  0x7c8d,0x806f,0x5df7,0x8d6b, 0x57b0,0x98e2,0x5703,0x79bf,
  0x5996,0x7941,0x540a,0x83df, 0x9c39,0x52d2,0x6bd8,0x86cb,
  0x4ec0,0x9a28,0x5366,0x8006, 0x7337,0x6492,0x8fed,0x5ac9,
  0x5420,0x537f,0x4faf,0x807e, 0x543b,0x7515,0x7b18,0x8749,
  0x54b3,0x704c,0x8997,0x6cab, 0x85fa,0x7114,0x696e,0x9328,
  0x745a,0x59d1,0x6e5b,0x617e, 0x53e2,0x8317,0x76e7,0x848b,
  0x85af,0x6925,0x5c60,0x7259, 0x75d5,0x8b90,
/* 0x5441(i:3610) */
  0x6e07,0x82ad,0x5c4f,0x7bed, 0x9784,0x6f70,0x764c,0x88b7,
  0x92d2,0x4f36,0x5efe,0x9061, 0x88e1,0x8471,0x711a,0x6d1b,
  0x80b4,0x74e2,0x7433,0x5a7f, 0x905c,0x980c,0x5319,0x906e,
  0x6bb4,0x85aa,0x7897,0x7afa, 0x6aae,0x8910,0x958f,0x620c,
  0x4f3d,0x4f7c,0x79be,0x9d0e, 0x4ed4,0x57a2,0x51a5,0x6900,
  0x6089,0x707c,0x7ae3,0x8956, 0x93a7,0x9c2d,0x5112,0x52fa,
  0x7cca,0x60f9,0x7078,0x81c6, 0x559d,0x6991,0x96c9,0x553e,
  0x805a,0x8304,0x8332,0x54fa, 0x565b,0x8fbf,0x5634,0x6760,
  0x5265,0x840e,0x5e5f,0x7b65, 0x9035,0x8387,0x6b4e,0x58be,
  0x6309,0x727d,0x97ad,0x69d0, 0x546a,0x984e,0x632b,0x714e,
  0x8557,0x7cde,0x6372,0x68f9, 0x7511,0x8602,0x6eba,0x5a3c,
  0x7a84,0x851a,0x95a4,0x59d0, 0x60da,0x51ea,0x5a29,0x7169,
  0x6f15,0x696b,0x63bb,0x75e9, 0x4e4e,0x7dbb,0x6934,0x8521,
  0x8ffa,0x9354,0x9c3b,0x5f17, 0x5ed3,0x8258,0x895f,0x82e7,
  0x52c3,0x5c51,0x83ab,0x7826, 0x79e1,0x7ff0,0x626e,0x60f0,
  0x5ca8,0x6f97,0x71a8,0x9909, 0x5132,0x5e37,0x5f04,0x637b,
  0x6753,0x68d7,0x6652,0x9cf6, 0x88b0,0x52ab,0x4fc4,0x4e3c,
  0x67b3,0x7baa,0x7f4d,0x8a23, 0x63b4,0x71e6,0x65a4,0x6f09,
  0x853d,0x5072,0x7dba,0x5516, 0x7b04,0x72fd,0x6cd3,0x8422,
  0x621f,0x50ad,0x8235,0x8718, 0x5919,0x6028,0x677c,0x6f23,
  0x75b9,0x695c,0x520e,0x8018, 0x8b01,0x71ed,0x5713,0x660f,
  0x83eb,0x7164,0x7d9b,0x5617, 0x7d7d,0x8f4d,0x9318,0x8569,
  0x5d17,0x678c,0x67de,0x87c7, 0x79ae,0x5835,0x8404,0x9041,
  0x7fd4,0x6e8c,0x8a63,0x9d08, 0x670f,0x939a,
/* 0x5541(i:3800) */
  0x63ac,0x602f,0x64e2,0x608d, 0x96b7,0x6357,0x8461,0x914b,
  0x75d8,0x60e7,0x9913,0x9c57, 0x5984,0x6deb,0x5e96,0x6d9c,
  0x9bf0,0x58bb,0x7977,0x60b6, 0x633f,0x5bf5,0x9812,0x558b,
  0x82d3,0x5147,0x6190,0x7953, 0x79bd,0x6c5d,0x9eba,0x9c48,
  0x8da8,0x5ee0,0x7d43,0x5efc, 0x854e,0x8ce4,0x5ae1,0x54e8,
  0x5023,0x52be,0x7dec,0x8511, 0x6666,0x6c3e,0x724c,0x8adc,
  0x9c0d,0x77a5,0x8b02,0x8d05, 0x6f11,0x9834,0x97fb,0x50fb,
  0x7f75,0x5a03,0x8513,0x4fb6, 0x634c,0x9d61,0x808b,0x5294,
  0x65a1,0x567a,0x5957,0x8d0b, 0x6a35,0x6ad3,0x70f9,0x865e,
  0x6fb1,0x51e7,0x7feb,0x59ea, 0x5e87,0x6b6a,0x754f,0x717d,
  0x914e,0x7d2c,0x8c79,0x6062, 0x621a,0x7fa8,0x5f1b,0x6c8c,
  0x86fe,0x7562,0x7b86,0x9ab8, 0x6627,0x7aba,0x844e,0x6f81,
  0x8b2c,0x86a4,0x6feb,0x7b8b, 0x7f77,0x8f2f,0x8e44,0x7e23,
  0x4e4d,0x79a6,0x8afa,0x903c, 0x50d1,0x9ecd,0x5edf,0x758f,
  0x631f,0x53db,0x9910,0x826e, 0x62f7,0x68fa,0x725d,0x803d,
  0x58d5,0x5c4d,0x86d9,0x540b, 0x8805,0x92f2,0x9237,0x5c61,
  0x985b,0x86e4,0x966a,0x7262, 0x6955,0x6cd7,0x6994,0x9c2f,
  0x77e7,0x68c9,0x8de8,0x6d6c, 0x67c1,0x9baa,0x619a,0x63a9,
  0x7015,0x9306,0x934d,0x6a61, 0x6258,0x5283,0x7525,0x5687,
  0x6c83,0x6834,0x649e,0x4e9b, 0x7252,0x59e6,0x8fc2,0x5fbd,
  0x6dd8,0x85f7,0x8a51,0x9817, 0x99c1,0x63a0,0x7c81,0x5b30,
  0x8139,0x5403,0x7e82,0x8106, 0x532a,0x6a8e,0x7f6b,0x54e9,
  0x5678,0x8ab9,0x6715,0x5bd3, 0x6478,0x64fe,0x6b1d,0x8cc2,
  0x51cb,0x7e8f,0x0000,0x0000, 0x0000,0x0000,
/* 0x5641(i:3990) */
  0x5f0c,0x4e10,0x4e15,0x4e28, 0x4e2a,0x4e31,0x4e36,0x4e3f,
  0x4e42,0x4e56,0x4e58,0x4e62, 0x4e82,0x4e85,0x4e8a,0x4e8e,
  0x5f0d,0x4e9e,0x4ea0,0x4ea2, 0x4eb0,0x4eb3,0x4eb6,0x4ece,
  0x4ecd,0x4ec4,0x4ec6,0x4ec2, 0x4ee1,0x4ed7,0x4ede,0x4eed,
  0x4edf,0x4efc,0x4f09,0x4f1c, 0x4f00,0x4f03,0x4f5a,0x4f30,
  0x4f5d,0x4f39,0x4f57,0x4f47, 0x4f5e,0x4f56,0x4f5b,0x4f92,
  0x4f8a,0x4f88,0x4f8f,0x4f9a, 0x4fad,0x4f98,0x4f7b,0x4fab,
  0x4f69,0x4f70,0x4f94,0x4f6f, 0x4f86,0x4f96,0x4fd4,0x4fce,
  0x4fd8,0x4fdb,0x4fd1,0x4fda, 0x4fd0,0x4fcd,0x4fe4,0x4fe5,
  0x501a,0x5040,0x5028,0x5014, 0x502a,0x5025,0x5005,0x5021,
  0x5022,0x5029,0x502c,0x4fff, 0x4ffe,0x4fef,0x5011,0x501e,
  0x5006,0x5043,0x5047,0x5055, 0x5050,0x5048,0x505a,0x5056,
  0x500f,0x5046,0x5070,0x5042, 0x506c,0x5078,0x5080,0x5094,
  0x509a,0x5085,0x50b4,0x6703, 0x50b2,0x50c9,0x50ca,0x50b3,
  0x50c2,0x50f4,0x50de,0x50e5, 0x50d8,0x50ed,0x50e3,0x50ee,
  0x50f9,0x50f5,0x5109,0x5101, 0x5102,0x511a,0x5115,0x5114,
  0x5116,0x5121,0x513a,0x5137, 0x513c,0x513b,0x513f,0x5140,
  0x514a,0x514c,0x5152,0x5154, 0x5162,0x5164,0x5169,0x516a,
  0x516e,0x5180,0x5182,0x56d8, 0x518c,0x5189,0x518f,0x5191,
  0x5193,0x5195,0x5196,0x519d, 0x51a4,0x51a6,0x51a2,0x51a9,
  0x51aa,0x51ab,0x51b3,0x51b1, 0x51b2,0x51b0,0x51b5,0x51be,
  0x51bd,0x51c5,0x51c9,0x51db, 0x51e0,0x51e9,0x51ec,0x51ed,
  0x51f0,0x51f5,0x51fe,0x5204, 0x520b,0x5214,0x5215,0x5227,
  0x522a,0x522e,0x5233,0x5239, 0x5244,0x524b,
/* 0x5741(i:4180) */
  0x524f,0x525e,0x5254,0x5271, 0x526a,0x5273,0x5274,0x5269,
  0x527f,0x527d,0x528d,0x5288, 0x5292,0x5291,0x529c,0x52a6,
  0x52ac,0x52ad,0x52bc,0x52b5, 0x52c1,0x52c0,0x52cd,0x52db,
  0x52de,0x52e3,0x52e6,0x52e0, 0x52f3,0x52f5,0x52f8,0x52f9,
  0x5300,0x5306,0x5307,0x5308, 0x7538,0x530d,0x5310,0x530f,
  0x5315,0x531a,0x5324,0x5323, 0x532f,0x5331,0x5333,0x5338,
  0x5340,0x5345,0x5346,0x5349, 0x4e17,0x534d,0x51d6,0x8209,
  0x535e,0x5369,0x536e,0x5372, 0x5377,0x537b,0x5382,0x5393,
  0x5396,0x53a0,0x53a6,0x53a5, 0x53ae,0x53b0,0x53b2,0x53b6,
  0x53c3,0x7c12,0x53dd,0x53df, 0x66fc,0xfa0e,0x71ee,0x53ee,
  0x53e8,0x53ed,0x53fa,0x5401, 0x543d,0x5440,0x542c,0x542d,
  0x543c,0x542e,0x5436,0x5429, 0x541d,0x544e,0x548f,0x5475,
  0x548e,0x545f,0x5471,0x5477, 0x5470,0x5492,0x547b,0x5480,
  0x549c,0x5476,0x5484,0x5490, 0x5486,0x548a,0x54c7,0x54bc,
  0x54af,0x54a2,0x54b8,0x54a5, 0x54ac,0x54c4,0x54d8,0x54c8,
  0x54a8,0x54ab,0x54c2,0x54a4, 0x54a9,0x54be,0x54e5,0x54ff,
  0x54e6,0x550f,0x5514,0x54fd, 0x54ee,0x54ed,0x54e2,0x5539,
  0x5540,0x5563,0x554c,0x552e, 0x555c,0x5545,0x5556,0x5557,
  0x5538,0x5533,0x555d,0x5599, 0x5580,0x558a,0x559f,0x557b,
  0x557e,0x5598,0x559e,0x55ae, 0x557c,0x5586,0x5583,0x55a9,
  0x5587,0x55a8,0x55c5,0x55df, 0x55c4,0x55dc,0x55e4,0x55d4,
  0x55f9,0x5614,0x55f7,0x5616, 0x55fe,0x55fd,0x561b,0x564e,
  0x5650,0x5636,0x5632,0x5638, 0x566b,0x5664,0x5686,0x562f,
  0x566c,0x566a,0x71df,0x5694, 0x568f,0x5680,
/* 0x5841(i:4370) */
  0x568a,0x56a0,0x56a5,0x56ae, 0x56b6,0x56b4,0x56c8,0x56c2,
  0x56bc,0x56c1,0x56c3,0x56c0, 0x56ce,0x56d3,0x56d1,0x56d7,
  0x56ee,0x56f9,0x56ff,0x5704, 0x5709,0x5708,0x570d,0x55c7,
  0x5718,0x5716,0x571c,0x5726, 0x5738,0x574e,0x573b,0x5759,
  0x5740,0x574f,0x5765,0x5788, 0x5761,0x577f,0x5789,0x5793,
  0x57a0,0x57a4,0x57b3,0x57ac, 0x57aa,0x57c3,0x57c6,0x57c8,
  0x57c0,0x57d4,0x57c7,0x57d2, 0x57d3,0x57d6,0xfa0f,0x580a,
  0x57e3,0x580b,0x5819,0x5821, 0x584b,0x5862,0x6bc0,0x583d,
  0x5852,0xfa10,0x5870,0x5879, 0x5885,0x5872,0x589f,0x58ab,
  0x58b8,0x589e,0x58ae,0x58b2, 0x58b9,0x58ba,0x58c5,0x58d3,
  0x58d1,0x58d7,0x58d9,0x58d8, 0x58de,0x58dc,0x58df,0x58e4,
  0x58e5,0x58ef,0x58f7,0x58f9, 0x58fb,0x58fc,0x5902,0x590a,
  0x590b,0x5910,0x591b,0x68a6, 0x5925,0x592c,0x592d,0x5932,
  0x5938,0x593e,0x5955,0x5950, 0x5953,0x595a,0x5958,0x595b,
  0x595d,0x5963,0x5962,0x5960, 0x5967,0x596c,0x5969,0x5978,
  0x5981,0x598d,0x599b,0x599d, 0x59a3,0x59a4,0x59b2,0x59ba,
  0x59c6,0x59e8,0x59d9,0x59da, 0x5a25,0x5a1f,0x5a11,0x5a1c,
  0x5a1a,0x5a09,0x5a40,0x5a6c, 0x5a49,0x5a35,0x5a36,0x5a62,
  0x5a6a,0x5a9a,0x5abc,0x5abe, 0x5ad0,0x5acb,0x5ac2,0x5abd,
  0x5ae3,0x5ad7,0x5ae6,0x5ae9, 0x5ad6,0x5afa,0x5afb,0x5b0c,
  0x5b0b,0x5b16,0x5b32,0x5b2a, 0x5b36,0x5b3e,0x5b43,0x5b45,
  0x5b40,0x5b51,0x5b55,0x5b56, 0x6588,0x5b5b,0x5b65,0x5b69,
  0x5b70,0x5b73,0x5b75,0x5b78, 0x5b7a,0x5b80,0x5b83,0x5ba6,
  0x5bb8,0x5bc3,0x5bc7,0x5bc0, 0x5bc9,0x752f,
/* 0x5941(i:4560) */
  0x5bd0,0x5bd8,0x5bde,0x5bec, 0x5be4,0x5be2,0x5be5,0x5beb,
  0x5bf0,0x5bf3,0x5bf6,0x5c05, 0x5c07,0x5c08,0x5c0d,0x5c13,
  0x5c1e,0x5c20,0x5c22,0x5c28, 0x5c38,0x5c41,0x5c46,0x5c4e,
  0x5c53,0x5c50,0x5b71,0x5c6c, 0x5c6e,0x5c76,0x5c79,0x5c8c,
  0x5c94,0x5cbe,0x5cab,0x5cbb, 0x5cb6,0x5cb7,0x5ca6,0x5cba,
  0x5cc5,0x5cbc,0x5cc7,0x5cd9, 0x5ce9,0x5cfd,0x5cfa,0x5cf5,
  0x5ced,0x5cea,0x5d0b,0x5d15, 0x5d1f,0x5d1b,0x5d11,0x5d27,
  0x5d22,0x5d1a,0x5d19,0x5d18, 0x5d4c,0x5d52,0x5d53,0xfa11,
  0x5d5c,0x5d4e,0x5d4b,0x5d42, 0x5d6c,0x5d73,0x5d6d,0x5d76,
  0x5d87,0x5d84,0x5d82,0x5d8c, 0x5da2,0x5d9d,0x5d90,0x5dac,
  0x5dae,0x5db7,0x5db8,0x5dbc, 0x5db9,0x5dc9,0x5dd0,0x5dd3,
  0x5dd2,0x5ddb,0x5deb,0x5df5, 0x5e0b,0x5e1a,0x5e19,0x5e11,
  0x5e1b,0x5e36,0x5e44,0x5e43, 0x5e40,0x5e47,0x5e4e,0x5e57,
  0x5e54,0x5e62,0x5e64,0x5e75, 0x5e76,0x5e7a,0x5e7f,0x5ea0,
  0x5ec1,0x5ec2,0x5ec8,0x5ed0, 0x5ecf,0x5edd,0x5eda,0x5edb,
  0x5ee2,0x5ee1,0x5ee8,0x5ee9, 0x5eec,0x5ef0,0x5ef1,0x5ef3,
  0x5ef4,0x5f03,0x5f09,0x5f0b, 0x5f11,0x5f16,0x5f21,0x5f29,
  0x5f2d,0x5f2f,0x5f34,0x5f38, 0x5f41,0x5f48,0x5f4c,0x5f4e,
  0x5f51,0x5f56,0x5f57,0x5f59, 0x5f5c,0x5f5d,0x5f61,0x5f67,
  0x5f73,0x5f77,0x5f83,0x5f82, 0x5f7f,0x5f8a,0x5f88,0x5f87,
  0x5f91,0x5f99,0x5f9e,0x5f98, 0x5fa0,0x5fa8,0x5fad,0x5fb7,
  0x5fbc,0x5fd6,0x5ffb,0x5fe4, 0x5ff8,0x5ff1,0x5ff0,0x5fdd,
  0x5fde,0x5fff,0x6021,0x6019, 0x6010,0x6029,0x600e,0x6031,
  0x601b,0x6015,0x602b,0x6026, 0x600f,0x603a,
/* 0x5a41(i:4750) */
  0x605a,0x6041,0x6060,0x605d, 0x606a,0x6077,0x605f,0x604a,
  0x6046,0x604d,0x6063,0x6043, 0x6064,0x606c,0x606b,0x6059,
  0x6085,0x6081,0x6083,0x609a, 0x6084,0x609b,0x608a,0x6096,
  0x6097,0x6092,0x60a7,0x608b, 0x60e1,0x60b8,0x60de,0x60e0,
  0x60d3,0x60bd,0x60c6,0x60b5, 0x60d5,0x60d8,0x6120,0x60f2,
  0x6115,0x6106,0x60f6,0x60f7, 0x6100,0x60f4,0x60fa,0x6103,
  0x6121,0x60fb,0x60f1,0x610d, 0x610e,0x6111,0x6147,0x614d,
  0x6137,0x6128,0x6127,0x613e, 0x614a,0x6130,0x613c,0x612c,
  0x6134,0x6165,0x615d,0x613d, 0x6142,0x6144,0x6173,0x6187,
  0x6177,0x6158,0x6159,0x615a, 0x616b,0x6174,0x616f,0x6171,
  0x615f,0x6153,0x6175,0x6198, 0x6199,0x6196,0x61ac,0x6194,
  0x618a,0x6191,0x61ab,0x61ae, 0x61cc,0x61ca,0x61c9,0x61c8,
  0x61c3,0x61c6,0x61ba,0x61cb, 0x7f79,0x61cd,0x61e6,0x61e3,
  0x61f4,0x61f7,0x61f6,0x61fd, 0x61fa,0x61ff,0x61fc,0x61fe,
  0x6200,0x6208,0x6209,0x620d, 0x6213,0x6214,0x621b,0x621e,
  0x6221,0x622a,0x622e,0x6230, 0x6232,0x6233,0x6241,0x624e,
  0x625e,0x6263,0x625b,0x6260, 0x6268,0x627c,0x6282,0x6289,
  0x6292,0x627e,0x6293,0x6296, 0x6283,0x6294,0x62d7,0x62d1,
  0x62bb,0x62cf,0x62ac,0x62c6, 0x62c8,0x62dc,0x62d4,0x62ca,
  0x62c2,0x62a6,0x62c7,0x629b, 0x62c9,0x630c,0x62ee,0x62f1,
  0x6327,0x6302,0x6308,0x62ef, 0x62f5,0x62ff,0x6350,0x634d,
  0x633e,0x634f,0x6396,0x638e, 0x6380,0x63ab,0x6376,0x63a3,
  0x638f,0x6389,0x639f,0x636b, 0x6369,0x63b5,0x63be,0x63e9,
  0x63c0,0x63c6,0x63f5,0x63e3, 0x63c9,0x63d2,
/* 0x5b41(i:4940) */
  0x63f6,0x63c4,0x6434,0x6406, 0x6413,0x6426,0x6436,0x641c,
  0x6417,0x6428,0x640f,0x6416, 0x644e,0x6467,0x646f,0x6460,
  0x6476,0x64b9,0x649d,0x64ce, 0x6495,0x64bb,0x6493,0x64a5,
  0x64a9,0x6488,0x64bc,0x64da, 0x64d2,0x64c5,0x64c7,0x64d4,
  0x64d8,0x64c2,0x64f1,0x64e7, 0x64e0,0x64e1,0x64e3,0x64ef,
  0x64f4,0x64f6,0x64f2,0x64fa, 0x6500,0x64fd,0x6518,0x651c,
  0x651d,0x6505,0x6524,0x6523, 0x652b,0x652c,0x6534,0x6535,
  0x6537,0x6536,0x6538,0x754b, 0x6548,0x654e,0x6556,0x654d,
  0x6558,0x6555,0x655d,0x6572, 0x6578,0x6582,0x6583,0x8b8a,
  0x659b,0x659f,0x65ab,0x65b7, 0x65c3,0x65c6,0x65c1,0x65c4,
  0x65cc,0x65d2,0x65d9,0x65e1, 0x65e0,0x65f1,0x6600,0x6615,
  0x6602,0x6772,0x6603,0x65fb, 0x6609,0x663f,0x6635,0x662e,
  0x661e,0x6634,0x661c,0x6624, 0x6644,0x6649,0x6665,0x6657,
  0x665e,0x6664,0x6659,0x6662, 0x665d,0xfa12,0x6673,0x6670,
  0x6683,0x6688,0x6684,0x6699, 0x6698,0x66a0,0x669d,0x66b2,
  0x66c4,0x66c1,0x66bf,0x66c9, 0x66be,0x66bc,0x66b8,0x66d6,
  0x66da,0x66e6,0x66e9,0x66f0, 0x66f5,0x66f7,0x66fa,0x670e,
  0xf929,0x6716,0x671e,0x7e22, 0x6726,0x6727,0x9738,0x672e,
  0x673f,0x6736,0x6737,0x6738, 0x6746,0x675e,0x6759,0x6766,
  0x6764,0x6789,0x6785,0x6770, 0x67a9,0x676a,0x678b,0x6773,
  0x67a6,0x67a1,0x67bb,0x67b7, 0x67ef,0x67b4,0x67ec,0x67e9,
  0x67b8,0x67e7,0x67e4,0x6852, 0x67dd,0x67e2,0x67ee,0x67c0,
  0x67ce,0x67b9,0x6801,0x67c6, 0x681e,0x6846,0x684d,0x6840,
  0x6844,0x6832,0x684e,0x6863, 0x6859,0x688d,
/* 0x5c41(i:5130) */
  0x6877,0x687f,0x689f,0x687e, 0x688f,0x68ad,0x6894,0x6883,
  0x68bc,0x68b9,0x6874,0x68b5, 0x68ba,0x690f,0x6901,0x68ca,
  0x6908,0x68d8,0x6926,0x68e1, 0x690c,0x68cd,0x68d4,0x68e7,
  0x68d5,0x6912,0x68ef,0x6904, 0x68e3,0x68e0,0x68cf,0x68c6,
  0x6922,0x692a,0x6921,0x6923, 0x6928,0xfa13,0x6979,0x6977,
  0x6936,0x6978,0x6954,0x696a, 0x6974,0x6968,0x693d,0x6959,
  0x6930,0x695e,0x695d,0x697e, 0x6981,0x69b2,0x69bf,0xfa14,
  0x6998,0x69c1,0x69d3,0x69be, 0x69ce,0x5be8,0x69ca,0x69b1,
  0x69dd,0x69bb,0x69c3,0x69a0, 0x699c,0x6995,0x69de,0x6a2e,
  0x69e8,0x6a02,0x6a1b,0x69ff, 0x69f9,0x69f2,0x69e7,0x69e2,
  0x6a1e,0x69ed,0x6a14,0x69eb, 0x6a0a,0x6a22,0x6a12,0x6a23,
  0x6a13,0x6a30,0x6a6b,0x6a44, 0x6a0c,0x6aa0,0x6a36,0x6a78,
  0x6a47,0x6a62,0x6a59,0x6a66, 0x6a48,0x6a46,0x6a38,0x6a72,
  0x6a73,0x6a90,0x6a8d,0x6a84, 0x6aa2,0x6aa3,0x6a7e,0x6a97,
  0x6aac,0x6aaa,0x6abb,0x6ac2, 0x6ab8,0x6ab3,0x6ac1,0x6ade,
  0x6ae2,0x6ad1,0x6ada,0x6ae4, 0x8616,0x8617,0x6aea,0x6b05,
  0x6b0a,0x6afa,0x6b12,0x6b16, 0x6b1f,0x6b38,0x6b37,0x6b39,
  0x76dc,0x98ee,0x6b47,0x6b43, 0x6b49,0x6b50,0x6b59,0x6b54,
  0x6b5b,0x6b5f,0x6b61,0x6b78, 0x6b79,0x6b7f,0x6b80,0x6b84,
  0x6b83,0x6b8d,0x6b98,0x6b95, 0x6b9e,0x6ba4,0x6baa,0x6bab,
  0x6baf,0x6bb1,0x6bb2,0x6bb3, 0x6bb7,0x6bbc,0x6bc6,0x6bcb,
  0x6bd3,0x6bd6,0x6bdf,0x6bec, 0x6beb,0x6bf3,0x6bef,0x6c08,
  0x6c13,0x6c14,0x6c1b,0x6c24, 0x6c23,0x6c3f,0x6c5e,0x6c55,
  0x6c5c,0x6c62,0x6c82,0x6c8d, 0x6c86,0x6c6f,
/* 0x5d41(i:5320) */
  0x6c9a,0x6c81,0x6c9b,0x6c7e, 0x6c68,0x6c73,0x6c92,0x6c90,
  0x6cc4,0x6cf1,0x6cbd,0x6cc5, 0x6cae,0x6cda,0x6cdd,0x6cb1,
  0x6cbe,0x6cba,0x6cdb,0x6cef, 0x6cd9,0x6cea,0x6d1f,0x6d04,
  0x6d36,0x6d2b,0x6d3d,0x6d33, 0x6d12,0x6d0c,0x6d63,0x6d87,
  0x6d93,0x6d6f,0x6d64,0x6d5a, 0x6d79,0x6d59,0x6d8e,0x6d95,
  0x6d9b,0x6d85,0x6d96,0x6df9, 0x6e0a,0x6e2e,0x6db5,0x6de6,
  0x6dc7,0x6dac,0x6db8,0x6dcf, 0x6dc6,0x6dec,0x6dde,0x6dcc,
  0x6de8,0x6df8,0x6dd2,0x6dc5, 0x6dfa,0x6dd9,0x6df2,0x6dfc,
  0x6de4,0x6dd5,0x6dea,0x6dee, 0x6e2d,0x6e6e,0x6e19,0x6e72,
  0x6e5f,0x6e39,0x6e3e,0x6e23, 0x6e6b,0x6e5c,0x6e2b,0x6e76,
  0x6e4d,0x6e1f,0x6e27,0x6e43, 0x6e3c,0x6e3a,0x6e4e,0x6e24,
  0x6e1d,0x6e38,0x6e82,0x6eaa, 0x6e98,0x6eb7,0x6ebd,0x6eaf,
  0x6ec4,0x6eb2,0x6ed4,0x6ed5, 0x6e8f,0x6ebf,0x6ec2,0x6e9f,
  0x6f41,0x6f45,0x6eec,0x6ef8, 0x6efe,0x6f3f,0x6ef2,0x6f31,
  0x6eef,0x6f32,0x6ecc,0x6eff, 0x6f3e,0x6f13,0x6ef7,0x6f86,
  0x6f7a,0x6f78,0x6f80,0x6f6f, 0x6f5b,0x6f6d,0x6f74,0x6f82,
  0x6f88,0x6f7c,0x6f58,0x6fc6, 0x6f8e,0x6f91,0x6f66,0x6fb3,
  0x6fa3,0x6fb5,0x6fa1,0x6fb9, 0x6fdb,0x6faa,0x6fc2,0x6fdf,
  0x6fd5,0x6fec,0x6fd8,0x6fd4, 0x6ff5,0x6fee,0x7005,0x7007,
  0x7009,0x700b,0x6ffa,0x7011, 0x7001,0x700f,0x701b,0x701a,
  0x701f,0x6ff3,0x7028,0x7018, 0x7030,0x703e,0x7032,0x7051,
  0x7063,0x7085,0x7099,0x70af, 0x70ab,0x70ac,0x70b8,0x70ae,
  0x70df,0x70cb,0x70d9,0x7109, 0x710f,0x7104,0x70f1,0x70fd,
  0x711c,0x7119,0x715c,0x7146, 0x7147,0x7166,
/* 0x5e41(i:5510) */
  0x7162,0x714c,0x7156,0x716c, 0x7188,0x718f,0x7184,0x7195,
  0xfa15,0x71ac,0x71c1,0x71b9, 0x71be,0x71d2,0x71e7,0x71c9,
  0x71d4,0x71d7,0x71ce,0x71f5, 0x71e0,0x71ec,0x71fb,0x71fc,
  0x71f9,0x71fe,0x71ff,0x720d, 0x7210,0x7228,0x722d,0x722c,
  0x7230,0x7232,0x723b,0x723c, 0x723f,0x7240,0x7246,0x724b,
  0x7258,0x7274,0x727e,0x7281, 0x7287,0x7282,0x7292,0x7296,
  0x72a2,0x72a7,0x72b1,0x72b2, 0x72be,0x72c3,0x72c6,0x72c4,
  0x72b9,0x72ce,0x72d2,0x72e2, 0x72e0,0x72e1,0x72f9,0x72f7,
  0x7317,0x730a,0x731c,0x7316, 0x731d,0x7324,0x7334,0x7329,
  0x732f,0xfa16,0x7325,0x733e, 0x734f,0x734e,0x7357,0x9ed8,
  0x736a,0x7368,0x7370,0x7377, 0x7378,0x7375,0x737b,0x73c8,
  0x73bd,0x73b3,0x73ce,0x73bb, 0x73c0,0x73c9,0x73d6,0x73e5,
  0x73e3,0x73d2,0x73ee,0x73f1, 0x73de,0x73f8,0x7407,0x73f5,
  0x7405,0x7426,0x742a,0x7425, 0x7429,0x742e,0x7432,0x743a,
  0x7455,0x743f,0x745f,0x7459, 0x7441,0x745c,0x7469,0x7470,
  0x7463,0x746a,0x7464,0x7462, 0x7489,0x746f,0x747e,0x749f,
  0x749e,0x74a2,0x74a7,0x74ca, 0x74cf,0x74d4,0x74e0,0x74e3,
  0x74e7,0x74e9,0x74ee,0x74f0, 0x74f2,0x74f1,0x74f7,0x74f8,
  0x7501,0x7504,0x7503,0x7505, 0x750d,0x750c,0x750e,0x7513,
  0x751e,0x7526,0x752c,0x753c, 0x7544,0x754d,0x754a,0x7549,
  0x7546,0x755b,0x755a,0x7564, 0x7567,0x756b,0x756f,0x7574,
  0x756d,0x7578,0x7576,0x7582, 0x7586,0x7587,0x758a,0x7589,
  0x7594,0x759a,0x759d,0x75a5, 0x75a3,0x75c2,0x75b3,0x75c3,
  0x75b5,0x75bd,0x75b8,0x75bc, 0x75b1,0x75cd,
/* 0x5f41(i:5700) */
  0x75ca,0x75d2,0x75d9,0x75e3, 0x75de,0x75fe,0x75ff,0x75fc,
  0x7601,0x75f0,0x75fa,0x75f2, 0x75f3,0x760b,0x7609,0x761f,
  0x7627,0x7620,0x7621,0x7622, 0x7624,0x7634,0x7630,0x763b,
  0x7647,0x7648,0x7658,0x7646, 0x765c,0x7661,0x7662,0x7668,
  0x7669,0x7667,0x766a,0x766c, 0x7670,0x7672,0x7676,0x767c,
  0x7682,0x7680,0x7683,0x7688, 0x768b,0x7699,0x769a,0x769c,
  0x769e,0x769b,0x76a6,0x76b0, 0x76b4,0x76b8,0x76b9,0x76ba,
  0x76c2,0xfa17,0x76cd,0x76d6, 0x76d2,0x76de,0x76e1,0x76e5,
  0x76ea,0x862f,0x76fb,0x7708, 0x7707,0x7704,0x7724,0x7729,
  0x7725,0x7726,0x771b,0x7737, 0x7738,0x7746,0x7747,0x775a,
  0x7768,0x776b,0x775b,0x7765, 0x777f,0x777e,0x7779,0x778e,
  0x778b,0x7791,0x77a0,0x779e, 0x77b0,0x77b6,0x77b9,0x77bf,
  0x77bc,0x77bd,0x77bb,0x77c7, 0x77cd,0x77da,0x77dc,0x77e3,
  0x77ee,0x52af,0x77fc,0x780c, 0x7812,0x7821,0x783f,0x7820,
  0x7845,0x784e,0x7864,0x7874, 0x788e,0x787a,0x7886,0x789a,
  0x787c,0x788c,0x78a3,0x78b5, 0x78aa,0x78af,0x78d1,0x78c6,
  0x78cb,0x78d4,0x78be,0x78bc, 0x78c5,0x78ca,0x78ec,0x78e7,
  0x78da,0x78fd,0x78f4,0x7907, 0x7911,0x7919,0x792c,0x792b,
  0x7930,0xfa18,0x7940,0x7960, 0xfa19,0x795f,0x795a,0x7955,
  0xfa1a,0x797f,0x798a,0x7994, 0xfa1b,0x799d,0x799b,0x79aa,
  0x79b3,0x79ba,0x79c9,0x79d5, 0x79e7,0x79ec,0x79e3,0x7a08,
  0x7a0d,0x7a18,0x7a19,0x7a1f, 0x7a31,0x7a3e,0x7a37,0x7a3b,
  0x7a43,0x7a57,0x7a49,0x7a62, 0x7a61,0x7a69,0x9f9d,0x7a70,
  0x7a79,0x7a7d,0x7a88,0x7a95, 0x7a98,0x7a96,
/* 0x6041(i:5890) */
  0x7a97,0x7aa9,0x7ab0,0x7ab6, 0x9083,0x7ac3,0x7abf,0x7ac5,
  0x7ac4,0x7ac7,0x7aca,0x7acd, 0x7acf,0x7ad2,0x7ad1,0x7ad5,
  0x7ad3,0x7ad9,0x7ada,0x7add, 0x7ae1,0x7ae2,0x7ae6,0x7ae7,
  0xfa1c,0x7aeb,0x7aed,0x7af0, 0x7af8,0x7b02,0x7b0f,0x7b0b,
  0x7b0a,0x7b06,0x7b33,0x7b36, 0x7b19,0x7b1e,0x7b35,0x7b28,
  0x7b50,0x7b4d,0x7b4c,0x7b45, 0x7b5d,0x7b75,0x7b7a,0x7b74,
  0x7b70,0x7b71,0x7b6e,0x7b9d, 0x7b98,0x7b9f,0x7b8d,0x7b9c,
  0x7b9a,0x7b92,0x7b8f,0x7b99, 0x7bcf,0x7bcb,0x7bcc,0x7bb4,
  0x7bc6,0x7b9e,0x7bdd,0x7be9, 0x7be6,0x7bf7,0x7be5,0x7c14,
  0x7c00,0x7c13,0x7c07,0x7bf3, 0x7c0d,0x7bf6,0x7c23,0x7c27,
  0x7c2a,0x7c1f,0x7c37,0x7c2b, 0x7c3d,0x7c40,0x7c4c,0x7c43,
  0x7c56,0x7c50,0x7c58,0x7c5f, 0x7c65,0x7c6c,0x7c75,0x7c83,
  0x7c90,0x7ca4,0x7ca2,0x7cab, 0x7ca1,0x7cad,0x7ca8,0x7cb3,
  0x7cb2,0x7cb1,0x7cae,0x7cb9, 0xfa1d,0x7cbd,0x7cc5,0x7cc2,
  0x7cd2,0x7ce2,0x7cd8,0x7cdc, 0x7cef,0x7cf2,0x7cf4,0x7cf6,
  0x7d06,0x7d02,0x7d1c,0x7d15, 0x7d0a,0x7d45,0x7d4b,0x7d2e,
  0x7d32,0x7d3f,0x7d35,0x7d48, 0x7d46,0x7d5c,0x7d73,0x7d56,
  0x7d4e,0x7d68,0x7d6e,0x7d4f, 0x7d63,0x7d93,0x7d89,0x7d5b,
  0x7dae,0x7da3,0x7db5,0x7db7, 0x7dc7,0x7dbd,0x7dab,0x7da2,
  0x7daf,0x7da0,0x7db8,0x7d9f, 0x7db0,0x7dd5,0x7dd8,0x7ddd,
  0x7dd6,0x7de4,0x7dde,0x7dfb, 0x7e0b,0x7df2,0x7de1,0x7ddc,
  0x7e05,0x7e0a,0x7e21,0x7e12, 0x7e1f,0x7e09,0x7e3a,0x7e46,
  0x7e66,0x7e31,0x7e3d,0x7e35, 0x7e3b,0x7e39,0x7e43,0x7e37,
  0x7e32,0x7e5d,0x7e56,0x7e5e, 0x7e52,0x7e59,
/* 0x6141(i:6080) */
  0x7e5a,0x7e67,0x7e79,0x7e6a, 0x7e69,0x7e7c,0x7e7b,0x7e7d,
  0x8fae,0x7e7f,0x7e83,0x7e89, 0x7e8e,0x7e8c,0x7e92,0x7e93,
  0x7e94,0x7e96,0x7e9b,0x7f38, 0x7f3a,0x7f45,0x7f47,0x7f4c,
  0x7f4e,0x7f51,0x7f55,0x7f54, 0x7f58,0x7f5f,0x7f60,0x7f68,
  0x7f67,0x7f69,0x7f78,0x7f82, 0x7f86,0x7f83,0x7f87,0x7f88,
  0x7f8c,0x7f94,0x7f9e,0x7f9d, 0x7f9a,0x7fa1,0x7fa3,0x7faf,
  0x7fae,0x7fb2,0x7fb9,0x7fb6, 0x7fb8,0x8b71,0xfa1e,0x7fc5,
  0x7fc6,0x7fca,0x7fd5,0x7fe1, 0x7fe6,0x7fe9,0x7ff3,0x7ff9,
  0x8004,0x800b,0x8012,0x8019, 0x801c,0x8021,0x8028,0x803f,
  0x803b,0x804a,0x8046,0x8052, 0x8058,0x805f,0x8062,0x8068,
  0x8073,0x8072,0x8070,0x8076, 0x8079,0x807d,0x807f,0x8084,
  0x8085,0x8093,0x809a,0x80ad, 0x5190,0x80ac,0x80db,0x80e5,
  0x80d9,0x80dd,0x80c4,0x80da, 0x8109,0x80ef,0x80f1,0x811b,
  0x8123,0x812f,0x814b,0x8146, 0x813e,0x8153,0x8151,0x80fc,
  0x8171,0x816e,0x8165,0x815f, 0x8166,0x8174,0x8183,0x8188,
  0x818a,0x8180,0x8182,0x81a0, 0x8195,0x81a3,0x8193,0x81b5,
  0x81a4,0x81a9,0x81b8,0x81b0, 0x81c8,0x81be,0x81bd,0x81c0,
  0x81c2,0x81ba,0x81c9,0x81cd, 0x81d1,0x81d8,0x81d9,0x81da,
  0x81df,0x81e0,0x81fa,0x81fb, 0x81fe,0x8201,0x8202,0x8205,
  0x820d,0x8210,0x8212,0x8216, 0x8229,0x822b,0x822e,0x8238,
  0x8233,0x8240,0x8259,0x825a, 0x825d,0x825f,0x8264,0x8262,
  0x8268,0x826a,0x826b,0x8271, 0x8277,0x827e,0x828d,0x8292,
  0x82ab,0x829f,0x82bb,0x82ac, 0x82e1,0x82e3,0x82df,0x8301,
  0x82d2,0x82f4,0x82f3,0x8303, 0x82fb,0x82f9,
/* 0x6241(i:6270) */
  0x82de,0x8306,0x82dc,0x82fa, 0x8309,0x82d9,0x8335,0x8362,
  0x8334,0x8316,0x8331,0x8340, 0x8339,0x8350,0x8345,0x832f,
  0x832b,0x8318,0x839a,0x83aa, 0x839f,0x83a2,0x8396,0x8323,
  0x838e,0x8375,0x837f,0x838a, 0x837c,0x83b5,0x8373,0x8393,
  0x83a0,0x8385,0x8389,0x83a8, 0x83f4,0x8413,0x83c7,0x83ce,
  0x83f7,0x83fd,0x8403,0x83d8, 0x840b,0x83c1,0x8407,0x83e0,
  0x83f2,0x840d,0x8420,0x83f6, 0x83bd,0x83fb,0x842a,0x8462,
  0x843c,0x8484,0x8477,0x846b, 0x8479,0x8448,0x846e,0x8482,
  0x8469,0x8446,0x846f,0x8438, 0x8435,0x84ca,0x84b9,0x84bf,
  0x849f,0x84b4,0x84cd,0x84bb, 0x84da,0x84d0,0x84c1,0x84ad,
  0x84c6,0x84d6,0x84a1,0x84d9, 0x84ff,0x84f4,0x8517,0x8518,
  0x852c,0x851f,0x8515,0x8514, 0x8506,0x8553,0x855a,0x8540,
  0x8559,0x8563,0x8558,0x8548, 0x8541,0x854a,0x854b,0x856b,
  0x8555,0x8580,0x85a4,0x8588, 0x8591,0x858a,0x85a8,0x856d,
  0x8594,0x859b,0x85ae,0x8587, 0x859c,0x8577,0x857e,0x8590,
  0xfa1f,0x820a,0x85b0,0x85c9, 0x85ba,0x85cf,0x85b9,0x85d0,
  0x85d5,0x85dd,0x85e5,0x85dc, 0x85f9,0x860a,0x8613,0x860b,
  0x85fe,0x8622,0x861a,0x8630, 0x863f,0xfa20,0x864d,0x4e55,
  0x8655,0x865f,0x8667,0x8671, 0x8693,0x86a3,0x86a9,0x868b,
  0x86aa,0x868c,0x86b6,0x86af, 0x86c4,0x86c6,0x86b0,0x86c9,
  0x86ce,0xfa21,0x86ab,0x86d4, 0x86de,0x86e9,0x86ec,0x86df,
  0x86db,0x8712,0x8706,0x8708, 0x8700,0x8703,0x86fb,0x8711,
  0x8709,0x870d,0x86f9,0x870a, 0x8734,0x873f,0x873b,0x8725,
  0x8729,0x871a,0x875f,0x8778, 0x874c,0x874e,
/* 0x6341(i:6460) */
  0x8774,0x8757,0x8768,0x8782, 0x876a,0x8760,0x876e,0x8759,
  0x8753,0x8763,0x877f,0x87a2, 0x87c6,0x879f,0x87af,0x87cb,
  0x87bd,0x87c0,0x87d0,0x96d6, 0x87ab,0x87c4,0x87b3,0x87d2,
  0x87bb,0x87ef,0x87f2,0x87e0, 0x880e,0x8807,0x880f,0x8816,
  0x880d,0x87fe,0x87f6,0x87f7, 0x8811,0x8815,0x8822,0x8821,
  0x8827,0x8831,0x8836,0x8839, 0x883b,0x8842,0x8844,0x884d,
  0x8852,0x8859,0x885e,0x8862, 0x886b,0x8881,0x887e,0x8875,
  0x887d,0x8872,0x8882,0x889e, 0x8897,0x8892,0x88ae,0x8899,
  0x88a2,0x888d,0x88a4,0x88bf, 0x88b5,0x88b1,0x88c3,0x88c4,
  0x88d4,0x88d8,0x88d9,0x88dd, 0x88f9,0x8902,0x88fc,0x88f5,
  0x88e8,0x88f2,0x8904,0x890c, 0x892a,0x891d,0x890a,0x8913,
  0x891e,0x8925,0x892b,0x8941, 0x893b,0x8936,0x8943,0x8938,
  0x894d,0x894c,0x8960,0x895e, 0x8966,0x896a,0x8964,0x896d,
  0x896f,0x8974,0x8977,0x897e, 0x8983,0x8988,0x898a,0x8993,
  0x8998,0x89a1,0x89a9,0x89a6, 0x89ac,0x89af,0x89b2,0x89ba,
  0x89bf,0x89bd,0x89c0,0x89da, 0x89dd,0x89e7,0x89f4,0x89f8,
  0x8a03,0x8a16,0x8a10,0x8a0c, 0x8a12,0x8a1b,0x8a1d,0x8a25,
  0x8a36,0x8a41,0x8a37,0x8a5b, 0x8a52,0x8a46,0x8a48,0x8a7c,
  0x8a6d,0x8a6c,0x8a62,0x8a79, 0x8a85,0x8a82,0x8a84,0x8aa8,
  0x8aa1,0x8a91,0x8aa5,0x8aa6, 0x8a9a,0x8aa3,0x8aa7,0x8acc,
  0x8abe,0x8acd,0x8ac2,0x8ada, 0x8af3,0x8ae7,0x8ae4,0x8af1,
  0x8b14,0x8ae0,0x8ae2,0x8ae1, 0x8adf,0xfa22,0x8af6,0x8af7,
  0x8ade,0x8adb,0x8b0c,0x8b07, 0x8b1a,0x8b16,0x8b10,0x8b17,
  0x8b20,0x8b33,0x8b41,0x97ab, 0x8b26,0x8b2b,
/* 0x6441(i:6650) */
  0x0000,0x8b4c,0x8b4f,0x8b4e, 0x8b53,0x8b49,0x8b56,0x8b5b,
  0x8b5a,0x8b74,0x8b6b,0x8b5f, 0x8b6c,0x8b6f,0x8b7d,0x8b7f,
  0x8b80,0x8b8c,0x8b8e,0x8b99, 0x8b92,0x8b93,0x8b96,0x8b9a,
  0x8c3a,0x8c41,0x8c3f,0x8c48, 0x8c4c,0x8c4e,0x8c50,0x8c55,
  0x8c62,0x8c6c,0x8c78,0x8c7a, 0x8c7c,0x8c82,0x8c89,0x8c85,
  0x8c8a,0x8c8d,0x8c8e,0x8c98, 0x8c94,0x621d,0x8cad,0x8caa,
  0x8cae,0x8cbd,0x8cb2,0x8cb3, 0x8cc1,0x8cb6,0x8cc8,0x8cce,
  0x8ccd,0x8ce3,0x8cda,0x8cf0, 0x8cf4,0x8cfd,0x8cfa,0x8cfb,
  0x8d07,0x8d0a,0x8d0f,0x8d0d, 0x8d12,0x8d10,0x8d13,0x8d14,
  0x8d16,0x8d67,0x8d6d,0x8d71, 0x8d76,0xfa23,0x8d81,0x8dc2,
  0x8dbe,0x8dba,0x8dcf,0x8dda, 0x8dd6,0x8dcc,0x8ddb,0x8dcb,
  0x8dea,0x8deb,0x8ddf,0x8de3, 0x8dfc,0x8e08,0x8dff,0x8e09,
  0x8e1d,0x8e1e,0x8e10,0x8e1f, 0x8e42,0x8e35,0x8e30,0x8e34,
  0x8e4a,0x8e47,0x8e49,0x8e4c, 0x8e50,0x8e48,0x8e59,0x8e64,
  0x8e60,0x8e55,0x8e63,0x8e76, 0x8e72,0x8e87,0x8e7c,0x8e81,
  0x8e85,0x8e84,0x8e8b,0x8e8a, 0x8e93,0x8e91,0x8e94,0x8e99,
  0x8ea1,0x8eaa,0x8eb1,0x8ebe, 0x8ec6,0x8ec5,0x8ec8,0x8ecb,
  0x8ecf,0x8edb,0x8ee3,0x8efc, 0x8efb,0x8eeb,0x8efe,0x8f0a,
  0x8f0c,0x8f05,0x8f15,0x8f12, 0x8f13,0x8f1c,0x8f19,0x8f1f,
  0x8f26,0x8f33,0x8f3b,0x8f39, 0x8f45,0x8f42,0x8f3e,0x8f49,
  0x8f46,0x8f4c,0x8f4e,0x8f57, 0x8f5c,0x8f62,0x8f63,0x8f64,
  0x8f9c,0x8f9f,0x8fa3,0x8fa8, 0x8fa7,0x8fad,0x8faf,0x8fb7,
  0xfa24,0x8fda,0x8fe5,0x8fe2, 0x8fef,0x8fe9,0x8ff4,0x9005,
  0x8ff9,0x8ff8,0x9011,0x9015, 0x900e,0x9021,
/* 0x6541(i:6840) */
  0x900d,0x901e,0x9016,0x900b, 0x9027,0x9036,0x9039,0x904f,
  0xfa25,0x9050,0x9051,0x9052, 0x9049,0x903e,0x9056,0x9058,
  0x905e,0x9068,0x9067,0x906f, 0x9076,0x96a8,0x9072,0x9082,
  0x907d,0x9089,0x9080,0x908f, 0x6248,0x90af,0x90b1,0x90b5,
  0x90e2,0x90e4,0x90db,0x90de, 0x9102,0xfa26,0x9115,0x9112,
  0x9119,0x9132,0x9127,0x9130, 0x914a,0x9156,0x9158,0x9163,
  0x9165,0x9169,0x9173,0x9172, 0x918b,0x9189,0x9182,0x91a2,
  0x91ab,0x91af,0x91aa,0x91b5, 0x91b4,0x91ba,0x91c0,0x91c1,
  0x91cb,0x91d0,0x91da,0x91db, 0x91d7,0x91de,0x91d6,0x91df,
  0x91e1,0x91ed,0x91f5,0x91ee, 0x91e4,0x91f6,0x91e5,0x9206,
  0x921e,0x91ff,0x9210,0x9214, 0x920a,0x922c,0x9215,0x9229,
  0x9257,0x9245,0x923a,0x9249, 0x9264,0x9240,0x923c,0x9248,
  0x924e,0x9250,0x9259,0x923f, 0x9251,0x9239,0x924b,0x9267,
  0x925a,0x929c,0x92a7,0x9277, 0x9278,0x9296,0x9293,0x929b,
  0x9295,0x92e9,0x92cf,0x92e7, 0x92d7,0x92d9,0x92d0,0xfa27,
  0x92d5,0x92b9,0x92b7,0x92e0, 0x92d3,0x933a,0x9335,0x930f,
  0x9325,0x92fa,0x9321,0x9344, 0x92fb,0xfa28,0x9319,0x931e,
  0x92ff,0x9322,0x931a,0x931d, 0x9323,0x9302,0x933b,0x9370,
  0x9360,0x937c,0x936e,0x9356, 0x9357,0x93b9,0x93b0,0x93a4,
  0x93ad,0x9394,0x93c8,0x93d6, 0x93c6,0x93d7,0x93e8,0x93e5,
  0x93d8,0x93c3,0x93dd,0x93de, 0x93d0,0x93e4,0x941a,0x93f8,
  0x9414,0x9413,0x9421,0x9403, 0x9407,0x9436,0x942b,0x9431,
  0x943a,0x9441,0x9452,0x9445, 0x9444,0x9448,0x945b,0x945a,
  0x9460,0x9462,0x945e,0x946a, 0x9475,0x9470,
/* 0x6641(i:7030) */
  0x9477,0x947f,0x947d,0x947c, 0x947e,0x9481,0x9582,0x9587,
  0x958a,0x9592,0x9594,0x9596, 0x9598,0x9599,0x95a0,0x95a8,
  0x95a7,0x95ad,0x95bc,0x95bb, 0x95b9,0x95be,0x95ca,0x6ff6,
  0x95c3,0x95cd,0x95cc,0x95d5, 0x95d4,0x95d6,0x95dc,0x95e1,
  0x95e5,0x95e2,0x9621,0x9628, 0x962e,0x962f,0x9642,0x964f,
  0x964c,0x964b,0x965c,0x965d, 0x965f,0x9666,0x9677,0x9672,
  0x966c,0x968d,0x968b,0xf9dc, 0x9698,0x9695,0x9697,0xfa29,
  0x969d,0x96a7,0x96aa,0x96b1, 0x96b2,0x96b0,0x96af,0x96b4,
  0x96b6,0x96b8,0x96b9,0x96ce, 0x96cb,0x96d5,0x96dc,0x96d9,
  0x96f9,0x9704,0x9706,0x9708, 0x9719,0x970d,0x9713,0x970e,
  0x9711,0x970f,0x9716,0x9724, 0x972a,0x9730,0x9733,0x9739,
  0x973b,0x973d,0x973e,0x9746, 0x9744,0x9743,0x9748,0x9742,
  0x9749,0x974d,0x974f,0x9751, 0x9755,0x975c,0x9760,0x9764,
  0x9766,0x9768,0x976d,0x9779, 0x9785,0x977c,0x9781,0x977a,
  0x978b,0x978f,0x9790,0x979c, 0x97a8,0x97a6,0x97a3,0x97b3,
  0x97b4,0x97c3,0x97c6,0x97c8, 0x97cb,0x97dc,0x97ed,0x97f2,
  0x7adf,0x97f5,0x980f,0x981a, 0x9824,0x9821,0x9837,0x983d,
  0x984f,0x984b,0x9857,0x9865, 0x986b,0x986f,0x9870,0x9871,
  0x9874,0x9873,0x98aa,0x98af, 0x98b1,0x98b6,0x98c4,0x98c3,
  0x98c6,0x98dc,0x98ed,0x98e9, 0xfa2a,0x98eb,0xfa2b,0x9903,
  0x991d,0x9912,0x9914,0x9918, 0x9927,0xfa2c,0x9921,0x991e,
  0x9924,0x9920,0x992c,0x992e, 0x993d,0x993e,0x9942,0x9949,
  0x9945,0x9950,0x994b,0x9951, 0x994c,0x9955,0x9997,0x9998,
  0x999e,0x99a5,0x99ad,0x99ae, 0x99bc,0x99df,
/* 0x6741(i:7220) */
  0x99db,0x99dd,0x99d8,0x99d1, 0x99ed,0x99ee,0x99e2,0x99f1,
  0x99f2,0x99fb,0x99f8,0x9a01, 0x9a0f,0x9a05,0x9a19,0x9a2b,
  0x9a37,0x9a40,0x9a45,0x9a42, 0x9a43,0x9a3e,0x9a55,0x9a4d,
  0x9a4e,0x9a5b,0x9a57,0x9a5f, 0x9a62,0x9a69,0x9a65,0x9a64,
  0x9a6a,0x9a6b,0x9aad,0x9ab0, 0x9abc,0x9ac0,0x9acf,0x9ad3,
  0x9ad4,0x9ad1,0x9ad9,0x9adc, 0x9ade,0x9adf,0x9ae2,0x9ae3,
  0x9ae6,0x9aef,0x9aeb,0x9aee, 0x9af4,0x9af1,0x9af7,0x9afb,
  0x9b06,0x9b18,0x9b1a,0x9b1f, 0x9b22,0x9b23,0x9b25,0x9b27,
  0x9b28,0x9b29,0x9b2a,0x9b2e, 0x9b2f,0x9b31,0x9b32,0x9b3b,
  0x9b44,0x9b43,0x9b4d,0x9b4e, 0x9b51,0x9b58,0x9b75,0x9b74,
  0x9b72,0x9b93,0x9b8f,0x9b83, 0x9b91,0x9b96,0x9b97,0x9b9f,
  0x9ba0,0x9ba8,0x9bb1,0x9bb4, 0x9bc0,0x9bca,0x9bbb,0x9bb9,
  0x9bc6,0x9bcf,0x9bd1,0x9bd2, 0x9be3,0x9be2,0x9be4,0x9bd4,
  0x9be1,0x9bf5,0x9bf1,0x9bf2, 0x9c04,0x9c1b,0x9c15,0x9c14,
  0x9c00,0x9c09,0x9c13,0x9c0c, 0x9c06,0x9c08,0x9c12,0x9c0a,
  0x9c2e,0x9c25,0x9c24,0x9c21, 0x9c30,0x9c47,0x9c32,0x9c46,
  0x9c3e,0x9c5a,0x9c60,0x9c67, 0x9c76,0x9c78,0x9ceb,0x9ce7,
  0x9cec,0x9cf0,0x9d09,0x9d03, 0x9d06,0x9d2a,0x9d26,0x9d2c,
  0x9d23,0x9d1f,0x9d15,0x9d12, 0x9d41,0x9d3f,0x9d44,0x9d3e,
  0x9d46,0x9d48,0x9d5d,0x9d5e, 0x9d59,0x9d51,0x9d50,0x9d64,
  0x9d72,0x9d70,0x9d87,0x9d6b, 0x9d6f,0x9d7a,0x9d9a,0x9da4,
  0x9da9,0x9dab,0x9db2,0x9dc4, 0x9dc1,0x9dbb,0x9db8,0x9dba,
  0x9dc6,0x9dcf,0x9dc2,0xfa2d, 0x9dd9,0x9dd3,0x9df8,0x9de6,
  0x9ded,0x9def,0x9dfd,0x9e1a, 0x9e1b,0x9e19,
/* 0x6841(i:7410) */
  0x9e1e,0x9e75,0x9e79,0x9e7d, 0x9e81,0x9e88,0x9e8b,0x9e8c,
  0x9e95,0x9e91,0x9e9d,0x9ea5, 0x9eb8,0x9eaa,0x9ead,0x9ebc,
  0x9ebe,0x9761,0x9ecc,0x9ecf, 0x9ed0,0x9ed1,0x9ed4,0x9edc,
  0x9ede,0x9edd,0x9ee0,0x9ee5, 0x9ee8,0x9eef,0x9ef4,0x9ef6,
  0x9ef7,0x9ef9,0x9efb,0x9efc, 0x9efd,0x9f07,0x9f08,0x76b7,
  0x9f15,0x9f21,0x9f2c,0x9f3e, 0x9f4a,0x9f4e,0x9f4f,0x9f52,
  0x9f54,0x9f63,0x9f5f,0x9f60, 0x9f61,0x9f66,0x9f67,0x9f6c,
  0x9f6a,0x9f77,0x9f72,0x9f76, 0x9f95,0x9f9c,0x9fa0,0x5c2d,
  0x69d9,0x9065,0x7476,0x51dc, 0x7155,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x6941(i:7600) */
  0xe000,0xe001,0xe002,0xe003, 0xe004,0xe005,0xe006,0xe007,
  0xe008,0xe009,0xe00a,0xe00b, 0xe00c,0xe00d,0xe00e,0xe00f,
  0xe010,0xe011,0xe012,0xe013, 0xe014,0xe015,0xe016,0xe017,
  0xe018,0xe019,0xe01a,0xe01b, 0xe01c,0xe01d,0xe01e,0xe01f,
  0xe020,0xe021,0xe022,0xe023, 0xe024,0xe025,0xe026,0xe027,
  0xe028,0xe029,0xe02a,0xe02b, 0xe02c,0xe02d,0xe02e,0xe02f,
  0xe030,0xe031,0xe032,0xe033, 0xe034,0xe035,0xe036,0xe037,
  0xe038,0xe039,0xe03a,0xe03b, 0xe03c,0xe03d,0xe03e,0xe03f,
  0xe040,0xe041,0xe042,0xe043, 0xe044,0xe045,0xe046,0xe047,
  0xe048,0xe049,0xe04a,0xe04b, 0xe04c,0xe04d,0xe04e,0xe04f,
  0xe050,0xe051,0xe052,0xe053, 0xe054,0xe055,0xe056,0xe057,
  0xe058,0xe059,0xe05a,0xe05b, 0xe05c,0xe05d,0xe05e,0xe05f,
  0xe060,0xe061,0xe062,0xe063, 0xe064,0xe065,0xe066,0xe067,
  0xe068,0xe069,0xe06a,0xe06b, 0xe06c,0xe06d,0xe06e,0xe06f,
  0xe070,0xe071,0xe072,0xe073, 0xe074,0xe075,0xe076,0xe077,
  0xe078,0xe079,0xe07a,0xe07b, 0xe07c,0xe07d,0xe07e,0xe07f,
  0xe080,0xe081,0xe082,0xe083, 0xe084,0xe085,0xe086,0xe087,
  0xe088,0xe089,0xe08a,0xe08b, 0xe08c,0xe08d,0xe08e,0xe08f,
  0xe090,0xe091,0xe092,0xe093, 0xe094,0xe095,0xe096,0xe097,
  0xe098,0xe099,0xe09a,0xe09b, 0xe09c,0xe09d,0xe09e,0xe09f,
  0xe0a0,0xe0a1,0xe0a2,0xe0a3, 0xe0a4,0xe0a5,0xe0a6,0xe0a7,
  0xe0a8,0xe0a9,0xe0aa,0xe0ab, 0xe0ac,0xe0ad,0xe0ae,0xe0af,
  0xe0b0,0xe0b1,0xe0b2,0xe0b3, 0xe0b4,0xe0b5,0xe0b6,0xe0b7,
  0xe0b8,0xe0b9,0xe0ba,0xe0bb, 0xe0bc,0xe0bd,
/* 0x6a41(i:7790) */
  0xe0be,0xe0bf,0xe0c0,0xe0c1, 0xe0c2,0xe0c3,0xe0c4,0xe0c5,
  0xe0c6,0xe0c7,0xe0c8,0xe0c9, 0xe0ca,0xe0cb,0xe0cc,0xe0cd,
  0xe0ce,0xe0cf,0xe0d0,0xe0d1, 0xe0d2,0xe0d3,0xe0d4,0xe0d5,
  0xe0d6,0xe0d7,0xe0d8,0xe0d9, 0xe0da,0xe0db,0xe0dc,0xe0dd,
  0xe0de,0xe0df,0xe0e0,0xe0e1, 0xe0e2,0xe0e3,0xe0e4,0xe0e5,
  0xe0e6,0xe0e7,0xe0e8,0xe0e9, 0xe0ea,0xe0eb,0xe0ec,0xe0ed,
  0xe0ee,0xe0ef,0xe0f0,0xe0f1, 0xe0f2,0xe0f3,0xe0f4,0xe0f5,
  0xe0f6,0xe0f7,0xe0f8,0xe0f9, 0xe0fa,0xe0fb,0xe0fc,0xe0fd,
  0xe0fe,0xe0ff,0xe100,0xe101, 0xe102,0xe103,0xe104,0xe105,
  0xe106,0xe107,0xe108,0xe109, 0xe10a,0xe10b,0xe10c,0xe10d,
  0xe10e,0xe10f,0xe110,0xe111, 0xe112,0xe113,0xe114,0xe115,
  0xe116,0xe117,0xe118,0xe119, 0xe11a,0xe11b,0xe11c,0xe11d,
  0xe11e,0xe11f,0xe120,0xe121, 0xe122,0xe123,0xe124,0xe125,
  0xe126,0xe127,0xe128,0xe129, 0xe12a,0xe12b,0xe12c,0xe12d,
  0xe12e,0xe12f,0xe130,0xe131, 0xe132,0xe133,0xe134,0xe135,
  0xe136,0xe137,0xe138,0xe139, 0xe13a,0xe13b,0xe13c,0xe13d,
  0xe13e,0xe13f,0xe140,0xe141, 0xe142,0xe143,0xe144,0xe145,
  0xe146,0xe147,0xe148,0xe149, 0xe14a,0xe14b,0xe14c,0xe14d,
  0xe14e,0xe14f,0xe150,0xe151, 0xe152,0xe153,0xe154,0xe155,
  0xe156,0xe157,0xe158,0xe159, 0xe15a,0xe15b,0xe15c,0xe15d,
  0xe15e,0xe15f,0xe160,0xe161, 0xe162,0xe163,0xe164,0xe165,
  0xe166,0xe167,0xe168,0xe169, 0xe16a,0xe16b,0xe16c,0xe16d,
  0xe16e,0xe16f,0xe170,0xe171, 0xe172,0xe173,0xe174,0xe175,
  0xe176,0xe177,0xe178,0xe179, 0xe17a,0xe17b,
/* 0x6b41(i:7980) */
  0xe17c,0xe17d,0xe17e,0xe17f, 0xe180,0xe181,0xe182,0xe183,
  0xe184,0xe185,0xe186,0xe187, 0xe188,0xe189,0xe18a,0xe18b,
  0xe18c,0xe18d,0xe18e,0xe18f, 0xe190,0xe191,0xe192,0xe193,
  0xe194,0xe195,0xe196,0xe197, 0xe198,0xe199,0xe19a,0xe19b,
  0xe19c,0xe19d,0xe19e,0xe19f, 0xe1a0,0xe1a1,0xe1a2,0xe1a3,
  0xe1a4,0xe1a5,0xe1a6,0xe1a7, 0xe1a8,0xe1a9,0xe1aa,0xe1ab,
  0xe1ac,0xe1ad,0xe1ae,0xe1af, 0xe1b0,0xe1b1,0xe1b2,0xe1b3,
  0xe1b4,0xe1b5,0xe1b6,0xe1b7, 0xe1b8,0xe1b9,0xe1ba,0xe1bb,
  0xe1bc,0xe1bd,0xe1be,0xe1bf, 0xe1c0,0xe1c1,0xe1c2,0xe1c3,
  0xe1c4,0xe1c5,0xe1c6,0xe1c7, 0xe1c8,0xe1c9,0xe1ca,0xe1cb,
  0xe1cc,0xe1cd,0xe1ce,0xe1cf, 0xe1d0,0xe1d1,0xe1d2,0xe1d3,
  0xe1d4,0xe1d5,0xe1d6,0xe1d7, 0xe1d8,0xe1d9,0xe1da,0xe1db,
  0xe1dc,0xe1dd,0xe1de,0xe1df, 0xe1e0,0xe1e1,0xe1e2,0xe1e3,
  0xe1e4,0xe1e5,0xe1e6,0xe1e7, 0xe1e8,0xe1e9,0xe1ea,0xe1eb,
  0xe1ec,0xe1ed,0xe1ee,0xe1ef, 0xe1f0,0xe1f1,0xe1f2,0xe1f3,
  0xe1f4,0xe1f5,0xe1f6,0xe1f7, 0xe1f8,0xe1f9,0xe1fa,0xe1fb,
  0xe1fc,0xe1fd,0xe1fe,0xe1ff, 0xe200,0xe201,0xe202,0xe203,
  0xe204,0xe205,0xe206,0xe207, 0xe208,0xe209,0xe20a,0xe20b,
  0xe20c,0xe20d,0xe20e,0xe20f, 0xe210,0xe211,0xe212,0xe213,
  0xe214,0xe215,0xe216,0xe217, 0xe218,0xe219,0xe21a,0xe21b,
  0xe21c,0xe21d,0xe21e,0xe21f, 0xe220,0xe221,0xe222,0xe223,
  0xe224,0xe225,0xe226,0xe227, 0xe228,0xe229,0xe22a,0xe22b,
  0xe22c,0xe22d,0xe22e,0xe22f, 0xe230,0xe231,0xe232,0xe233,
  0xe234,0xe235,0xe236,0xe237, 0xe238,0xe239,
/* 0x6c41(i:8170) */
  0xe23a,0xe23b,0xe23c,0xe23d, 0xe23e,0xe23f,0xe240,0xe241,
  0xe242,0xe243,0xe244,0xe245, 0xe246,0xe247,0xe248,0xe249,
  0xe24a,0xe24b,0xe24c,0xe24d, 0xe24e,0xe24f,0xe250,0xe251,
  0xe252,0xe253,0xe254,0xe255, 0xe256,0xe257,0xe258,0xe259,
  0xe25a,0xe25b,0xe25c,0xe25d, 0xe25e,0xe25f,0xe260,0xe261,
  0xe262,0xe263,0xe264,0xe265, 0xe266,0xe267,0xe268,0xe269,
  0xe26a,0xe26b,0xe26c,0xe26d, 0xe26e,0xe26f,0xe270,0xe271,
  0xe272,0xe273,0xe274,0xe275, 0xe276,0xe277,0xe278,0xe279,
  0xe27a,0xe27b,0xe27c,0xe27d, 0xe27e,0xe27f,0xe280,0xe281,
  0xe282,0xe283,0xe284,0xe285, 0xe286,0xe287,0xe288,0xe289,
  0xe28a,0xe28b,0xe28c,0xe28d, 0xe28e,0xe28f,0xe290,0xe291,
  0xe292,0xe293,0xe294,0xe295, 0xe296,0xe297,0xe298,0xe299,
  0xe29a,0xe29b,0xe29c,0xe29d, 0xe29e,0xe29f,0xe2a0,0xe2a1,
  0xe2a2,0xe2a3,0xe2a4,0xe2a5, 0xe2a6,0xe2a7,0xe2a8,0xe2a9,
  0xe2aa,0xe2ab,0xe2ac,0xe2ad, 0xe2ae,0xe2af,0xe2b0,0xe2b1,
  0xe2b2,0xe2b3,0xe2b4,0xe2b5, 0xe2b6,0xe2b7,0xe2b8,0xe2b9,
  0xe2ba,0xe2bb,0xe2bc,0xe2bd, 0xe2be,0xe2bf,0xe2c0,0xe2c1,
  0xe2c2,0xe2c3,0xe2c4,0xe2c5, 0xe2c6,0xe2c7,0xe2c8,0xe2c9,
  0xe2ca,0xe2cb,0xe2cc,0xe2cd, 0xe2ce,0xe2cf,0xe2d0,0xe2d1,
  0xe2d2,0xe2d3,0xe2d4,0xe2d5, 0xe2d6,0xe2d7,0xe2d8,0xe2d9,
  0xe2da,0xe2db,0xe2dc,0xe2dd, 0xe2de,0xe2df,0xe2e0,0xe2e1,
  0xe2e2,0xe2e3,0xe2e4,0xe2e5, 0xe2e6,0xe2e7,0xe2e8,0xe2e9,
  0xe2ea,0xe2eb,0xe2ec,0xe2ed, 0xe2ee,0xe2ef,0xe2f0,0xe2f1,
  0xe2f2,0xe2f3,0xe2f4,0xe2f5, 0xe2f6,0xe2f7,
/* 0x6d41(i:8360) */
  0xe2f8,0xe2f9,0xe2fa,0xe2fb, 0xe2fc,0xe2fd,0xe2fe,0xe2ff,
  0xe300,0xe301,0xe302,0xe303, 0xe304,0xe305,0xe306,0xe307,
  0xe308,0xe309,0xe30a,0xe30b, 0xe30c,0xe30d,0xe30e,0xe30f,
  0xe310,0xe311,0xe312,0xe313, 0xe314,0xe315,0xe316,0xe317,
  0xe318,0xe319,0xe31a,0xe31b, 0xe31c,0xe31d,0xe31e,0xe31f,
  0xe320,0xe321,0xe322,0xe323, 0xe324,0xe325,0xe326,0xe327,
  0xe328,0xe329,0xe32a,0xe32b, 0xe32c,0xe32d,0xe32e,0xe32f,
  0xe330,0xe331,0xe332,0xe333, 0xe334,0xe335,0xe336,0xe337,
  0xe338,0xe339,0xe33a,0xe33b, 0xe33c,0xe33d,0xe33e,0xe33f,
  0xe340,0xe341,0xe342,0xe343, 0xe344,0xe345,0xe346,0xe347,
  0xe348,0xe349,0xe34a,0xe34b, 0xe34c,0xe34d,0xe34e,0xe34f,
  0xe350,0xe351,0xe352,0xe353, 0xe354,0xe355,0xe356,0xe357,
  0xe358,0xe359,0xe35a,0xe35b, 0xe35c,0xe35d,0xe35e,0xe35f,
  0xe360,0xe361,0xe362,0xe363, 0xe364,0xe365,0xe366,0xe367,
  0xe368,0xe369,0xe36a,0xe36b, 0xe36c,0xe36d,0xe36e,0xe36f,
  0xe370,0xe371,0xe372,0xe373, 0xe374,0xe375,0xe376,0xe377,
  0xe378,0xe379,0xe37a,0xe37b, 0xe37c,0xe37d,0xe37e,0xe37f,
  0xe380,0xe381,0xe382,0xe383, 0xe384,0xe385,0xe386,0xe387,
  0xe388,0xe389,0xe38a,0xe38b, 0xe38c,0xe38d,0xe38e,0xe38f,
  0xe390,0xe391,0xe392,0xe393, 0xe394,0xe395,0xe396,0xe397,
  0xe398,0xe399,0xe39a,0xe39b, 0xe39c,0xe39d,0xe39e,0xe39f,
  0xe3a0,0xe3a1,0xe3a2,0xe3a3, 0xe3a4,0xe3a5,0xe3a6,0xe3a7,
  0xe3a8,0xe3a9,0xe3aa,0xe3ab, 0xe3ac,0xe3ad,0xe3ae,0xe3af,
  0xe3b0,0xe3b1,0xe3b2,0xe3b3, 0xe3b4,0xe3b5,
/* 0x6e41(i:8550) */
  0xe3b6,0xe3b7,0xe3b8,0xe3b9, 0xe3ba,0xe3bb,0xe3bc,0xe3bd,
  0xe3be,0xe3bf,0xe3c0,0xe3c1, 0xe3c2,0xe3c3,0xe3c4,0xe3c5,
  0xe3c6,0xe3c7,0xe3c8,0xe3c9, 0xe3ca,0xe3cb,0xe3cc,0xe3cd,
  0xe3ce,0xe3cf,0xe3d0,0xe3d1, 0xe3d2,0xe3d3,0xe3d4,0xe3d5,
  0xe3d6,0xe3d7,0xe3d8,0xe3d9, 0xe3da,0xe3db,0xe3dc,0xe3dd,
  0xe3de,0xe3df,0xe3e0,0xe3e1, 0xe3e2,0xe3e3,0xe3e4,0xe3e5,
  0xe3e6,0xe3e7,0xe3e8,0xe3e9, 0xe3ea,0xe3eb,0xe3ec,0xe3ed,
  0xe3ee,0xe3ef,0xe3f0,0xe3f1, 0xe3f2,0xe3f3,0xe3f4,0xe3f5,
  0xe3f6,0xe3f7,0xe3f8,0xe3f9, 0xe3fa,0xe3fb,0xe3fc,0xe3fd,
  0xe3fe,0xe3ff,0xe400,0xe401, 0xe402,0xe403,0xe404,0xe405,
  0xe406,0xe407,0xe408,0xe409, 0xe40a,0xe40b,0xe40c,0xe40d,
  0xe40e,0xe40f,0xe410,0xe411, 0xe412,0xe413,0xe414,0xe415,
  0xe416,0xe417,0xe418,0xe419, 0xe41a,0xe41b,0xe41c,0xe41d,
  0xe41e,0xe41f,0xe420,0xe421, 0xe422,0xe423,0xe424,0xe425,
  0xe426,0xe427,0xe428,0xe429, 0xe42a,0xe42b,0xe42c,0xe42d,
  0xe42e,0xe42f,0xe430,0xe431, 0xe432,0xe433,0xe434,0xe435,
  0xe436,0xe437,0xe438,0xe439, 0xe43a,0xe43b,0xe43c,0xe43d,
  0xe43e,0xe43f,0xe440,0xe441, 0xe442,0xe443,0xe444,0xe445,
  0xe446,0xe447,0xe448,0xe449, 0xe44a,0xe44b,0xe44c,0xe44d,
  0xe44e,0xe44f,0xe450,0xe451, 0xe452,0xe453,0xe454,0xe455,
  0xe456,0xe457,0xe458,0xe459, 0xe45a,0xe45b,0xe45c,0xe45d,
  0xe45e,0xe45f,0xe460,0xe461, 0xe462,0xe463,0xe464,0xe465,
  0xe466,0xe467,0xe468,0xe469, 0xe46a,0xe46b,0xe46c,0xe46d,
  0xe46e,0xe46f,0xe470,0xe471, 0xe472,0xe473,
/* 0x6f41(i:8740) */
  0xe474,0xe475,0xe476,0xe477, 0xe478,0xe479,0xe47a,0xe47b,
  0xe47c,0xe47d,0xe47e,0xe47f, 0xe480,0xe481,0xe482,0xe483,
  0xe484,0xe485,0xe486,0xe487, 0xe488,0xe489,0xe48a,0xe48b,
  0xe48c,0xe48d,0xe48e,0xe48f, 0xe490,0xe491,0xe492,0xe493,
  0xe494,0xe495,0xe496,0xe497, 0xe498,0xe499,0xe49a,0xe49b,
  0xe49c,0xe49d,0xe49e,0xe49f, 0xe4a0,0xe4a1,0xe4a2,0xe4a3,
  0xe4a4,0xe4a5,0xe4a6,0xe4a7, 0xe4a8,0xe4a9,0xe4aa,0xe4ab,
  0xe4ac,0xe4ad,0xe4ae,0xe4af, 0xe4b0,0xe4b1,0xe4b2,0xe4b3,
  0xe4b4,0xe4b5,0xe4b6,0xe4b7, 0xe4b8,0xe4b9,0xe4ba,0xe4bb,
  0xe4bc,0xe4bd,0xe4be,0xe4bf, 0xe4c0,0xe4c1,0xe4c2,0xe4c3,
  0xe4c4,0xe4c5,0xe4c6,0xe4c7, 0xe4c8,0xe4c9,0xe4ca,0xe4cb,
  0xe4cc,0xe4cd,0xe4ce,0xe4cf, 0xe4d0,0xe4d1,0xe4d2,0xe4d3,
  0xe4d4,0xe4d5,0xe4d6,0xe4d7, 0xe4d8,0xe4d9,0xe4da,0xe4db,
  0xe4dc,0xe4dd,0xe4de,0xe4df, 0xe4e0,0xe4e1,0xe4e2,0xe4e3,
  0xe4e4,0xe4e5,0xe4e6,0xe4e7, 0xe4e8,0xe4e9,0xe4ea,0xe4eb,
  0xe4ec,0xe4ed,0xe4ee,0xe4ef, 0xe4f0,0xe4f1,0xe4f2,0xe4f3,
  0xe4f4,0xe4f5,0xe4f6,0xe4f7, 0xe4f8,0xe4f9,0xe4fa,0xe4fb,
  0xe4fc,0xe4fd,0xe4fe,0xe4ff, 0xe500,0xe501,0xe502,0xe503,
  0xe504,0xe505,0xe506,0xe507, 0xe508,0xe509,0xe50a,0xe50b,
  0xe50c,0xe50d,0xe50e,0xe50f, 0xe510,0xe511,0xe512,0xe513,
  0xe514,0xe515,0xe516,0xe517, 0xe518,0xe519,0xe51a,0xe51b,
  0xe51c,0xe51d,0xe51e,0xe51f, 0xe520,0xe521,0xe522,0xe523,
  0xe524,0xe525,0xe526,0xe527, 0xe528,0xe529,0xe52a,0xe52b,
  0xe52c,0xe52d,0xe52e,0xe52f, 0xe530,0xe531,
/* 0x7041(i:8930) */
  0xe532,0xe533,0xe534,0xe535, 0xe536,0xe537,0xe538,0xe539,
  0xe53a,0xe53b,0xe53c,0xe53d, 0xe53e,0xe53f,0xe540,0xe541,
  0xe542,0xe543,0xe544,0xe545, 0xe546,0xe547,0xe548,0xe549,
  0xe54a,0xe54b,0xe54c,0xe54d, 0xe54e,0xe54f,0xe550,0xe551,
  0xe552,0xe553,0xe554,0xe555, 0xe556,0xe557,0xe558,0xe559,
  0xe55a,0xe55b,0xe55c,0xe55d, 0xe55e,0xe55f,0xe560,0xe561,
  0xe562,0xe563,0xe564,0xe565, 0xe566,0xe567,0xe568,0xe569,
  0xe56a,0xe56b,0xe56c,0xe56d, 0xe56e,0xe56f,0xe570,0xe571,
  0xe572,0xe573,0xe574,0xe575, 0xe576,0xe577,0xe578,0xe579,
  0xe57a,0xe57b,0xe57c,0xe57d, 0xe57e,0xe57f,0xe580,0xe581,
  0xe582,0xe583,0xe584,0xe585, 0xe586,0xe587,0xe588,0xe589,
  0xe58a,0xe58b,0xe58c,0xe58d, 0xe58e,0xe58f,0xe590,0xe591,
  0xe592,0xe593,0xe594,0xe595, 0xe596,0xe597,0xe598,0xe599,
  0xe59a,0xe59b,0xe59c,0xe59d, 0xe59e,0xe59f,0xe5a0,0xe5a1,
  0xe5a2,0xe5a3,0xe5a4,0xe5a5, 0xe5a6,0xe5a7,0xe5a8,0xe5a9,
  0xe5aa,0xe5ab,0xe5ac,0xe5ad, 0xe5ae,0xe5af,0xe5b0,0xe5b1,
  0xe5b2,0xe5b3,0xe5b4,0xe5b5, 0xe5b6,0xe5b7,0xe5b8,0xe5b9,
  0xe5ba,0xe5bb,0xe5bc,0xe5bd, 0xe5be,0xe5bf,0xe5c0,0xe5c1,
  0xe5c2,0xe5c3,0xe5c4,0xe5c5, 0xe5c6,0xe5c7,0xe5c8,0xe5c9,
  0xe5ca,0xe5cb,0xe5cc,0xe5cd, 0xe5ce,0xe5cf,0xe5d0,0xe5d1,
  0xe5d2,0xe5d3,0xe5d4,0xe5d5, 0xe5d6,0xe5d7,0xe5d8,0xe5d9,
  0xe5da,0xe5db,0xe5dc,0xe5dd, 0xe5de,0xe5df,0xe5e0,0xe5e1,
  0xe5e2,0xe5e3,0xe5e4,0xe5e5, 0xe5e6,0xe5e7,0xe5e8,0xe5e9,
  0xe5ea,0xe5eb,0xe5ec,0xe5ed, 0xe5ee,0xe5ef,
/* 0x7141(i:9120) */
  0xe5f0,0xe5f1,0xe5f2,0xe5f3, 0xe5f4,0xe5f5,0xe5f6,0xe5f7,
  0xe5f8,0xe5f9,0xe5fa,0xe5fb, 0xe5fc,0xe5fd,0xe5fe,0xe5ff,
  0xe600,0xe601,0xe602,0xe603, 0xe604,0xe605,0xe606,0xe607,
  0xe608,0xe609,0xe60a,0xe60b, 0xe60c,0xe60d,0xe60e,0xe60f,
  0xe610,0xe611,0xe612,0xe613, 0xe614,0xe615,0xe616,0xe617,
  0xe618,0xe619,0xe61a,0xe61b, 0xe61c,0xe61d,0xe61e,0xe61f,
  0xe620,0xe621,0xe622,0xe623, 0xe624,0xe625,0xe626,0xe627,
  0xe628,0xe629,0xe62a,0xe62b, 0xe62c,0xe62d,0xe62e,0xe62f,
  0xe630,0xe631,0xe632,0xe633, 0xe634,0xe635,0xe636,0xe637,
  0xe638,0xe639,0xe63a,0xe63b, 0xe63c,0xe63d,0xe63e,0xe63f,
  0xe640,0xe641,0xe642,0xe643, 0xe644,0xe645,0xe646,0xe647,
  0xe648,0xe649,0xe64a,0xe64b, 0xe64c,0xe64d,0xe64e,0xe64f,
  0xe650,0xe651,0xe652,0xe653, 0xe654,0xe655,0xe656,0xe657,
  0xe658,0xe659,0xe65a,0xe65b, 0xe65c,0xe65d,0xe65e,0xe65f,
  0xe660,0xe661,0xe662,0xe663, 0xe664,0xe665,0xe666,0xe667,
  0xe668,0xe669,0xe66a,0xe66b, 0xe66c,0xe66d,0xe66e,0xe66f,
  0xe670,0xe671,0xe672,0xe673, 0xe674,0xe675,0xe676,0xe677,
  0xe678,0xe679,0xe67a,0xe67b, 0xe67c,0xe67d,0xe67e,0xe67f,
  0xe680,0xe681,0xe682,0xe683, 0xe684,0xe685,0xe686,0xe687,
  0xe688,0xe689,0xe68a,0xe68b, 0xe68c,0xe68d,0xe68e,0xe68f,
  0xe690,0xe691,0xe692,0xe693, 0xe694,0xe695,0xe696,0xe697,
  0xe698,0xe699,0xe69a,0xe69b, 0xe69c,0xe69d,0xe69e,0xe69f,
  0xe6a0,0xe6a1,0xe6a2,0xe6a3, 0xe6a4,0xe6a5,0xe6a6,0xe6a7,
  0xe6a8,0xe6a9,0xe6aa,0xe6ab, 0xe6ac,0xe6ad,
/* 0x7241(i:9310) */
  0xe6ae,0xe6af,0xe6b0,0xe6b1, 0xe6b2,0xe6b3,0xe6b4,0xe6b5,
  0xe6b6,0xe6b7,0xe6b8,0xe6b9, 0xe6ba,0xe6bb,0xe6bc,0xe6bd,
  0xe6be,0xe6bf,0xe6c0,0xe6c1, 0xe6c2,0xe6c3,0xe6c4,0xe6c5,
  0xe6c6,0xe6c7,0xe6c8,0xe6c9, 0xe6ca,0xe6cb,0xe6cc,0xe6cd,
  0xe6ce,0xe6cf,0xe6d0,0xe6d1, 0xe6d2,0xe6d3,0xe6d4,0xe6d5,
  0xe6d6,0xe6d7,0xe6d8,0xe6d9, 0xe6da,0xe6db,0xe6dc,0xe6dd,
  0xe6de,0xe6df,0xe6e0,0xe6e1, 0xe6e2,0xe6e3,0xe6e4,0xe6e5,
  0xe6e6,0xe6e7,0xe6e8,0xe6e9, 0xe6ea,0xe6eb,0xe6ec,0xe6ed,
  0xe6ee,0xe6ef,0xe6f0,0xe6f1, 0xe6f2,0xe6f3,0xe6f4,0xe6f5,
  0xe6f6,0xe6f7,0xe6f8,0xe6f9, 0xe6fa,0xe6fb,0xe6fc,0xe6fd,
  0xe6fe,0xe6ff,0xe700,0xe701, 0xe702,0xe703,0xe704,0xe705,
  0xe706,0xe707,0xe708,0xe709, 0xe70a,0xe70b,0xe70c,0xe70d,
  0xe70e,0xe70f,0xe710,0xe711, 0xe712,0xe713,0xe714,0xe715,
  0xe716,0xe717,0xe718,0xe719, 0xe71a,0xe71b,0xe71c,0xe71d,
  0xe71e,0xe71f,0xe720,0xe721, 0xe722,0xe723,0xe724,0xe725,
  0xe726,0xe727,0xe728,0xe729, 0xe72a,0xe72b,0xe72c,0xe72d,
  0xe72e,0xe72f,0xe730,0xe731, 0xe732,0xe733,0xe734,0xe735,
  0xe736,0xe737,0xe738,0xe739, 0xe73a,0xe73b,0xe73c,0xe73d,
  0xe73e,0xe73f,0xe740,0xe741, 0xe742,0xe743,0xe744,0xe745,
  0xe746,0xe747,0xe748,0xe749, 0xe74a,0xe74b,0xe74c,0xe74d,
  0xe74e,0xe74f,0xe750,0xe751, 0xe752,0xe753,0xe754,0xe755,
  0xe756,0xe757,0xe758,0xe759, 0xe75a,0xe75b,0xe75c,0xe75d,
  0xe75e,0xe75f,0xe760,0xe761, 0xe762,0xe763,0xe764,0xe765,
  0xe766,0xe767,0xe768,0xe769, 0xe76a,0xe76b,
/* 0x7341(i:9500) */
  0xe76c,0xe76d,0xe76e,0xe76f, 0xe770,0xe771,0xe772,0xe773,
  0xe774,0xe775,0xe776,0xe777, 0xe778,0xe779,0xe77a,0xe77b,
  0xe77c,0xe77d,0xe77e,0xe77f, 0xe780,0xe781,0xe782,0xe783,
  0xe784,0xe785,0xe786,0xe787, 0xe788,0xe789,0xe78a,0xe78b,
  0xe78c,0xe78d,0xe78e,0xe78f, 0xe790,0xe791,0xe792,0xe793,
  0xe794,0xe795,0xe796,0xe797, 0xe798,0xe799,0xe79a,0xe79b,
  0xe79c,0xe79d,0xe79e,0xe79f, 0xe7a0,0xe7a1,0xe7a2,0xe7a3,
  0xe7a4,0xe7a5,0xe7a6,0xe7a7, 0xe7a8,0xe7a9,0xe7aa,0xe7ab,
  0xe7ac,0xe7ad,0xe7ae,0xe7af, 0xe7b0,0xe7b1,0xe7b2,0xe7b3,
  0xe7b4,0xe7b5,0xe7b6,0xe7b7, 0xe7b8,0xe7b9,0xe7ba,0xe7bb,
  0xe7bc,0xe7bd,0xe7be,0xe7bf, 0xe7c0,0xe7c1,0xe7c2,0xe7c3,
  0xe7c4,0xe7c5,0xe7c6,0xe7c7, 0xe7c8,0xe7c9,0xe7ca,0xe7cb,
  0xe7cc,0xe7cd,0xe7ce,0xe7cf, 0xe7d0,0xe7d1,0xe7d2,0xe7d3,
  0xe7d4,0xe7d5,0xe7d6,0xe7d7, 0xe7d8,0xe7d9,0xe7da,0xe7db,
  0xe7dc,0xe7dd,0xe7de,0xe7df, 0xe7e0,0xe7e1,0xe7e2,0xe7e3,
  0xe7e4,0xe7e5,0xe7e6,0xe7e7, 0xe7e8,0xe7e9,0xe7ea,0xe7eb,
  0xe7ec,0xe7ed,0xe7ee,0xe7ef, 0xe7f0,0xe7f1,0xe7f2,0xe7f3,
  0xe7f4,0xe7f5,0xe7f6,0xe7f7, 0xe7f8,0xe7f9,0xe7fa,0xe7fb,
  0xe7fc,0xe7fd,0xe7fe,0xe7ff, 0xe800,0xe801,0xe802,0xe803,
  0xe804,0xe805,0xe806,0xe807, 0xe808,0xe809,0xe80a,0xe80b,
  0xe80c,0xe80d,0xe80e,0xe80f, 0xe810,0xe811,0xe812,0xe813,
  0xe814,0xe815,0xe816,0xe817, 0xe818,0xe819,0xe81a,0xe81b,
  0xe81c,0xe81d,0xe81e,0xe81f, 0xe820,0xe821,0xe822,0xe823,
  0xe824,0xe825,0xe826,0xe827, 0xe828,0xe829,
/* 0x7441(i:9690) */
  0xe82a,0xe82b,0xe82c,0xe82d, 0xe82e,0xe82f,0xe830,0xe831,
  0xe832,0xe833,0xe834,0xe835, 0xe836,0xe837,0xe838,0xe839,
  0xe83a,0xe83b,0xe83c,0xe83d, 0xe83e,0xe83f,0xe840,0xe841,
  0xe842,0xe843,0xe844,0xe845, 0xe846,0xe847,0xe848,0xe849,
  0xe84a,0xe84b,0xe84c,0xe84d, 0xe84e,0xe84f,0xe850,0xe851,
  0xe852,0xe853,0xe854,0xe855, 0xe856,0xe857,0xe858,0xe859,
  0xe85a,0xe85b,0xe85c,0xe85d, 0xe85e,0xe85f,0xe860,0xe861,
  0xe862,0xe863,0xe864,0xe865, 0xe866,0xe867,0xe868,0xe869,
  0xe86a,0xe86b,0xe86c,0xe86d, 0xe86e,0xe86f,0xe870,0xe871,
  0xe872,0xe873,0xe874,0xe875, 0xe876,0xe877,0xe878,0xe879,
  0xe87a,0xe87b,0xe87c,0xe87d, 0xe87e,0xe87f,0xe880,0xe881,
  0xe882,0xe883,0xe884,0xe885, 0xe886,0xe887,0xe888,0xe889,
  0xe88a,0xe88b,0xe88c,0xe88d, 0xe88e,0xe88f,0xe890,0xe891,
  0xe892,0xe893,0xe894,0xe895, 0xe896,0xe897,0xe898,0xe899,
  0xe89a,0xe89b,0xe89c,0xe89d, 0xe89e,0xe89f,0xe8a0,0xe8a1,
  0xe8a2,0xe8a3,0xe8a4,0xe8a5, 0xe8a6,0xe8a7,0xe8a8,0xe8a9,
  0xe8aa,0xe8ab,0xe8ac,0xe8ad, 0xe8ae,0xe8af,0xe8b0,0xe8b1,
  0xe8b2,0xe8b3,0xe8b4,0xe8b5, 0xe8b6,0xe8b7,0xe8b8,0xe8b9,
  0xe8ba,0xe8bb,0xe8bc,0xe8bd, 0xe8be,0xe8bf,0xe8c0,0xe8c1,
  0xe8c2,0xe8c3,0xe8c4,0xe8c5, 0xe8c6,0xe8c7,0xe8c8,0xe8c9,
  0xe8ca,0xe8cb,0xe8cc,0xe8cd, 0xe8ce,0xe8cf,0xe8d0,0xe8d1,
  0xe8d2,0xe8d3,0xe8d4,0xe8d5, 0xe8d6,0xe8d7,0xe8d8,0xe8d9,
  0xe8da,0xe8db,0xe8dc,0xe8dd, 0xe8de,0xe8df,0xe8e0,0xe8e1,
  0xe8e2,0xe8e3,0xe8e4,0xe8e5, 0xe8e6,0xe8e7,
/* 0x7541(i:9880) */
  0xe8e8,0xe8e9,0xe8ea,0xe8eb, 0xe8ec,0xe8ed,0xe8ee,0xe8ef,
  0xe8f0,0xe8f1,0xe8f2,0xe8f3, 0xe8f4,0xe8f5,0xe8f6,0xe8f7,
  0xe8f8,0xe8f9,0xe8fa,0xe8fb, 0xe8fc,0xe8fd,0xe8fe,0xe8ff,
  0xe900,0xe901,0xe902,0xe903, 0xe904,0xe905,0xe906,0xe907,
  0xe908,0xe909,0xe90a,0xe90b, 0xe90c,0xe90d,0xe90e,0xe90f,
  0xe910,0xe911,0xe912,0xe913, 0xe914,0xe915,0xe916,0xe917,
  0xe918,0xe919,0xe91a,0xe91b, 0xe91c,0xe91d,0xe91e,0xe91f,
  0xe920,0xe921,0xe922,0xe923, 0xe924,0xe925,0xe926,0xe927,
  0xe928,0xe929,0xe92a,0xe92b, 0xe92c,0xe92d,0xe92e,0xe92f,
  0xe930,0xe931,0xe932,0xe933, 0xe934,0xe935,0xe936,0xe937,
  0xe938,0xe939,0xe93a,0xe93b, 0xe93c,0xe93d,0xe93e,0xe93f,
  0xe940,0xe941,0xe942,0xe943, 0xe944,0xe945,0xe946,0xe947,
  0xe948,0xe949,0xe94a,0xe94b, 0xe94c,0xe94d,0xe94e,0xe94f,
  0xe950,0xe951,0xe952,0xe953, 0xe954,0xe955,0xe956,0xe957,
  0xe958,0xe959,0xe95a,0xe95b, 0xe95c,0xe95d,0xe95e,0xe95f,
  0xe960,0xe961,0xe962,0xe963, 0xe964,0xe965,0xe966,0xe967,
  0xe968,0xe969,0xe96a,0xe96b, 0xe96c,0xe96d,0xe96e,0xe96f,
  0xe970,0xe971,0xe972,0xe973, 0xe974,0xe975,0xe976,0xe977,
  0xe978,0xe979,0xe97a,0xe97b, 0xe97c,0xe97d,0xe97e,0xe97f,
  0xe980,0xe981,0xe982,0xe983, 0xe984,0xe985,0xe986,0xe987,
  0xe988,0xe989,0xe98a,0xe98b, 0xe98c,0xe98d,0xe98e,0xe98f,
  0xe990,0xe991,0xe992,0xe993, 0xe994,0xe995,0xe996,0xe997,
  0xe998,0xe999,0xe99a,0xe99b, 0xe99c,0xe99d,0xe99e,0xe99f,
  0xe9a0,0xe9a1,0xe9a2,0xe9a3, 0xe9a4,0xe9a5,
/* 0x7641(i:10070) */
  0xe9a6,0xe9a7,0xe9a8,0xe9a9, 0xe9aa,0xe9ab,0xe9ac,0xe9ad,
  0xe9ae,0xe9af,0xe9b0,0xe9b1, 0xe9b2,0xe9b3,0xe9b4,0xe9b5,
  0xe9b6,0xe9b7,0xe9b8,0xe9b9, 0xe9ba,0xe9bb,0xe9bc,0xe9bd,
  0xe9be,0xe9bf,0xe9c0,0xe9c1, 0xe9c2,0xe9c3,0xe9c4,0xe9c5,
  0xe9c6,0xe9c7,0xe9c8,0xe9c9, 0xe9ca,0xe9cb,0xe9cc,0xe9cd,
  0xe9ce,0xe9cf,0xe9d0,0xe9d1, 0xe9d2,0xe9d3,0xe9d4,0xe9d5,
  0xe9d6,0xe9d7,0xe9d8,0xe9d9, 0xe9da,0xe9db,0xe9dc,0xe9dd,
  0xe9de,0xe9df,0xe9e0,0xe9e1, 0xe9e2,0xe9e3,0xe9e4,0xe9e5,
  0xe9e6,0xe9e7,0xe9e8,0xe9e9, 0xe9ea,0xe9eb,0xe9ec,0xe9ed,
  0xe9ee,0xe9ef,0xe9f0,0xe9f1, 0xe9f2,0xe9f3,0xe9f4,0xe9f5,
  0xe9f6,0xe9f7,0xe9f8,0xe9f9, 0xe9fa,0xe9fb,0xe9fc,0xe9fd,
  0xe9fe,0xe9ff,0xea00,0xea01, 0xea02,0xea03,0xea04,0xea05,
  0xea06,0xea07,0xea08,0xea09, 0xea0a,0xea0b,0xea0c,0xea0d,
  0xea0e,0xea0f,0xea10,0xea11, 0xea12,0xea13,0xea14,0xea15,
  0xea16,0xea17,0xea18,0xea19, 0xea1a,0xea1b,0xea1c,0xea1d,
  0xea1e,0xea1f,0xea20,0xea21, 0xea22,0xea23,0xea24,0xea25,
  0xea26,0xea27,0xea28,0xea29, 0xea2a,0xea2b,0xea2c,0xea2d,
  0xea2e,0xea2f,0xea30,0xea31, 0xea32,0xea33,0xea34,0xea35,
  0xea36,0xea37,0xea38,0xea39, 0xea3a,0xea3b,0xea3c,0xea3d,
  0xea3e,0xea3f,0xea40,0xea41, 0xea42,0xea43,0xea44,0xea45,
  0xea46,0xea47,0xea48,0xea49, 0xea4a,0xea4b,0xea4c,0xea4d,
  0xea4e,0xea4f,0xea50,0xea51, 0xea52,0xea53,0xea54,0xea55,
  0xea56,0xea57,0xea58,0xea59, 0xea5a,0xea5b,0xea5c,0xea5d,
  0xea5e,0xea5f,0xea60,0xea61, 0xea62,0xea63,
/* 0x7741(i:10260) */
  0xea64,0xea65,0xea66,0xea67, 0xea68,0xea69,0xea6a,0xea6b,
  0xea6c,0xea6d,0xea6e,0xea6f, 0xea70,0xea71,0xea72,0xea73,
  0xea74,0xea75,0xea76,0xea77, 0xea78,0xea79,0xea7a,0xea7b,
  0xea7c,0xea7d,0xea7e,0xea7f, 0xea80,0xea81,0xea82,0xea83,
  0xea84,0xea85,0xea86,0xea87, 0xea88,0xea89,0xea8a,0xea8b,
  0xea8c,0xea8d,0xea8e,0xea8f, 0xea90,0xea91,0xea92,0xea93,
  0xea94,0xea95,0xea96,0xea97, 0xea98,0xea99,0xea9a,0xea9b,
  0xea9c,0xea9d,0xea9e,0xea9f, 0xeaa0,0xeaa1,0xeaa2,0xeaa3,
  0xeaa4,0xeaa5,0xeaa6,0xeaa7, 0xeaa8,0xeaa9,0xeaaa,0xeaab,
  0xeaac,0xeaad,0xeaae,0xeaaf, 0xeab0,0xeab1,0xeab2,0xeab3,
  0xeab4,0xeab5,0xeab6,0xeab7, 0xeab8,0xeab9,0xeaba,0xeabb,
  0xeabc,0xeabd,0xeabe,0xeabf, 0xeac0,0xeac1,0xeac2,0xeac3,
  0xeac4,0xeac5,0xeac6,0xeac7, 0xeac8,0xeac9,0xeaca,0xeacb,
  0xeacc,0xeacd,0xeace,0xeacf, 0xead0,0xead1,0xead2,0xead3,
  0xead4,0xead5,0xead6,0xead7, 0xead8,0xead9,0xeada,0xeadb,
  0xeadc,0xeadd,0xeade,0xeadf, 0xeae0,0xeae1,0xeae2,0xeae3,
  0xeae4,0xeae5,0xeae6,0xeae7, 0xeae8,0xeae9,0xeaea,0xeaeb,
  0xeaec,0xeaed,0xeaee,0xeaef, 0xeaf0,0xeaf1,0xeaf2,0xeaf3,
  0xeaf4,0xeaf5,0xeaf6,0xeaf7, 0xeaf8,0xeaf9,0xeafa,0xeafb,
  0xeafc,0xeafd,0xeafe,0xeaff, 0xeb00,0xeb01,0xeb02,0xeb03,
  0xeb04,0xeb05,0xeb06,0xeb07, 0xeb08,0xeb09,0xeb0a,0xeb0b,
  0xeb0c,0xeb0d,0xeb0e,0xeb0f, 0xeb10,0xeb11,0xeb12,0xeb13,
  0xeb14,0xeb15,0xeb16,0xeb17, 0xeb18,0xeb19,0xeb1a,0xeb1b,
  0xeb1c,0xeb1d,0xeb1e,0xeb1f, 0xeb20,0xeb21,
/* 0x7841(i:10450) */
  0xeb22,0xeb23,0xeb24,0xeb25, 0xeb26,0xeb27,0xeb28,0xeb29,
  0xeb2a,0xeb2b,0xeb2c,0xeb2d, 0xeb2e,0xeb2f,0xeb30,0xeb31,
  0xeb32,0xeb33,0xeb34,0xeb35, 0xeb36,0xeb37,0xeb38,0xeb39,
  0xeb3a,0xeb3b,0xeb3c,0xeb3d, 0xeb3e,0xeb3f,0xeb40,0xeb41,
  0xeb42,0xeb43,0xeb44,0xeb45, 0xeb46,0xeb47,0xeb48,0xeb49,
  0xeb4a,0xeb4b,0xeb4c,0xeb4d, 0xeb4e,0xeb4f,0xeb50,0xeb51,
  0xeb52,0xeb53,0xeb54,0xeb55, 0xeb56,0xeb57,0xeb58,0xeb59,
  0xeb5a,0xeb5b,0xeb5c,0xeb5d, 0xeb5e,0xeb5f,0xeb60,0xeb61,
  0xeb62,0xeb63,0xeb64,0xeb65, 0xeb66,0xeb67,0xeb68,0xeb69,
  0xeb6a,0xeb6b,0xeb6c,0xeb6d, 0xeb6e,0xeb6f,0xeb70,0xeb71,
  0xeb72,0xeb73,0xeb74,0xeb75, 0xeb76,0xeb77,0xeb78,0xeb79,
  0xeb7a,0xeb7b,0xeb7c,0xeb7d, 0xeb7e,0xeb7f,0xeb80,0xeb81,
  0xeb82,0xeb83,0xeb84,0xeb85, 0xeb86,0xeb87,0xeb88,0xeb89,
  0xeb8a,0xeb8b,0xeb8c,0xeb8d, 0xeb8e,0xeb8f,0xeb90,0xeb91,
  0xeb92,0xeb93,0xeb94,0xeb95, 0xeb96,0xeb97,0xeb98,0xeb99,
  0xeb9a,0xeb9b,0xeb9c,0xeb9d, 0xeb9e,0xeb9f,0xeba0,0xeba1,
  0xeba2,0xeba3,0xeba4,0xeba5, 0xeba6,0xeba7,0xeba8,0xeba9,
  0xebaa,0xebab,0xebac,0xebad, 0xebae,0xebaf,0xebb0,0xebb1,
  0xebb2,0xebb3,0xebb4,0xebb5, 0xebb6,0xebb7,0xebb8,0xebb9,
  0xebba,0xebbb,0xebbc,0xebbd, 0xebbe,0xebbf,0xebc0,0xebc1,
  0xebc2,0xebc3,0xebc4,0xebc5, 0xebc6,0xebc7,0xebc8,0xebc9,
  0xebca,0xebcb,0xebcc,0xebcd, 0xebce,0xebcf,0xebd0,0xebd1,
  0xebd2,0xebd3,0xebd4,0xebd5, 0xebd6,0xebd7,0xebd8,0xebd9,
  0xebda,0xebdb,0xebdc,0xebdd, 0xebde,0xebdf,
/* 0x7941(i:10640) */
  0xebe0,0xebe1,0xebe2,0xebe3, 0xebe4,0xebe5,0xebe6,0xebe7,
  0xebe8,0xebe9,0xebea,0xebeb, 0xebec,0xebed,0xebee,0xebef,
  0xebf0,0xebf1,0xebf2,0xebf3, 0xebf4,0xebf5,0xebf6,0xebf7,
  0xebf8,0xebf9,0xebfa,0xebfb, 0xebfc,0xebfd,0xebfe,0xebff,
  0xec00,0xec01,0xec02,0xec03, 0xec04,0xec05,0xec06,0xec07,
  0xec08,0xec09,0xec0a,0xec0b, 0xec0c,0xec0d,0xec0e,0xec0f,
  0xec10,0xec11,0xec12,0xec13, 0xec14,0xec15,0xec16,0xec17,
  0xec18,0xec19,0xec1a,0xec1b, 0xec1c,0xec1d,0xec1e,0xec1f,
  0xec20,0xec21,0xec22,0xec23, 0xec24,0xec25,0xec26,0xec27,
  0xec28,0xec29,0xec2a,0xec2b, 0xec2c,0xec2d,0xec2e,0xec2f,
  0xec30,0xec31,0xec32,0xec33, 0xec34,0xec35,0xec36,0xec37,
  0xec38,0xec39,0xec3a,0xec3b, 0xec3c,0xec3d,0xec3e,0xec3f,
  0xec40,0xec41,0xec42,0xec43, 0xec44,0xec45,0xec46,0xec47,
  0xec48,0xec49,0xec4a,0xec4b, 0xec4c,0xec4d,0xec4e,0xec4f,
  0xec50,0xec51,0xec52,0xec53, 0xec54,0xec55,0xec56,0xec57,
  0xec58,0xec59,0xec5a,0xec5b, 0xec5c,0xec5d,0xec5e,0xec5f,
  0xec60,0xec61,0xec62,0xec63, 0xec64,0xec65,0xec66,0xec67,
  0xec68,0xec69,0xec6a,0xec6b, 0xec6c,0xec6d,0xec6e,0xec6f,
  0xec70,0xec71,0xec72,0xec73, 0xec74,0xec75,0xec76,0xec77,
  0xec78,0xec79,0xec7a,0xec7b, 0xec7c,0xec7d,0xec7e,0xec7f,
  0xec80,0xec81,0xec82,0xec83, 0xec84,0xec85,0xec86,0xec87,
  0xec88,0xec89,0xec8a,0xec8b, 0xec8c,0xec8d,0xec8e,0xec8f,
  0xec90,0xec91,0xec92,0xec93, 0xec94,0xec95,0xec96,0xec97,
  0xec98,0xec99,0xec9a,0xec9b, 0xec9c,0xec9d,
/* 0x7a41(i:10830) */
  0xec9e,0xec9f,0xeca0,0xeca1, 0xeca2,0xeca3,0xeca4,0xeca5,
  0xeca6,0xeca7,0xeca8,0xeca9, 0xecaa,0xecab,0xecac,0xecad,
  0xecae,0xecaf,0xecb0,0xecb1, 0xecb2,0xecb3,0xecb4,0xecb5,
  0xecb6,0xecb7,0xecb8,0xecb9, 0xecba,0xecbb,0xecbc,0xecbd,
  0xecbe,0xecbf,0xecc0,0xecc1, 0xecc2,0xecc3,0xecc4,0xecc5,
  0xecc6,0xecc7,0xecc8,0xecc9, 0xecca,0xeccb,0xeccc,0xeccd,
  0xecce,0xeccf,0xecd0,0xecd1, 0xecd2,0xecd3,0xecd4,0xecd5,
  0xecd6,0xecd7,0xecd8,0xecd9, 0xecda,0xecdb,0xecdc,0xecdd,
  0xecde,0xecdf,0xece0,0xece1, 0xece2,0xece3,0xece4,0xece5,
  0xece6,0xece7,0xece8,0xece9, 0xecea,0xeceb,0xecec,0xeced,
  0xecee,0xecef,0xecf0,0xecf1, 0xecf2,0xecf3,0xecf4,0xecf5,
  0xecf6,0xecf7,0xecf8,0xecf9, 0xecfa,0xecfb,0xecfc,0xecfd,
  0xecfe,0xecff,0xed00,0xed01, 0xed02,0xed03,0xed04,0xed05,
  0xed06,0xed07,0xed08,0xed09, 0xed0a,0xed0b,0xed0c,0xed0d,
  0xed0e,0xed0f,0xed10,0xed11, 0xed12,0xed13,0xed14,0xed15,
  0xed16,0xed17,0xed18,0xed19, 0xed1a,0xed1b,0xed1c,0xed1d,
  0xed1e,0xed1f,0xed20,0xed21, 0xed22,0xed23,0xed24,0xed25,
  0xed26,0xed27,0xed28,0xed29, 0xed2a,0xed2b,0xed2c,0xed2d,
  0xed2e,0xed2f,0xed30,0xed31, 0xed32,0xed33,0xed34,0xed35,
  0xed36,0xed37,0xed38,0xed39, 0xed3a,0xed3b,0xed3c,0xed3d,
  0xed3e,0xed3f,0xed40,0xed41, 0xed42,0xed43,0xed44,0xed45,
  0xed46,0xed47,0xed48,0xed49, 0xed4a,0xed4b,0xed4c,0xed4d,
  0xed4e,0xed4f,0xed50,0xed51, 0xed52,0xed53,0xed54,0xed55,
  0xed56,0xed57,0xed58,0xed59, 0xed5a,0xed5b,
/* 0x7b41(i:11020) */
  0xed5c,0xed5d,0xed5e,0xed5f, 0xed60,0xed61,0xed62,0xed63,
  0xed64,0xed65,0xed66,0xed67, 0xed68,0xed69,0xed6a,0xed6b,
  0xed6c,0xed6d,0xed6e,0xed6f, 0xed70,0xed71,0xed72,0xed73,
  0xed74,0xed75,0xed76,0xed77, 0xed78,0xed79,0xed7a,0xed7b,
  0xed7c,0xed7d,0xed7e,0xed7f, 0xed80,0xed81,0xed82,0xed83,
  0xed84,0xed85,0xed86,0xed87, 0xed88,0xed89,0xed8a,0xed8b,
  0xed8c,0xed8d,0xed8e,0xed8f, 0xed90,0xed91,0xed92,0xed93,
  0xed94,0xed95,0xed96,0xed97, 0xed98,0xed99,0xed9a,0xed9b,
  0xed9c,0xed9d,0xed9e,0xed9f, 0xeda0,0xeda1,0xeda2,0xeda3,
  0xeda4,0xeda5,0xeda6,0xeda7, 0xeda8,0xeda9,0xedaa,0xedab,
  0xedac,0xedad,0xedae,0xedaf, 0xedb0,0xedb1,0xedb2,0xedb3,
  0xedb4,0xedb5,0xedb6,0xedb7, 0xedb8,0xedb9,0xedba,0xedbb,
  0xedbc,0xedbd,0xedbe,0xedbf, 0xedc0,0xedc1,0xedc2,0xedc3,
  0xedc4,0xedc5,0xedc6,0xedc7, 0xedc8,0xedc9,0xedca,0xedcb,
  0xedcc,0xedcd,0xedce,0xedcf, 0xedd0,0xedd1,0xedd2,0xedd3,
  0xedd4,0xedd5,0xedd6,0xedd7, 0xedd8,0xedd9,0xedda,0xeddb,
  0xeddc,0xeddd,0xedde,0xeddf, 0xede0,0xede1,0xede2,0xede3,
  0xede4,0xede5,0xede6,0xede7, 0xede8,0xede9,0xedea,0xedeb,
  0xedec,0xeded,0xedee,0xedef, 0xedf0,0xedf1,0xedf2,0xedf3,
  0xedf4,0xedf5,0xedf6,0xedf7, 0xedf8,0xedf9,0xedfa,0xedfb,
  0xedfc,0xedfd,0xedfe,0xedff, 0xee00,0xee01,0xee02,0xee03,
  0xee04,0xee05,0xee06,0xee07, 0xee08,0xee09,0xee0a,0xee0b,
  0xee0c,0xee0d,0xee0e,0xee0f, 0xee10,0xee11,0xee12,0xee13,
  0xee14,0xee15,0xee16,0xee17, 0xee18,0xee19,
/* 0x7c41(i:11210) */
  0xee1a,0xee1b,0xee1c,0xee1d, 0xee1e,0xee1f,0xee20,0xee21,
  0xee22,0xee23,0xee24,0xee25, 0xee26,0xee27,0xee28,0xee29,
  0xee2a,0xee2b,0xee2c,0xee2d, 0xee2e,0xee2f,0xee30,0xee31,
  0xee32,0xee33,0xee34,0xee35, 0xee36,0xee37,0xee38,0xee39,
  0xee3a,0xee3b,0xee3c,0xee3d, 0xee3e,0xee3f,0xee40,0xee41,
  0xee42,0xee43,0xee44,0xee45, 0xee46,0xee47,0xee48,0xee49,
  0xee4a,0xee4b,0xee4c,0xee4d, 0xee4e,0xee4f,0xee50,0xee51,
  0xee52,0xee53,0xee54,0xee55, 0xee56,0xee57,0xee58,0xee59,
  0xee5a,0xee5b,0xee5c,0xee5d, 0xee5e,0xee5f,0xee60,0xee61,
  0xee62,0xee63,0xee64,0xee65, 0xee66,0xee67,0xee68,0xee69,
  0xee6a,0xee6b,0xee6c,0xee6d, 0xee6e,0xee6f,0xee70,0xee71,
  0xee72,0xee73,0xee74,0xee75, 0xee76,0xee77,0xee78,0xee79,
  0xee7a,0xee7b,0xee7c,0xee7d, 0xee7e,0xee7f,0xee80,0xee81,
  0xee82,0xee83,0xee84,0xee85, 0xee86,0xee87,0xee88,0xee89,
  0xee8a,0xee8b,0xee8c,0xee8d, 0xee8e,0xee8f,0xee90,0xee91,
  0xee92,0xee93,0xee94,0xee95, 0xee96,0xee97,0xee98,0xee99,
  0xee9a,0xee9b,0xee9c,0xee9d, 0xee9e,0xee9f,0xeea0,0xeea1,
  0xeea2,0xeea3,0xeea4,0xeea5, 0xeea6,0xeea7,0xeea8,0xeea9,
  0xeeaa,0xeeab,0xeeac,0xeead, 0xeeae,0xeeaf,0xeeb0,0xeeb1,
  0xeeb2,0xeeb3,0xeeb4,0xeeb5, 0xeeb6,0xeeb7,0xeeb8,0xeeb9,
  0xeeba,0xeebb,0xeebc,0xeebd, 0xeebe,0xeebf,0xeec0,0xeec1,
  0xeec2,0xeec3,0xeec4,0xeec5, 0xeec6,0xeec7,0xeec8,0xeec9,
  0xeeca,0xeecb,0xeecc,0xeecd, 0xeece,0xeecf,0xeed0,0xeed1,
  0xeed2,0xeed3,0xeed4,0xeed5, 0xeed6,0xeed7,
/* 0x7d41(i:11400) */
  0xeed8,0xeed9,0xeeda,0xeedb, 0xeedc,0xeedd,0xeede,0xeedf,
  0xeee0,0xeee1,0xeee2,0xeee3, 0xeee4,0xeee5,0xeee6,0xeee7,
  0xeee8,0xeee9,0xeeea,0xeeeb, 0xeeec,0xeeed,0xeeee,0xeeef,
  0xeef0,0xeef1,0xeef2,0xeef3, 0xeef4,0xeef5,0xeef6,0xeef7,
  0xeef8,0xeef9,0xeefa,0xeefb, 0xeefc,0xeefd,0xeefe,0xeeff,
  0xef00,0xef01,0xef02,0xef03, 0xef04,0xef05,0xef06,0xef07,
  0xef08,0xef09,0xef0a,0xef0b, 0xef0c,0xef0d,0xef0e,0xef0f,
  0xef10,0xef11,0xef12,0xef13, 0xef14,0xef15,0xef16,0xef17,
  0xef18,0xef19,0xef1a,0xef1b, 0xef1c,0xef1d,0xef1e,0xef1f,
  0xef20,0xef21,0xef22,0xef23, 0xef24,0xef25,0xef26,0xef27,
  0xef28,0xef29,0xef2a,0xef2b, 0xef2c,0xef2d,0xef2e,0xef2f,
  0xef30,0xef31,0xef32,0xef33, 0xef34,0xef35,0xef36,0xef37,
  0xef38,0xef39,0xef3a,0xef3b, 0xef3c,0xef3d,0xef3e,0xef3f,
  0xef40,0xef41,0xef42,0xef43, 0xef44,0xef45,0xef46,0xef47,
  0xef48,0xef49,0xef4a,0xef4b, 0xef4c,0xef4d,0xef4e,0xef4f,
  0xef50,0xef51,0xef52,0xef53, 0xef54,0xef55,0xef56,0xef57,
  0xef58,0xef59,0xef5a,0xef5b, 0xef5c,0xef5d,0xef5e,0xef5f,
  0xef60,0xef61,0xef62,0xef63, 0xef64,0xef65,0xef66,0xef67,
  0xef68,0xef69,0xef6a,0xef6b, 0xef6c,0xef6d,0xef6e,0xef6f,
  0xef70,0xef71,0xef72,0xef73, 0xef74,0xef75,0xef76,0xef77,
  0xef78,0xef79,0xef7a,0xef7b, 0xef7c,0xef7d,0xef7e,0xef7f,
  0xef80,0xef81,0xef82,0xef83, 0xef84,0xef85,0xef86,0xef87,
  0xef88,0xef89,0xef8a,0xef8b, 0xef8c,0xef8d,0xef8e,0xef8f,
  0xef90,0xef91,0xef92,0xef93, 0xef94,0xef95,
/* 0x7e41(i:11590) */
  0xef96,0xef97,0xef98,0xef99, 0xef9a,0xef9b,0xef9c,0xef9d,
  0xef9e,0xef9f,0xefa0,0xefa1, 0xefa2,0xefa3,0xefa4,0xefa5,
  0xefa6,0xefa7,0xefa8,0xefa9, 0xefaa,0xefab,0xefac,0xefad,
  0xefae,0xefaf,0xefb0,0xefb1, 0xefb2,0xefb3,0xefb4,0xefb5,
  0xefb6,0xefb7,0xefb8,0xefb9, 0xefba,0xefbb,0xefbc,0xefbd,
  0xefbe,0xefbf,0xefc0,0xefc1, 0xefc2,0xefc3,0xefc4,0xefc5,
  0xefc6,0xefc7,0xefc8,0xefc9, 0xefca,0xefcb,0xefcc,0xefcd,
  0xefce,0xefcf,0xefd0,0xefd1, 0xefd2,0xefd3,0xefd4,0xefd5,
  0xefd6,0xefd7,0xefd8,0xefd9, 0xefda,0xefdb,0xefdc,0xefdd,
  0xefde,0xefdf,0xefe0,0xefe1, 0xefe2,0xefe3,0xefe4,0xefe5,
  0xefe6,0xefe7,0xefe8,0xefe9, 0xefea,0xefeb,0xefec,0xefed,
  0xefee,0xefef,0xeff0,0xeff1, 0xeff2,0xeff3,0xeff4,0xeff5,
  0xeff6,0xeff7,0xeff8,0xeff9, 0xeffa,0xeffb,0xeffc,0xeffd,
  0xeffe,0xefff,0xf000,0xf001, 0xf002,0xf003,0xf004,0xf005,
  0xf006,0xf007,0xf008,0xf009, 0xf00a,0xf00b,0xf00c,0xf00d,
  0xf00e,0xf00f,0xf010,0xf011, 0xf012,0xf013,0xf014,0xf015,
  0xf016,0xf017,0xf018,0xf019, 0xf01a,0xf01b,0xf01c,0xf01d,
  0xf01e,0xf01f,0xf020,0xf021, 0xf022,0xf023,0xf024,0xf025,
  0xf026,0xf027,0xf028,0xf029, 0xf02a,0xf02b,0xf02c,0xf02d,
  0xf02e,0xf02f,0xf030,0xf031, 0xf032,0xf033,0xf034,0xf035,
  0xf036,0xf037,0xf038,0xf039, 0xf03a,0xf03b,0xf03c,0xf03d,
  0xf03e,0xf03f,0xf040,0xf041, 0xf042,0xf043,0xf044,0xf045,
  0xf046,0xf047,0xf048,0xf049, 0xf04a,0xf04b,0xf04c,0xf04d,
  0xf04e,0xf04f,0xf050,0xf051, 0xf052,0xf053,
/* 0x7f41(i:11780) */
  0xf054,0xf055,0xf056,0xf057, 0xf058,0xf059,0xf05a,0xf05b,
  0xf05c,0xf05d,0xf05e,0xf05f, 0xf060,0xf061,0xf062,0xf063,
  0xf064,0xf065,0xf066,0xf067, 0xf068,0xf069,0xf06a,0xf06b,
  0xf06c,0xf06d,0xf06e,0xf06f, 0xf070,0xf071,0xf072,0xf073,
  0xf074,0xf075,0xf076,0xf077, 0xf078,0xf079,0xf07a,0xf07b,
  0xf07c,0xf07d,0xf07e,0xf07f, 0xf080,0xf081,0xf082,0xf083,
  0xf084,0xf085,0xf086,0xf087, 0xf088,0xf089,0xf08a,0xf08b,
  0xf08c,0xf08d,0xf08e,0xf08f, 0xf090,0xf091,0xf092,0xf093,
  0xf094,0xf095,0xf096,0xf097, 0xf098,0xf099,0xf09a,0xf09b,
  0xf09c,0xf09d,0xf09e,0xf09f, 0xf0a0,0xf0a1,0xf0a2,0xf0a3,
  0xf0a4,0xf0a5,0xf0a6,0xf0a7, 0xf0a8,0xf0a9,0xf0aa,0xf0ab,
  0xf0ac,0xf0ad,0xf0ae,0xf0af, 0xf0b0,0xf0b1,0xf0b2,0xf0b3,
  0xf0b4,0xf0b5,0xf0b6,0xf0b7, 0xf0b8,0xf0b9,0xf0ba,0xf0bb,
  0xf0bc,0xf0bd,0xf0be,0xf0bf, 0xf0c0,0xf0c1,0xf0c2,0xf0c3,
  0xf0c4,0xf0c5,0xf0c6,0xf0c7, 0xf0c8,0xf0c9,0xf0ca,0xf0cb,
  0xf0cc,0xf0cd,0xf0ce,0xf0cf, 0xf0d0,0xf0d1,0xf0d2,0xf0d3,
  0xf0d4,0xf0d5,0xf0d6,0xf0d7, 0xf0d8,0xf0d9,0xf0da,0xf0db,
  0xf0dc,0xf0dd,0xf0de,0xf0df, 0xf0e0,0xf0e1,0xf0e2,0xf0e3,
  0xf0e4,0xf0e5,0xf0e6,0xf0e7, 0xf0e8,0xf0e9,0xf0ea,0xf0eb,
  0xf0ec,0xf0ed,0xf0ee,0xf0ef, 0xf0f0,0xf0f1,0xf0f2,0xf0f3,
  0xf0f4,0xf0f5,0xf0f6,0xf0f7, 0xf0f8,0xf0f9,0xf0fa,0xf0fb,
  0xf0fc,0xf0fd,0xf0fe,0xf0ff, 0xf100,0xf101,0xf102,0xf103,
  0xf104,0xf105,0xf106,0xf107, 0xf108,0xf109,0xf10a,0xf10b,
  0xf10c,0xf10d,0xf10e,0xf10f, 0xf110,0xf111
};

unsigned short uni_t_ibm933[30970] = {
/* codelimit: 30970 */
/* 0x4100(i:0) */
  0x3001,0x3002,0x30fb,0x2025, 0x2026,0x00a8,0x3003,0x2010,
  0x2015,0x2225,0xff3c,0xffe3, 0x2018,0x2019,0x201c,0x201d,
  0x3014,0x3015,0x3008,0x3009, 0x300a,0x300b,0x300c,0x300d,
  0x300e,0x300f,0x3010,0x3011, 0x00b1,0x00d7,0x00f7,0x01c2,
  0x2266,0x2267,0x221e,0x2234, 0x00b0,0x2032,0x2033,0x2103,
  0x212a,0xff3e,0xffe1,0xffe5, 0x3396,0x3397,0x2113,0x33c4,
  0x339c,0x339d,0x339e,0x338e, 0x338f,0x00a7,0x203b,0x2606,
  0x2605,0x25cb,0x25cf,0x25ce, 0x25c7,0x25c6,0x25a1,0x25a0,
  0x25b3,0x25b2,0x25bd,0x25bc, 0x2192,0x2190,0x2191,0x2193,
  0x2194,0x3013,0xff3b,0xff3d, 0x2260,0x2264,0x2265,0x212b,
  0x2642,0x2640,0x2220,0x22a5, 0x2312,0x2202,0x2207,0x2261,
  0x2252,0x226a,0x226b,0x221a, 0x223d,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x4241(i:190) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0xffe0,0xff0e,0xff1c, 0xff08,0xff0b,0xff5c,0xff06,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0xff01,0xff04,0xff0a, 0xff09,0xff1b,0xffe2,0xff0d,
  0xff0f,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0xffe4,0xff0c,0xff05, 0xff3f,0xff1e,0xff1f,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xff40,0xff1a,0xff03,0xff20, 0xff07,0xff1d,0xff02,0x0000,
  0xff41,0xff42,0xff43,0xff44, 0xff45,0xff46,0xff47,0xff48,
  0xff49,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xff4a,0xff4b,0xff4c,0xff4d, 0xff4e,0xff4f,0xff50,0xff51,
  0xff52,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x301c,0xff53,0xff54,0xff55, 0xff56,0xff57,0xff58,0xff59,
  0xff5a,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0xff5b,
  0xff21,0xff22,0xff23,0xff24, 0xff25,0xff26,0xff27,0xff28,
  0xff29,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0xff5d,
  0xff2a,0xff2b,0xff2c,0xff2d, 0xff2e,0xff2f,0xff30,0xff31,
  0xff32,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0xffe6,
  0x0000,0xff33,0xff34,0xff35, 0xff36,0xff37,0xff38,0xff39,
  0xff3a,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0xff10,
  0xff11,0xff12,0xff13,0xff14, 0xff15,0xff16,0xff17,0xff18,
  0xff19,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x4341(i:380) */
  0x3165,0x3166,0x3167,0x3168, 0x3169,0x316a,0x316b,0x316c,
  0x316d,0x316e,0x316f,0x3170, 0x3171,0x3172,0x3173,0x3174,
  0x3175,0x3176,0x3177,0x3178, 0x3179,0x317a,0x317b,0x317c,
  0x317d,0x317e,0x317f,0x3180, 0x3181,0x3182,0x3183,0x3184,
  0x3185,0x3186,0x3187,0x3188, 0x3189,0x318a,0x318b,0x318c,
  0x318d,0x318e,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x4441(i:570) */
  0x3041,0x3042,0x3043,0x3044, 0x3045,0x3046,0x3047,0x3048,
  0x3049,0x304a,0x304b,0x304c, 0x304d,0x304e,0x304f,0x3050,
  0x3051,0x3052,0x3053,0x3054, 0x3055,0x3056,0x3057,0x3058,
  0x3059,0x305a,0x305b,0x305c, 0x305d,0x305e,0x305f,0x3060,
  0x3061,0x3062,0x3063,0x3064, 0x3065,0x3066,0x3067,0x3068,
  0x3069,0x306a,0x306b,0x306c, 0x306d,0x306e,0x306f,0x3070,
  0x3071,0x3072,0x3073,0x3074, 0x3075,0x3076,0x3077,0x3078,
  0x3079,0x307a,0x307b,0x307c, 0x307d,0x307e,0x307f,0x3080,
  0x3081,0x3082,0x3083,0x3084, 0x3085,0x3086,0x3087,0x3088,
  0x3089,0x308a,0x308b,0x308c, 0x308d,0x308e,0x308f,0x3090,
  0x3091,0x3092,0x3093,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x4541(i:760) */
  0x30a1,0x30a2,0x30a3,0x30a4, 0x30a5,0x30a6,0x30a7,0x30a8,
  0x30a9,0x30aa,0x30ab,0x30ac, 0x30ad,0x30ae,0x30af,0x30b0,
  0x30b1,0x30b2,0x30b3,0x30b4, 0x30b5,0x30b6,0x30b7,0x30b8,
  0x30b9,0x30ba,0x30bb,0x30bc, 0x30bd,0x30be,0x30bf,0x30c0,
  0x30c1,0x30c2,0x30c3,0x30c4, 0x30c5,0x30c6,0x30c7,0x30c8,
  0x30c9,0x30ca,0x30cb,0x30cc, 0x30cd,0x30ce,0x30cf,0x30d0,
  0x30d1,0x30d2,0x30d3,0x30d4, 0x30d5,0x30d6,0x30d7,0x30d8,
  0x30d9,0x30da,0x30db,0x30dc, 0x30dd,0x30de,0x30df,0x30e0,
  0x30e1,0x30e2,0x30e3,0x30e4, 0x30e5,0x30e6,0x30e7,0x30e8,
  0x30e9,0x30ea,0x30eb,0x30ec, 0x30ed,0x30ee,0x30ef,0x30f0,
  0x30f1,0x30f2,0x30f3,0x30f4, 0x30f5,0x30f6,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x4641(i:950) */
  0x2170,0x2171,0x2172,0x2173, 0x2174,0x2175,0x2176,0x2177,
  0x2178,0x2179,0x0000,0x0000, 0x0000,0x0000,0x0000,0x2160,
  0x2161,0x2162,0x2163,0x2164, 0x2165,0x2166,0x2167,0x2168,
  0x2169,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0391,0x0392,0x0393,0x0394, 0x0395,0x0396,0x0397,0x0398,
  0x0399,0x039a,0x039b,0x039c, 0x039d,0x039e,0x039f,0x03a0,
  0x03a1,0x03a3,0x03a4,0x03a5, 0x03a6,0x03a7,0x03a8,0x03a9,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x03b1,0x03b2,0x03b3,0x03b4, 0x03b5,0x03b6,0x03b7,0x03b8,
  0x03b9,0x03ba,0x03bb,0x03bc, 0x03bd,0x03be,0x03bf,0x03c0,
  0x03c1,0x03c3,0x03c4,0x03c5, 0x03c6,0x03c7,0x03c8,0x03c9,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x4741(i:1140) */
  0x2500,0x2502,0x250c,0x2510, 0x2518,0x2514,0x251c,0x252c,
  0x2524,0x2534,0x253c,0x2501, 0x2503,0x250f,0x2513,0x251b,
  0x2517,0x2523,0x2533,0x252b, 0x253b,0x254b,0x2520,0x252f,
  0x2528,0x2537,0x253f,0x251d, 0x2530,0x2525,0x2538,0x2542,
  0x2512,0x2511,0x251a,0x2519, 0x2516,0x2515,0x250e,0x250d,
  0x251e,0x251f,0x2521,0x2522, 0x2526,0x2527,0x2529,0x252a,
  0x252d,0x252e,0x2531,0x2532, 0x2535,0x2536,0x2539,0x253a,
  0x253d,0x253e,0x2540,0x2541, 0x2543,0x2544,0x2545,0x2546,
  0x2547,0x2548,0x2549,0x254a, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x4841(i:1330) */
  0x3395,0x3398,0x33a3,0x33a4, 0x33a5,0x33a6,0x3399,0x339a,
  0x339b,0x339f,0x33a0,0x33a1, 0x33a2,0x33ca,0x338d,0x33cf,
  0x3388,0x3389,0x33c8,0x33a7, 0x33a8,0x33b0,0x33b1,0x33b2,
  0x33b3,0x33b4,0x33b5,0x33b6, 0x33b7,0x33b8,0x33b9,0x3380,
  0x3381,0x3382,0x3383,0x3384, 0x33ba,0x33bb,0x33bc,0x33bd,
  0x33be,0x33bf,0x3390,0x3391, 0x3392,0x3393,0x3394,0x2126,
  0x33c0,0x33c1,0x338a,0x338b, 0x338c,0x33d6,0x33c5,0x33ad,
  0x33ae,0x33af,0x33db,0x33a9, 0x33aa,0x33ab,0x33ac,0x33dd,
  0x33d0,0x33d3,0x33c3,0x33c9, 0x33dc,0x33c6,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x4941(i:1520) */
  0x221d,0x2235,0x222b,0x222c, 0x2208,0x220b,0x2286,0x2287,
  0x2282,0x2283,0x222a,0x2229, 0x2227,0x2228,0x21d2,0x21d4,
  0x2200,0x2203,0x00b4,0xff5e, 0x02c7,0x02d8,0x02dd,0x02da,
  0x02d9,0x00b8,0x02db,0x00a1, 0x00bf,0x02d0,0x222e,0x2211,
  0x220f,0x00a4,0x2109,0x2030, 0x25c1,0x25c0,0x25b7,0x25b6,
  0x2664,0x2660,0x2661,0x2665, 0x2667,0x2663,0x25c9,0x25c8,
  0x25a3,0x25d0,0x25d1,0x2592, 0x25a4,0x25a5,0x25a8,0x25a7,
  0x25a6,0x25a9,0x2668,0x260f, 0x260e,0x261c,0x261e,0x00b6,
  0x2020,0x2021,0x2195,0x2197, 0x2199,0x2196,0x2198,0x266d,
  0x2669,0x266a,0x266c,0x327f, 0x321c,0x2116,0x33c7,0x2122,
  0x33c2,0x33d8,0x2121,0x02ba, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x4a41(i:1710) */
  0x0410,0x0411,0x0412,0x0413, 0x0414,0x0415,0x0401,0x0416,
  0x0417,0x0418,0x0419,0x041a, 0x041b,0x041c,0x041d,0x041e,
  0x041f,0x0420,0x0421,0x0422, 0x0423,0x0424,0x0425,0x0426,
  0x0427,0x0428,0x0429,0x042a, 0x042b,0x042c,0x042d,0x042e,
  0x042f,0x0430,0x0431,0x0432, 0x0433,0x0434,0x0435,0x0451,
  0x0436,0x0437,0x0438,0x0439, 0x043a,0x043b,0x043c,0x043d,
  0x043e,0x043f,0x0440,0x0441, 0x0442,0x0443,0x0444,0x0445,
  0x0446,0x0447,0x0448,0x0449, 0x044a,0x044b,0x044c,0x044d,
  0x044e,0x044f,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x4b41(i:1900) */
  0x00c6,0x00d0,0x00aa,0x0126, 0x0000,0x0132,0x0000,0x013f,
  0x0141,0x00d8,0x0152,0x00ba, 0x00de,0x0166,0x014a,0x0000,
  0x3260,0x3261,0x3262,0x3263, 0x3264,0x3265,0x3266,0x3267,
  0x3268,0x3269,0x326a,0x326b, 0x326c,0x326d,0x326e,0x326f,
  0x3270,0x3271,0x3272,0x3273, 0x3274,0x3275,0x3276,0x3277,
  0x3278,0x3279,0x327a,0x327b, 0x24d0,0x24d1,0x24d2,0x24d3,
  0x24d4,0x24d5,0x24d6,0x24d7, 0x24d8,0x24d9,0x24da,0x24db,
  0x24dc,0x24dd,0x24de,0x24df, 0x24e0,0x24e1,0x24e2,0x24e3,
  0x24e4,0x24e5,0x24e6,0x24e7, 0x24e8,0x24e9,0x2460,0x2461,
  0x2462,0x2463,0x2464,0x2465, 0x2466,0x2467,0x2468,0x2469,
  0x246a,0x246b,0x246c,0x246d, 0x246e,0x00bd,0x2153,0x2154,
  0x00bc,0x00be,0x215b,0x215c, 0x215d,0x215e,0x0000,0x00e6,
  0x0111,0x00f0,0x0127,0x0131, 0x0133,0x0138,0x0140,0x0142,
  0x00f8,0x0153,0x00df,0x00fe, 0x0167,0x014b,0x0149,0x3200,
  0x3201,0x3202,0x3203,0x3204, 0x3205,0x3206,0x3207,0x3208,
  0x3209,0x320a,0x320b,0x320c, 0x320d,0x320e,0x320f,0x3210,
  0x3211,0x3212,0x3213,0x3214, 0x3215,0x3216,0x3217,0x3218,
  0x3219,0x321a,0x321b,0x249c, 0x249d,0x249e,0x249f,0x24a0,
  0x24a1,0x24a2,0x24a3,0x24a4, 0x24a5,0x24a6,0x24a7,0x24a8,
  0x24a9,0x24aa,0x24ab,0x24ac, 0x24ad,0x24ae,0x24af,0x24b0,
  0x24b1,0x24b2,0x24b3,0x24b4, 0x24b5,0x2474,0x2475,0x2476,
  0x2477,0x2478,0x2479,0x247a, 0x247b,0x247c,0x247d,0x247e,
  0x247f,0x2480,0x2481,0x2482, 0x00b9,0x00b2,0x00b3,0x2074,
  0x207f,0x2081,0x2082,0x2083, 0x2084,0x0000,
/* 0x4c41(i:2090) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x4d41(i:2280) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x4e41(i:2470) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x4f41(i:2660) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x5041(i:2850) */
  0x4f3d,0x4f73,0x5047,0x50f9, 0x52a0,0x53ef,0x5475,0x54e5,
  0x5609,0x5ac1,0x5bb6,0x6687, 0x67ef,0x67b6,0x6b4c,0x7a3c,
  0x82db,0x8304,0x8857,0x8888, 0x8a36,0x8cc8,0x8dcf,0x8efb,
  0x8fe6,0x99d5,0x523b,0x5374, 0x5404,0xf843,0x606a,0x64f1,
  0x6bbc,0x73cf,0x811a,0x89ba, 0x89d2,0x95a3,0x520a,0x58be,
  0x5978,0x59e6,0x5e72,0x5e79, 0x61c7,0x63c0,0x6746,0x6f97,
  0x764e,0x770b,0x7a08,0x7aff, 0x7c21,0x826e,0x8271,0x809d,
  0x8aeb,0x9593,0x4e6b,0x559d, 0x66f7,0x6e34,0x78a3,0x7aed,
  0x8910,0x7faf,0x845b,0x97a8, 0x52d8,0x574e,0x582a,0x5d4c,
  0x611f,0x61be,0x6562,0x67d1, 0x6a44,0x6e1b,0x7518,0x75b3,
  0x76e3,0x7d3a,0x9163,0x9451, 0x9f95,0x5323,0x5cac,0x7532,
  0x80db,0x9240,0x9598,0x5ca1, 0x525b,0x59dc,0x5d17,0x5eb7,
  0x5f3a,0x5f4a,0x6177,0x6c5f, 0x7586,0x7db1,0x8941,0x7ce0,
  0x8154,0x8591,0x8b1b,0x92fc, 0x964d,0x4ecb,0x4ef7,0x500b,
  0x51f1,0x6137,0x613e,0x6168, 0x6539,0x69ea,0x6f11,0x75a5,
  0x7686,0x76d6,0x7b87,0x82a5, 0x84cb,0x958b,0x5ba2,0x5751,
  0xf901,0x7cb3,0x7fb9,0x91b5, 0x53bb,0x5c45,0x5de8,0x62d2,
  0x636e,0x64da,0x6e20,0x70ac, 0x64e7,0x8ddd,0x907d,0xf902,
  0xf844,0x92f8,0x4e7e,0x4ef6, 0x5065,0x5dfe,0x5efa,0x6106,
  0x8654,0x8e47,0x9375,0x9a2b, 0x4e5e,0x5091,0x6770,0x5109,
  0x528d,0x6aa2,0x77bc,0x9ed4, 0x52ab,0x602f,0x5048,0x61a9,
  0x63ed,0x64ca,0x683c,0x6a84, 0x6fc0,0x89a1,0x9694,0x9abc,
  0x5805,0x80a9,0x727d,0x72ac, 0x7504,0x7d79,0x7e6d,0x898b,
  0x8b74,0x9063,0x9d51,0x6f54, 0x6c7a,0x7d50,
/* 0x5141(i:3040) */
  0x7f3a,0x8a23,0x517c,0x614a, 0x7b9d,0x84b9,0x8b19,0x938c,
  0x4eac,0x50be,0x52c1,0x52cd, 0x537f,0x54fd,0x5883,0x5e9a,
  0x5f91,0x6176,0x66bb,0x6243, 0x64ce,0x656c,0x666f,0x66f4,
  0x6897,0x6aa0,0x6d87,0x7085, 0x71b2,0x749f,0x74ca,0x754a,
  0x75d9,0x786c,0x78ec,0x7adf, 0x7af6,0x7d45,0x7d93,0x8015,
  0x803f,0x811b,0x8396,0x8b66, 0x8f15,0x9015,0x93e1,0x9803,
  0x9838,0x9a5a,0x9be8,0x4fc2, 0x5553,0x5951,0x5b63,0x5c46,
  0x60b8,0x6212,0x6842,0x68b0, 0x6eaa,0x754c,0x7678,0x78ce,
  0xf845,0x7a3d,0x7cfb,0x7e6b, 0x7e7c,0x8a08,0x8aa1,0x968e,
  0x8c3f,0x96de,0x9dc4,0x53e9, 0x53e4,0x544a,0x5471,0x56fa,
  0x59d1,0x5b64,0x5eab,0x62f7, 0x6537,0x6545,0x6572,0x67af,
  0x6772,0x6cbd,0x75fc,0x7690, 0x8831,0x77bd,0x7a3f,0x777e,
  0x8003,0x80a1,0x818f,0x82e6, 0x85c1,0x88b4,0x8a41,0x8aa5,
  0xf903,0x8f9c,0x932e,0x96c7, 0x9867,0x9ad8,0x9f13,0x54ed,
  0x659b,0x66f2,0x688f,0x7a40, 0x8c37,0x9d60,0x56f0,0x5764,
  0x5d11,0x6606,0x68b1,0x68cd, 0x6efe,0x889e,0x6c68,0xf904,
  0x9aa8,0x4f9b,0x516c,0x5171, 0x529f,0x5b54,0x5de5,0x8ca2,
  0x606d,0x6050,0x62f1,0x63a7, 0x653b,0x6831,0x69d3,0x7a7a,
  0x7b9c,0x5be1,0x6208,0x679c, 0x74dc,0x79d1,0x83d3,0x874c,
  0x8a87,0x8ab2,0x904e,0x9846, 0x5ed3,0x69e8,0x85ff,0x90ed,
  0x970d,0xf905,0x51a0,0x5b98, 0x5bec,0x6163,0x68fa,0x74d8,
  0x6b3e,0x704c,0x76e5,0x7ba1, 0x7f50,0x83c5,0x89c0,0x8cab,
  0x95dc,0x9928,0x9e1b,0x522e, 0x605d,0x62ec,0x9002,0x5149,
  0x5321,0x58d9,0x5ee3,0x66e0, 0x6d38,0x72c2,
/* 0x5241(i:3230) */
  0x73d6,0x7b50,0x80f1,0x945b, 0x5366,0x639b,0x7f6b,0x4e56,
  0x5080,0x584a,0x58de,0x602a, 0x6127,0x62d0,0x69d0,0x9b41,
  0x5b8f,0x7d18,0x80b1,0x8f5f, 0x4ea4,0x50d1,0x54ac,0x55ac,
  0x5b0c,0x5da0,0x5de7,0x654e, 0x652a,0x6821,0x6a4b,0x72e1,
  0x768e,0x77ef,0x7d5e,0x7ff9, 0x81a0,0x854e,0x86df,0x8f03,
  0x8f4e,0x90ca,0x9278,0x9903, 0x9a55,0x9bab,0x4e18,0x4e45,
  0x4e5d,0x4ec7,0x4f5d,0x4ff1, 0x50b4,0x5177,0x52fe,0x5340,
  0x53e3,0x53e5,0x548e,0x5614, 0x57a2,0x5abe,0x5ad7,0x5bc7,
  0x5d87,0x5ed0,0x61fc,0x62d8, 0x6551,0xf846,0x67b8,0x67e9,
  0x69cb,0x6b50,0x6bc6,0x6bec, 0x6c42,0x6e9d,0x7078,0x72d7,
  0x7396,0x7403,0x750c,0x77bf, 0x77e9,0x7a76,0x7d7f,0x8cfc,
  0x81fc,0x8205,0x820a,0x82df, 0x8862,0x89af,0x8b33,0x8ec0,
  0x9011,0x90b1,0x9264,0x98b6, 0x99d2,0x9a45,0x9ce9,0x9dd7,
  0x9f9c,0x570b,0x5c40,0x63ac, 0x83ca,0x97a0,0x9eb4,0x7a98,
  0x7fa4,0x8ecd,0x541b,0x90e1, 0x5800,0x5c48,0x6398,0x7a9f,
  0x5bae,0x5f13,0x7a79,0x7aae, 0x8eac,0x5026,0x5238,0x52f8,
  0x5377,0x5708,0x62f3,0x6b0a, 0x7737,0x53a5,0x8e76,0x95d5,
  0x673a,0x6ac3,0x6f70,0x8a6d, 0x8dea,0x8ecc,0x994b,0x6b78,
  0x8cb4,0x9b3c,0xf907,0x53eb, 0x572d,0x594e,0x63c6,0x73ea,
  0x7845,0x7aba,0x8475,0x7cfe, 0x898f,0x8d73,0x9035,0x95a8,
  0x5747,0x7b60,0x83cc,0x921e, 0xf908,0x6a58,0x514b,0x524b,
  0x5287,0x621f,0x6975,0x68d8, 0x9699,0x50c5,0x52e4,0x5df9,
  0x61c3,0x65a4,0x6839,0x69ff, 0x6f0c,0x747e,0x7b4b,0x82b9,
  0x83eb,0x89b2,0x8b39,0x8fd1, 0x9949,0xf909,
/* 0x5341(i:3420) */
  0x4eca,0x64d2,0x6a8e,0x7434, 0x7981,0x79bd,0x887f,0x887e,
  0x895f,0xf90a,0x9326,0x53ca, 0x5c8c,0x6025,0x6271,0x6c72,
  0x7b08,0x7d1a,0x7d66,0x4e98, 0x5162,0x77dc,0x80af,0x4f01,
  0x4f0e,0x5176,0x5180,0x55dc, 0x5668,0x573b,0x57fa,0x5914,
  0x5947,0x5993,0x5bc4,0x5c90, 0x8c48,0x5d0e,0x5e7e,0x5df1,
  0x5fcc,0x6280,0x65d7,0x65e3, 0x671f,0x675e,0x68cb,0x68c4,
  0x6a5f,0x6b3a,0x6c23,0x6c7d, 0x6c82,0x6dc7,0x7426,0x742a,
  0x74a3,0x7578,0x757f,0x7881, 0x78ef,0x7947,0x7948,0x797a,
  0x7b95,0x7d00,0x7dba,0xf847, 0x8006,0x802d,0x808c,0x671e,
  0x8a18,0x8b4f,0x8d77,0x9321, 0x98e2,0x9951,0x9a0e,0x9a0f,
  0x9a65,0x9c2d,0x9e92,0x7dca, 0x4f76,0x5409,0x62ee,0x6854,
  0x91d1,0xf848,0x55ab,0x513a, 0x61e6,0x62cf,0x62ff,0x7cef,
  0x90a3,0x8afe,0x6696,0x7156, 0x96e3,0x637a,0x634f,0x5357,
  0x5583,0x7537,0x7d0d,0x56ca, 0x5a18,0x66e9,0x4e43,0x5167,
  0x5948,0x67f0,0x8010,0x8ffa, 0x5973,0x5e74,0x79ca,0x5ff5,
  0x606c,0x62c8,0x637b,0x4f5e, 0x5be7,0xf849,0x52aa,0x5974,
  0x5b65,0x5f29,0x6012,0x7459, 0x6fc3,0x81bf,0x8fb2,0x60f1,
  0x8166,0x5c3f,0xf84a,0x5ae9, 0x8a25,0x7d10,0x80fd,0x5c3c,
  0x6ce5,0x533f,0x6eba,0x591a, 0x8336,0x4e39,0x4f46,0x55ae,
  0x5718,0x58c7,0x65b7,0x65e6, 0x6a80,0x6bb5,0x6e4d,0x77ed,
  0x7aef,0x7c1e,0x7dde,0x86cb, 0x8892,0x9132,0x935b,0x977c,
  0x601b,0x64bb,0x737a,0x75b8, 0x9054,0x95e5,0x97c3,0x5556,
  0x64d4,0x66c7,0x6de1,0x6f6d, 0x6fb9,0x75f0,0x8043,0x81bd,
  0x8983,0x8ac7,0x8b5a,0x6c93, 0x7b54,0x8e0f,
/* 0x5441(i:3610) */
  0x905d,0x515a,0x5802,0x5858, 0x5e62,0x5510,0x649e,0x68e0,
  0x7576,0x7cd6,0x87f7,0x9ee8, 0x4ee3,0x5788,0x5927,0x5c0d,
  0x5cb1,0x5e36,0x5f85,0x6234, 0x64e1,0x73b3,0x7893,0x81fa,
  0x888b,0x8cb8,0x968a,0x9edb, 0x5b85,0x5fb7,0x60b3,0x5012,
  0x5200,0x5230,0x5716,0x5835, 0x5857,0x5c0e,0x5c60,0x5cf6,
  0x5ea6,0x5f92,0x60bc,0x6311, 0x6417,0x6843,0x68f9,0x6dd8,
  0x6e21,0x6ed4,0x6fe4,0x71fe, 0x76dc,0x7779,0x79b1,0x7a3b,
  0x8404,0x83df,0x8ced,0x8df3, 0x8e48,0x9003,0x9014,0x9053,
  0x90fd,0x934d,0x9676,0x97dc, 0x6bd2,0x7006,0x7258,0x72a2,
  0x7368,0x7763,0x79bf,0x7be4, 0x7e9b,0x8b80,0x58a9,0x60c7,
  0x6566,0x66be,0x6c8c,0x71c9, 0x8c5a,0x9813,0x5484,0x4e6d,
  0x7a81,0x4edd,0x51ac,0x51cd, 0x52d5,0x540c,0x578c,0x61a7,
  0x6771,0x6850,0x68df,0x6d1e, 0x6f7c,0x7ae5,0x75bc,0x77b3,
  0x8463,0x80f4,0x9285,0x515c, 0x6597,0x675c,0x6793,0x75d8,
  0x7ac7,0x8373,0x809a,0x86aa, 0xf95a,0x8c46,0x982d,0x5c6f,
  0x81c0,0x9041,0x906f,0x920d, 0x5f97,0x6a59,0x6ed5,0x706f,
  0x71c8,0x767b,0x7b49,0x85e4, 0x8b04,0x9127,0x9419,0x9a30,
  0x5587,0x61f6,0x7669,0x7f85, 0x863f,0x87ba,0x88f8,0x908f,
  0xf95c,0x6d1b,0x70d9,0x7296, 0x73de,0x7d61,0x843d,0x916a,
  0x99f1,0x4e82,0x5375,0x5e71, 0x6b04,0x6b12,0x703e,0x721b,
  0x862d,0x9e1e,0x524c,0x57d3, 0x8fa3,0x5d50,0x64e5,0x652c,
  0x6b16,0x6feb,0x7c43,0x7e9c, 0x85cd,0x8964,0x89bd,0x62c9,
  0x81d8,0x881f,0x5eca,0x6717, 0x6994,0x6d6a,0x72fc,0x7405,
  0x746f,0x8782,0x90de,0x4f86, 0x840a,0x51b7,
/* 0x5541(i:3800) */
  0x63a0,0x7565,0x4eae,0x5169, 0x5006,0x51c9,0x6881,0x6dbc,
  0x6a11,0x7cae,0x7cb1,0x7ce7, 0x826f,0x8ad2,0x8f1b,0x91cf,
  0x9b4e,0x4fb6,0x52f5,0x5442, 0x5eec,0x623e,0x65c5,0x6ada,
  0x6ffe,0x7658,0x792a,0x8182, 0x85dc,0x616e,0x8823,0x8821,
  0x9462,0x95ad,0x9a62,0x9a6a, 0x9e97,0x9ece,0x529b,0x6b77,
  0x66c6,0x6adf,0x701d,0x792b, 0x8f62,0x9742,0x6190,0x6200,
  0x6523,0x6f23,0x7149,0x7df4, 0x806f,0x84ee,0x8f26,0x9023,
  0x934a,0x51bd,0x52a3,0x5217, 0x6d0c,0x70c8,0x88c2,0x5ec9,
  0x6582,0x6bae,0x6fc2,0x7c3e, 0x7375,0x9b23,0x4ee4,0x4f36,
  0x56f9,0x5dba,0x601c,0x6624, 0x6ce0,0x73b2,0x7f9a,0x7fce,
  0x82d3,0x86c9,0x901e,0x96f6, 0x9748,0x9234,0x9818,0x9f61,
  0x4f8b,0x79ae,0x91b4,0x96b7, 0x52de,0x6488,0x6ad3,0x6f66,
  0x7210,0x7018,0x76e7,0x8001, 0x826b,0x8606,0x865c,0x8def,
  0x8f05,0x8f64,0x9732,0x9b6f, 0x9dfa,0x9e75,0x6f09,0x788c,
  0xf84b,0x7da0,0x8f46,0x9304, 0x9e93,0x9e7f,0x8ad6,0x58df,
  0x5f04,0x6727,0x7027,0x74cf, 0x7c60,0x807e,0x5121,0x7262,
  0x78ca,0x7c5f,0x857e,0x8a84, 0x8cf4,0x8cc2,0x96f7,0x4e86,
  0x50da,0xf84c,0x5bee,0x5ed6, 0x71ce,0x7642,0x77ad,0x6599,
  0x804a,0x84fc,0x907c,0x9f8d, 0x50c2,0x58d8,0x5c62,0x6a13,
  0x6dda,0x6f0f,0x7d2f,0x7e37, 0x8938,0x964b,0x9acf,0x5289,
  0x67f3,0x69b4,0x6d41,0x6e9c, 0x7409,0x7460,0x7559,0x7624,
  0x786b,0x8b2c,0x985e,0x516d, 0x622e,0x9678,0x502b,0x5d19,
  0x6dea,0x7db8,0x8f2a,0x5f8b, 0x6144,0x6817,0xf961,0x7abf,
  0x9686,0x808b,0x52d2,0x51db, 0x5ee9,0x51cc,
/* 0x5641(i:3990) */
  0x695e,0x7a1c,0x7dbe,0x83f1, 0x9675,0x4fda,0x5229,0x5398,
  0x540f,0x5c65,0x60a7,0xf84d, 0x674e,0x68a8,0x6f13,0x7281,
  0x72f8,0x7406,0x7483,0x75e2, 0x79bb,0x7f79,0x7c6c,0x87ad,
  0x88cf,0x91cc,0x91d0,0x96e2, 0x9b51,0x9bc9,0x541d,0x71d0,
  0x7498,0x85fa,0x8eaa,0x96a3, 0x9c57,0x9e9f,0x6797,0x6dcb,
  0x7433,0x75f3,0x81e8,0x9716, 0x5ca6,0x782c,0x7acb,0x7b20,
  0x7c92,0x5abd,0x6469,0x746a, 0x75f2,0x78e8,0x87c7,0x99ac,
  0x9b54,0x9ebb,0x5bde,0x5e55, 0x6f20,0x819c,0x83ab,0x5a29,
  0x5dd2,0x5f4e,0x6162,0x633d, 0x6669,0x66fc,0x6eff,0x6f2b,
  0x7063,0x779e,0x842c,0x8513, 0x883b,0x8b3e,0x8f13,0x93dd,
  0x9945,0x9b18,0x9c3b,0x62b9, 0x672b,0x6cab,0x896a,0x977a,
  0x4ea1,0x5984,0x5fd8,0x5fd9, 0x671b,0x7db2,0x7f54,0x8292,
  0x832b,0x83bd,0x9099,0x9b4d, 0x57cb,0x59b9,0x5a92,0x5bd0,
  0x6627,0x679a,0x6885,0x6bcf, 0x7164,0x771b,0x7f75,0x82fa,
  0x8cb7,0x8ce3,0x9081,0x9b45, 0x8108,0x8109,0x8c8a,0x964c,
  0x9a40,0x9ea5,0x5b5f,0x6c13, 0x731b,0x76df,0x76f2,0x840c,
  0x51aa,0x8993,0x4fdb,0x514d, 0x52c9,0x5195,0x68c9,0x7704,
  0x7720,0x7dbf,0x7dec,0x9762, 0x9eb5,0x6ec5,0x8511,0x547d,
  0x51a5,0x540d,0x9cf4,0x660e, 0x669d,0x6e9f,0x76bf,0x8317,
  0x879f,0x9169,0x9298,0x8882, 0x4fae,0x52df,0x5e3d,0x59c6,
  0x6155,0x6478,0x66ae,0x5192, 0x67d0,0x6a21,0x6bcd,0x6bdb,
  0x725f,0x7261,0x7738,0x77db, 0x8004,0x8017,0x8305,0x8b00,
  0x8b28,0x8c8c,0x927e,0x6728, 0x6c90,0x7267,0x76ee,0x7766,
  0x7a46,0x6b7f,0x6c92,0x5922, 0x6726,0x6fdb,
/* 0x5741(i:4180) */
  0x77c7,0x8499,0x536f,0x5893, 0x5999,0x5edf,0x63cf,0x6634,
  0x6773,0x6e3a,0x732b,0x82d7, 0x9328,0x52d9,0x5deb,0x61cb,
  0x620a,0x62c7,0x64ab,0x65e0, 0x6b66,0x6bcb,0x7121,0x755d,
  0x7e46,0x821e,0x8302,0x856a, 0x8aa3,0x8cbf,0x9727,0x9d61,
  0x58a8,0x9ed8,0x520e,0x543b, 0x6587,0x6c76,0x7d0b,0x7d0a,
  0x868a,0x9580,0x554f,0x805e, 0x52ff,0x7269,0x5473,0x5a9a,
  0x5c3e,0x5d4b,0x9761,0x5f4c, 0x5fae,0x672a,0x6e3c,0x7030,
  0x7709,0x7c73,0x7cdc,0x7f8e, 0x8587,0x8b0e,0x8ff7,0x60b6,
  0x610d,0x61ab,0x654f,0x65fc, 0x65fb,0x6c11,0x6cef,0x739f,
  0x73c9,0x9594,0x95a9,0x5bc6, 0x871c,0x8b10,0xf84e,0x525d,
  0x535a,0x62cd,0x640f,0x64b2, 0x6734,0x6a38,0x6b02,0x6cca,
  0x7254,0x73c0,0x749e,0x7b94, 0x7e1b,0x7c95,0x818a,0x8236,
  0x8584,0x8feb,0x96f9,0x99c1, 0x4f34,0x534a,0x53cd,0x53db,
  0x62cc,0x642c,0x6500,0x6591, 0x69c3,0x6f58,0x6cee,0x73ed,
  0x7554,0x76e4,0x78fb,0x792c, 0x7d46,0x80d6,0x87e0,0x822c,
  0x8fd4,0x9812,0x98ef,0x52c3, 0x62d4,0x6f51,0x64a5,0x767c,
  0x8dcb,0x91b1,0x9262,0x9aee, 0x9b43,0x5023,0x508d,0x574a,
  0x59a8,0x5c28,0x5e47,0x5f77, 0x623f,0x653e,0x65b9,0x65c1,
  0x6609,0x699c,0x7d21,0x80aa, 0x8180,0x822b,0x82b3,0x84a1,
  0x868c,0x8a2a,0x8b17,0x90a6, 0x9632,0x9ae3,0x9b74,0x9f90,
  0x4ff3,0x500d,0xf963,0x57f9, 0x5f98,0x62dc,0x6392,0x676f,
  0x6e43,0x76c3,0x80da,0x80cc, 0x88f5,0x88f4,0x8919,0x8ce0,
  0x8f29,0x914d,0x966a,0x4f2f, 0x4f70,0x5e1b,0x67cf,0x6822,
  0x767d,0x767e,0x9b44,0x6a0a, 0xf84f,0x7169,
/* 0x5841(i:4370) */
  0x756a,0xf964,0x7e41,0x7ffb, 0x8543,0x85e9,0x98dc,0x4f10,
  0x7b4f,0x7f70,0x95a5,0x51e1, 0x5e06,0x68b5,0x6c3e,0x6c4e,
  0x6cdb,0x72af,0x7bc4,0x8303, 0x6cd5,0x743a,0x50fb,0x5288,
  0x58c1,0x64d8,0x74a7,0x7656, 0x78a7,0x8f9f,0x95e2,0x9739,
  0xf965,0x535e,0x5f01,0x6c74, 0x8fae,0x8b8a,0x8fa8,0x8faf,
  0xf850,0x908a,0x99e2,0x5225, 0x5f46,0x77a5,0x9c49,0x9f08,
  0x4e19,0x5002,0x5175,0x5c5b, 0x5e77,0x661e,0x663a,0x67c4,
  0x70b3,0x7501,0x75c5,0x7add, 0x79c9,0x8f27,0x8ff8,0x9920,
  0x4fdd,0x5821,0x5831,0x5bf6, 0x666e,0x6b65,0x6e7a,0x6d11,
  0x6f7d,0x752b,0x88dc,0x8913, 0x8b5c,0x8f14,0x9d07,0x9efc,
  0x4f0f,0x50d5,0x5310,0x535c, 0x5b93,0x5fa9,0x798f,0x670d,
  0x8179,0x832f,0x8514,0x8986, 0x8760,0x8907,0x8f3b,0x99a5,
  0x9c12,0x672c,0x4e76,0x4e30, 0x4ff8,0x5949,0x5c01,0x5cf0,
  0x5cef,0x6367,0x742b,0x68d2, 0x70fd,0x7e2b,0x8451,0x84ec,
  0x8702,0x9022,0x92d2,0x9cf3, 0x4ec6,0x4ed8,0x5085,0x5256,
  0x526f,0x5426,0x57e0,0x592b, 0x5a66,0x5b75,0x5bcc,0x5e9c,
  0xf966,0x6276,0x6577,0x65a7, 0x6d6e,0x6ea5,0x7236,0x7c3f,
  0x7f36,0x7b26,0x7f58,0x8151, 0x8150,0x819a,0x8299,0x82fb,
  0x8709,0x8a03,0x8ca0,0x8ce6, 0x8cfb,0x8d74,0x8dba,0x90e8,
  0x91dc,0x961c,0x9644,0x982b, 0x99d9,0x9b92,0x9ce7,0x5317,
  0x5206,0x5674,0xf851,0x58b3, 0x5954,0x596e,0x5fff,0x61a4,
  0x626e,0x6c7e,0x711a,0x76c6, 0x7c89,0x7cde,0x7d1b,0x82ac,
  0x8561,0x96f0,0xf967,0x4f5b, 0xf852,0x5f17,0x62c2,0x9af4,
  0x9efb,0x5d29,0x670b,0x68da, 0x787c,0x7e43,
/* 0x5941(i:4560) */
  0x9d6c,0x4e15,0x5099,0x5315, 0x532a,0x5351,0x5983,0x59a3,
  0x5a62,0x5e87,0x60b2,0x618a, 0x6249,0x6279,0x6590,0xf853,
  0x69a7,0x6c98,0xf968,0x6cb8, 0x6bd4,0x6bd8,0x7435,0x75fa,
  0x7765,0x7812,0x7891,0x79d8, 0x7be6,0x7dcb,0x7fe1,0x80a5,
  0x8153,0x813e,0x81c2,0x83f2, 0x871a,0x88e8,0x8ab9,0x8b6c,
  0x8cbb,0x8f61,0x9119,0x975e, 0x98db,0x9ac0,0x9f3b,0x5b2a,
  0x8cd3,0x5f6c,0x64ef,0x658c, 0x6ab3,0x6baf,0x6ff1,0x7015,
  0x725d,0x860b,0x8ca7,0xf854, 0x983b,0x9870,0x9b22,0x6191,
  0x6c37,0x8058,0x9a01,0x4e4d, 0x4e8b,0x4e9b,0x4ed5,0x4f3c,
  0x4f3a,0x820d,0x4f7f,0x50ff, 0x53f2,0x53f8,0x56db,0x5506,
  0x55e3,0x58eb,0x5962,0x59d2, 0x5a11,0x5beb,0x5bfa,0x5df3,
  0x5e2b,0xf855,0x5f99,0x601d, 0x6368,0x8d66,0x65af,0x659c,
  0x67fb,0x68ad,0x6942,0x69ce, 0x6c99,0x6cd7,0x6e23,0x7009,
  0x90aa,0x7345,0x7940,0x793e, 0x7960,0x6b7b,0x7802,0x79c1,
  0x7b25,0x7be9,0x84d1,0x7d17, 0x7d72,0x838e,0x86c7,0x88df,
  0x8a50,0x8a5e,0x8b1d,0x8cdc, 0x5c04,0x8fad,0x8086,0x98fc,
  0x99df,0x524a,0xf969,0x69ca, 0x6714,0xf96a,0x9460,0x5098,
  0x522a,0x5c71,0x6563,0x6c55, 0x73ca,0x7523,0x759d,0x7b97,
  0x849c,0x9178,0x6492,0x6bba, 0x4e77,0x85a9,0x4e09,0xf96b,
  0x6749,0x68ee,0x6e17,0x886b, 0x829f,0x8518,0x6b43,0x63f7,
  0x6f81,0x98af,0x9364,0x970e, 0x4e0a,0x50b7,0x50cf,0x511f,
  0x5546,0x55aa,0x5617,0x723d, 0x5b40,0x5c19,0x5e8a,0x5ea0,
  0x5ec2,0x5e38,0x60f3,0x76f8, 0x6851,0x6a61,0x6ba4,0x6e58,
  0x72c0,0x7240,0x7965,0x7bb1, 0x7fd4,0x88f3,
/* 0x5a41(i:4750) */
  0x89f4,0x8c61,0x8cde,0x8a73, 0x971c,0x585e,0x74bd,0x8cfd,
  0x9c13,0xf96c,0x7a61,0x7d22, 0x8272,0x7272,0x751f,0x7525,
  0xf96d,0x7b19,0x566c,0x58fb, 0x5885,0x5a7f,0x7280,0x5dbc,
  0x5e8f,0x5eb6,0x5f90,0x6055, 0x6292,0x654d,0x6691,0x66d9,
  0x66f8,0x6816,0x68f2,0x745e, 0x7d6e,0x7dd6,0x7f72,0x80e5,
  0x8212,0x85af,0x897f,0x8a93, 0x92e4,0x901d,0x9ecd,0xf856,
  0x9f20,0x5915,0x596d,0xf857, 0x5e2d,0x60dc,0x6614,0x6673,
  0x6790,0x6c50,0x6dc5,0x6f5f, 0x77f3,0x78a9,0x84c6,0x91cb,
  0x932b,0x5148,0x4ed9,0x50ca, 0xf858,0x5584,0x5ba3,0x5c20,
  0x6103,0x6247,0x65cb,0xf859, 0x717d,0x71f9,0x79aa,0x7444,
  0x7487,0x74bf,0x766c,0x7dda, 0x7e55,0x7fa8,0x817a,0x81b3,
  0x8239,0x861a,0x87ec,0x8a75, 0x8de3,0x9078,0x9291,0xf85a,
  0x9bae,0x5070,0x5368,0x820c, 0xf85b,0x5c51,0x6308,0x6954,
  0x6d29,0x6e2b,0x859b,0x8a2d, 0x8aaa,0x96ea,0x6bb2,0x7e96,
  0x87fe,0x8d0d,0x66b9,0x9583, 0x71ee,0x651d,0x6d89,0xf96e,
  0x57ce,0x59d3,0x6027,0x60fa, 0x6210,0x661f,0x665f,0x7329,
  0x76db,0x7701,0x7b6c,0x8056, 0x8072,0x8165,0x8aa0,0x9192,
  0x4e16,0x52e2,0x6b72,0x6d17, 0x7a05,0x7b39,0x7d30,0xf96f,
  0x8cb0,0x53ec,0x562f,0x5851, 0x5c0f,0x5c11,0x5bb5,0x5de2,
  0x6383,0x6414,0x6240,0x662d, 0x68b3,0x6cbc,0x6d88,0x6eaf,
  0x701f,0x70a4,0x71d2,0x7526, 0x758e,0x758f,0x7b11,0x7c2b,
  0x7d20,0x7d39,0x8258,0x852c, 0x856d,0x8607,0x8a34,0x900d,
  0x9061,0x90b5,0x92b7,0x9704, 0x97f6,0x9a37,0x4fd7,0x5c6c,
  0x675f,0x7c9f,0x7e8c,0x901f, 0x5b6b,0x640d,
/* 0x5b41(i:4940) */
  0x905c,0x7387,0x87c0,0x5b8b, 0x677e,0x8a1f,0x8aa6,0x9001,
  0x980c,0x5237,0xf970,0x7051, 0x7463,0x788e,0x9396,0x8870,
  0x91d7,0x4fee,0x53d7,0x53df, 0x56da,0x55fd,0x5782,0x58fd,
  0x5ac2,0x5b88,0xf85c,0x5cab, 0x5e25,0x620d,0x6101,0x624b,
  0x6388,0x641c,0x6536,0x6578, 0x666c,0x6a39,0x6b8a,0x71e7,
  0x6c34,0x6d19,0x6eb2,0x6f31, 0x72e9,0x7378,0x795f,0x7626,
  0x7761,0xf85d,0x79c0,0x7a57, 0x7aea,0x7cb9,0x7d8f,0x7dac,
  0x7e61,0x7f9e,0x8129,0x8331, 0x8490,0x84da,0x85ea,0x8896,
  0x8ab0,0x8f38,0x9042,0x9083, 0x916c,0x9296,0x92b9,0x968b,
  0x96a8,0x96d6,0x9700,0x9808, 0x9996,0x9ad3,0x9b1a,0x53d4,
  0x587e,0x5919,0x5b70,0x5bbf, 0x6dd1,0x719f,0x8085,0x83fd,
  0x5faa,0x6042,0x65ec,0x696f, 0x6b89,0x6d35,0x6df3,0x73e3,
  0x76fe,0x77ac,0x7b4d,0x7d14, 0x8123,0x821c,0x8340,0x8a62,
  0x5de1,0x9187,0x931e,0x9806, 0x99b4,0x9d89,0x620c,0x8853,
  0x8ff0,0x5d07,0x5d27,0x5d69, 0x745f,0x819d,0x8671,0x8768,
  0x62fe,0x6fd5,0x7fd2,0x8936, 0x8972,0x4e1e,0x4e58,0x50e7,
  0x5347,0x627f,0x6607,0x52dd, 0x7e69,0x8805,0x965e,0x4f8d,
  0x5319,0x557b,0x5636,0x59cb, 0x5aa4,0xf85e,0x5c38,0x5c4d,
  0x5e02,0x5f11,0x6043,0x65bd, 0x662f,0x6642,0x67be,0x67f4,
  0x731c,0x77e2,0x793a,0x8996, 0x7de6,0x7fc5,0x8494,0x84cd,
  0x8a69,0x8a66,0x8ae1,0x8c7a, 0x57f4,0x5bd4,0x5f0f,0x606f,
  0x62ed,0x690d,0x6b96,0x6e5c, 0x7184,0x8b58,0x8efe,0x98df,
  0x98fe,0x4f38,0x4fe1,0x547b, 0x5a20,0x5bb8,0x613c,0x65b0,
  0x6668,0x71fc,0x7533,0x77e7, 0x795e,0x7d33,
/* 0x5c41(i:5130) */
  0x814e,0x81e3,0x8398,0x85aa, 0x8703,0x8a0a,0x8eab,0x8f9b,
  0xf971,0x8fc5,0x5931,0x5ba4, 0x5be6,0x6089,0xf85f,0x5be9,
  0x5c0b,0x5fc3,0xf972,0x6c81, 0x6df1,0x700b,0x751a,0x82af,
  0x4ec0,0x5341,0xf973,0x96d9, 0x6c0f,0x4e9e,0x4fc4,0x5152,
  0x5a25,0x5ce8,0x6211,0x7259, 0x82bd,0x86fe,0x8859,0x8a1d,
  0x963f,0x96c5,0x9913,0x9d09, 0x9d5d,0x580a,0x5cb3,0x5dbd,
  0x6115,0x60e1,0x63e1,0x6a02, 0x6e25,0x843c,0x984e,0x9f77,
  0x5b89,0x5cb8,0x6309,0x664f, 0x6848,0x773c,0x96c1,0x8d0b,
  0x978d,0x9854,0x9d08,0x621e, 0x65a1,0x8b01,0x8ecb,0x904f,
  0x95bc,0x5d52,0x5dd6,0x5eb5, 0x6697,0x764c,0x83f4,0x8af3,
  0x95c7,0x9eef,0x58d3,0x62bc, 0x72ce,0x9d28,0x4ef0,0x592e,
  0x600f,0x663b,0x6b83,0x79e7, 0x9785,0x9d26,0x5393,0x57c3,
  0x5d16,0x611b,0x6b38,0x6daf, 0x769a,0x66d6,0x788d,0x7919,
  0x827e,0x54c0,0x9698,0x9744, 0x9749,0x5384,0x6396,0x6db2,
  0x814b,0x9628,0x984d,0x6afb, 0x7f4c,0x9daf,0x9e1a,0x4e5f,
  0x503b,0x51b6,0x591c,0xf860, 0x63f6,0x6930,0x723a,0x8036,
  0xf974,0x60f9,0x91ce,0x5f31, 0x7bdb,0x7c65,0x7d04,0x82e5,
  0x846f,0x85e5,0x8e8d,0x4f6f, 0x58e4,0x5b43,0x6059,0x63da,
  0x6518,0x656d,0x6698,0x694a, 0x6a23,0x6d0b,0x7001,0x716c,
  0x7a70,0x75d2,0x760d,0x7f8a, 0x7f98,0x8944,0x8b93,0x91c0,
  0x967d,0x990a,0x5704,0x5fa1, 0x6554,0x65bc,0x6f01,0x79a6,
  0x8a9e,0x99ad,0x9b5a,0x9f6c, 0x5104,0x61b6,0x6291,0x6a8d,
  0x81c6,0x5043,0x5830,0x5f66, 0x7109,0x8a00,0x8afa,0x5b7c,
  0x513c,0x56b4,0x5944,0x63a9, 0x6df9,0x5daa,
/* 0x5d41(i:5320) */
  0x696d,0x605a,0x4e88,0x4f59, 0x5982,0x6b5f,0x6c5d,0x8207,
  0x9918,0x4ea6,0x57df,0xf861, 0x5f79,0x6613,0x75ab,0x7e79,
  0x8b6f,0x9006,0x9a5b,0x56a5, 0x5827,0x59f8,0x5a1f,0x5bb4,
  0x5ef6,0x6350,0xf991,0x693d, 0x6cbf,0x6d93,0x6d8e,0x6df5,
  0x6f14,0x70df,0x7136,0x7159, 0x71c3,0x71d5,0x784f,0x786f,
  0x7b75,0x7de3,0xf862,0x81d9, 0x8815,0x884d,0x8b8c,0x8edf,
  0x925b,0x9cf6,0xf99e,0x6085, 0x6d85,0x71b1,0xf9a1,0x95b1,
  0x53ad,0x5869,0x67d3,0x708e, 0x7130,0x9e7d,0x82d2,0x8276,
  0x95bb,0x995c,0x9ae5,0x66c4, 0x71c1,0x8449,0x584b,0x5b30,
  0x5f71,0x6620,0x668e,0x6979, 0x69ae,0x6c38,0x6cf3,0x6f41,
  0x701b,0x71df,0x745b,0xf9ae, 0x74d4,0x76c8,0x7e93,0x82f1,
  0x8a60,0x8fce,0x502a,0x5208, 0x53e1,0x66f3,0x6fca,0x730a,
  0x7768,0x777f,0x7ff3,0x82ae, 0x854b,0x85dd,0x8602,0x88d4,
  0x8a63,0x8b7d,0x8c6b,0x92b3, 0x9713,0x9810,0x4e94,0x4f0d,
  0x50b2,0x5348,0x5433,0x55da, 0x58ba,0x5967,0x5a1b,0x5be4,
  0x609f,0xf9b9,0x65ff,0x6664, 0x68a7,0x6c5a,0x70cf,0x7352,
  0x8708,0x8aa4,0x9068,0x543e, 0x5c4b,0x6c83,0x7344,0x7389,
  0x923a,0x5abc,0x6eab,0x7465, 0x761f,0x7a69,0x8580,0x860a,
  0x9c2e,0x5140,0x58c5,0x74ee, 0x7670,0x64c1,0x7515,0x7fc1,
  0x9095,0x96cd,0x6e26,0x74e6, 0x7aa9,0x86d9,0x8778,0x8a1b,
  0x81e5,0x5a49,0x5b8c,0x5b9b, 0x6d63,0x73a9,0x742c,0x7897,
  0x7de9,0x7feb,0x8155,0x839e, 0x8c4c,0x962e,0x9811,0x66f0,
  0x5f80,0x65fa,0x6789,0x6c6a, 0x738b,0x502d,0x6b6a,0x77ee,
  0x5916,0x5dcd,0x7325,0x754f, 0x50e5,0x51f9,
/* 0x5e41(i:5510) */
  0x582f,0x592d,0x5996,0x59da, 0x5da2,0x62d7,0x6416,0x64fe,
  0x66dc,0x8170,0xf9bf,0x6a48, 0x7464,0x7a88,0x7aaf,0x7e47,
  0x7e5e,0x8000,0x8558,0x87ef, 0x8981,0x8b20,0x9059,0x9080,
  0x9952,0x8fb1,0x617e,0x6b32, 0x6d74,0x8925,0x50ad,0x52c7,
  0x5bb9,0x5eb8,0x5197,0x6995, 0x6e67,0x6eb6,0x7194,0x7462,
  0x7528,0x8073,0x8202,0x8338, 0x84c9,0x86f9,0x8e0a,0x9394,
  0x93de,0x4f51,0x5076,0x512a, 0x53c8,0x53cb,0x53f3,0x5401,
  0x5b87,0x5bd3,0x5c24,0x4e8e, 0x611a,0x6182,0x725b,0x76c2,
  0x7950,0x7991,0x79b9,0x7fbd, 0x828b,0x865e,0x8fc2,0x9047,
  0x90f5,0x9685,0x96e8,0x96e9, 0x65ed,0x6631,0x715c,0x7a36,
  0x90c1,0x980a,0x4e91,0xf9c5, 0x6b9e,0x8018,0x82b8,0x904b,
  0x9695,0x96f2,0x97fb,0x71a8, 0x851a,0x9b31,0x718a,0x96c4,
  0x5143,0x539f,0x54e1,0x5712, 0x5713,0x7230,0x57a3,0x5a9b,
  0x5bc3,0x6028,0x613f,0x63f4, 0x6e90,0x733f,0x7457,0x82d1,
  0x873f,0x8881,0x8f45,0x9060, 0x9662,0x9858,0x9d1b,0x6708,
  0x8d8a,0x925e,0x4f4d,0x5049, 0x50de,0x5371,0x570d,0x59d4,
  0x5c09,0x5e43,0x6170,0x5a01, 0x6e2d,0x7232,0x744b,0x7def,
  0x80c3,0x840e,0x8466,0x875f, 0x885b,0x885e,0x8b02,0x9055,
  0x97cb,0x9b4f,0x4e73,0x6538, 0x4f91,0x5112,0x516a,0x5e7c,
  0x552f,0x55a9,0x56ff,0x5b7a, 0x5ba5,0x5e37,0x5e7d,0x5ebe,
  0x60a0,0x60df,0x6109,0x6108, 0x63c4,0x6709,0x67d4,0x67da,
  0x6961,0x6cb9,0x6e38,0x6fe1, 0x7336,0x745c,0x7531,0x7652,
  0x7dad,0x81fe,0x8438,0x8564, 0x88d5,0x8a98,0x8adb,0x8aed,
  0x8e42,0x8e30,0x904a,0x903e, 0x907a,0x9149,
/* 0x5f41(i:5700) */
  0x91c9,0x936e,0x9edd,0x6bd3, 0x8089,0x80b2,0x9b3b,0x5141,
  0x596b,0x5c39,0x6f64,0x73a7, 0x80e4,0x958f,0x807f,0x620e,
  0x7d68,0x878d,0x57a0,0x6069, 0x6147,0x6abc,0x6bb7,0x73e2,
  0x9280,0x8abe,0x96b1,0x9f66, 0x4e59,0x541f,0x6deb,0x852d,
  0x9670,0x98ee,0x97f3,0x6339, 0x63d6,0x6ce3,0x9091,0x51dd,
  0x61c9,0x81ba,0x9df9,0x4f9d, 0x501a,0x5100,0x7591,0x77e3,
  0x5b9c,0x610f,0x61ff,0x64ec, 0x6bc5,0x7fa9,0x8264,0x87fb,
  0x8863,0x8abc,0x8b70,0x91ab, 0x4e8c,0x4ee5,0x4f0a,0x5937,
  0x59e8,0x5df2,0x8cb3,0x5f1b, 0x5f5b,0x6021,0xf9e0,0x682e,
  0x723e,0x73e5,0x7570,0x75cd, 0x79fb,0x800c,0x8033,0x8351,
  0x98f4,0x990c,0x9823,0x7037, 0x7ffc,0x76ca,0x7fca,0x7fcc,
  0x4eba,0x4ec1,0x4ede,0x5203, 0x5370,0x54bd,0x56e0,0x59fb,
  0x5bc5,0x5f15,0x5fcd,0x6e6e, 0x8a8d,0x976d,0x9777,0x4e00,
  0x4f7e,0x58f9,0x65e5,0x6ea2, 0x9038,0x93b0,0x99b9,0x4efb,
  0x58ec,0x598a,0x59d9,0x7a14, 0x834f,0x8cc3,0x5165,0x4ecd,
  0x5b55,0x5269,0x4ed4,0x523a, 0x54a8,0x59c9,0x59ff,0x5b50,
  0x5b5c,0x5b57,0x6063,0x6148, 0x6ecb,0x7099,0x716e,0x7386,
  0x74f7,0x75b5,0x7725,0x78c1, 0x7ca2,0x7d2b,0x8005,0x8014,
  0x81ea,0x8517,0x85c9,0x89dc, 0x8aee,0x8cc7,0x8d6d,0x96cc,
  0x4f5c,0x52fa,0x56bc,0x65ab, 0x6628,0x67de,0x707c,0x70b8,
  0x7235,0x7dbd,0x828d,0x914c, 0x96c0,0x9d72,0x68e7,0x6b98,
  0x6f7a,0x76de,0x5c91,0x66ab, 0x6f5b,0x6f5c,0x7bb4,0x7c2a,
  0x8695,0x8836,0x96dc,0x4e08, 0x4ed7,0x5320,0x5834,0x58bb,
  0x596c,0x5d82,0x5e33,0x5e84, 0x5f35,0x638c,
/* 0x6041(i:5890) */
  0x66b2,0x6756,0x6a1f,0x6aa3, 0x6b0c,0x6f3f,0x58ef,0x5c07,
  0x7246,0xf9fa,0x7350,0x748b, 0x7634,0x7ae0,0x7ca7,0x8178,
  0x81df,0x838a,0x846c,0x8523, 0x8594,0x85cf,0x88c5,0x88dd,
  0x8d13,0x91ac,0x9577,0x969c, 0x518d,0x54c9,0x5728,0x5bb0,
  0x624d,0x6750,0x683d,0x6893, 0x6ed3,0x707d,0x7e94,0x88c1,
  0x8ca1,0x8f09,0x9f4b,0x9f4e, 0x722d,0x7b8f,0x8acd,0x931a,
  0x4f4e,0x4f47,0x5132,0x5480, 0x59d0,0x5e95,0x62b5,0x6775,
  0x67e2,0x696e,0x6a17,0x6cae, 0x6e1a,0x72d9,0x732a,0x75bd,
  0x7bb8,0x82e7,0x8457,0x85f7, 0x86c6,0x8a5b,0x8c6c,0x8caf,
  0x8e87,0x9019,0x90b8,0x52e3, 0x5ae1,0x5bc2,0x6458,0x6575,
  0x6ef4,0x72c4,0x7684,0x7a4d, 0x7b1b,0x7c4d,0x7cf4,0x7e3e,
  0x837b,0x8b2b,0x8cca,0x8d64, 0x8de1,0x8e5f,0x8fea,0x8ff9,
  0x9069,0x50b3,0x5168,0x5178, 0x524d,0x526a,0x56c0,0x5861,
  0x5960,0x5c08,0x5c55,0x5dd3, 0x5edb,0x609b,0x6230,0x6813,
  0x6bbf,0x6c08,0x6fb1,0x714e, 0x7530,0x7538,0x7672,0x78da,
  0x7b8b,0x7bad,0x7bc6,0x7e8f, 0x7fe6,0x8a6e,0x8f3e,0x8f49,
  0x923f,0x9293,0x9322,0x96fb, 0x985a,0x986b,0x991e,0x5207,
  0x622a,0x6298,0x6d59,0x7a83, 0x7aca,0x7bc0,0x7d76,0x5360,
  0x5cbe,0x5e97,0x6f38,0x70b9, 0x9ede,0x7c98,0x9711,0x63a5,
  0x647a,0x6904,0x8776,0x4e01, 0x4e95,0x4ead,0x505c,0x5075,
  0x5448,0x59c3,0x5e40,0x5ef7, 0x5f81,0x5b9a,0x5ead,0x60c5,
  0x633a,0x653f,0x6574,0x65cc, 0x6676,0x6678,0x6883,0x6968,
  0x6b63,0x6c40,0x6de8,0x6e1f, 0x753a,0x775b,0x7887,0x798e,
  0x7a0b,0x7a7d,0x9756,0x7cbe, 0x8247,0x8a02,
/* 0x6141(i:6080) */
  0x8aea,0x8c9e,0x912d,0x914a, 0x91d8,0x9266,0x9320,0x9706,
  0x975c,0x9802,0x9f0e,0x5236, 0x5291,0x557c,0x5824,0x5e1d,
  0x5f1f,0x608c,0x63d0,0x6662, 0x68af,0x6fdf,0x7445,0x81cd,
  0x796d,0x7b2c,0x85ba,0x88fd, 0x8af8,0x8e36,0x8e44,0x918d,
  0x9664,0x969b,0x973d,0x984c, 0x9f4a,0x4fce,0x51cb,0x5146,
  0x52a9,0xf863,0x5632,0x566a, 0x5f14,0x5f6b,0x63aa,0x64cd,
  0x65e9,0x6641,0x66fa,0x66f9, 0x671d,0x689d,0x68d7,0x69fd,
  0x6f15,0x6f6e,0x7167,0x71e5, 0x722a,0x7681,0x773a,0x7956,
  0x795a,0x79df,0x7a20,0x7a95, 0x7ac8,0x7b0a,0x7c97,0x7cdf,
  0x7cf6,0x7d44,0x7d5b,0x7e70, 0x8087,0x85fb,0x86a4,0x8a54,
  0x8abf,0x8d99,0x8e81,0x9020, 0x906d,0x91e3,0x963b,0x9bdb,
  0x9ce5,0x65cf,0x7c07,0x8db3, 0x93c3,0x5b58,0x5c0a,0x5352,
  0x62d9,0x731d,0x5027,0x5b97, 0x5f9e,0x616b,0x68d5,0x6a05,
  0x6dd9,0x742e,0x7a2e,0x7d42, 0x7d9c,0x7e31,0x816b,0x8e35,
  0x8e64,0x937e,0x9418,0x4f50, 0x5750,0x5de6,0x5ea7,0x632b,
  0x7f6a,0x4e3b,0x4f4f,0x4f8f, 0x505a,0x5eda,0x546a,0x5468,
  0x55fe,0x594f,0x5b99,0x5dde, 0x665d,0x6731,0x67f1,0x682a,
  0x70b7,0x6ce8,0x6d32,0x9152, 0x73e0,0x7587,0x851f,0x7c4c,
  0x7d02,0x7d2c,0x7da2,0x8098, 0x80c4,0x821f,0x86db,0x8a3b,
  0x8a85,0x8d70,0x8e8a,0x8f33, 0x914e,0x9031,0x9444,0x99d0,
  0x7af9,0x7ca5,0x4fca,0x5101, 0x51c6,0x57c8,0x5cfb,0x6659,
  0x6a3d,0x6d5a,0x6e96,0x6fec, 0x756f,0x7ae3,0x8822,0x9021,
  0x9075,0x96bc,0x99ff,0x8301, 0x4e2d,0x4ef2,0x8846,0x91cd,
  0xf864,0x537d,0x6adb,0x696b, 0x6c41,0x847a,
/* 0x6241(i:6270) */
  0x589e,0x618e,0x62ef,0x70dd, 0x66fe,0x7511,0x75c7,0x84b8,
  0x8a3c,0x8b49,0x8d08,0x4e4b, 0x53ea,0x54ab,0x5730,0x5740,
  0x5fd7,0x6301,0x6307,0x646f, 0x652f,0x65e8,0x667a,0x679d,
  0x67b3,0x6b62,0x6c60,0x6f2c, 0x75e3,0x77e5,0x7825,0x7957,
  0x7949,0x7d19,0x80a2,0x8102, 0x81f3,0x829d,0x8718,0x8a8c,
  0xf9fc,0x8d04,0x8dbe,0x9072, 0x76f4,0x7a19,0x7a37,0x7e54,
  0x8077,0x8fb0,0x55d4,0x5875, 0x632f,0x6649,0x699b,0x6d25,
  0x6eb1,0x73cd,0x7468,0x74a1, 0x75b9,0x76e1,0x771e,0x778b,
  0x79e6,0x7e09,0x8a3a,0x8cd1, 0x8eeb,0x9032,0x93ad,0x9663,
  0x9673,0x9707,0x53f1,0x7a92, 0x59ea,0x5ac9,0x5e19,0x684e,
  0x75be,0x79e9,0x81a3,0x86ed, 0x8cea,0x8dcc,0x8fed,0x659f,
  0x6715,0x57f7,0x96c6,0x7ddd, 0x8f2f,0x5fb5,0x61f2,0x6f84,
  0x4e14,0x501f,0x7b9a,0x53c9, 0x55df,0x5dee,0x5d6f,0x6b21,
  0x6b64,0x78cb,0xf9fe,0x8e49, 0x906e,0x8eca,0x6349,0x643e,
  0x7740,0x7a84,0x932f,0x947f, 0x9f6a,0x64b0,0x6faf,0x71e6,
  0x74a8,0x74da,0x7ac4,0x7e82, 0x7cb2,0x7e98,0x8b9a,0x8d0a,
  0x947d,0xf865,0x9910,0x994c, 0x5239,0x5bdf,0x64e6,0x672d,
  0x50ed,0x53c3,0x5879,0x6158, 0x6159,0x615a,0x61fa,0x65ac,
  0x7ad9,0x8b92,0x5021,0x5009, 0x5231,0x5275,0x5531,0x5a3c,
  0x5ee0,0x5f70,0x60b5,0x655e, 0x660c,0x6636,0x66a2,0x69cd,
  0x6c05,0x6ec4,0x6f32,0x7621, 0x7a93,0x8139,0x8259,0x83d6,
  0x84bc,0x50b5,0x57f0,0x5f69, 0x63a1,0x7826,0x7db5,0x83dc,
  0x8521,0x91c7,0x91f5,0x518a, 0x67f5,0x7b56,0x7c00,0x8cac,
  0x51c4,0x59bb,0x60bd,0x8655, 0xf9ff,0x5254,
/* 0x6341(i:6460) */
  0x5c3a,0x617d,0x621a,0x62d3, 0x64f2,0x65a5,0x6ecc,0x7620,
  0x810a,0x8734,0x8e91,0x965f, 0x96bb,0x4edf,0x5343,0x5598,
  0x5929,0x5ddd,0x64c5,0x6cc9, 0x6dfa,0x6ffa,0x7a7f,0x821b,
  0x85a6,0x8ce4,0x8e10,0x9077, 0x91e7,0x95e1,0x9621,0x97c6,
  0x51f8,0x5fb9,0x54f2,0x5586, 0x64a4,0x6f88,0x7db4,0x8f4d,
  0x9435,0x50c9,0x5c16,0x6cbe, 0x6dfb,0x751b,0x77bb,0x7c37,
  0x7c64,0x8ac2,0x59be,0x5e16, 0x6377,0x7252,0x758a,0x776b,
  0x8adc,0x8cbc,0x8f12,0x5ef3, 0x6674,0x6df8,0x807d,0x83c1,
  0x873b,0x8acb,0x9751,0x9bd6, 0xfa00,0x5243,0x66ff,0x6d95,
  0x6eef,0x780c,0x7de0,0x8ae6, 0x902e,0x905e,0x9746,0x9ad4,
  0x521d,0x54e8,0x5ced,0x6194, 0x6284,0x62db,0x68a2,0x6912,
  0x695a,0x6a35,0x7092,0x7126, 0x785d,0x7901,0x790e,0x79d2,
  0x7a0d,0x7d83,0x8096,0x8349, 0x8549,0x8c82,0x8d85,0x9162,
  0x918b,0x91ae,0x9214,0x9798, 0x4fc3,0x56d1,0xf866,0x71ed,
  0x77d7,0x8700,0x89f8,0x8e85, 0x9ad1,0x5bf8,0x5fd6,0x6751,
  0x53e2,0x585a,0x5bf5,0x6031, 0x6460,0x7e3d,0x8070,0x8471,
  0x9283,0x64ae,0x50ac,0x5d14, 0x6467,0x6700,0x589c,0x62bd,
  0x63a8,0x690e,0x6978,0xf867, 0x6a1e,0x6e6b,0x7503,0x76ba,
  0x79cb,0x7b92,0x82bb,0x8429, 0x8da8,0x8ffd,0x9112,0x914b,
  0x919c,0x9318,0x9310,0x96db, 0x97a6,0x9c0d,0x9e81,0x9ea4,
  0x4e11,0xf868,0x795d,0x755c, 0x7afa,0x7b51,0x7bc9,0x7e2e,
  0x8233,0x84c4,0x8e74,0x8ef8, 0x9010,0x6625,0x693f,0x51fa,
  0x9edc,0x5145,0x51b2,0x5fe0, 0x6c96,0x87f2,0x885d,0x8877,
  0x60b4,0x81b5,0x8403,0x53d6, 0x5439,0x5634,
/* 0x6441(i:6650) */
  0x5a36,0x5c31,0x6a47,0x708a, 0x7fe0,0x805a,0x8106,0x81ed,
  0xf869,0x8da3,0x9189,0x9a5f, 0x9df2,0x4ec4,0x5074,0x60fb,
  0x6e2c,0x5c64,0x4f88,0x5024, 0x55e4,0x5cd9,0x5df5,0x5e5f,
  0x5fb4,0x6894,0x6cbb,0x6dc4, 0x71be,0x75d4,0x75f4,0x7661,
  0x96c9,0x7a1a,0x7dc7,0x7dfb, 0x7f6e,0x6065,0x81f4,0x8f1c,
  0x99b3,0x9d44,0x9f52,0x5247, 0x52c5,0x98ed,0x89aa,0x4e03,
  0x67d2,0x6f06,0x4fb5,0x5be2, 0x5ff1,0x6795,0x6c88,0x6d78,
  0x7827,0x91dd,0x937c,0x87c4, 0x79e4,0x7a31,0x5feb,0x4ed6,
  0x553e,0x58ae,0x59a5,0x60f0, 0x6253,0x6736,0x6955,0x8235,
  0x9640,0x99dd,0x502c,0x5353, 0x5544,0xfa01,0x6258,0x62c6,
  0xfa02,0x64e2,0x67dd,0x6a50, 0x6fc1,0x6fef,0x7422,0x8a17,
  0x9438,0x5451,0x5606,0x5766, 0x5f48,0x619a,0x6b4e,0x7058,
  0x70ad,0x7dbb,0x8a95,0x596a, 0x812b,0x63a2,0x803d,0x8caa,
  0x5854,0x642d,0x69bb,0x5b95, 0x5e11,0x6e6f,0x8569,0x514c,
  0x53f0,0x592a,0x6020,0x614b, 0x6b86,0x6c70,0x6cf0,0x7b1e,
  0x80ce,0x82d4,0x8dc6,0x90b0, 0x98b1,0x99c4,0xfa04,0x64c7,
  0x6fa4,0xf86a,0x6491,0x6504, 0x514e,0x5410,0x571f,0x8a0e,
  0x615f,0x6876,0xfa05,0x75db, 0x7b52,0x7d71,0x901a,0x5806,
  0x817f,0x892a,0x9000,0x9839, 0x5078,0x5957,0x59ac,0x6295,
  0x900f,0x9b2a,0x615d,0x7279, 0x5a46,0x5761,0x5df4,0x628a,
  0x64ad,0x6777,0x6ce2,0x6d3e, 0x722c,0x7436,0x7834,0x7f77,
  0x82ad,0x8ddb,0x9817,0x5742, 0x5224,0x677f,0x7248,0x8ca9,
  0x8fa6,0x74e3,0x962a,0x516b, 0x53ed,0x634c,0x4f69,0x5504,
  0x6096,0x6c9b,0x6d7f,0x724c, 0x72fd,0x7a17,
/* 0x6541(i:6840) */
  0x8c9d,0x6557,0x8987,0x5f6d, 0x6f8e,0x70f9,0x81a8,0x610e,
  0x4fbf,0x504f,0x6241,0x7247, 0x7bc7,0x7de8,0x7fe9,0x8759,
  0x904d,0x97ad,0x8cb6,0x576a, 0x5e73,0x840d,0x8a55,0x5420,
  0x5b16,0x5e63,0x5ee2,0x5f0a, 0x6583,0x80ba,0x853d,0x9589,
  0x965b,0x4f48,0x5305,0x530d, 0x530f,0x5486,0x54fa,0x5703,
  0x5e96,0x5e03,0x6016,0x62b1, 0x629b,0x6355,0x6ce1,0x6d66,
  0x70ae,0x75b1,0x7832,0x80de, 0x812f,0x8216,0x8461,0x84b2,
  0x888d,0x8912,0x924b,0x92ea, 0x9784,0x98fd,0x9b91,0x5e45,
  0x66b4,0x7011,0x7206,0x4ff5, 0x527d,0x5f6a,0x6153,0x6753,
  0x6a19,0x6f02,0x74e2,0x7968, 0x8868,0x8c79,0x98c4,0xf86b,
  0x54c1,0x7a1f,0x99ae,0x6953, 0x8af7,0x8c4a,0x98a8,0x5f7c,
  0x62ab,0x75b2,0x76ae,0x84d6, 0x88ab,0x907f,0x5339,0x5f3c,
  0x5fc5,0x6ccc,0x7562,0x758b, 0x7b46,0x8e55,0x4e4f,0x903c,
  0x4e0b,0x4f55,0x590f,0x5ec8, 0x6630,0x6cb3,0x7455,0x8766,
  0x8377,0x8cc0,0x9050,0x971e, 0x9c15,0x58d1,0x5b78,0x7627,
  0x8650,0x8b14,0x9db4,0x5bd2, 0x6068,0x608d,0x65f1,0x6c57,
  0x6f22,0x6fa3,0x7f55,0x7ff0, 0xf86c,0x9592,0x9591,0x9650,
  0x97d3,0x9df3,0x5272,0x8f44, 0x51fd,0x542b,0x54b8,0x5563,
  0x558a,0x6abb,0x6db5,0x7dd8, 0x8266,0x9677,0x5408,0x54c8,
  0x76d2,0x86e4,0x95a4,0x965c, 0x4ea2,0x4f09,0x59ee,0x5df7,
  0x6052,0x6297,0x676d,0x6841, 0x6c86,0x6e2f,0x7095,0x7f38,
  0x809b,0x822a,0xfa09,0x9805, 0x4ea5,0x5055,0x54b3,0x595a,
  0x5793,0x5b69,0x5bb3,0x5ee8, 0x61c8,0x6977,0x6d77,0x87f9,
  0x89e3,0x8a72,0x8ae7,0x9082, 0x99ed,0x9ab8,
/* 0x6641(i:7030) */
  0x52be,0x6838,0x5016,0x5e78, 0x674f,0x884c,0x4eab,0x5411,
  0x56ae,0x9115,0x73e6,0x97ff, 0x9909,0x9957,0x9999,0x5653,
  0x589f,0x865b,0x8a31,0x61b2, 0x8ed2,0x737b,0x6b47,0x96aa,
  0x9a57,0x5955,0x7200,0x8d6b, 0x9769,0x5cf4,0x5f26,0x61f8,
  0x70ab,0x73fe,0x7384,0x7729, 0x7d43,0x7d62,0x7e23,0x8237,
  0x8852,0xfa0a,0x8ce2,0x9249, 0x986f,0x5b51,0x7a74,0x8840,
  0x9801,0x5acc,0xf86d,0x4fe0, 0x5354,0x593e,0x5cfd,0x633e,
  0x6d79,0x72f9,0x7bcb,0x8107, 0x8105,0x83a2,0xf86e,0x92cf,
  0x9830,0x4ea8,0x5211,0x578b, 0x5f62,0x5144,0x7005,0x70af,
  0x73e9,0x834a,0x87a2,0x8861, 0x90a2,0x93a3,0x99a8,0x516e,
  0x5f57,0x60e0,0x6167,0x8559, 0x91af,0x978b,0x4e4e,0x4e92,
  0x8c6a,0x547c,0x58fa,0x58d5, 0x597d,0x5f27,0x660a,0x6236,
  0x6beb,0x6d69,0x6dcf,0x6e56, 0x6ef8,0x6f94,0x6fe9,0x6fe0,
  0x705d,0x72d0,0x745a,0x74e0, 0x7693,0x769e,0x795c,0x7cca,
  0x7e1e,0x80e1,0x846b,0x864e, 0x865f,0x8774,0x8b77,0x6248,
  0x9190,0x93ac,0x9800,0x9865, 0x60d1,0x6216,0x9177,0x5a5a,
  0x660f,0x6df7,0x6e3e,0x743f, 0x9b42,0x5ffd,0x60da,0x7b0f,
  0x9dbb,0x5f18,0x54c4,0x6c5e, 0x6cd3,0x6d2a,0x9d3b,0x7d05,
  0x8679,0x8a0c,0x5316,0x5b05, 0x6a3a,0x706b,0x798d,0x7575,
  0x79be,0x548c,0x82b1,0x83ef, 0x8a71,0x9774,0x8ca8,0xfa0b,
  0x64f4,0x652b,0x78ba,0x78bb, 0x7a6b,0x944a,0x4e38,0x559a,
  0x571c,0x5ba6,0x5e7b,0x60a3, 0x61fd,0x63db,0x6853,0x6b61,
  0x6e19,0x7165,0x74b0,0x7d08, 0x9084,0x9a69,0x9c25,0x9b1f,
  0x6d3b,0x6ed1,0x733e,0x8c41, 0x95ca,0x51f0,
/* 0x6741(i:7220) */
  0x5a93,0x5fa8,0x6033,0x604d, 0x614c,0x60f6,0x6643,0x6cc1,
  0x6ec9,0x714c,0x7687,0x7bc1, 0x8352,0x8757,0x9051,0x968d,
  0x9ec3,0x56de,0x5efb,0x5f8a, 0x6062,0x6094,0x61f7,0x6666,
  0x6703,0x6a9c,0x6dee,0x6fae, 0x7070,0x736a,0x7e6a,0x81be,
  0x86d4,0x8aa8,0x8cc4,0x5283, 0x7372,0x6a6b,0x54ee,0x5686,
  0x56c2,0x5b5d,0x6548,0x66c9, 0x689f,0x723b,0x80b4,0x9175,
  0x4faf,0x5019,0x539a,0x540e, 0x543c,0x5589,0x55c5,0x5f8c,
  0x673d,0x7334,0x9005,0x7bcc, 0x52f3,0x5864,0x58ce,0x6688,
  0x7104,0x718f,0x71fb,0x85b0, 0x8a13,0x85a8,0x55a7,0x8431,
  0x5349,0x5599,0x6bc1,0x5f59, 0x5fbd,0x63ee,0x6689,0x7147,
  0x8af1,0x8f1d,0x9ebe,0x4f11, 0x643a,0x70cb,0x7566,0x8667,
  0x6064,0x8b4e,0x9df8,0x51f6, 0x5308,0x5147,0x6d36,0x80f8,
  0x9ed1,0x5ffb,0x6615,0x6b23, 0x75d5,0x5403,0x5c79,0x7d07,
  0x8fc4,0x6b20,0x6b46,0x6b3d, 0x5438,0x6070,0x6d3d,0x8208,
  0x50d6,0x559c,0x566b,0x59ec, 0x5b09,0x5e0c,0x66e6,0x6199,
  0x6231,0x72a7,0x7199,0x51de, 0x71b9,0x79a7,0x7a00,0x7fb2,
  0x8a70,0x9821,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x6841(i:7410) */
  0x67b7,0x73c2,0x75c2,0x6164, 0x4f83,0x67ec,0x687f,0x78f5,
  0x874e,0x6221,0x77b0,0x90af, 0x9452,0x5808,0x757a,0x7d73,
  0x7f8c,0x8221,0x9c47,0x584f, 0xf900,0x93a7,0x5580,0x5028,
  0x795b,0x8e1e,0x9245,0x6957, 0x8171,0x6840,0x5292,0x9210,
  0x8ff2,0x8188,0x6289,0x9257, 0x4fd3,0x501e,0x5106,0x5770,
  0x61ac,0x70f1,0x74a5,0x583a, 0x68e8,0x5c3b,0x66a0,0x69c1,
  0x7f94,0x82fd,0x83f0,0x7428, 0x9be4,0x73d9,0x86a3,0x978f,
  0x4e32,0x8de8,0x934b,0x742f, 0x4f8a,0x709a,0x5775,0x8009,
  0x92b6,0x97ab,0x88d9,0x828e, 0x6372,0x6dc3,0x7357,0x8568,
  0xf906,0x6677,0x69fb,0x7ac5, 0x52fb,0x7547,0x52a4,0x5997,
  0x6611,0x82a9,0x4f0b,0x57fc, 0x7398,0x7482,0x7941,0x7f88,
  0x9324,0xf90b,0xf90c,0x5a1c, 0xf90d,0xf90e,0xf90f,0xf910,
  0xf911,0xf912,0xf913,0xf914, 0xf915,0xf916,0xf917,0xf918,
  0xf919,0xf91a,0xf91b,0xf91c, 0xf91d,0xf91e,0xf91f,0xf920,
  0xf921,0x678f,0x6960,0x6e73, 0xf922,0xf923,0xf924,0xf925,
  0xf926,0xf927,0x8872,0xf928, 0xf929,0xf92a,0xf92b,0xf92c,
  0xf92d,0xf92e,0x649a,0x5bd7, 0xf92f,0xf930,0xf931,0xf932,
  0xf933,0xf934,0xf935,0xf936, 0xf937,0xf938,0x99d1,0xf939,
  0xf93a,0xf93b,0xf93c,0xf93d, 0xf93e,0xf93f,0xf940,0xf941,
  0xf942,0xf943,0xf944,0xf945, 0xf946,0xf947,0xf948,0xf949,
  0xf94a,0xf94b,0xf94c,0xf94d, 0xf94e,0xf94f,0xf950,0xf951,
  0x677b,0xf952,0xf953,0xf954, 0xf955,0xf956,0xf957,0xf958,
  0xf959,0x4eb6,0x5f56,0x6fbe, 0x574d,0x61ba,0x6e5b,0x8541,
  0x931f,0x7553,0x6207,0x87b3, 0x576e,0x5d8b,
/* 0x6941(i:7600) */
  0x6389,0x6ac2,0x89a9,0x65fd, 0x711e,0x9017,0x829a,0x5d9d,
  0xf95b,0xf95d,0xf95e,0x5d0d, 0x5fa0,0x5137,0x7489,0xf95f,
  0x5cba,0x7b2d,0x8046,0x6fa7, 0xf960,0x64c4,0x6f5e,0x797f,
  0x83c9,0x7028,0x8cda,0x9b27, 0x5a41,0x763b,0x851e,0x93e4,
  0x65d2,0x700f,0x4f96,0x51dc, 0x550e,0x6d6c,0xf962,0x7fb8,
  0x8389,0x88e1,0x6f7e,0x78bc, 0x9088,0x4e07,0x534d,0x551c,
  0x8309,0x8f1e,0x6c94,0x6927, 0x7791,0x84c2,0x6479,0x7441,
  0x82bc,0x9da9,0x7ad7,0x61ae, 0x6959,0x73f7,0x5011,0x96ef,
  0x6c95,0x68b6,0x6963,0x6e44, 0x9ef4,0x5cb7,0x7de1,0x7622,
  0x76fc,0x78d0,0x6e24,0x678b, 0x6ec2,0x78c5,0x7119,0x5e61,
  0x71d4,0x6a97,0x8617,0x68c5, 0x9a08,0x73e4,0x83e9,0x8f39,
  0x71a2,0x4e0d,0x4fef,0x5490, 0x5b5a,0x8240,0x83a9,0x5429,
  0x6610,0x8cc1,0x5f7f,0x6787, 0x6bd6,0x6bd7,0x79d5,0x7c83,
  0x56ac,0x6d5c,0x73ad,0x4fdf, 0x67f6,0x9e9d,0x9730,0x715e,
  0x9212,0x5ce0,0x55c7,0x637f, 0x7b6e,0x5b0b,0x657e,0x6e32,
  0x7401,0x9425,0x994d,0x6cc4, 0x893b,0x9f67,0x5261,0x965d,
  0x5bac,0x73f9,0x7619,0x7be0, 0x6d91,0x8b16,0x8d16,0x5dfd,
  0x84c0,0x98e1,0x609a,0x6dde, 0x5cc0,0x7407,0x74b2,0x8b90,
  0x96a7,0x6f5a,0x7421,0x74b9, 0x5f87,0x6812,0x6a53,0x84f4,
  0x8563,0x8ac4,0x9265,0x5c4e, 0x8c55,0x7bd2,0x8755,0x4f81,
  0x85ce,0x8af6,0x555e,0x83aa, 0x5e44,0x9102,0x9354,0x9c10,
  0x9b9f,0x5535,0x5ca9,0x627c, 0x7e0a,0xf975,0xf976,0x84bb,
  0xf977,0xf978,0xf979,0xf97a, 0x79b3,0xf97b,0xf97c,0xf97d,
  0xf97e,0x7600,0x8616,0x4ffa, 0x5186,0xf97f,
/* 0x6a41(i:7790) */
  0xf980,0xf981,0xf982,0xf983, 0xf984,0x74b5,0x7916,0xf985,
  0x8245,0x8339,0x8f3f,0x8f5d, 0xf986,0xf987,0xf988,0xf989,
  0xf98a,0xf98b,0xf98c,0xf98d, 0xf98e,0xf98f,0xf990,0x633b,
  0x6c87,0xf992,0xf993,0xf994, 0xf995,0xf996,0x7e2f,0xf997,
  0xf998,0xf999,0xf99a,0xf99b, 0xf99c,0xf99d,0xf99f,0xf9a0,
  0xf9a2,0xf9a3,0xf9a4,0xf9a5, 0x7430,0xf9a6,0xf9a7,0xf9a8,
  0xf9a9,0xf9aa,0xf9ab,0x5db8, 0xf9ac,0x6e36,0x6fda,0x702f,
  0x7150,0x7370,0xf9ad,0x7a4e, 0xf9af,0xf9b0,0xf9b1,0x9348,
  0xf9b2,0x9719,0xf9b3,0xf9b4, 0x4e42,0xf9b5,0x6c6d,0x7a62,
  0xf9b6,0xf9b7,0xf9b8,0x4fc9, 0x5862,0x61ca,0x6556,0x6fb3,
  0x71ac,0x7b7d,0x9c32,0x9f07, 0x7e15,0x9954,0x7aaa,0x68a1,
  0x6900,0x7413,0x8118,0x5a03, 0x5d6c,0xf9ba,0xf9bb,0x5be5,
  0xf9bc,0xf9bd,0x6493,0xf9be, 0xf9c0,0x71ff,0xf9c1,0xf9c2,
  0xf9c3,0x7e1f,0x4fd1,0x57c7, 0x5889,0x6142,0x6d8c,0x752c,
  0xf9c4,0x65f4,0x7397,0x7440, 0x7d06,0x85d5,0x91ea,0x52d6,
  0x5f67,0x682f,0x6a52,0x6f90, 0x7189,0x8553,0x4e90,0x5ac4,
  0x6c85,0x6d39,0x6e72,0xf9c6, 0x6690,0x853f,0x8918,0xf9c7,
  0xf9c8,0xf9c9,0x6962,0x6d27, 0xf9ca,0xf9cb,0x7337,0xf9cc,
  0xf9cd,0xf9ce,0xf9cf,0xf9d0, 0xf9d1,0x5809,0xf9d2,0xf9d3,
  0xf9d4,0xf9d5,0xf9d6,0x8d07, 0xf9d7,0x9217,0xf9d8,0xf9d9,
  0xf9da,0xf9db,0x701c,0xf9dc, 0x6905,0x858f,0xf9dd,0xf9de,
  0xf9df,0xf9e1,0xf9e2,0xf9e3, 0xf9e4,0xf9e5,0xf9e6,0x8084,
  0x82e1,0xf9e7,0xf9e8,0x8cbd, 0x9087,0xf9e9,0xf9ea,0xf9eb,
  0xf9ec,0x8b1a,0xf9ed,0xf9ee, 0xf9ef,0x7d6a,
/* 0x6b41(i:7980) */
  0x8335,0xf9f0,0x8693,0xf9f1, 0xf9f2,0xf9f3,0x4f5a,0x6041,
  0xf9f4,0xf9f5,0xf9f6,0x5344, 0xf9f7,0xf9f8,0xf9f9,0x82bf,
  0x8328,0x5b71,0x81e7,0x6e3d, 0x7e21,0x7d35,0x83f9,0x96ce,
  0x9f5f,0x540a,0xf9fb,0x7fdf, 0x93d1,0x4f43,0x4f7a,0x587c,
  0x7420,0x7551,0x7b4c,0x942b, 0x7664,0x9b8e,0x67fe,0x6a89,
  0x6dc0,0x6e5e,0x701e,0x70a1, 0x738e,0x73fd,0x7d8e,0x92cc,
  0x74aa,0x96d5,0x60b0,0x8e2a, 0x59dd,0x6e4a,0x6f8d,0x5bef,
  0x710c,0x96cb,0x7e52,0x6c9a, 0x82b7,0x5507,0x6422,0x664b,
  0x686d,0x6b84,0x755b,0x7e1d, 0x81fb,0x852f,0x8897,0x4f84,
  0x74c6,0xf9fd,0x6f57,0x93f6, 0x4f98,0x7c12,0x7d2e,0x8b96,
  0x6134,0x7316,0x5bc0,0x5be8, 0x501c,0x8e60,0x7394,0x8f1f,
  0x7c3d,0x8a79,0x581e,0x527f, 0x8278,0x82d5,0x90a8,0x60a4,
  0x6181,0x8525,0x8acf,0x939a, 0x9a36,0x8e59,0x7443,0x672e,
  0x8d05,0x53a0,0x7a49,0x86a9, 0x741b,0x54a4,0x62d6,0x99b1,
  0x577c,0x666b,0x7438,0x7708, 0xfa03,0x69cc,0x95d6,0x64fa,
  0x9211,0x9a19,0x67b0,0xfa06, 0x82de,0x900b,0x66dd,0xfa07,
  0x98c7,0x9a43,0x9642,0x73cc, 0x82fe,0x999d,0x53a6,0x701a,
  0x929c,0x9e79,0x95d4,0x5ae6, 0xfa08,0x7023,0x8347,0x6af6,
  0x4fd4,0x774d,0x6ceb,0x73b9, 0x665b,0x6cc2,0x6ece,0x7050,
  0x7192,0x7469,0x9008,0x66b3, 0x8e4a,0x5cb5,0x6667,0x7425,
  0x82a6,0x84bf,0x70d8,0x8b41, 0x5950,0x6665,0x5e4c,0x6130,
  0x6644,0x69a5,0x6e5f,0x6f62, 0x749c,0x7c27,0x532f,0x8334,
  0x5b96,0x9404,0x6585,0x6d8d, 0x6dc6,0x9a4d,0x5e3f,0x7166,
  0x73dd,0x52db,0x6684,0x714a, 0x7098,0x8a16,
/* 0x6c41(i:8170) */
  0x7fd5,0x56cd,0x6198,0x665e, 0x71ba,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x6d41(i:8360) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x6e41(i:8550) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x6f41(i:8740) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x7041(i:8930) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x7141(i:9120) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x7241(i:9310) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x7341(i:9500) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x7441(i:9690) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x7541(i:9880) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x7641(i:10070) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x7741(i:10260) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x7841(i:10450) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x7941(i:10640) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x7a41(i:10830) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x7b41(i:11020) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x7c41(i:11210) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x7d41(i:11400) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x7e41(i:11590) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x7f41(i:11780) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x8041(i:11970) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x8141(i:12160) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x8241(i:12350) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x8341(i:12540) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x8441(i:12730) */
  0x3164,0x0000,0x0000,0x3133, 0x0000,0x3135,0x3136,0x0000,
  0x0000,0x313a,0x313b,0x313c, 0x313d,0x313e,0x313f,0x3140,
  0x0000,0x0000,0x0000,0x3144, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x314f,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x3150,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x3151,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x3152,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x3153,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x8541(i:12920) */
  0x3154,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x3155,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x3156,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x3157,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x3158,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x3159,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x8641(i:13110) */
  0x315a,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x315b,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x315c,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x315d,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x315e,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x315f,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x8741(i:13300) */
  0x3160,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x3161,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x3162,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x3163,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x8841(i:13490) */
  0x3131,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xac00,0xac01,0xac02,0x0000, 0xac04,0x0000,0x0000,0xac07,
  0xac08,0xac09,0xac0a,0xac0b, 0x0000,0x0000,0x0000,0x0000,
  0xac10,0x0000,0xac11,0xac12, 0xac13,0xac14,0xac15,0xac16,
  0xac17,0x0000,0xac19,0xac1a, 0xac1b,0x0000,0x0000,0x0000,
  0xac1c,0xac1d,0x0000,0x0000, 0xac20,0x0000,0x0000,0x0000,
  0xac24,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xac2c,0x0000,0xac2d,0x0000, 0xac2f,0xac30,0xac31,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xac38,0xac39,0x0000,0x0000, 0xac3c,0x0000,0x0000,0x0000,
  0xac40,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0xac4b,0x0000,0xac4d,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xac54,0x0000,0x0000,0x0000, 0xac58,0x0000,0x0000,0x0000,
  0xac5c,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xac70,0xac71,0x0000,0x0000, 0xac74,0x0000,0x0000,0xac77,
  0xac78,0xac79,0xac7a,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xac80,0x0000,0xac81,0x0000, 0xac83,0xac84,0xac85,0xac86,
  0xac87,0x0000,0xac89,0xac8a, 0xac8b,0x0000,
/* 0x8941(i:13680) */
  0xac8c,0x0000,0x0000,0x0000, 0xac90,0x0000,0x0000,0xac93,
  0xac94,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xac9c,0x0000,0xac9d,0x0000, 0xac9f,0xaca0,0xaca1,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xaca8,0xaca9,0xacaa,0x0000, 0xacac,0x0000,0x0000,0xacaf,
  0xacb0,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xacb8,0x0000,0xacb9,0x0000, 0xacbb,0xacbc,0xacbd,0x0000,
  0x0000,0x0000,0xacc1,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xacc4,0x0000,0x0000,0x0000, 0xacc8,0x0000,0x0000,0x0000,
  0xaccc,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0xacd5,0x0000, 0xacd7,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xace0,0xace1,0x0000,0x0000, 0xace4,0x0000,0x0000,0xace7,
  0xace8,0xace9,0xacea,0x0000, 0xacec,0x0000,0x0000,0xacef,
  0xacf0,0x0000,0xacf1,0x0000, 0xacf3,0x0000,0xacf5,0xacf6,
  0x0000,0x0000,0x0000,0xacfa, 0x0000,0x0000,0x0000,0x0000,
  0xacfc,0xacfd,0x0000,0x0000, 0xad00,0x0000,0x0000,0x0000,
  0xad04,0x0000,0xad06,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xad0c,0x0000,0xad0d,0x0000, 0xad0f,0x0000,0xad11,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xad18,0xad19,0x0000,0x0000, 0xad1c,0x0000,0x0000,0x0000,
  0xad20,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xad28,0x0000,0xad29,0x0000, 0xad2b,0xad2c,0xad2d,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x8a41(i:13870) */
  0xad34,0xad35,0x0000,0x0000, 0xad38,0x0000,0x0000,0x0000,
  0xad3c,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xad44,0x0000,0xad45,0x0000, 0xad47,0x0000,0xad49,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xad50,0x0000,0x0000,0x0000, 0xad54,0x0000,0x0000,0x0000,
  0xad58,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0xad61,0x0000, 0xad63,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xad6c,0xad6d,0x0000,0x0000, 0xad70,0x0000,0x0000,0xad73,
  0xad74,0xad75,0xad76,0x0000, 0x0000,0x0000,0x0000,0xad7b,
  0xad7c,0x0000,0xad7d,0x0000, 0xad7f,0x0000,0xad81,0xad82,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xad88,0xad89,0x0000,0x0000, 0xad8c,0x0000,0x0000,0x0000,
  0xad90,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0xad9b,0xad9c,0xad9d,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xada4,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0xadb7,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xadc0,0xadc1,0x0000,0x0000, 0xadc4,0x0000,0x0000,0x0000,
  0xadc8,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xadd0,0x0000,0xadd1,0x0000, 0xadd3,0x0000,0xadd5,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x8b41(i:14060) */
  0xaddc,0x0000,0x0000,0x0000, 0xade0,0x0000,0x0000,0x0000,
  0xade4,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xadec,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xadf8,0xadf9,0x0000,0x0000, 0xadfc,0x0000,0x0000,0xadff,
  0xae00,0xae01,0xae02,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xae08,0x0000,0xae09,0x0000, 0xae0b,0x0000,0xae0d,0x0000,
  0xae0f,0x0000,0xae11,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xae14,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0xae27,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xae30,0xae31,0x0000,0x0000, 0xae34,0x0000,0x0000,0xae37,
  0xae38,0x0000,0xae3a,0x0000, 0xae3c,0x0000,0x0000,0x0000,
  0xae40,0x0000,0xae41,0x0000, 0xae43,0xae44,0xae45,0xae46,
  0x0000,0x0000,0xae49,0xae4a, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x8c41(i:14250) */
  0x3132,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xae4c,0xae4d,0xae4e,0x0000, 0xae50,0x0000,0x0000,0x0000,
  0xae54,0x0000,0xae56,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xae5c,0x0000,0xae5d,0x0000, 0xae5f,0xae60,0xae61,0xae62,
  0x0000,0x0000,0xae65,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xae68,0xae69,0x0000,0x0000, 0xae6c,0x0000,0x0000,0x0000,
  0xae70,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xae78,0x0000,0xae79,0x0000, 0xae7b,0xae7c,0xae7d,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xae84,0xae85,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xae8c,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xaea0,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xaebc,0xaebd,0xaebe,0x0000, 0xaec0,0x0000,0x0000,0x0000,
  0xaec4,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xaecc,0x0000,0xaecd,0x0000, 0xaecf,0xaed0,0xaed1,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x8d41(i:14440) */
  0xaed8,0xaed9,0x0000,0x0000, 0xaedc,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xaee8,0x0000,0x0000,0x0000, 0xaeeb,0x0000,0xaeed,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xaef4,0x0000,0x0000,0x0000, 0xaef8,0x0000,0x0000,0x0000,
  0xaefc,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xaf04,0x0000,0x0000,0x0000, 0xaf07,0xaf08,0x0000,0x0000,
  0x0000,0x0000,0xaf0d,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xaf10,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xaf2c,0xaf2d,0x0000,0x0000, 0xaf30,0x0000,0xaf32,0xaf33,
  0xaf34,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xaf3c,0x0000,0xaf3d,0x0000, 0xaf3f,0x0000,0xaf41,0xaf42,
  0xaf43,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xaf48,0xaf49,0x0000,0x0000, 0xaf4c,0x0000,0x0000,0x0000,
  0xaf50,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xaf58,0x0000,0x0000,0x0000, 0xaf5b,0xaf5c,0xaf5d,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xaf64,0xaf65,0x0000,0x0000, 0xaf68,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0xaf79,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x8e41(i:14630) */
  0xaf80,0x0000,0x0000,0x0000, 0xaf84,0x0000,0x0000,0x0000,
  0xaf88,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xaf90,0x0000,0xaf91,0x0000, 0xaf93,0x0000,0xaf95,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xaf9c,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0xafb2,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xafb8,0xafb9,0x0000,0x0000, 0xafbc,0x0000,0x0000,0xafbf,
  0xafc0,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0xafc7,
  0xafc8,0x0000,0xafc9,0x0000, 0xafcb,0x0000,0xafcd,0xafce,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xafd4,0x0000,0x0000,0x0000, 0xafd8,0x0000,0x0000,0x0000,
  0xafdc,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0xafe7,0xafe8,0xafe9,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xaff0,0xaff1,0x0000,0x0000, 0xaff4,0x0000,0x0000,0x0000,
  0xaff8,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb000,0x0000,0xb001,0x0000, 0x0000,0xb004,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb00c,0xb00d,0x0000,0x0000, 0xb010,0x0000,0x0000,0x0000,
  0xb014,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb01c,0x0000,0xb01d,0x0000, 0x0000,0x0000,0xb021,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x8f41(i:14820) */
  0xb028,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb044,0xb045,0x0000,0x0000, 0xb048,0x0000,0xb04a,0x0000,
  0xb04c,0x0000,0xb04e,0x0000, 0x0000,0x0000,0x0000,0xb053,
  0xb054,0x0000,0xb055,0x0000, 0xb057,0x0000,0xb059,0x0000,
  0x0000,0x0000,0xb05d,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb060,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb07c,0xb07d,0x0000,0x0000, 0xb080,0x0000,0x0000,0x0000,
  0xb084,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb08c,0x0000,0xb08d,0x0000, 0xb08f,0xb090,0xb091,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x9041(i:15010) */
  0x3134,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb098,0xb099,0xb09a,0x0000, 0xb09c,0x0000,0x0000,0xb09f,
  0xb0a0,0xb0a1,0xb0a2,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb0a8,0x0000,0xb0a9,0x0000, 0xb0ab,0xb0ac,0xb0ad,0xb0ae,
  0xb0af,0x0000,0xb0b1,0x0000, 0xb0b3,0x0000,0x0000,0x0000,
  0xb0b4,0xb0b5,0x0000,0x0000, 0xb0b8,0x0000,0x0000,0xb0bb,
  0xb0bc,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb0c4,0x0000,0xb0c5,0x0000, 0xb0c7,0xb0c8,0xb0c9,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb0d0,0xb0d1,0x0000,0x0000, 0xb0d4,0x0000,0x0000,0x0000,
  0xb0d8,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb0e0,0x0000,0x0000,0x0000, 0x0000,0x0000,0xb0e5,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb0ec,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb108,0xb109,0x0000,0xb10b, 0xb10c,0x0000,0x0000,0xb10f,
  0xb110,0x0000,0xb112,0xb113, 0x0000,0x0000,0x0000,0x0000,
  0xb118,0x0000,0xb119,0x0000, 0xb11b,0xb11c,0xb11d,0xb11e,
  0x0000,0x0000,0x0000,0x0000, 0xb123,0x0000,
/* 0x9141(i:15200) */
  0xb124,0xb125,0x0000,0x0000, 0xb128,0x0000,0x0000,0x0000,
  0xb12c,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb134,0x0000,0xb135,0x0000, 0xb137,0xb138,0xb139,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb140,0xb141,0x0000,0x0000, 0xb144,0x0000,0x0000,0xb147,
  0xb148,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb150,0x0000,0xb151,0x0000, 0xb153,0xb154,0xb155,0x0000,
  0x0000,0xb158,0xb159,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb15c,0x0000,0x0000,0x0000, 0xb160,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0xb16f,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb178,0xb179,0xb17a,0x0000, 0xb17c,0x0000,0x0000,0x0000,
  0xb180,0x0000,0xb182,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb188,0x0000,0xb189,0x0000, 0xb18b,0x0000,0xb18d,0x0000,
  0x0000,0x0000,0x0000,0xb192, 0xb193,0x0000,0x0000,0x0000,
  0xb194,0x0000,0x0000,0x0000, 0xb198,0x0000,0x0000,0x0000,
  0xb19c,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0xb1a7,0xb1a8,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb1b0,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x9241(i:15390) */
  0xb1cc,0x0000,0x0000,0x0000, 0xb1d0,0x0000,0x0000,0x0000,
  0xb1d4,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb1dc,0x0000,0xb1dd,0x0000, 0xb1df,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb1e8,0xb1e9,0x0000,0x0000, 0xb1ec,0x0000,0x0000,0x0000,
  0xb1f0,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0xb1f9,0x0000, 0xb1fb,0x0000,0xb1fd,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb204,0xb205,0x0000,0x0000, 0xb208,0x0000,0x0000,0xb20b,
  0xb20c,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb214,0x0000,0xb215,0x0000, 0xb217,0x0000,0xb219,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb220,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0xb233,0xb234,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb23c,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb258,0x0000,0x0000,0x0000, 0xb25c,0x0000,0x0000,0x0000,
  0xb260,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb268,0x0000,0xb269,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x9341(i:15580) */
  0xb274,0xb275,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb27c,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb284,0x0000,0xb285,0x0000, 0x0000,0x0000,0xb289,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb290,0xb291,0x0000,0x0000, 0xb294,0x0000,0x0000,0x0000,
  0xb298,0xb299,0xb29a,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb2a0,0x0000,0xb2a1,0x0000, 0xb2a3,0x0000,0xb2a5,0xb2a6,
  0xb2a7,0x0000,0x0000,0xb2aa, 0x0000,0x0000,0x0000,0x0000,
  0xb2ac,0x0000,0x0000,0x0000, 0xb2b0,0x0000,0x0000,0x0000,
  0xb2b4,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0xb2c1,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb2c8,0xb2c9,0x0000,0x0000, 0xb2cc,0x0000,0x0000,0x0000,
  0xb2d0,0xb2d1,0xb2d2,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb2d8,0x0000,0xb2d9,0x0000, 0xb2db,0x0000,0xb2dd,0x0000,
  0x0000,0xb2e0,0x0000,0xb2e2, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x9441(i:15770) */
  0x3137,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb2e4,0xb2e5,0xb2e6,0x0000, 0xb2e8,0x0000,0x0000,0xb2eb,
  0xb2ec,0xb2ed,0xb2ee,0xb2ef, 0x0000,0x0000,0x0000,0xb2f3,
  0xb2f4,0x0000,0xb2f5,0x0000, 0xb2f7,0xb2f8,0xb2f9,0xb2fa,
  0xb2fb,0x0000,0x0000,0x0000, 0xb2ff,0x0000,0x0000,0x0000,
  0xb300,0xb301,0x0000,0x0000, 0xb304,0x0000,0x0000,0x0000,
  0xb308,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb310,0x0000,0xb311,0x0000, 0xb313,0xb314,0xb315,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb31c,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0xb331,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb338,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb354,0xb355,0xb356,0x0000, 0xb358,0x0000,0x0000,0xb35b,
  0xb35c,0x0000,0xb35e,0xb35f, 0x0000,0x0000,0x0000,0x0000,
  0xb364,0x0000,0xb365,0x0000, 0xb367,0xb368,0xb369,0xb36a,
  0xb36b,0x0000,0x0000,0xb36e, 0x0000,0x0000,
/* 0x9541(i:15960) */
  0xb370,0xb371,0x0000,0x0000, 0xb374,0x0000,0x0000,0x0000,
  0xb378,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb380,0x0000,0xb381,0x0000, 0xb383,0xb384,0xb385,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb38c,0x0000,0x0000,0x0000, 0xb390,0x0000,0x0000,0x0000,
  0xb394,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb39c,0x0000,0x0000,0x0000, 0x0000,0xb3a0,0xb3a1,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb3a8,0x0000,0x0000,0x0000, 0xb3ac,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb3c4,0xb3c5,0x0000,0x0000, 0xb3c8,0x0000,0x0000,0xb3cb,
  0xb3cc,0x0000,0xb3ce,0x0000, 0xb3d0,0x0000,0x0000,0xb3d3,
  0xb3d4,0x0000,0xb3d5,0x0000, 0xb3d7,0x0000,0xb3d9,0x0000,
  0xb3db,0x0000,0xb3dd,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb3e0,0x0000,0x0000,0x0000, 0xb3e4,0x0000,0x0000,0x0000,
  0xb3e8,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb3fc,0x0000,0x0000,0x0000, 0xb400,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0xb40f,0xb410,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x9641(i:16150) */
  0xb418,0x0000,0x0000,0x0000, 0xb41c,0x0000,0x0000,0x0000,
  0xb420,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb428,0x0000,0xb429,0x0000, 0xb42b,0xb42c,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb434,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb450,0xb451,0x0000,0x0000, 0xb454,0x0000,0x0000,0xb457,
  0xb458,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb460,0x0000,0xb461,0x0000, 0xb463,0x0000,0xb465,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb46c,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0xb47f,0xb480,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb488,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0xb49d,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb4a4,0x0000,0x0000,0x0000, 0xb4a8,0x0000,0x0000,0x0000,
  0xb4ac,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb4b4,0x0000,0xb4b5,0x0000, 0xb4b7,0x0000,0xb4b9,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x9741(i:16340) */
  0xb4c0,0xb4c1,0x0000,0x0000, 0xb4c4,0x0000,0x0000,0x0000,
  0xb4c8,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb4d0,0x0000,0x0000,0x0000, 0x0000,0x0000,0xb4d5,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb4dc,0xb4dd,0x0000,0x0000, 0xb4e0,0x0000,0x0000,0xb4e3,
  0xb4e4,0x0000,0xb4e6,0xb4e7, 0x0000,0x0000,0x0000,0x0000,
  0xb4ec,0x0000,0xb4ed,0x0000, 0xb4ef,0x0000,0xb4f1,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb4f8,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb514,0xb515,0x0000,0x0000, 0xb518,0x0000,0x0000,0xb51b,
  0xb51c,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb524,0x0000,0xb525,0x0000, 0xb527,0xb528,0xb529,0xb52a,
  0x0000,0x0000,0x0000,0xb52e, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x9841(i:16530) */
  0x3138,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb530,0xb531,0xb532,0x0000, 0xb534,0x0000,0x0000,0xb537,
  0xb538,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0xb53f,
  0xb540,0x0000,0xb541,0x0000, 0xb543,0xb544,0xb545,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0xb54b,0x0000,0x0000,0x0000,
  0xb54c,0xb54d,0x0000,0x0000, 0xb550,0x0000,0x0000,0x0000,
  0xb554,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb55c,0x0000,0xb55d,0x0000, 0xb55f,0xb560,0xb561,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb568,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb584,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb5a0,0xb5a1,0x0000,0x0000, 0xb5a4,0x0000,0x0000,0x0000,
  0xb5a8,0x0000,0xb5aa,0xb5ab, 0x0000,0x0000,0x0000,0x0000,
  0xb5b0,0x0000,0xb5b1,0x0000, 0xb5b3,0xb5b4,0xb5b5,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0xb5bb,0x0000,
/* 0x9941(i:16720) */
  0xb5bc,0xb5bd,0x0000,0x0000, 0xb5c0,0x0000,0x0000,0x0000,
  0xb5c4,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb5cc,0x0000,0xb5cd,0x0000, 0xb5cf,0xb5d0,0xb5d1,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb5d8,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0xb5ec,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb5f4,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb610,0xb611,0x0000,0x0000, 0xb614,0x0000,0x0000,0x0000,
  0xb618,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0xb625,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb62c,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb634,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb648,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x9a41(i:16910) */
  0xb664,0x0000,0x0000,0x0000, 0xb668,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb680,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb69c,0xb69d,0x0000,0x0000, 0xb6a0,0x0000,0x0000,0x0000,
  0xb6a4,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0xb6ab,
  0xb6ac,0x0000,0x0000,0x0000, 0x0000,0x0000,0xb6b1,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb6b8,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb6d4,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb6f0,0x0000,0x0000,0x0000, 0xb6f4,0x0000,0x0000,0x0000,
  0xb6f8,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb700,0x0000,0xb701,0x0000, 0x0000,0x0000,0xb705,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x9b41(i:17100) */
  0xb70c,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb728,0xb729,0x0000,0x0000, 0xb72c,0x0000,0x0000,0xb72f,
  0xb730,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb738,0x0000,0xb739,0x0000, 0xb73b,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb744,0x0000,0x0000,0x0000, 0xb748,0x0000,0x0000,0x0000,
  0xb74c,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb754,0x0000,0xb755,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb760,0x0000,0x0000,0x0000, 0xb764,0x0000,0x0000,0x0000,
  0xb768,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb770,0x0000,0xb771,0x0000, 0xb773,0x0000,0xb775,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x9c41(i:17290) */
  0x3139,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb77c,0xb77d,0x0000,0x0000, 0xb780,0x0000,0x0000,0x0000,
  0xb784,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb78c,0x0000,0xb78d,0x0000, 0xb78f,0xb790,0xb791,0xb792,
  0x0000,0x0000,0x0000,0xb796, 0xb797,0x0000,0x0000,0x0000,
  0xb798,0xb799,0x0000,0x0000, 0xb79c,0x0000,0x0000,0x0000,
  0xb7a0,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb7a8,0x0000,0xb7a9,0x0000, 0xb7ab,0xb7ac,0xb7ad,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb7b4,0xb7b5,0x0000,0x0000, 0xb7b8,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0xb7c7,0x0000,0xb7c9,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb7d0,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb7ec,0xb7ed,0x0000,0x0000, 0xb7f0,0x0000,0x0000,0x0000,
  0xb7f4,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb7fc,0x0000,0xb7fd,0x0000, 0xb7ff,0xb800,0xb801,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0xb807,0x0000,
/* 0x9d41(i:17480) */
  0xb808,0xb809,0x0000,0x0000, 0xb80c,0x0000,0x0000,0xb80f,
  0xb810,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb818,0x0000,0xb819,0x0000, 0xb81b,0x0000,0xb81d,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb824,0xb825,0x0000,0x0000, 0xb828,0x0000,0x0000,0x0000,
  0xb82c,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb834,0x0000,0xb835,0x0000, 0xb837,0xb838,0xb839,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb840,0x0000,0x0000,0x0000, 0xb844,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0xb851,0x0000, 0xb853,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb85c,0xb85d,0x0000,0x0000, 0xb860,0x0000,0x0000,0x0000,
  0xb864,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb86c,0x0000,0xb86d,0x0000, 0xb86f,0x0000,0xb871,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb878,0x0000,0x0000,0x0000, 0xb87c,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0xb88d,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb894,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0xb8a8,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x9e41(i:17670) */
  0xb8b0,0x0000,0x0000,0x0000, 0xb8b4,0x0000,0x0000,0x0000,
  0xb8b8,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb8c0,0x0000,0xb8c1,0x0000, 0xb8c3,0x0000,0xb8c5,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb8cc,0x0000,0x0000,0x0000, 0xb8d0,0x0000,0x0000,0x0000,
  0xb8d4,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb8dc,0x0000,0xb8dd,0x0000, 0xb8df,0x0000,0xb8e1,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb8e8,0xb8e9,0x0000,0x0000, 0xb8ec,0x0000,0x0000,0x0000,
  0xb8f0,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb8f8,0x0000,0xb8f9,0x0000, 0xb8fb,0x0000,0xb8fd,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb904,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0xb917,0xb918,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb920,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb93c,0xb93d,0x0000,0x0000, 0xb940,0x0000,0x0000,0x0000,
  0xb944,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb94c,0x0000,0x0000,0x0000, 0xb94f,0x0000,0xb951,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x9f41(i:17860) */
  0xb958,0xb959,0x0000,0x0000, 0xb95c,0x0000,0x0000,0x0000,
  0xb960,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb968,0x0000,0xb969,0x0000, 0xb96b,0x0000,0xb96d,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb974,0xb975,0x0000,0x0000, 0xb978,0x0000,0x0000,0x0000,
  0xb97c,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb984,0x0000,0xb985,0x0000, 0xb987,0x0000,0xb989,0xb98a,
  0x0000,0x0000,0xb98d,0xb98e, 0x0000,0x0000,0x0000,0x0000,
  0xb990,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb9ac,0xb9ad,0x0000,0x0000, 0xb9b0,0x0000,0x0000,0x0000,
  0xb9b4,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb9bc,0x0000,0xb9bd,0x0000, 0xb9bf,0x0000,0xb9c1,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xa041(i:18050) */
  0x3141,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb9c8,0xb9c9,0x0000,0x0000, 0xb9cc,0x0000,0xb9ce,0xb9cf,
  0xb9d0,0xb9d1,0xb9d2,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb9d8,0x0000,0xb9d9,0x0000, 0xb9db,0x0000,0xb9dd,0xb9de,
  0xb9df,0x0000,0xb9e1,0x0000, 0xb9e3,0x0000,0x0000,0x0000,
  0xb9e4,0xb9e5,0x0000,0x0000, 0xb9e8,0x0000,0x0000,0x0000,
  0xb9ec,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb9f4,0x0000,0xb9f5,0x0000, 0xb9f7,0xb9f8,0xb9f9,0xb9fa,
  0xb9fb,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xba00,0xba01,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xba08,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0xba15,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xba1c,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xba38,0xba39,0x0000,0x0000, 0xba3c,0x0000,0x0000,0x0000,
  0xba40,0x0000,0xba42,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xba48,0x0000,0xba49,0x0000, 0xba4b,0x0000,0xba4d,0xba4e,
  0x0000,0x0000,0x0000,0x0000, 0xba53,0x0000,
/* 0xa141(i:18240) */
  0xba54,0xba55,0x0000,0x0000, 0xba58,0x0000,0x0000,0x0000,
  0xba5c,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xba64,0x0000,0xba65,0x0000, 0xba67,0xba68,0xba69,0x0000,
  0xba6b,0x0000,0xba6d,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xba70,0xba71,0x0000,0x0000, 0xba74,0x0000,0x0000,0x0000,
  0xba78,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xba80,0x0000,0x0000,0x0000, 0xba83,0xba84,0xba85,0x0000,
  0xba87,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xba8c,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xbaa8,0xbaa9,0x0000,0xbaab, 0xbaac,0x0000,0x0000,0xbaaf,
  0xbab0,0x0000,0xbab2,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xbab8,0x0000,0xbab9,0x0000, 0xbabb,0x0000,0xbabd,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0xbac3,0x0000,0x0000,0x0000,
  0xbac4,0x0000,0x0000,0x0000, 0xbac8,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0xbad8,0xbad9,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xbae0,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xa241(i:18430) */
  0xbafc,0x0000,0x0000,0x0000, 0xbb00,0x0000,0x0000,0x0000,
  0xbb04,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0xbb0d,0x0000, 0xbb0f,0x0000,0xbb11,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xbb18,0x0000,0x0000,0x0000, 0xbb1c,0x0000,0x0000,0x0000,
  0xbb20,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0xbb29,0x0000, 0xbb2b,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xbb34,0xbb35,0xbb36,0x0000, 0xbb38,0x0000,0x0000,0xbb3b,
  0xbb3c,0xbb3d,0xbb3e,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xbb44,0x0000,0xbb45,0x0000, 0xbb47,0x0000,0xbb49,0x0000,
  0x0000,0x0000,0xbb4d,0x0000, 0xbb4f,0x0000,0x0000,0x0000,
  0xbb50,0x0000,0x0000,0x0000, 0xbb54,0x0000,0x0000,0x0000,
  0xbb58,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0xbb61,0x0000, 0xbb63,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xbb6c,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xbb88,0x0000,0x0000,0x0000, 0xbb8c,0x0000,0x0000,0x0000,
  0xbb90,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xa341(i:18620) */
  0xbba4,0x0000,0x0000,0x0000, 0xbba8,0x0000,0x0000,0x0000,
  0xbbac,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xbbb4,0x0000,0x0000,0x0000, 0xbbb7,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xbbc0,0xbbc1,0x0000,0x0000, 0xbbc4,0x0000,0x0000,0x0000,
  0xbbc8,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xbbd0,0x0000,0x0000,0x0000, 0xbbd3,0x0000,0xbbd5,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xbbdc,0x0000,0x0000,0x0000, 0xbbe0,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xbbf8,0xbbf9,0x0000,0x0000, 0xbbfc,0x0000,0x0000,0xbbff,
  0xbc00,0x0000,0xbc02,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xbc08,0x0000,0xbc09,0x0000, 0xbc0b,0xbc0c,0xbc0d,0xbc0e,
  0xbc0f,0x0000,0xbc11,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xa441(i:18810) */
  0x3142,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xbc14,0xbc15,0xbc16,0xbc17, 0xbc18,0x0000,0x0000,0xbc1b,
  0xbc1c,0xbc1d,0xbc1e,0xbc1f, 0x0000,0x0000,0x0000,0x0000,
  0xbc24,0x0000,0xbc25,0x0000, 0xbc27,0xbc28,0xbc29,0x0000,
  0x0000,0x0000,0xbc2d,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xbc30,0xbc31,0x0000,0x0000, 0xbc34,0x0000,0x0000,0xbc37,
  0xbc38,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xbc40,0x0000,0xbc41,0x0000, 0xbc43,0xbc44,0xbc45,0x0000,
  0x0000,0x0000,0xbc49,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xbc4c,0xbc4d,0x0000,0x0000, 0xbc50,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xbc5c,0x0000,0xbc5d,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xbc68,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xbc84,0xbc85,0x0000,0x0000, 0xbc88,0x0000,0x0000,0xbc8b,
  0xbc8c,0x0000,0xbc8e,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xbc94,0x0000,0xbc95,0x0000, 0xbc97,0xbc98,0xbc99,0xbc9a,
  0x0000,0xbc9c,0x0000,0x0000, 0x0000,0x0000,
/* 0xa541(i:19000) */
  0xbca0,0xbca1,0x0000,0x0000, 0xbca4,0x0000,0x0000,0xbca7,
  0xbca8,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xbcb0,0x0000,0xbcb1,0x0000, 0xbcb3,0xbcb4,0xbcb5,0x0000,
  0x0000,0x0000,0xbcb9,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xbcbc,0xbcbd,0x0000,0x0000, 0xbcc0,0x0000,0x0000,0x0000,
  0xbcc4,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xbccc,0x0000,0xbccd,0x0000, 0xbccf,0xbcd0,0xbcd1,0xbcd2,
  0xbcd3,0xbcd4,0xbcd5,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xbcd8,0x0000,0x0000,0x0000, 0xbcdc,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xbcf4,0xbcf5,0xbcf6,0x0000, 0xbcf8,0x0000,0x0000,0x0000,
  0xbcfc,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xbd04,0x0000,0xbd05,0x0000, 0xbd07,0x0000,0xbd09,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xbd10,0x0000,0x0000,0x0000, 0xbd14,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0xbd23,0xbd24,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xbd2c,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0xbd40,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xa641(i:19190) */
  0xbd48,0xbd49,0x0000,0x0000, 0xbd4c,0x0000,0x0000,0x0000,
  0xbd50,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xbd58,0x0000,0xbd59,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xbd64,0x0000,0x0000,0x0000, 0xbd68,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xbd80,0xbd81,0x0000,0x0000, 0xbd84,0x0000,0x0000,0xbd87,
  0xbd88,0xbd89,0xbd8a,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xbd90,0x0000,0xbd91,0x0000, 0xbd93,0x0000,0xbd95,0x0000,
  0xbd97,0x0000,0xbd99,0xbd9a, 0x0000,0x0000,0x0000,0x0000,
  0xbd9c,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xbda4,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0xbdb0,0x0000,0x0000,
  0x0000,0xbdb4,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xbdb8,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xbdd4,0xbdd5,0x0000,0x0000, 0xbdd8,0x0000,0x0000,0x0000,
  0xbddc,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0xbde9,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xa741(i:19380) */
  0xbdf0,0x0000,0x0000,0x0000, 0xbdf4,0x0000,0x0000,0x0000,
  0xbdf8,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xbe00,0x0000,0x0000,0x0000, 0xbe03,0x0000,0xbe05,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xbe0c,0xbe0d,0x0000,0x0000, 0xbe10,0x0000,0x0000,0x0000,
  0xbe14,0x0000,0x0000,0x0000, 0xbe18,0x0000,0x0000,0x0000,
  0xbe1c,0x0000,0xbe1d,0x0000, 0xbe1f,0x0000,0xbe21,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xbe28,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xbe44,0xbe45,0x0000,0x0000, 0xbe48,0x0000,0x0000,0xbe4b,
  0xbe4c,0x0000,0xbe4e,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xbe54,0x0000,0xbe55,0x0000, 0xbe57,0x0000,0xbe59,0xbe5a,
  0xbe5b,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xa841(i:19570) */
  0x3143,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xbe60,0xbe61,0x0000,0x0000, 0xbe64,0x0000,0x0000,0x0000,
  0xbe68,0x0000,0xbe6a,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xbe70,0x0000,0xbe71,0x0000, 0xbe73,0xbe74,0xbe75,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0xbe7b,0x0000,0x0000,0x0000,
  0xbe7c,0xbe7d,0x0000,0x0000, 0xbe80,0x0000,0x0000,0x0000,
  0xbe84,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xbe8c,0x0000,0xbe8d,0x0000, 0xbe8f,0xbe90,0xbe91,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xbe98,0xbe99,0x0000,0x0000, 0xbe9c,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xbea8,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xbeb4,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xbed0,0xbed1,0x0000,0x0000, 0xbed4,0x0000,0x0000,0xbed7,
  0xbed8,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xbee0,0x0000,0x0000,0x0000, 0xbee3,0xbee4,0xbee5,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xa941(i:19760) */
  0xbeec,0xbeed,0x0000,0x0000, 0xbef0,0x0000,0x0000,0x0000,
  0xbef4,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0xbeff,0x0000,0xbf01,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xbf08,0xbf09,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xbf18,0x0000,0xbf19,0x0000, 0xbf1b,0xbf1c,0xbf1d,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xbf24,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xbf40,0xbf41,0x0000,0x0000, 0xbf44,0x0000,0x0000,0x0000,
  0xbf48,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xbf50,0x0000,0xbf51,0x0000, 0x0000,0x0000,0xbf55,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xbf5c,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xbf78,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xaa41(i:19950) */
  0xbf94,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xbfb0,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xbfc0,0x0000,0x0000,0x0000, 0x0000,0x0000,0xbfc5,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xbfcc,0xbfcd,0x0000,0x0000, 0xbfd0,0x0000,0x0000,0x0000,
  0xbfd4,0xbfd5,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xbfdc,0x0000,0xbfdd,0x0000, 0xbfdf,0x0000,0xbfe1,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xbfe8,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc004,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc020,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xab41(i:20140) */
  0xc03c,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0xc051,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc058,0xc059,0x0000,0x0000, 0xc05c,0x0000,0x0000,0x0000,
  0xc060,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc068,0x0000,0xc069,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc074,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc090,0xc091,0x0000,0x0000, 0xc094,0x0000,0x0000,0x0000,
  0xc098,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc0a0,0x0000,0xc0a1,0x0000, 0xc0a3,0x0000,0xc0a5,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xac41(i:20330) */
  0x3145,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc0ac,0xc0ad,0xc0ae,0xc0af, 0xc0b0,0x0000,0x0000,0xc0b3,
  0xc0b4,0xc0b5,0xc0b6,0xc0b7, 0x0000,0x0000,0x0000,0xc0bb,
  0xc0bc,0x0000,0xc0bd,0x0000, 0xc0bf,0xc0c0,0xc0c1,0x0000,
  0xc0c3,0x0000,0xc0c5,0x0000, 0xc0c7,0x0000,0x0000,0x0000,
  0xc0c8,0xc0c9,0x0000,0x0000, 0xc0cc,0x0000,0x0000,0xc0cf,
  0xc0d0,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc0d8,0x0000,0xc0d9,0x0000, 0xc0db,0xc0dc,0xc0dd,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc0e4,0xc0e5,0x0000,0x0000, 0xc0e8,0x0000,0x0000,0x0000,
  0xc0ec,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc0f4,0x0000,0xc0f5,0x0000, 0xc0f7,0x0000,0xc0f9,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc100,0x0000,0x0000,0x0000, 0xc104,0x0000,0x0000,0x0000,
  0xc108,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc110,0x0000,0x0000,0x0000, 0x0000,0x0000,0xc115,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc11c,0xc11d,0xc11e,0xc11f, 0xc120,0x0000,0x0000,0xc123,
  0xc124,0xc125,0xc126,0xc127, 0x0000,0x0000,0x0000,0x0000,
  0xc12c,0x0000,0xc12d,0x0000, 0xc12f,0xc130,0xc131,0x0000,
  0x0000,0x0000,0x0000,0xc136, 0x0000,0x0000,
/* 0xad41(i:20520) */
  0xc138,0xc139,0x0000,0x0000, 0xc13c,0x0000,0x0000,0xc13f,
  0xc140,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc148,0x0000,0xc149,0x0000, 0xc14b,0xc14c,0xc14d,0x0000,
  0x0000,0x0000,0xc151,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc154,0xc155,0x0000,0xc157, 0xc158,0x0000,0x0000,0x0000,
  0xc15c,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc164,0x0000,0xc165,0x0000, 0xc167,0xc168,0xc169,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc170,0x0000,0x0000,0x0000, 0xc174,0x0000,0x0000,0x0000,
  0xc178,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0xc185,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc18c,0xc18d,0xc18e,0x0000, 0xc190,0x0000,0x0000,0xc193,
  0xc194,0x0000,0xc196,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc19c,0x0000,0xc19d,0x0000, 0xc19f,0x0000,0xc1a1,0x0000,
  0x0000,0x0000,0xc1a5,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc1a8,0xc1a9,0x0000,0x0000, 0xc1ac,0x0000,0x0000,0x0000,
  0xc1b0,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0xc1bb,0x0000,0xc1bd,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc1c4,0x0000,0x0000,0x0000, 0xc1c8,0x0000,0x0000,0x0000,
  0xc1cc,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc1d4,0x0000,0x0000,0x0000, 0xc1d7,0xc1d8,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xae41(i:20710) */
  0xc1e0,0x0000,0x0000,0x0000, 0xc1e4,0x0000,0x0000,0x0000,
  0xc1e8,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc1f0,0x0000,0xc1f1,0x0000, 0xc1f3,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc1fc,0xc1fd,0x0000,0x0000, 0xc200,0x0000,0x0000,0x0000,
  0xc204,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc20c,0x0000,0xc20d,0x0000, 0xc20f,0x0000,0xc211,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc218,0xc219,0x0000,0x0000, 0xc21c,0x0000,0x0000,0xc21f,
  0xc220,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc228,0x0000,0xc229,0x0000, 0xc22b,0x0000,0xc22d,0x0000,
  0xc22f,0x0000,0xc231,0xc232, 0x0000,0x0000,0x0000,0x0000,
  0xc234,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0xc248,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc250,0xc251,0x0000,0x0000, 0xc254,0x0000,0x0000,0x0000,
  0xc258,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc260,0x0000,0x0000,0x0000, 0x0000,0x0000,0xc265,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc26c,0xc26d,0x0000,0x0000, 0xc270,0x0000,0x0000,0x0000,
  0xc274,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc27c,0x0000,0xc27d,0x0000, 0xc27f,0x0000,0xc281,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xaf41(i:20900) */
  0xc288,0xc289,0x0000,0x0000, 0xc28c,0x0000,0x0000,0x0000,
  0xc290,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc298,0x0000,0x0000,0x0000, 0xc29b,0x0000,0xc29d,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc2a4,0xc2a5,0x0000,0x0000, 0xc2a8,0x0000,0x0000,0x0000,
  0xc2ac,0xc2ad,0x0000,0x0000, 0x0000,0x0000,0x0000,0xc2b3,
  0xc2b4,0x0000,0xc2b5,0x0000, 0xc2b7,0x0000,0xc2b9,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc2c0,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc2dc,0xc2dd,0x0000,0x0000, 0xc2e0,0x0000,0x0000,0xc2e3,
  0xc2e4,0x0000,0xc2e6,0x0000, 0x0000,0x0000,0x0000,0xc2eb,
  0xc2ec,0x0000,0xc2ed,0x0000, 0xc2ef,0x0000,0xc2f1,0x0000,
  0x0000,0x0000,0x0000,0xc2f6, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xb041(i:21090) */
  0x3146,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc2f8,0xc2f9,0x0000,0xc2fb, 0xc2fc,0x0000,0x0000,0x0000,
  0xc300,0x0000,0xc302,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc308,0x0000,0xc309,0x0000, 0xc30b,0xc30c,0xc30d,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0xc313,0x0000,0x0000,0x0000,
  0xc314,0xc315,0x0000,0x0000, 0xc318,0x0000,0x0000,0x0000,
  0xc31c,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc324,0x0000,0xc325,0x0000, 0xc327,0xc328,0xc329,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc330,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0xc343,0x0000,0xc345,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc34c,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc368,0xc369,0x0000,0x0000, 0xc36c,0x0000,0x0000,0x0000,
  0xc370,0x0000,0xc372,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc378,0x0000,0xc379,0x0000, 0xc37b,0xc37c,0xc37d,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xb141(i:21280) */
  0xc384,0xc385,0x0000,0x0000, 0xc388,0x0000,0x0000,0x0000,
  0xc38c,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0xc399,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc3a0,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc3bc,0x0000,0x0000,0x0000, 0xc3c0,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc3d8,0xc3d9,0x0000,0x0000, 0xc3dc,0x0000,0x0000,0xc3df,
  0xc3e0,0x0000,0xc3e2,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc3e8,0x0000,0xc3e9,0x0000, 0x0000,0x0000,0xc3ed,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc3f4,0xc3f5,0x0000,0x0000, 0xc3f8,0x0000,0x0000,0x0000,
  0xc3fc,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0xc408,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc410,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0xc424,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xb241(i:21470) */
  0xc42c,0x0000,0x0000,0x0000, 0xc430,0x0000,0x0000,0x0000,
  0xc434,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc43c,0x0000,0xc43d,0x0000, 0xc43f,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc448,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc464,0xc465,0x0000,0x0000, 0xc468,0x0000,0x0000,0x0000,
  0xc46c,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc474,0x0000,0xc475,0x0000, 0xc477,0x0000,0xc479,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc480,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0xc493,0xc494,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc49c,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc4b8,0x0000,0x0000,0x0000, 0xc4bc,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0xc4d3,0x0000,
/* 0xb341(i:21660) */
  0xc4d4,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0xc4e9,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc4f0,0xc4f1,0x0000,0x0000, 0xc4f4,0x0000,0x0000,0x0000,
  0xc4f8,0x0000,0xc4fa,0x0000, 0x0000,0x0000,0x0000,0xc4ff,
  0xc500,0x0000,0xc501,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc50c,0x0000,0x0000,0x0000, 0xc510,0x0000,0x0000,0x0000,
  0xc514,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc51c,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc528,0xc529,0x0000,0x0000, 0xc52c,0x0000,0x0000,0x0000,
  0xc530,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc538,0x0000,0xc539,0x0000, 0xc53b,0xc53c,0xc53d,0x0000,
  0xc53f,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xb441(i:21850) */
  0x3147,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc544,0xc545,0x0000,0x0000, 0xc548,0xc549,0xc54a,0x0000,
  0xc54c,0xc54d,0xc54e,0xc54f, 0x0000,0x0000,0x0000,0xc553,
  0xc554,0x0000,0xc555,0x0000, 0xc557,0xc558,0xc559,0x0000,
  0x0000,0x0000,0xc55d,0xc55e, 0xc55f,0x0000,0x0000,0x0000,
  0xc560,0xc561,0x0000,0x0000, 0xc564,0x0000,0x0000,0x0000,
  0xc568,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc570,0x0000,0xc571,0x0000, 0xc573,0xc574,0xc575,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc57c,0xc57d,0x0000,0x0000, 0xc580,0x0000,0x0000,0x0000,
  0xc584,0x0000,0x0000,0xc587, 0x0000,0x0000,0x0000,0x0000,
  0xc58c,0x0000,0xc58d,0x0000, 0xc58f,0xc590,0xc591,0x0000,
  0x0000,0x0000,0xc595,0x0000, 0xc597,0x0000,0x0000,0x0000,
  0xc598,0x0000,0x0000,0x0000, 0xc59c,0x0000,0x0000,0x0000,
  0xc5a0,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0xc5a9,0x0000, 0xc5ab,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc5b4,0xc5b5,0xc5b6,0x0000, 0xc5b8,0xc5b9,0x0000,0xc5bb,
  0xc5bc,0xc5bd,0xc5be,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc5c4,0x0000,0xc5c5,0xc5c6, 0xc5c7,0xc5c8,0xc5c9,0xc5ca,
  0x0000,0xc5cc,0x0000,0xc5ce, 0x0000,0x0000,
/* 0xb541(i:22040) */
  0xc5d0,0xc5d1,0x0000,0x0000, 0xc5d4,0x0000,0x0000,0x0000,
  0xc5d8,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc5e0,0x0000,0xc5e1,0x0000, 0xc5e3,0x0000,0xc5e5,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc5ec,0xc5ed,0xc5ee,0x0000, 0xc5f0,0xc5f1,0x0000,0xc5f3,
  0xc5f4,0x0000,0xc5f6,0xc5f7, 0x0000,0x0000,0x0000,0x0000,
  0xc5fc,0x0000,0xc5fd,0xc5fe, 0xc5ff,0xc600,0xc601,0x0000,
  0x0000,0x0000,0xc605,0xc606, 0xc607,0x0000,0x0000,0x0000,
  0xc608,0x0000,0x0000,0x0000, 0xc60c,0x0000,0x0000,0x0000,
  0xc610,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc618,0x0000,0xc619,0x0000, 0xc61b,0xc61c,0xc61d,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc624,0xc625,0x0000,0x0000, 0xc628,0x0000,0x0000,0xc62b,
  0xc62c,0xc62d,0xc62e,0x0000, 0xc630,0x0000,0x0000,0xc633,
  0xc634,0x0000,0xc635,0x0000, 0xc637,0x0000,0xc639,0xc63a,
  0xc63b,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc640,0xc641,0x0000,0x0000, 0xc644,0x0000,0x0000,0x0000,
  0xc648,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc650,0x0000,0xc651,0x0000, 0xc653,0xc654,0xc655,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc65c,0xc65d,0x0000,0x0000, 0xc660,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc66c,0x0000,0x0000,0x0000, 0xc66f,0x0000,0xc671,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xb641(i:22230) */
  0xc678,0xc679,0x0000,0x0000, 0xc67c,0x0000,0x0000,0x0000,
  0xc680,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc688,0x0000,0xc689,0x0000, 0xc68b,0x0000,0xc68d,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc694,0xc695,0x0000,0x0000, 0xc698,0x0000,0x0000,0x0000,
  0xc69c,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc6a4,0x0000,0xc6a5,0x0000, 0xc6a7,0x0000,0xc6a9,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc6b0,0xc6b1,0x0000,0x0000, 0xc6b4,0x0000,0x0000,0xc6b7,
  0xc6b8,0xc6b9,0xc6ba,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc6c0,0x0000,0xc6c1,0x0000, 0xc6c3,0x0000,0xc6c5,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc6cc,0xc6cd,0x0000,0x0000, 0xc6d0,0x0000,0x0000,0x0000,
  0xc6d4,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc6dc,0x0000,0xc6dd,0x0000, 0xc6df,0xc6e0,0xc6e1,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc6e8,0xc6e9,0x0000,0x0000, 0xc6ec,0x0000,0x0000,0x0000,
  0xc6f0,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc6f8,0x0000,0xc6f9,0x0000, 0x0000,0x0000,0xc6fd,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc704,0xc705,0x0000,0x0000, 0xc708,0x0000,0x0000,0xc70b,
  0xc70c,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc714,0x0000,0xc715,0x0000, 0xc717,0x0000,0xc719,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xb741(i:22420) */
  0xc720,0xc721,0x0000,0x0000, 0xc724,0x0000,0x0000,0x0000,
  0xc728,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc730,0x0000,0xc731,0x0000, 0xc733,0x0000,0xc735,0xc736,
  0xc737,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc73c,0xc73d,0x0000,0x0000, 0xc740,0x0000,0x0000,0x0000,
  0xc744,0x0000,0x0000,0x0000, 0x0000,0x0000,0xc74a,0x0000,
  0xc74c,0x0000,0xc74d,0x0000, 0xc74f,0x0000,0xc751,0xc752,
  0xc753,0xc754,0xc755,0xc756, 0xc757,0x0000,0x0000,0x0000,
  0xc758,0x0000,0x0000,0x0000, 0xc75c,0x0000,0x0000,0x0000,
  0xc760,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc768,0x0000,0x0000,0x0000, 0xc76b,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc774,0xc775,0x0000,0x0000, 0xc778,0x0000,0x0000,0xc77b,
  0xc77c,0xc77d,0xc77e,0x0000, 0x0000,0x0000,0x0000,0xc783,
  0xc784,0x0000,0xc785,0x0000, 0xc787,0xc788,0xc789,0xc78a,
  0x0000,0x0000,0x0000,0xc78e, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xb841(i:22610) */
  0x3148,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc790,0xc791,0x0000,0x0000, 0xc794,0x0000,0xc796,0xc797,
  0xc798,0x0000,0xc79a,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc7a0,0x0000,0xc7a1,0x0000, 0xc7a3,0xc7a4,0xc7a5,0xc7a6,
  0xc7a7,0x0000,0x0000,0xc7aa, 0x0000,0x0000,0x0000,0x0000,
  0xc7ac,0xc7ad,0x0000,0x0000, 0xc7b0,0x0000,0x0000,0x0000,
  0xc7b4,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc7bc,0x0000,0xc7bd,0x0000, 0xc7bf,0xc7c0,0xc7c1,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc7c8,0xc7c9,0x0000,0x0000, 0xc7cc,0x0000,0xc7ce,0x0000,
  0xc7d0,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc7d8,0x0000,0x0000,0x0000, 0x0000,0x0000,0xc7dd,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc7e4,0x0000,0x0000,0x0000, 0xc7e8,0x0000,0x0000,0x0000,
  0xc7ec,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc800,0xc801,0x0000,0x0000, 0xc804,0x0000,0x0000,0xc807,
  0xc808,0x0000,0xc80a,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc810,0x0000,0xc811,0x0000, 0xc813,0xc814,0xc815,0xc816,
  0x0000,0x0000,0x0000,0x0000, 0xc81b,0x0000,
/* 0xb941(i:22800) */
  0xc81c,0xc81d,0x0000,0x0000, 0xc820,0x0000,0x0000,0x0000,
  0xc824,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc82c,0x0000,0xc82d,0x0000, 0xc82f,0x0000,0xc831,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc838,0xc839,0x0000,0x0000, 0xc83c,0x0000,0x0000,0x0000,
  0xc840,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc848,0x0000,0xc849,0x0000, 0xc84b,0xc84c,0xc84d,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc854,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc870,0xc871,0x0000,0x0000, 0xc874,0x0000,0x0000,0x0000,
  0xc878,0x0000,0xc87a,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc880,0x0000,0xc881,0x0000, 0xc883,0x0000,0xc885,0xc886,
  0xc887,0x0000,0x0000,0x0000, 0xc88b,0x0000,0x0000,0x0000,
  0xc88c,0xc88d,0x0000,0x0000, 0xc890,0x0000,0x0000,0x0000,
  0xc894,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc89c,0x0000,0xc89d,0x0000, 0xc89f,0xc8a0,0xc8a1,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc8a8,0x0000,0x0000,0x0000, 0xc8ac,0x0000,0x0000,0x0000,
  0xc8b0,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc8b8,0x0000,0x0000,0x0000, 0x0000,0xc8bc,0xc8bd,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xba41(i:22990) */
  0xc8c4,0x0000,0x0000,0x0000, 0xc8c8,0x0000,0x0000,0x0000,
  0xc8cc,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc8d4,0x0000,0xc8d5,0x0000, 0xc8d7,0x0000,0xc8d9,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc8e0,0xc8e1,0x0000,0x0000, 0xc8e4,0x0000,0x0000,0x0000,
  0xc8e8,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc8f0,0x0000,0xc8f1,0x0000, 0x0000,0x0000,0xc8f5,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc8fc,0xc8fd,0x0000,0x0000, 0xc900,0x0000,0x0000,0x0000,
  0xc904,0xc905,0xc906,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc90c,0x0000,0xc90d,0x0000, 0xc90f,0x0000,0xc911,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc918,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0xc92b,0xc92c,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc934,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc950,0xc951,0x0000,0x0000, 0xc954,0x0000,0x0000,0x0000,
  0xc958,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc960,0x0000,0xc961,0x0000, 0xc963,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xbb41(i:23180) */
  0xc96c,0xc96d,0x0000,0x0000, 0xc970,0x0000,0x0000,0x0000,
  0xc974,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc97c,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc988,0xc989,0x0000,0x0000, 0xc98c,0x0000,0x0000,0x0000,
  0xc990,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc998,0x0000,0xc999,0x0000, 0xc99b,0x0000,0xc99d,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc9a4,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc9c0,0xc9c1,0x0000,0x0000, 0xc9c4,0x0000,0x0000,0xc9c7,
  0xc9c8,0x0000,0xc9ca,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc9d0,0x0000,0xc9d1,0x0000, 0xc9d3,0xc9d4,0xc9d5,0xc9d6,
  0x0000,0x0000,0xc9d9,0xc9da, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xbc41(i:23370) */
  0x3149,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc9dc,0xc9dd,0x0000,0x0000, 0xc9e0,0x0000,0xc9e2,0x0000,
  0xc9e4,0x0000,0x0000,0xc9e7, 0x0000,0x0000,0x0000,0x0000,
  0xc9ec,0x0000,0xc9ed,0x0000, 0xc9ef,0xc9f0,0xc9f1,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc9f8,0xc9f9,0x0000,0x0000, 0xc9fc,0x0000,0x0000,0x0000,
  0xca00,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xca08,0x0000,0xca09,0x0000, 0xca0b,0xca0c,0xca0d,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xca14,0x0000,0x0000,0x0000, 0xca18,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0xca29,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xca30,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xca4c,0xca4d,0x0000,0x0000, 0xca50,0x0000,0x0000,0x0000,
  0xca54,0x0000,0x0000,0xca57, 0x0000,0x0000,0x0000,0x0000,
  0xca5c,0x0000,0xca5d,0x0000, 0xca5f,0xca60,0xca61,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xbd41(i:23560) */
  0xca68,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xca70,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0xca7d,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xca84,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0xca97,0xca98,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xcaa0,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xcabc,0xcabd,0x0000,0x0000, 0xcac0,0x0000,0x0000,0x0000,
  0xcac4,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xcacc,0x0000,0xcacd,0x0000, 0xcacf,0x0000,0xcad1,0xcad2,
  0xcad3,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xcad8,0xcad9,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xcae0,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0xcaec,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xcaf4,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0xcb08,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xbe41(i:23750) */
  0xcb10,0x0000,0x0000,0x0000, 0xcb14,0x0000,0x0000,0x0000,
  0xcb18,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xcb20,0x0000,0xcb21,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xcb2c,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0xcb41,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xcb48,0xcb49,0x0000,0x0000, 0xcb4c,0x0000,0x0000,0x0000,
  0xcb50,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xcb58,0x0000,0xcb59,0x0000, 0x0000,0x0000,0xcb5d,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xcb64,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0xcb78,0xcb79,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xcb80,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xcb9c,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xbf41(i:23940) */
  0xcbb8,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xcbd4,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xcbe4,0x0000,0xcbe5,0x0000, 0xcbe7,0x0000,0xcbe9,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xcbf0,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xcc0c,0xcc0d,0x0000,0x0000, 0xcc10,0x0000,0x0000,0x0000,
  0xcc14,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xcc1c,0x0000,0xcc1d,0x0000, 0xcc1f,0x0000,0xcc21,0xcc22,
  0x0000,0x0000,0x0000,0xcc26, 0xcc27,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xc041(i:24130) */
  0x314a,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xcc28,0xcc29,0x0000,0x0000, 0xcc2c,0x0000,0xcc2e,0xcc2f,
  0xcc30,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xcc38,0x0000,0xcc39,0x0000, 0xcc3b,0xcc3c,0xcc3d,0xcc3e,
  0xcc3f,0x0000,0x0000,0xcc42, 0x0000,0x0000,0x0000,0x0000,
  0xcc44,0xcc45,0x0000,0x0000, 0xcc48,0x0000,0x0000,0x0000,
  0xcc4c,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xcc54,0x0000,0xcc55,0x0000, 0xcc57,0xcc58,0xcc59,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xcc60,0x0000,0x0000,0x0000, 0xcc64,0x0000,0xcc66,0x0000,
  0xcc68,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xcc70,0x0000,0xcc71,0x0000, 0x0000,0x0000,0xcc75,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xcc7c,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xcc98,0xcc99,0x0000,0x0000, 0xcc9c,0x0000,0x0000,0x0000,
  0xcca0,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xcca8,0x0000,0xcca9,0x0000, 0xccab,0xccac,0xccad,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xc141(i:24320) */
  0xccb4,0xccb5,0x0000,0x0000, 0xccb8,0x0000,0x0000,0x0000,
  0xccbc,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xccc4,0x0000,0xccc5,0x0000, 0xccc7,0x0000,0xccc9,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xccd0,0x0000,0x0000,0x0000, 0xccd4,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0xcce3,0xcce4,0xcce5,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xccec,0x0000,0x0000,0x0000, 0xccf0,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0xcd01,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xcd08,0xcd09,0x0000,0x0000, 0xcd0c,0x0000,0x0000,0x0000,
  0xcd10,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xcd18,0x0000,0xcd19,0x0000, 0xcd1b,0x0000,0xcd1d,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xcd24,0x0000,0x0000,0x0000, 0xcd28,0x0000,0x0000,0x0000,
  0xcd2c,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0xcd39,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xcd40,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xc241(i:24510) */
  0xcd5c,0x0000,0x0000,0x0000, 0xcd60,0x0000,0x0000,0x0000,
  0xcd64,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xcd6c,0x0000,0xcd6d,0x0000, 0xcd6f,0x0000,0xcd71,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xcd78,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xcd88,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xcd94,0xcd95,0x0000,0x0000, 0xcd98,0x0000,0x0000,0x0000,
  0xcd9c,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xcda4,0x0000,0xcda5,0x0000, 0xcda7,0x0000,0xcda9,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xcdb0,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0xcdc3,0xcdc4,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xcdcc,0x0000,0x0000,0x0000, 0xcdd0,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xcde8,0x0000,0x0000,0x0000, 0xcdec,0x0000,0x0000,0x0000,
  0xcdf0,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xcdf8,0x0000,0xcdf9,0x0000, 0xcdfb,0x0000,0xcdfd,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xc341(i:24700) */
  0xce04,0x0000,0x0000,0x0000, 0xce08,0x0000,0x0000,0x0000,
  0xce0c,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xce14,0x0000,0x0000,0x0000, 0x0000,0x0000,0xce19,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xce20,0xce21,0x0000,0x0000, 0xce24,0x0000,0x0000,0x0000,
  0xce28,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xce30,0x0000,0xce31,0x0000, 0xce33,0x0000,0xce35,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xce3c,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xce58,0xce59,0x0000,0x0000, 0xce5c,0x0000,0x0000,0xce5f,
  0xce60,0xce61,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xce68,0x0000,0xce69,0x0000, 0xce6b,0x0000,0xce6d,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xc441(i:24890) */
  0x314b,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xce74,0xce75,0x0000,0x0000, 0xce78,0x0000,0x0000,0xce7b,
  0xce7c,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xce84,0x0000,0xce85,0x0000, 0xce87,0x0000,0xce89,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xce90,0xce91,0x0000,0x0000, 0xce94,0x0000,0x0000,0xce97,
  0xce98,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xcea0,0x0000,0xcea1,0x0000, 0xcea3,0xcea4,0xcea5,0x0000,
  0x0000,0x0000,0xcea9,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xceac,0xcead,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0xcec1,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xcec8,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xcee4,0xcee5,0x0000,0x0000, 0xcee8,0x0000,0x0000,0xceeb,
  0xceec,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xcef4,0x0000,0xcef5,0x0000, 0xcef7,0xcef8,0xcef9,0x0000,
  0x0000,0x0000,0xcefd,0x0000, 0x0000,0x0000,
/* 0xc541(i:25080) */
  0xcf00,0xcf01,0x0000,0x0000, 0xcf04,0x0000,0x0000,0x0000,
  0xcf08,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xcf10,0x0000,0xcf11,0x0000, 0xcf13,0x0000,0xcf15,0x0000,
  0x0000,0x0000,0xcf19,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xcf1c,0x0000,0x0000,0x0000, 0xcf20,0x0000,0x0000,0x0000,
  0xcf24,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xcf2c,0x0000,0xcf2d,0x0000, 0xcf2f,0xcf30,0xcf31,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xcf38,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xcf54,0xcf55,0x0000,0x0000, 0xcf58,0x0000,0x0000,0x0000,
  0xcf5c,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xcf64,0x0000,0xcf65,0x0000, 0xcf67,0x0000,0xcf69,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xcf70,0xcf71,0x0000,0x0000, 0xcf74,0x0000,0x0000,0x0000,
  0xcf78,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xcf80,0x0000,0x0000,0x0000, 0x0000,0x0000,0xcf85,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xcf8c,0xcf8d,0x0000,0x0000, 0xcf90,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0xcf9f,0x0000,0xcfa1,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xc641(i:25270) */
  0xcfa8,0x0000,0x0000,0x0000, 0xcfac,0x0000,0x0000,0x0000,
  0xcfb0,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0xcfbd,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xcfc4,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xcfe0,0xcfe1,0x0000,0x0000, 0xcfe4,0x0000,0x0000,0x0000,
  0xcfe8,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xcff0,0x0000,0xcff1,0x0000, 0xcff3,0x0000,0xcff5,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xcffc,0x0000,0x0000,0x0000, 0xd000,0x0000,0x0000,0x0000,
  0xd004,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0xd011,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd018,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0xd02d,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd034,0xd035,0x0000,0x0000, 0xd038,0x0000,0x0000,0x0000,
  0xd03c,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd044,0x0000,0xd045,0x0000, 0xd047,0x0000,0xd049,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xc741(i:25460) */
  0xd050,0x0000,0x0000,0x0000, 0xd054,0x0000,0x0000,0x0000,
  0xd058,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd060,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd06c,0xd06d,0x0000,0x0000, 0xd070,0x0000,0x0000,0x0000,
  0xd074,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd07c,0x0000,0xd07d,0x0000, 0x0000,0x0000,0xd081,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd088,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd0a4,0xd0a5,0x0000,0x0000, 0xd0a8,0x0000,0x0000,0x0000,
  0xd0ac,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd0b4,0x0000,0xd0b5,0x0000, 0xd0b7,0x0000,0xd0b9,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xc841(i:25650) */
  0x314c,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd0c0,0xd0c1,0x0000,0x0000, 0xd0c4,0x0000,0x0000,0x0000,
  0xd0c8,0xd0c9,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd0d0,0x0000,0xd0d1,0x0000, 0xd0d3,0xd0d4,0xd0d5,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd0dc,0xd0dd,0x0000,0x0000, 0xd0e0,0x0000,0x0000,0x0000,
  0xd0e4,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd0ec,0x0000,0xd0ed,0x0000, 0xd0ef,0xd0f0,0xd0f1,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd0f8,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0xd10d,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd114,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd130,0xd131,0x0000,0x0000, 0xd134,0x0000,0x0000,0x0000,
  0xd138,0x0000,0xd13a,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd140,0x0000,0xd141,0x0000, 0xd143,0xd144,0xd145,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xc941(i:25840) */
  0xd14c,0xd14d,0x0000,0x0000, 0xd150,0x0000,0x0000,0x0000,
  0xd154,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd15c,0x0000,0xd15d,0x0000, 0xd15f,0xd160,0xd161,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd168,0xd169,0x0000,0x0000, 0xd16c,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0xd17c,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd184,0x0000,0x0000,0x0000, 0xd188,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd1a0,0xd1a1,0x0000,0x0000, 0xd1a4,0x0000,0x0000,0x0000,
  0xd1a8,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd1b0,0x0000,0xd1b1,0x0000, 0xd1b3,0x0000,0xd1b5,0x0000,
  0x0000,0x0000,0x0000,0xd1ba, 0x0000,0x0000,0x0000,0x0000,
  0xd1bc,0x0000,0x0000,0x0000, 0xd1c0,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd1d8,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xca41(i:26030) */
  0xd1f4,0x0000,0x0000,0x0000, 0xd1f8,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0xd207,0x0000,0xd209,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd210,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd22c,0xd22d,0x0000,0x0000, 0xd230,0x0000,0x0000,0x0000,
  0xd234,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd23c,0x0000,0xd23d,0x0000, 0xd23f,0x0000,0xd241,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd248,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0xd25c,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd264,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0xd277,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd280,0xd281,0x0000,0x0000, 0xd284,0x0000,0x0000,0x0000,
  0xd288,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd290,0x0000,0xd291,0x0000, 0xd293,0x0000,0xd295,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xcb41(i:26220) */
  0xd29c,0x0000,0x0000,0x0000, 0xd2a0,0x0000,0x0000,0x0000,
  0xd2a4,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd2ac,0x0000,0x0000,0x0000, 0x0000,0x0000,0xd2b1,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd2b8,0xd2b9,0x0000,0x0000, 0xd2bc,0x0000,0x0000,0xd2bf,
  0xd2c0,0x0000,0xd2c2,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd2c8,0x0000,0xd2c9,0x0000, 0xd2cb,0x0000,0xd2cd,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd2d4,0x0000,0x0000,0x0000, 0xd2d8,0x0000,0x0000,0x0000,
  0xd2dc,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd2e4,0x0000,0xd2e5,0x0000, 0xd2e7,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd2f0,0xd2f1,0x0000,0x0000, 0xd2f4,0x0000,0x0000,0x0000,
  0xd2f8,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd300,0x0000,0xd301,0x0000, 0xd303,0x0000,0xd305,0x0000,
  0x0000,0x0000,0x0000,0xd30a, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xcc41(i:26410) */
  0x314d,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd30c,0xd30d,0xd30e,0x0000, 0xd310,0x0000,0x0000,0x0000,
  0xd314,0x0000,0xd316,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd31c,0x0000,0xd31d,0x0000, 0xd31f,0xd320,0xd321,0x0000,
  0x0000,0x0000,0xd325,0xd326, 0x0000,0x0000,0x0000,0x0000,
  0xd328,0xd329,0x0000,0x0000, 0xd32c,0x0000,0x0000,0x0000,
  0xd330,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd338,0x0000,0xd339,0x0000, 0xd33b,0xd33c,0xd33d,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd344,0xd345,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0xd359,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd360,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd37c,0xd37d,0x0000,0x0000, 0xd380,0x0000,0x0000,0x0000,
  0xd384,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd38c,0x0000,0xd38d,0x0000, 0xd38f,0xd390,0xd391,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xcd41(i:26600) */
  0xd398,0xd399,0x0000,0x0000, 0xd39c,0x0000,0x0000,0x0000,
  0xd3a0,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd3a8,0x0000,0xd3a9,0x0000, 0xd3ab,0x0000,0xd3ad,0x0000,
  0x0000,0x0000,0x0000,0xd3b2, 0x0000,0x0000,0x0000,0x0000,
  0xd3b4,0xd3b5,0x0000,0x0000, 0xd3b8,0x0000,0x0000,0x0000,
  0xd3bc,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd3c4,0x0000,0xd3c5,0x0000, 0xd3c7,0xd3c8,0xd3c9,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd3d0,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd3d8,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0xd3e1,0x0000, 0xd3e3,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd3ec,0xd3ed,0x0000,0x0000, 0xd3f0,0x0000,0x0000,0x0000,
  0xd3f4,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd3fc,0x0000,0xd3fd,0x0000, 0xd3ff,0x0000,0xd401,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd408,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0xd41d,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd424,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xce41(i:26790) */
  0xd440,0x0000,0x0000,0x0000, 0xd444,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd45c,0x0000,0x0000,0x0000, 0xd460,0x0000,0x0000,0x0000,
  0xd464,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0xd46d,0x0000, 0xd46f,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd478,0xd479,0x0000,0x0000, 0xd47c,0x0000,0x0000,0xd47f,
  0xd480,0x0000,0xd482,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd488,0x0000,0xd489,0x0000, 0xd48b,0x0000,0xd48d,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd494,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0xd4a9,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd4b0,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd4cc,0x0000,0x0000,0x0000, 0xd4d0,0x0000,0x0000,0x0000,
  0xd4d4,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd4dc,0x0000,0x0000,0x0000, 0xd4df,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xcf41(i:26980) */
  0xd4e8,0xd4e9,0x0000,0x0000, 0xd4ec,0x0000,0x0000,0x0000,
  0xd4f0,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd4f8,0x0000,0x0000,0x0000, 0xd4fb,0x0000,0xd4fd,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd504,0xd505,0x0000,0x0000, 0xd508,0x0000,0x0000,0x0000,
  0xd50c,0x0000,0x0000,0x0000, 0xd510,0x0000,0x0000,0x0000,
  0xd514,0x0000,0xd515,0x0000, 0xd517,0x0000,0xd519,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd520,0x0000,0x0000,0x0000, 0xd524,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd53c,0xd53d,0x0000,0x0000, 0xd540,0x0000,0x0000,0x0000,
  0xd544,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd54c,0x0000,0xd54d,0x0000, 0xd54f,0x0000,0xd551,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xd041(i:27170) */
  0x314e,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd558,0xd559,0x0000,0x0000, 0xd55c,0x0000,0x0000,0xd55f,
  0xd560,0xd561,0x0000,0x0000, 0x0000,0xd565,0x0000,0x0000,
  0xd568,0x0000,0xd569,0x0000, 0xd56b,0xd56c,0xd56d,0x0000,
  0x0000,0x0000,0xd571,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd574,0xd575,0x0000,0x0000, 0xd578,0x0000,0x0000,0x0000,
  0xd57c,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd584,0x0000,0xd585,0x0000, 0xd587,0xd588,0xd589,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd590,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0xd5a5,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd5ac,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd5c8,0xd5c9,0x0000,0x0000, 0xd5cc,0x0000,0x0000,0xd5cf,
  0xd5d0,0x0000,0xd5d2,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd5d8,0x0000,0xd5d9,0x0000, 0xd5db,0x0000,0xd5dd,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xd141(i:27360) */
  0xd5e4,0xd5e5,0x0000,0x0000, 0xd5e8,0x0000,0x0000,0x0000,
  0xd5ec,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd5f4,0x0000,0xd5f5,0x0000, 0xd5f7,0x0000,0xd5f9,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd600,0xd601,0x0000,0x0000, 0xd604,0x0000,0x0000,0x0000,
  0xd608,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd610,0x0000,0xd611,0x0000, 0xd613,0xd614,0xd615,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd61c,0x0000,0x0000,0x0000, 0xd620,0x0000,0x0000,0x0000,
  0xd624,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd62c,0x0000,0xd62d,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd638,0xd639,0x0000,0x0000, 0xd63c,0x0000,0x0000,0x0000,
  0xd640,0x0000,0x0000,0x0000, 0x0000,0xd645,0x0000,0x0000,
  0xd648,0x0000,0xd649,0x0000, 0xd64b,0x0000,0xd64d,0x0000,
  0x0000,0x0000,0xd651,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd654,0xd655,0x0000,0x0000, 0xd658,0x0000,0x0000,0x0000,
  0xd65c,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0xd667,0x0000,0xd669,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd670,0xd671,0x0000,0x0000, 0xd674,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0xd683,0x0000,0xd685,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xd241(i:27550) */
  0xd68c,0xd68d,0x0000,0x0000, 0xd690,0x0000,0x0000,0x0000,
  0xd694,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0xd69d,0x0000, 0xd69f,0x0000,0xd6a1,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd6a8,0xd6a9,0x0000,0x0000, 0xd6ac,0x0000,0x0000,0x0000,
  0xd6b0,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd6b8,0x0000,0xd6b9,0x0000, 0xd6bb,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd6c4,0xd6c5,0x0000,0x0000, 0xd6c8,0x0000,0x0000,0x0000,
  0xd6cc,0x0000,0x0000,0x0000, 0x0000,0xd6d1,0x0000,0x0000,
  0xd6d4,0x0000,0xd6d5,0x0000, 0xd6d7,0x0000,0xd6d9,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd6e0,0x0000,0x0000,0x0000, 0xd6e4,0x0000,0x0000,0x0000,
  0xd6e8,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd6f0,0x0000,0x0000,0x0000, 0x0000,0x0000,0xd6f5,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd6fc,0xd6fd,0x0000,0x0000, 0xd700,0x0000,0x0000,0x0000,
  0xd704,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd70c,0x0000,0x0000,0x0000, 0x0000,0x0000,0xd711,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd718,0xd719,0x0000,0x0000, 0xd71c,0x0000,0x0000,0x0000,
  0xd720,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd728,0x0000,0xd729,0x0000, 0xd72b,0x0000,0xd72d,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xd341(i:27740) */
  0xd734,0xd735,0x0000,0x0000, 0xd738,0x0000,0x0000,0x0000,
  0xd73c,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd744,0x0000,0x0000,0x0000, 0xd747,0x0000,0xd749,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd750,0xd751,0x0000,0x0000, 0xd754,0x0000,0xd756,0xd757,
  0xd758,0xd759,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd760,0x0000,0xd761,0x0000, 0xd763,0x0000,0xd765,0x0000,
  0x0000,0x0000,0xd769,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd76c,0xd76d,0x0000,0x0000, 0xd770,0x0000,0x0000,0x0000,
  0xd774,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd77c,0x0000,0xd77d,0x0000, 0x0000,0x0000,0xd781,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd788,0xd789,0x0000,0x0000, 0xd78c,0x0000,0x0000,0x0000,
  0xd790,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd798,0x0000,0xd799,0x0000, 0xd79b,0x0000,0xd79d,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xd441(i:27930) */
  0xe000,0xe001,0xe002,0xe003, 0xe004,0xe005,0xe006,0xe007,
  0xe008,0xe009,0xe00a,0xe00b, 0xe00c,0xe00d,0xe00e,0xe00f,
  0xe010,0xe011,0xe012,0xe013, 0xe014,0xe015,0xe016,0xe017,
  0xe018,0xe019,0xe01a,0xe01b, 0xe01c,0xe01d,0xe01e,0xe01f,
  0xe020,0xe021,0xe022,0xe023, 0xe024,0xe025,0xe026,0xe027,
  0xe028,0xe029,0xe02a,0xe02b, 0xe02c,0xe02d,0xe02e,0xe02f,
  0xe030,0xe031,0xe032,0xe033, 0xe034,0xe035,0xe036,0xe037,
  0xe038,0xe039,0xe03a,0xe03b, 0xe03c,0xe03d,0xe03e,0x0000,
  0xe03f,0xe040,0xe041,0xe042, 0xe043,0xe044,0xe045,0xe046,
  0xe047,0xe048,0xe049,0xe04a, 0xe04b,0xe04c,0xe04d,0xe04e,
  0xe04f,0xe050,0xe051,0xe052, 0xe053,0xe054,0xe055,0xe056,
  0xe057,0xe058,0xe059,0xe05a, 0xe05b,0xe05c,0xe05d,0xe05e,
  0xe05f,0xe060,0xe061,0xe062, 0xe063,0xe064,0xe065,0xe066,
  0xe067,0xe068,0xe069,0xe06a, 0xe06b,0xe06c,0xe06d,0xe06e,
  0xe06f,0xe070,0xe071,0xe072, 0xe073,0xe074,0xe075,0xe076,
  0xe077,0xe078,0xe079,0xe07a, 0xe07b,0xe07c,0xe07d,0xe07e,
  0xe07f,0xe080,0xe081,0xe082, 0xe083,0xe084,0xe085,0xe086,
  0xe087,0xe088,0xe089,0xe08a, 0xe08b,0xe08c,0xe08d,0xe08e,
  0xe08f,0xe090,0xe091,0xe092, 0xe093,0xe094,0xe095,0xe096,
  0xe097,0xe098,0xe099,0xe09a, 0xe09b,0xe09c,0xe09d,0xe09e,
  0xe09f,0xe0a0,0xe0a1,0xe0a2, 0xe0a3,0xe0a4,0xe0a5,0xe0a6,
  0xe0a7,0xe0a8,0xe0a9,0xe0aa, 0xe0ab,0xe0ac,0xe0ad,0xe0ae,
  0xe0af,0xe0b0,0xe0b1,0xe0b2, 0xe0b3,0xe0b4,0xe0b5,0xe0b6,
  0xe0b7,0xe0b8,0xe0b9,0xe0ba, 0xe0bb,0x0000,
/* 0xd541(i:28120) */
  0xe0bc,0xe0bd,0xe0be,0xe0bf, 0xe0c0,0xe0c1,0xe0c2,0xe0c3,
  0xe0c4,0xe0c5,0xe0c6,0xe0c7, 0xe0c8,0xe0c9,0xe0ca,0xe0cb,
  0xe0cc,0xe0cd,0xe0ce,0xe0cf, 0xe0d0,0xe0d1,0xe0d2,0xe0d3,
  0xe0d4,0xe0d5,0xe0d6,0xe0d7, 0xe0d8,0xe0d9,0xe0da,0xe0db,
  0xe0dc,0xe0dd,0xe0de,0xe0df, 0xe0e0,0xe0e1,0xe0e2,0xe0e3,
  0xe0e4,0xe0e5,0xe0e6,0xe0e7, 0xe0e8,0xe0e9,0xe0ea,0xe0eb,
  0xe0ec,0xe0ed,0xe0ee,0xe0ef, 0xe0f0,0xe0f1,0xe0f2,0xe0f3,
  0xe0f4,0xe0f5,0xe0f6,0xe0f7, 0xe0f8,0xe0f9,0xe0fa,0x0000,
  0xe0fb,0xe0fc,0xe0fd,0xe0fe, 0xe0ff,0xe100,0xe101,0xe102,
  0xe103,0xe104,0xe105,0xe106, 0xe107,0xe108,0xe109,0xe10a,
  0xe10b,0xe10c,0xe10d,0xe10e, 0xe10f,0xe110,0xe111,0xe112,
  0xe113,0xe114,0xe115,0xe116, 0xe117,0xe118,0xe119,0xe11a,
  0xe11b,0xe11c,0xe11d,0xe11e, 0xe11f,0xe120,0xe121,0xe122,
  0xe123,0xe124,0xe125,0xe126, 0xe127,0xe128,0xe129,0xe12a,
  0xe12b,0xe12c,0xe12d,0xe12e, 0xe12f,0xe130,0xe131,0xe132,
  0xe133,0xe134,0xe135,0xe136, 0xe137,0xe138,0xe139,0xe13a,
  0xe13b,0xe13c,0xe13d,0xe13e, 0xe13f,0xe140,0xe141,0xe142,
  0xe143,0xe144,0xe145,0xe146, 0xe147,0xe148,0xe149,0xe14a,
  0xe14b,0xe14c,0xe14d,0xe14e, 0xe14f,0xe150,0xe151,0xe152,
  0xe153,0xe154,0xe155,0xe156, 0xe157,0xe158,0xe159,0xe15a,
  0xe15b,0xe15c,0xe15d,0xe15e, 0xe15f,0xe160,0xe161,0xe162,
  0xe163,0xe164,0xe165,0xe166, 0xe167,0xe168,0xe169,0xe16a,
  0xe16b,0xe16c,0xe16d,0xe16e, 0xe16f,0xe170,0xe171,0xe172,
  0xe173,0xe174,0xe175,0xe176, 0xe177,0x0000,
/* 0xd641(i:28310) */
  0xe178,0xe179,0xe17a,0xe17b, 0xe17c,0xe17d,0xe17e,0xe17f,
  0xe180,0xe181,0xe182,0xe183, 0xe184,0xe185,0xe186,0xe187,
  0xe188,0xe189,0xe18a,0xe18b, 0xe18c,0xe18d,0xe18e,0xe18f,
  0xe190,0xe191,0xe192,0xe193, 0xe194,0xe195,0xe196,0xe197,
  0xe198,0xe199,0xe19a,0xe19b, 0xe19c,0xe19d,0xe19e,0xe19f,
  0xe1a0,0xe1a1,0xe1a2,0xe1a3, 0xe1a4,0xe1a5,0xe1a6,0xe1a7,
  0xe1a8,0xe1a9,0xe1aa,0xe1ab, 0xe1ac,0xe1ad,0xe1ae,0xe1af,
  0xe1b0,0xe1b1,0xe1b2,0xe1b3, 0xe1b4,0xe1b5,0xe1b6,0x0000,
  0xe1b7,0xe1b8,0xe1b9,0xe1ba, 0xe1bb,0xe1bc,0xe1bd,0xe1be,
  0xe1bf,0xe1c0,0xe1c1,0xe1c2, 0xe1c3,0xe1c4,0xe1c5,0xe1c6,
  0xe1c7,0xe1c8,0xe1c9,0xe1ca, 0xe1cb,0xe1cc,0xe1cd,0xe1ce,
  0xe1cf,0xe1d0,0xe1d1,0xe1d2, 0xe1d3,0xe1d4,0xe1d5,0xe1d6,
  0xe1d7,0xe1d8,0xe1d9,0xe1da, 0xe1db,0xe1dc,0xe1dd,0xe1de,
  0xe1df,0xe1e0,0xe1e1,0xe1e2, 0xe1e3,0xe1e4,0xe1e5,0xe1e6,
  0xe1e7,0xe1e8,0xe1e9,0xe1ea, 0xe1eb,0xe1ec,0xe1ed,0xe1ee,
  0xe1ef,0xe1f0,0xe1f1,0xe1f2, 0xe1f3,0xe1f4,0xe1f5,0xe1f6,
  0xe1f7,0xe1f8,0xe1f9,0xe1fa, 0xe1fb,0xe1fc,0xe1fd,0xe1fe,
  0xe1ff,0xe200,0xe201,0xe202, 0xe203,0xe204,0xe205,0xe206,
  0xe207,0xe208,0xe209,0xe20a, 0xe20b,0xe20c,0xe20d,0xe20e,
  0xe20f,0xe210,0xe211,0xe212, 0xe213,0xe214,0xe215,0xe216,
  0xe217,0xe218,0xe219,0xe21a, 0xe21b,0xe21c,0xe21d,0xe21e,
  0xe21f,0xe220,0xe221,0xe222, 0xe223,0xe224,0xe225,0xe226,
  0xe227,0xe228,0xe229,0xe22a, 0xe22b,0xe22c,0xe22d,0xe22e,
  0xe22f,0xe230,0xe231,0xe232, 0xe233,0x0000,
/* 0xd741(i:28500) */
  0xe234,0xe235,0xe236,0xe237, 0xe238,0xe239,0xe23a,0xe23b,
  0xe23c,0xe23d,0xe23e,0xe23f, 0xe240,0xe241,0xe242,0xe243,
  0xe244,0xe245,0xe246,0xe247, 0xe248,0xe249,0xe24a,0xe24b,
  0xe24c,0xe24d,0xe24e,0xe24f, 0xe250,0xe251,0xe252,0xe253,
  0xe254,0xe255,0xe256,0xe257, 0xe258,0xe259,0xe25a,0xe25b,
  0xe25c,0xe25d,0xe25e,0xe25f, 0xe260,0xe261,0xe262,0xe263,
  0xe264,0xe265,0xe266,0xe267, 0xe268,0xe269,0xe26a,0xe26b,
  0xe26c,0xe26d,0xe26e,0xe26f, 0xe270,0xe271,0xe272,0x0000,
  0xe273,0xe274,0xe275,0xe276, 0xe277,0xe278,0xe279,0xe27a,
  0xe27b,0xe27c,0xe27d,0xe27e, 0xe27f,0xe280,0xe281,0xe282,
  0xe283,0xe284,0xe285,0xe286, 0xe287,0xe288,0xe289,0xe28a,
  0xe28b,0xe28c,0xe28d,0xe28e, 0xe28f,0xe290,0xe291,0xe292,
  0xe293,0xe294,0xe295,0xe296, 0xe297,0xe298,0xe299,0xe29a,
  0xe29b,0xe29c,0xe29d,0xe29e, 0xe29f,0xe2a0,0xe2a1,0xe2a2,
  0xe2a3,0xe2a4,0xe2a5,0xe2a6, 0xe2a7,0xe2a8,0xe2a9,0xe2aa,
  0xe2ab,0xe2ac,0xe2ad,0xe2ae, 0xe2af,0xe2b0,0xe2b1,0xe2b2,
  0xe2b3,0xe2b4,0xe2b5,0xe2b6, 0xe2b7,0xe2b8,0xe2b9,0xe2ba,
  0xe2bb,0xe2bc,0xe2bd,0xe2be, 0xe2bf,0xe2c0,0xe2c1,0xe2c2,
  0xe2c3,0xe2c4,0xe2c5,0xe2c6, 0xe2c7,0xe2c8,0xe2c9,0xe2ca,
  0xe2cb,0xe2cc,0xe2cd,0xe2ce, 0xe2cf,0xe2d0,0xe2d1,0xe2d2,
  0xe2d3,0xe2d4,0xe2d5,0xe2d6, 0xe2d7,0xe2d8,0xe2d9,0xe2da,
  0xe2db,0xe2dc,0xe2dd,0xe2de, 0xe2df,0xe2e0,0xe2e1,0xe2e2,
  0xe2e3,0xe2e4,0xe2e5,0xe2e6, 0xe2e7,0xe2e8,0xe2e9,0xe2ea,
  0xe2eb,0xe2ec,0xe2ed,0xe2ee, 0xe2ef,0x0000,
/* 0xd841(i:28690) */
  0xe2f0,0xe2f1,0xe2f2,0xe2f3, 0xe2f4,0xe2f5,0xe2f6,0xe2f7,
  0xe2f8,0xe2f9,0xe2fa,0xe2fb, 0xe2fc,0xe2fd,0xe2fe,0xe2ff,
  0xe300,0xe301,0xe302,0xe303, 0xe304,0xe305,0xe306,0xe307,
  0xe308,0xe309,0xe30a,0xe30b, 0xe30c,0xe30d,0xe30e,0xe30f,
  0xe310,0xe311,0xe312,0xe313, 0xe314,0xe315,0xe316,0xe317,
  0xe318,0xe319,0xe31a,0xe31b, 0xe31c,0xe31d,0xe31e,0xe31f,
  0xe320,0xe321,0xe322,0xe323, 0xe324,0xe325,0xe326,0xe327,
  0xe328,0xe329,0xe32a,0xe32b, 0xe32c,0xe32d,0xe32e,0x0000,
  0xe32f,0xe330,0xe331,0xe332, 0xe333,0xe334,0xe335,0xe336,
  0xe337,0xe338,0xe339,0xe33a, 0xe33b,0xe33c,0xe33d,0xe33e,
  0xe33f,0xe340,0xe341,0xe342, 0xe343,0xe344,0xe345,0xe346,
  0xe347,0xe348,0xe349,0xe34a, 0xe34b,0xe34c,0xe34d,0xe34e,
  0xe34f,0xe350,0xe351,0xe352, 0xe353,0xe354,0xe355,0xe356,
  0xe357,0xe358,0xe359,0xe35a, 0xe35b,0xe35c,0xe35d,0xe35e,
  0xe35f,0xe360,0xe361,0xe362, 0xe363,0xe364,0xe365,0xe366,
  0xe367,0xe368,0xe369,0xe36a, 0xe36b,0xe36c,0xe36d,0xe36e,
  0xe36f,0xe370,0xe371,0xe372, 0xe373,0xe374,0xe375,0xe376,
  0xe377,0xe378,0xe379,0xe37a, 0xe37b,0xe37c,0xe37d,0xe37e,
  0xe37f,0xe380,0xe381,0xe382, 0xe383,0xe384,0xe385,0xe386,
  0xe387,0xe388,0xe389,0xe38a, 0xe38b,0xe38c,0xe38d,0xe38e,
  0xe38f,0xe390,0xe391,0xe392, 0xe393,0xe394,0xe395,0xe396,
  0xe397,0xe398,0xe399,0xe39a, 0xe39b,0xe39c,0xe39d,0xe39e,
  0xe39f,0xe3a0,0xe3a1,0xe3a2, 0xe3a3,0xe3a4,0xe3a5,0xe3a6,
  0xe3a7,0xe3a8,0xe3a9,0xe3aa, 0xe3ab,0x0000,
/* 0xd941(i:28880) */
  0xe3ac,0xe3ad,0xe3ae,0xe3af, 0xe3b0,0xe3b1,0xe3b2,0xe3b3,
  0xe3b4,0xe3b5,0xe3b6,0xe3b7, 0xe3b8,0xe3b9,0xe3ba,0xe3bb,
  0xe3bc,0xe3bd,0xe3be,0xe3bf, 0xe3c0,0xe3c1,0xe3c2,0xe3c3,
  0xe3c4,0xe3c5,0xe3c6,0xe3c7, 0xe3c8,0xe3c9,0xe3ca,0xe3cb,
  0xe3cc,0xe3cd,0xe3ce,0xe3cf, 0xe3d0,0xe3d1,0xe3d2,0xe3d3,
  0xe3d4,0xe3d5,0xe3d6,0xe3d7, 0xe3d8,0xe3d9,0xe3da,0xe3db,
  0xe3dc,0xe3dd,0xe3de,0xe3df, 0xe3e0,0xe3e1,0xe3e2,0xe3e3,
  0xe3e4,0xe3e5,0xe3e6,0xe3e7, 0xe3e8,0xe3e9,0xe3ea,0x0000,
  0xe3eb,0xe3ec,0xe3ed,0xe3ee, 0xe3ef,0xe3f0,0xe3f1,0xe3f2,
  0xe3f3,0xe3f4,0xe3f5,0xe3f6, 0xe3f7,0xe3f8,0xe3f9,0xe3fa,
  0xe3fb,0xe3fc,0xe3fd,0xe3fe, 0xe3ff,0xe400,0xe401,0xe402,
  0xe403,0xe404,0xe405,0xe406, 0xe407,0xe408,0xe409,0xe40a,
  0xe40b,0xe40c,0xe40d,0xe40e, 0xe40f,0xe410,0xe411,0xe412,
  0xe413,0xe414,0xe415,0xe416, 0xe417,0xe418,0xe419,0xe41a,
  0xe41b,0xe41c,0xe41d,0xe41e, 0xe41f,0xe420,0xe421,0xe422,
  0xe423,0xe424,0xe425,0xe426, 0xe427,0xe428,0xe429,0xe42a,
  0xe42b,0xe42c,0xe42d,0xe42e, 0xe42f,0xe430,0xe431,0xe432,
  0xe433,0xe434,0xe435,0xe436, 0xe437,0xe438,0xe439,0xe43a,
  0xe43b,0xe43c,0xe43d,0xe43e, 0xe43f,0xe440,0xe441,0xe442,
  0xe443,0xe444,0xe445,0xe446, 0xe447,0xe448,0xe449,0xe44a,
  0xe44b,0xe44c,0xe44d,0xe44e, 0xe44f,0xe450,0xe451,0xe452,
  0xe453,0xe454,0xe455,0xe456, 0xe457,0xe458,0xe459,0xe45a,
  0xe45b,0xe45c,0xe45d,0xe45e, 0xe45f,0xe460,0xe461,0xe462,
  0xe463,0xe464,0xe465,0xe466, 0xe467,0x0000,
/* 0xda41(i:29070) */
  0xe468,0xe469,0xe46a,0xe46b, 0xe46c,0xe46d,0xe46e,0xe46f,
  0xe470,0xe471,0xe472,0xe473, 0xe474,0xe475,0xe476,0xe477,
  0xe478,0xe479,0xe47a,0xe47b, 0xe47c,0xe47d,0xe47e,0xe47f,
  0xe480,0xe481,0xe482,0xe483, 0xe484,0xe485,0xe486,0xe487,
  0xe488,0xe489,0xe48a,0xe48b, 0xe48c,0xe48d,0xe48e,0xe48f,
  0xe490,0xe491,0xe492,0xe493, 0xe494,0xe495,0xe496,0xe497,
  0xe498,0xe499,0xe49a,0xe49b, 0xe49c,0xe49d,0xe49e,0xe49f,
  0xe4a0,0xe4a1,0xe4a2,0xe4a3, 0xe4a4,0xe4a5,0xe4a6,0x0000,
  0xe4a7,0xe4a8,0xe4a9,0xe4aa, 0xe4ab,0xe4ac,0xe4ad,0xe4ae,
  0xe4af,0xe4b0,0xe4b1,0xe4b2, 0xe4b3,0xe4b4,0xe4b5,0xe4b6,
  0xe4b7,0xe4b8,0xe4b9,0xe4ba, 0xe4bb,0xe4bc,0xe4bd,0xe4be,
  0xe4bf,0xe4c0,0xe4c1,0xe4c2, 0xe4c3,0xe4c4,0xe4c5,0xe4c6,
  0xe4c7,0xe4c8,0xe4c9,0xe4ca, 0xe4cb,0xe4cc,0xe4cd,0xe4ce,
  0xe4cf,0xe4d0,0xe4d1,0xe4d2, 0xe4d3,0xe4d4,0xe4d5,0xe4d6,
  0xe4d7,0xe4d8,0xe4d9,0xe4da, 0xe4db,0xe4dc,0xe4dd,0xe4de,
  0xe4df,0xe4e0,0xe4e1,0xe4e2, 0xe4e3,0xe4e4,0xe4e5,0xe4e6,
  0xe4e7,0xe4e8,0xe4e9,0xe4ea, 0xe4eb,0xe4ec,0xe4ed,0xe4ee,
  0xe4ef,0xe4f0,0xe4f1,0xe4f2, 0xe4f3,0xe4f4,0xe4f5,0xe4f6,
  0xe4f7,0xe4f8,0xe4f9,0xe4fa, 0xe4fb,0xe4fc,0xe4fd,0xe4fe,
  0xe4ff,0xe500,0xe501,0xe502, 0xe503,0xe504,0xe505,0xe506,
  0xe507,0xe508,0xe509,0xe50a, 0xe50b,0xe50c,0xe50d,0xe50e,
  0xe50f,0xe510,0xe511,0xe512, 0xe513,0xe514,0xe515,0xe516,
  0xe517,0xe518,0xe519,0xe51a, 0xe51b,0xe51c,0xe51d,0xe51e,
  0xe51f,0xe520,0xe521,0xe522, 0xe523,0x0000,
/* 0xdb41(i:29260) */
  0xe524,0xe525,0xe526,0xe527, 0xe528,0xe529,0xe52a,0xe52b,
  0xe52c,0xe52d,0xe52e,0xe52f, 0xe530,0xe531,0xe532,0xe533,
  0xe534,0xe535,0xe536,0xe537, 0xe538,0xe539,0xe53a,0xe53b,
  0xe53c,0xe53d,0xe53e,0xe53f, 0xe540,0xe541,0xe542,0xe543,
  0xe544,0xe545,0xe546,0xe547, 0xe548,0xe549,0xe54a,0xe54b,
  0xe54c,0xe54d,0xe54e,0xe54f, 0xe550,0xe551,0xe552,0xe553,
  0xe554,0xe555,0xe556,0xe557, 0xe558,0xe559,0xe55a,0xe55b,
  0xe55c,0xe55d,0xe55e,0xe55f, 0xe560,0xe561,0xe562,0x0000,
  0xe563,0xe564,0xe565,0xe566, 0xe567,0xe568,0xe569,0xe56a,
  0xe56b,0xe56c,0xe56d,0xe56e, 0xe56f,0xe570,0xe571,0xe572,
  0xe573,0xe574,0xe575,0xe576, 0xe577,0xe578,0xe579,0xe57a,
  0xe57b,0xe57c,0xe57d,0xe57e, 0xe57f,0xe580,0xe581,0xe582,
  0xe583,0xe584,0xe585,0xe586, 0xe587,0xe588,0xe589,0xe58a,
  0xe58b,0xe58c,0xe58d,0xe58e, 0xe58f,0xe590,0xe591,0xe592,
  0xe593,0xe594,0xe595,0xe596, 0xe597,0xe598,0xe599,0xe59a,
  0xe59b,0xe59c,0xe59d,0xe59e, 0xe59f,0xe5a0,0xe5a1,0xe5a2,
  0xe5a3,0xe5a4,0xe5a5,0xe5a6, 0xe5a7,0xe5a8,0xe5a9,0xe5aa,
  0xe5ab,0xe5ac,0xe5ad,0xe5ae, 0xe5af,0xe5b0,0xe5b1,0xe5b2,
  0xe5b3,0xe5b4,0xe5b5,0xe5b6, 0xe5b7,0xe5b8,0xe5b9,0xe5ba,
  0xe5bb,0xe5bc,0xe5bd,0xe5be, 0xe5bf,0xe5c0,0xe5c1,0xe5c2,
  0xe5c3,0xe5c4,0xe5c5,0xe5c6, 0xe5c7,0xe5c8,0xe5c9,0xe5ca,
  0xe5cb,0xe5cc,0xe5cd,0xe5ce, 0xe5cf,0xe5d0,0xe5d1,0xe5d2,
  0xe5d3,0xe5d4,0xe5d5,0xe5d6, 0xe5d7,0xe5d8,0xe5d9,0xe5da,
  0xe5db,0xe5dc,0xe5dd,0xe5de, 0xe5df,0x0000,
/* 0xdc41(i:29450) */
  0xe5e0,0xe5e1,0xe5e2,0xe5e3, 0xe5e4,0xe5e5,0xe5e6,0xe5e7,
  0xe5e8,0xe5e9,0xe5ea,0xe5eb, 0xe5ec,0xe5ed,0xe5ee,0xe5ef,
  0xe5f0,0xe5f1,0xe5f2,0xe5f3, 0xe5f4,0xe5f5,0xe5f6,0xe5f7,
  0xe5f8,0xe5f9,0xe5fa,0xe5fb, 0xe5fc,0xe5fd,0xe5fe,0xe5ff,
  0xe600,0xe601,0xe602,0xe603, 0xe604,0xe605,0xe606,0xe607,
  0xe608,0xe609,0xe60a,0xe60b, 0xe60c,0xe60d,0xe60e,0xe60f,
  0xe610,0xe611,0xe612,0xe613, 0xe614,0xe615,0xe616,0xe617,
  0xe618,0xe619,0xe61a,0xe61b, 0xe61c,0xe61d,0xe61e,0x0000,
  0xe61f,0xe620,0xe621,0xe622, 0xe623,0xe624,0xe625,0xe626,
  0xe627,0xe628,0xe629,0xe62a, 0xe62b,0xe62c,0xe62d,0xe62e,
  0xe62f,0xe630,0xe631,0xe632, 0xe633,0xe634,0xe635,0xe636,
  0xe637,0xe638,0xe639,0xe63a, 0xe63b,0xe63c,0xe63d,0xe63e,
  0xe63f,0xe640,0xe641,0xe642, 0xe643,0xe644,0xe645,0xe646,
  0xe647,0xe648,0xe649,0xe64a, 0xe64b,0xe64c,0xe64d,0xe64e,
  0xe64f,0xe650,0xe651,0xe652, 0xe653,0xe654,0xe655,0xe656,
  0xe657,0xe658,0xe659,0xe65a, 0xe65b,0xe65c,0xe65d,0xe65e,
  0xe65f,0xe660,0xe661,0xe662, 0xe663,0xe664,0xe665,0xe666,
  0xe667,0xe668,0xe669,0xe66a, 0xe66b,0xe66c,0xe66d,0xe66e,
  0xe66f,0xe670,0xe671,0xe672, 0xe673,0xe674,0xe675,0xe676,
  0xe677,0xe678,0xe679,0xe67a, 0xe67b,0xe67c,0xe67d,0xe67e,
  0xe67f,0xe680,0xe681,0xe682, 0xe683,0xe684,0xe685,0xe686,
  0xe687,0xe688,0xe689,0xe68a, 0xe68b,0xe68c,0xe68d,0xe68e,
  0xe68f,0xe690,0xe691,0xe692, 0xe693,0xe694,0xe695,0xe696,
  0xe697,0xe698,0xe699,0xe69a, 0xe69b,0x0000,
/* 0xdd41(i:29640) */
  0xe69c,0xe69d,0xe69e,0xe69f, 0xe6a0,0xe6a1,0xe6a2,0xe6a3,
  0xe6a4,0xe6a5,0xe6a6,0xe6a7, 0xe6a8,0xe6a9,0xe6aa,0xe6ab,
  0xe6ac,0xe6ad,0xe6ae,0xe6af, 0xe6b0,0xe6b1,0xe6b2,0xe6b3,
  0xe6b4,0xe6b5,0xe6b6,0xe6b7, 0xe6b8,0xe6b9,0xe6ba,0xe6bb,
  0xe6bc,0xe6bd,0xe6be,0xe6bf, 0xe6c0,0xe6c1,0xe6c2,0xe6c3,
  0xe6c4,0xe6c5,0xe6c6,0xe6c7, 0xe6c8,0xe6c9,0xe6ca,0xe6cb,
  0xe6cc,0xe6cd,0xe6ce,0xe6cf, 0xe6d0,0xe6d1,0xe6d2,0xe6d3,
  0xe6d4,0xe6d5,0xe6d6,0xe6d7, 0xe6d8,0xe6d9,0xe6da,0x0000,
  0xe6db,0xe6dc,0xe6dd,0xe6de, 0xe6df,0xe6e0,0xe6e1,0xe6e2,
  0xe6e3,0xe6e4,0xe6e5,0xe6e6, 0xe6e7,0xe6e8,0xe6e9,0xe6ea,
  0xe6eb,0xe6ec,0xe6ed,0xe6ee, 0xe6ef,0xe6f0,0xe6f1,0xe6f2,
  0xe6f3,0xe6f4,0xe6f5,0xe6f6, 0xe6f7,0xe6f8,0xe6f9,0xe6fa,
  0xe6fb,0xe6fc,0xe6fd,0xe6fe, 0xe6ff,0xe700,0xe701,0xe702,
  0xe703,0xe704,0xe705,0xe706, 0xe707,0xe708,0xe709,0xe70a,
  0xe70b,0xe70c,0xe70d,0xe70e, 0xe70f,0xe710,0xe711,0xe712,
  0xe713,0xe714,0xe715,0xe716, 0xe717,0xe718,0xe719,0xe71a,
  0xe71b,0xe71c,0xe71d,0xe71e, 0xe71f,0xe720,0xe721,0xe722,
  0xe723,0xe724,0xe725,0xe726, 0xe727,0xe728,0xe729,0xe72a,
  0xe72b,0xe72c,0xe72d,0xe72e, 0xe72f,0xe730,0xe731,0xe732,
  0xe733,0xe734,0xe735,0xe736, 0xe737,0xe738,0xe739,0xe73a,
  0xe73b,0xe73c,0xe73d,0xe73e, 0xe73f,0xe740,0xe741,0xe742,
  0xe743,0xe744,0xe745,0xe746, 0xe747,0xe748,0xe749,0xe74a,
  0xe74b,0xe74c,0xe74d,0xe74e, 0xe74f,0xe750,0xe751,0xe752,
  0xe753,0xe754,0xe755,0xe756, 0xe757,0x0000,
/* 0xde41(i:29830) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xdf41(i:30020) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xe041(i:30210) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xe141(i:30400) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xe241(i:30590) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xe341(i:30780) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000
/* 0xe441(i:30970) */
};

unsigned short uni_t_ibm935[11970] = {
/* EBCDIC Simplified chinese - codelimit: 11970 */
/* 0x4100(i:0) */
  0x03b1,0x03b2,0x03b3,0x03b4, 0x03b5,0x03b6,0x03b7,0x03b8,
  0x03b9,0x03ba,0x03bb,0x03bc, 0x03bd,0x03be,0x03bf,0x03c0,
  0x03c1,0x03c3,0x03c4,0x03c5, 0x03c6,0x03c7,0x03c8,0x03c9,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0391,0x0392,0x0393,0x0394, 0x0395,0x0396,0x0397,0x0398,
  0x0399,0x039a,0x039b,0x039c, 0x039d,0x039e,0x039f,0x03a0,
  0x03a1,0x03a3,0x03a4,0x03a5, 0x03a6,0x03a7,0x03a8,0x03a9,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0430,
  0x0431,0x0432,0x0433,0x0434, 0x0435,0x0451,0x0436,0x0437,
  0x0438,0x0439,0x043a,0x043b, 0x043c,0x043d,0x043e,0x043f,
  0x0440,0x0441,0x0442,0x0443, 0x0444,0x0445,0x0446,0x0447,
  0x0448,0x0449,0x044a,0x044b, 0x044c,0x044d,0x044e,0x044f,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x2170,0x2171,0x2172,0x2173, 0x2174,0x2175,0x2176,0x2177,
  0x2178,0x2179,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0410,
  0x0411,0x0412,0x0413,0x0414, 0x0415,0x0401,0x0416,0x0417,
  0x0418,0x0419,0x041a,0x041b, 0x041c,0x041d,0x041e,0x041f,
  0x0420,0x0421,0x0422,0x0423, 0x0424,0x0425,0x0426,0x0427,
  0x0428,0x0429,0x042a,0x042b, 0x042c,0x042d,0x042e,0x042f,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x2160,0x2161,0x2162,0x2163, 0x2164,0x2165,0x2166,0x2167,
  0x2168,0x2169,0x216a,0x216b, 0x0000,0x0000,
/* 0x4241(i:190) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0xffe1,0xff0e,0xff1c, 0xff08,0xff0b,0xff5c,0xff06,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0xff01,0xffe5,0xff0a, 0xff09,0xff1b,0xffe2,0xff0d,
  0xff0f,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0xffe4,0xff0c,0xff05, 0xff3f,0xff1e,0xff1f,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xff40,0xff1a,0xff03,0xff20, 0xff07,0xff1d,0xff02,0x0000,
  0xff41,0xff42,0xff43,0xff44, 0xff45,0xff46,0xff47,0xff48,
  0xff49,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xff4a,0xff4b,0xff4c,0xff4d, 0xff4e,0xff4f,0xff50,0xff51,
  0xff52,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xffe3,0xff53,0xff54,0xff55, 0xff56,0xff57,0xff58,0xff59,
  0xff5a,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0xff5b,
  0xff21,0xff22,0xff23,0xff24, 0xff25,0xff26,0xff27,0xff28,
  0xff29,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0xff5d,
  0xff2a,0xff2b,0xff2c,0xff2d, 0xff2e,0xff2f,0xff30,0xff31,
  0xff32,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0xff04,
  0x0000,0xff33,0xff34,0xff35, 0xff36,0xff37,0xff38,0xff39,
  0xff3a,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0xff10,
  0xff11,0xff12,0xff13,0xff14, 0xff15,0xff16,0xff17,0xff18,
  0xff19,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x4341(i:380) */
  0x3002,0x300c,0x300d,0x3001, 0x30fb,0x30f2,0x30a1,0x30a3,
  0x30a5,0xffe0,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x30a7,0x30a9,0x30e3,0x30e5, 0x30e7,0x30c3,0x30ee,0x30fc,
  0x30f5,0x30f6,0xf83d,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x30a2,0x30a4,0x30a6,0x30a8, 0x30aa,0x30ab,0x30ad,0x30af,
  0x30b1,0x30b3,0x0000,0x30b5, 0x30b7,0x30b9,0x30bb,0x30bd,
  0x30bf,0x30c1,0x30c4,0x30c6, 0x30c8,0x30ca,0x30cb,0x30cc,
  0x30cd,0x30ce,0x0000,0x0000, 0x30cf,0x30d2,0x30d5,0x0000,
  0xff5e,0x30d8,0x30db,0x30de, 0x30df,0x30e0,0x30e1,0x30e2,
  0x30e4,0x30e6,0x0000,0x30e8, 0x30e9,0x30ea,0x30eb,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x30ec,0x30ed,0x30ef, 0x30f3,0x309b,0x309c,0x30ac,
  0x30ae,0x30b0,0x30b2,0x30b4, 0x30b6,0x30b8,0x30ba,0x30bc,
  0x30be,0x30c0,0x30c2,0x30c5, 0x30c7,0x30c9,0x30d0,0x30d3,
  0x30d6,0x30d9,0x30dc,0x30f4, 0x30d1,0x30d4,0x30d7,0x30da,
  0x30dd,0x30f0,0x30f1,0x30fd, 0x30fe,0x0000,0x0000,0xff3c,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x4441(i:570) */
  0x0000,0x300e,0x300f,0xff3b, 0xff3d,0x3092,0x3041,0x3043,
  0x3045,0x2015,0x00b1,0x2260, 0x221e,0x2103,0x0000,0x00b4,
  0x3047,0x3049,0x3083,0x3085, 0x3087,0x3063,0x308e,0x0000,
  0x0000,0x2010,0x3003,0xf83e, 0x3005,0x3006,0x3007,0x00a8,
  0x2018,0x201c,0x3014,0x3008, 0x300a,0x3010,0x2264,0x2234,
  0x2642,0x00a7,0x203b,0x3012, 0x3231,0x2116,0x2121,0xff3e,
  0x2019,0x201d,0x3015,0x3009, 0x300b,0x3011,0x2265,0x2235,
  0x2640,0x00d7,0x00f7,0x2016, 0x3013,0x2025,0x2026,0x0000,
  0x3042,0x3044,0x3046,0x3048, 0x304a,0x304b,0x304d,0x304f,
  0x3051,0x3053,0x0000,0x3055, 0x3057,0x3059,0x305b,0x305d,
  0x305f,0x3061,0x3064,0x3066, 0x3068,0x306a,0x306b,0x306c,
  0x306d,0x306e,0x0000,0x0000, 0x306f,0x3072,0x3075,0x0000,
  0x0000,0x3078,0x307b,0x307e, 0x307f,0x3080,0x3081,0x3082,
  0x3084,0x3086,0x0000,0x3088, 0x3089,0x308a,0x308b,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x308c,0x308d,0x308f, 0x3093,0x0000,0x0000,0x304c,
  0x304e,0x3050,0x3052,0x3054, 0x3056,0x3058,0x305a,0x305c,
  0x305e,0x3060,0x3062,0x3065, 0x3067,0x3069,0x3070,0x3073,
  0x3076,0x3079,0x307c,0x0000, 0x3071,0x3074,0x3077,0x307a,
  0x307d,0x3090,0x3091,0x309d, 0x309e,0x0000,0x0000,0x25cb,
  0x25cf,0x25b3,0x25b2,0x25ce, 0x2606,0x2605,0x25c7,0x25c6,
  0x25a1,0x25a0,0x25bd,0x25bc, 0x00b0,0x2032,0x2033,0x2192,
  0x2190,0x2191,0x2193,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x4541(i:760) */
  0x0000,0x0000,0x0000,0x0000, 0x02c9,0x02c7,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x3016,0x3017, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x2236,0x2227,0x2228, 0x2211,0x220f,0x222a,0x2229,
  0x2208,0x2237,0x221a,0x22a5, 0x2225,0x2220,0x2312,0x2299,
  0x222b,0x222e,0x2261,0x224c, 0x2248,0x223d,0x221d,0x0000,
  0x226e,0x226f,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x00a4,
  0x0000,0x0000,0x2030,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x2488,0x2489,0x248a,0x248b, 0x248c,0x248d,0x248e,0x248f,
  0x2490,0x2491,0x2492,0x2493, 0x2494,0x2495,0x2496,0x2497,
  0x2498,0x2499,0x249a,0x249b, 0x2474,0x2475,0x2476,0x2477,
  0x2478,0x2479,0x247a,0x247b, 0x247c,0x247d,0x247e,0x247f,
  0x2480,0x2481,0x2482,0x2483, 0x2484,0x2485,0x2486,0x2487,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x2460,0x2461,0x2462,0x2463, 0x2464,0x2465,0x2466,0x2467,
  0x2468,0x2469,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x3220,0x3221,0x3222,0x3223, 0x3224,0x3225,0x3226,0x3227,
  0x3228,0x3229,0x0000,0x0000, 0x0000,0x0000,
/* 0x4641(i:950) */
  0x0101,0x00e1,0x01ce,0x00e0, 0x0113,0x00e9,0x011b,0x00e8,
  0x012b,0x00ed,0x01d0,0x00ec, 0x014d,0x00f3,0x01d2,0x00f2,
  0x016b,0x00fa,0x01d4,0x00f9, 0x01d6,0x01d8,0x01da,0x01dc,
  0x00fc,0x00ea,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x3105,0x3106,0x3107,0x3108,
  0x3109,0x310a,0x310b,0x310c, 0x310d,0x310e,0x310f,0x3110,
  0x3111,0x3112,0x3113,0x3114, 0x3115,0x3116,0x3117,0x3118,
  0x3119,0x311a,0x311b,0x311c, 0x311d,0x311e,0x311f,0x3120,
  0x3121,0x3122,0x3123,0x3124, 0x3125,0x3126,0x3127,0x3128,
  0x3129,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x2500, 0x2501,0x2502,0x2503,0x2504,
  0x2505,0x2506,0x2507,0x2508, 0x2509,0x250a,0x250b,0x250c,
  0x250d,0x250e,0x250f,0x2510, 0x2511,0x2512,0x2513,0x2514,
  0x2515,0x2516,0x2517,0x2518, 0x2519,0x251a,0x251b,0x251c,
  0x251d,0x251e,0x251f,0x2520, 0x2521,0x2522,0x2523,0x2524,
  0x2525,0x2526,0x2527,0x2528, 0x2529,0x252a,0x252b,0x252c,
  0x252d,0x252e,0x252f,0x2530, 0x2531,0x2532,0x2533,0x2534,
  0x2535,0x2536,0x2537,0x2538, 0x2539,0x253a,0x253b,0x253c,
  0x253d,0x253e,0x253f,0x2540, 0x2541,0x2542,0x2543,0x2544,
  0x2545,0x2546,0x2547,0x2548, 0x2549,0x254a,0x254b,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x4741(i:1140) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x4841(i:1330) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x554a,
  0x963f,0x57c3,0x6328,0x54ce, 0x5509,0x54c0,0x7691,0x764c,
  0x853c,0x77ee,0x827e,0x788d, 0x7231,0x9698,0x978d,0x6c28,
  0x5b89,0x4ffa,0x6309,0x6697, 0x5cb8,0x80fa,0x6848,0x80ae,
  0x6602,0x76ce,0x51f9,0x6556, 0x71ac,0x7ff1,0x8884,0x50b2,
  0x5965,0x61ca,0x6fb3,0x82ad, 0x634c,0x6252,0x53ed,0x5427,
  0x7b06,0x516b,0x75a4,0x5df4, 0x62d4,0x8dcb,0x9776,0x628a,
  0x8019,0x575d,0x9738,0x7f62, 0x7238,0x767d,0x67cf,0x767e,
  0x6446,0x4f70,0x8d25,0x62dc, 0x7a17,0x6591,0x73ed,0x642c,
  0x6273,0x822c,0x9881,0x677f, 0x7248,0x626e,0x62cc,0x4f34,
  0x74e3,0x534a,0x529e,0x7eca, 0x90a6,0x5e2e,0x6886,0x699c,
  0x8180,0x7ed1,0x68d2,0x78c5, 0x868c,0x9551,0x508d,0x8c24,
  0x82de,0x80de,0x5305,0x8912, 0x5265,0x0000,
/* 0x4941(i:1520) */
  0x8584,0x96f9,0x4fdd,0x5821, 0x9971,0x5b9d,0x62b1,0x62a5,
  0x66b4,0x8c79,0x9c8d,0x7206, 0x676f,0x7891,0x60b2,0x5351,
  0x5317,0x8f88,0x80cc,0x8d1d, 0x94a1,0x500d,0x72c8,0x5907,
  0x60eb,0x7119,0x88ab,0x5954, 0x82ef,0x672c,0x7b28,0x5d29,
  0x7ef7,0x752d,0x6cf5,0x8e66, 0x8ff8,0x903c,0x9f3b,0x6bd4,
  0x9119,0x7b14,0x5f7c,0x78a7, 0x84d6,0x853d,0x6bd5,0x6bd9,
  0x6bd6,0x5e01,0x5e87,0x75f9, 0x95ed,0x655d,0x5f0a,0x5fc5,
  0x8f9f,0x58c1,0x81c2,0x907f, 0x965b,0x97ad,0x8fb9,0x0000,
  0x7f16,0x8d2c,0x6241,0x4fbf, 0x53d8,0x535e,0x8fa8,0x8fa9,
  0x8fab,0x904d,0x6807,0x5f6a, 0x8198,0x8868,0x9cd6,0x618b,
  0x522b,0x762a,0x5f6c,0x658c, 0x6fd2,0x6ee8,0x5bbe,0x6448,
  0x5175,0x51b0,0x67c4,0x4e19, 0x79c9,0x997c,0x70b3,0x75c5,
  0x5e76,0x73bb,0x83e0,0x64ad, 0x62e8,0x94b5,0x6ce2,0x535a,
  0x52c3,0x640f,0x94c2,0x7b94, 0x4f2f,0x5e1b,0x8236,0x8116,
  0x818a,0x6e24,0x6cca,0x9a73, 0x6355,0x535c,0x54fa,0x8865,
  0x57e0,0x4e0d,0x5e03,0x6b65, 0x7c3f,0x90e8,0x6016,0x64e6,
  0x731c,0x88c1,0x6750,0x624d, 0x8d22,0x776c,0x8e29,0x91c7,
  0x5f69,0x83dc,0x8521,0x9910, 0x53c2,0x8695,0x6b8b,0x60ed,
  0x60e8,0x707f,0x82cd,0x8231, 0x4ed3,0x6ca7,0x85cf,0x64cd,
  0x7cd9,0x69fd,0x66f9,0x8349, 0x5395,0x7b56,0x4fa7,0x518c,
  0x6d4b,0x5c42,0x8e6d,0x63d2, 0x53c9,0x832c,0x8336,0x67e5,
  0x78b4,0x643d,0x5bdf,0x5c94, 0x5dee,0x8be7,0x62c6,0x67f4,
  0x8c7a,0x6400,0x63ba,0x8749, 0x998b,0x8c17,0x7f20,0x94f2,
  0x4ea7,0x9610,0x98a4,0x660c, 0x7316,0x0000,
/* 0x4a41(i:1710) */
  0x573a,0x5c1d,0x5e38,0x957f, 0x507f,0x80a0,0x5382,0x655e,
  0x7545,0x5531,0x5021,0x8d85, 0x6284,0x949e,0x671d,0x5632,
  0x6f6e,0x5de2,0x5435,0x7092, 0x8f66,0x626f,0x64a4,0x63a3,
  0x5f7b,0x6f88,0x90f4,0x81e3, 0x8fb0,0x5c18,0x6668,0x5ff1,
  0x6c89,0x9648,0x8d81,0x886c, 0x6491,0x79f0,0x57ce,0x6a59,
  0x6210,0x5448,0x4e58,0x7a0b, 0x60e9,0x6f84,0x8bda,0x627f,
  0x901e,0x9a8b,0x79e4,0x5403, 0x75f4,0x6301,0x5319,0x6c60,
  0x8fdf,0x5f1b,0x9a70,0x803b, 0x9f7f,0x4f88,0x5c3a,0x0000,
  0x8d64,0x7fc5,0x65a5,0x70bd, 0x5145,0x51b2,0x866b,0x5d07,
  0x5ba0,0x62bd,0x916c,0x7574, 0x8e0c,0x7a20,0x6101,0x7b79,
  0x4ec7,0x7ef8,0x7785,0x4e11, 0x81ed,0x521d,0x51fa,0x6a71,
  0x53a8,0x8e87,0x9504,0x96cf, 0x6ec1,0x9664,0x695a,0x7840,
  0x50a8,0x77d7,0x6410,0x89e6, 0x5904,0x63e3,0x5ddd,0x7a7f,
  0x693d,0x4f20,0x8239,0x5598, 0x4e32,0x75ae,0x7a97,0x5e62,
  0x5e8a,0x95ef,0x521b,0x5439, 0x708a,0x6376,0x9524,0x5782,
  0x6625,0x693f,0x9187,0x5507, 0x6df3,0x7eaf,0x8822,0x6233,
  0x7ef0,0x75b5,0x8328,0x78c1, 0x96cc,0x8f9e,0x6148,0x74f7,
  0x8bcd,0x6b64,0x523a,0x8d50, 0x6b21,0x806a,0x8471,0x56f1,
  0x5306,0x4ece,0x4e1b,0x51d1, 0x7c97,0x918b,0x7c07,0x4fc3,
  0x8e7f,0x7be1,0x7a9c,0x6467, 0x5d14,0x50ac,0x8106,0x7601,
  0x7cb9,0x6dec,0x7fe0,0x6751, 0x5b58,0x5bf8,0x78cb,0x64ae,
  0x6413,0x63aa,0x632b,0x9519, 0x642d,0x8fbe,0x7b54,0x7629,
  0x6253,0x5927,0x5446,0x6b79, 0x50a3,0x6234,0x5e26,0x6b86,
  0x4ee3,0x8d37,0x888b,0x5f85, 0x902e,0x0000,
/* 0x4b41(i:1900) */
  0x6020,0x803d,0x62c5,0x4e39, 0x5355,0x90f8,0x63b8,0x80c6,
  0x65e6,0x6c2e,0x4f46,0x60ee, 0x6de1,0x8bde,0x5f39,0x86cb,
  0x5f53,0x6321,0x515a,0x8361, 0x6863,0x5200,0x6363,0x8e48,
  0x5012,0x5c9b,0x7977,0x5bfc, 0x5230,0x7a3b,0x60bc,0x9053,
  0x76d7,0x5fb7,0x5f97,0x7684, 0x8e6c,0x706f,0x767b,0x7b49,
  0x77aa,0x51f3,0x9093,0x5824, 0x4f4e,0x6ef4,0x8fea,0x654c,
  0x7b1b,0x72c4,0x6da4,0x7fdf, 0x5ae1,0x62b5,0x5e95,0x5730,
  0x8482,0x7b2c,0x5e1d,0x5f1f, 0x9012,0x7f14,0x98a0,0x0000,
  0x6382,0x6ec7,0x7898,0x70b9, 0x5178,0x975b,0x57ab,0x7535,
  0x4f43,0x7538,0x5e97,0x60e6, 0x5960,0x6dc0,0x6bbf,0x7889,
  0x53fc,0x96d5,0x51cb,0x5201, 0x6389,0x540a,0x9493,0x8c03,
  0x8dcc,0x7239,0x789f,0x8776, 0x8fed,0x8c0d,0x53e0,0x4e01,
  0x76ef,0x53ee,0x9489,0x9876, 0x9f0e,0x952d,0x5b9a,0x8ba2,
  0x4e22,0x4e1c,0x51ac,0x8463, 0x61c2,0x52a8,0x680b,0x4f97,
  0x606b,0x51bb,0x6d1e,0x515c, 0x6296,0x6597,0x9661,0x8c46,
  0x9017,0x75d8,0x90fd,0x7763, 0x6bd2,0x728a,0x72ec,0x8bfb,
  0x5835,0x7779,0x8d4c,0x675c, 0x9540,0x809a,0x5ea6,0x6e21,
  0x5992,0x7aef,0x77ed,0x953b, 0x6bb5,0x65ad,0x7f0e,0x5806,
  0x5151,0x961f,0x5bf9,0x58a9, 0x5428,0x8e72,0x6566,0x987f,
  0x56e4,0x949d,0x76fe,0x9041, 0x6387,0x54c6,0x591a,0x593a,
  0x579b,0x8eb2,0x6735,0x8dfa, 0x8235,0x5241,0x60f0,0x5815,
  0x86fe,0x5ce8,0x9e45,0x4fc4, 0x989d,0x8bb9,0x5a25,0x6076,
  0x5384,0x627c,0x904f,0x9102, 0x997f,0x6069,0x800c,0x513f,
  0x8033,0x5c14,0x9975,0x6d31, 0x4e8c,0x0000,
/* 0x4c41(i:2090) */
  0x8d30,0x53d1,0x7f5a,0x7b4f, 0x4f10,0x4e4f,0x9600,0x6cd5,
  0x73d0,0x85e9,0x5e06,0x756a, 0x7ffb,0x6a0a,0x77fe,0x9492,
  0x7e41,0x51e1,0x70e6,0x53cd, 0x8fd4,0x8303,0x8d29,0x72af,
  0x996d,0x6cdb,0x574a,0x82b3, 0x65b9,0x80aa,0x623f,0x9632,
  0x59a8,0x4eff,0x8bbf,0x7eba, 0x653e,0x83f2,0x975e,0x5561,
  0x98de,0x80a5,0x532a,0x8bfd, 0x5420,0x80ba,0x5e9f,0x6cb8,
  0x8d39,0x82ac,0x915a,0x5429, 0x6c1b,0x5206,0x7eb7,0x575f,
  0x711a,0x6c7e,0x7c89,0x594b, 0x4efd,0x5fff,0x6124,0x0000,
  0x7caa,0x4e30,0x5c01,0x67ab, 0x8702,0x5cf0,0x950b,0x98ce,
  0x75af,0x70fd,0x9022,0x51af, 0x7f1d,0x8bbd,0x5949,0x51e4,
  0x4f5b,0x5426,0x592b,0x6577, 0x80a4,0x5b75,0x6276,0x62c2,
  0x8f90,0x5e45,0x6c1f,0x7b26, 0x4f0f,0x4fd8,0x670d,0x6d6e,
  0x6daa,0x798f,0x88b1,0x5f17, 0x752b,0x629a,0x8f85,0x4fef,
  0x91dc,0x65a7,0x812f,0x8151, 0x5e9c,0x8150,0x8d74,0x526f,
  0x8986,0x8d4b,0x590d,0x5085, 0x4ed8,0x961c,0x7236,0x8179,
  0x8d1f,0x5bcc,0x8ba3,0x9644, 0x5987,0x7f1a,0x5490,0x5676,
  0x560e,0x8be5,0x6539,0x6982, 0x9499,0x76d6,0x6e89,0x5e72,
  0x7518,0x6746,0x67d1,0x7aff, 0x809d,0x8d76,0x611f,0x79c6,
  0x6562,0x8d63,0x5188,0x521a, 0x94a2,0x7f38,0x809b,0x7eb2,
  0x5c97,0x6e2f,0x6760,0x7bd9, 0x768b,0x9ad8,0x818f,0x7f94,
  0x7cd5,0x641e,0x9550,0x7a3f, 0x544a,0x54e5,0x6b4c,0x6401,
  0x6208,0x9e3d,0x80f3,0x7599, 0x5272,0x9769,0x845b,0x683c,
  0x86e4,0x9601,0x9694,0x94ec, 0x4e2a,0x5404,0x7ed9,0x6839,
  0x8ddf,0x8015,0x66f4,0x5e9a, 0x7fb9,0x0000,
/* 0x4d41(i:2280) */
  0x57c2,0x803f,0x6897,0x5de5, 0x653b,0x529f,0x606d,0x9f9a,
  0x4f9b,0x8eac,0x516c,0x5bab, 0x5f13,0x5de9,0x6c5e,0x62f1,
  0x8d21,0x5171,0x94a9,0x52fe, 0x6c9f,0x82df,0x72d7,0x57a2,
  0x6784,0x8d2d,0x591f,0x8f9c, 0x83c7,0x5495,0x7b8d,0x4f30,
  0x6cbd,0x5b64,0x59d1,0x9f13, 0x53e4,0x86ca,0x9aa8,0x8c37,
  0x80a1,0x6545,0x987e,0x56fa, 0x96c7,0x522e,0x74dc,0x5250,
  0x5be1,0x6302,0x8902,0x4e56, 0x62d0,0x602a,0x68fa,0x5173,
  0x5b98,0x51a0,0x89c2,0x7ba1, 0x9986,0x7f50,0x60ef,0x0000,
  0x704c,0x8d2f,0x5149,0x5e7f, 0x901b,0x7470,0x89c4,0x572d,
  0x7845,0x5f52,0x9f9f,0x95fa, 0x8f68,0x9b3c,0x8be1,0x7678,
  0x6842,0x67dc,0x8dea,0x8d35, 0x523d,0x8f8a,0x6eda,0x68cd,
  0x9505,0x90ed,0x56fd,0x679c, 0x88f9,0x8fc7,0x54c8,0x9ab8,
  0x5b69,0x6d77,0x6c26,0x4ea5, 0x5bb3,0x9a87,0x9163,0x61a8,
  0x90af,0x97e9,0x542b,0x6db5, 0x5bd2,0x51fd,0x558a,0x7f55,
  0x7ff0,0x64bc,0x634d,0x65f1, 0x61be,0x608d,0x710a,0x6c57,
  0x6c49,0x592f,0x676d,0x822a, 0x58d5,0x568e,0x8c6a,0x6beb,
  0x90dd,0x597d,0x8017,0x53f7, 0x6d69,0x5475,0x559d,0x8377,
  0x83cf,0x6838,0x79be,0x548c, 0x4f55,0x5408,0x76d2,0x8c89,
  0x9602,0x6cb3,0x6db8,0x8d6b, 0x8910,0x9e64,0x8d3a,0x563f,
  0x9ed1,0x75d5,0x5f88,0x72e0, 0x6068,0x54fc,0x4ea8,0x6a2a,
  0x8861,0x6052,0x8f70,0x54c4, 0x70d8,0x8679,0x9e3f,0x6d2a,
  0x5b8f,0x5f18,0x7ea2,0x5589, 0x4faf,0x7334,0x543c,0x539a,
  0x5019,0x540e,0x547c,0x4e4e, 0x5ffd,0x745a,0x58f6,0x846b,
  0x80e1,0x8774,0x72d0,0x7cca, 0x6e56,0x0000,
/* 0x4e41(i:2470) */
  0x5f27,0x864e,0x552c,0x62a4, 0x4e92,0x6caa,0x6237,0x82b1,
  0x54d7,0x534e,0x733e,0x6ed1, 0x753b,0x5212,0x5316,0x8bdd,
  0x69d0,0x5f8a,0x6000,0x6dee, 0x574f,0x6b22,0x73af,0x6853,
  0x8fd8,0x7f13,0x6362,0x60a3, 0x5524,0x75ea,0x8c62,0x7115,
  0x6da3,0x5ba6,0x5e7b,0x8352, 0x614c,0x9ec4,0x78fa,0x8757,
  0x7c27,0x7687,0x51f0,0x60f6, 0x714c,0x6643,0x5e4c,0x604d,
  0x8c0e,0x7070,0x6325,0x8f89, 0x5fbd,0x6062,0x86d4,0x56de,
  0x6bc1,0x6094,0x6167,0x5349, 0x60e0,0x6666,0x8d3f,0x0000,
  0x79fd,0x4f1a,0x70e9,0x6c47, 0x8bb3,0x8bf2,0x7ed8,0x8364,
  0x660f,0x5a5a,0x9b42,0x6d51, 0x6df7,0x8c41,0x6d3b,0x4f19,
  0x706b,0x83b7,0x6216,0x60d1, 0x970d,0x8d27,0x7978,0x51fb,
  0x573e,0x57fa,0x673a,0x7578, 0x7a3d,0x79ef,0x7b95,0x808c,
  0x9965,0x8ff9,0x6fc0,0x8ba5, 0x9e21,0x59ec,0x7ee9,0x7f09,
  0x5409,0x6781,0x68d8,0x8f91, 0x7c4d,0x96c6,0x53ca,0x6025,
  0x75be,0x6c72,0x5373,0x5ac9, 0x7ea7,0x6324,0x51e0,0x810a,
  0x5df1,0x84df,0x6280,0x5180, 0x5b63,0x4f0e,0x796d,0x5242,
  0x60b8,0x6d4e,0x5bc4,0x5bc2, 0x8ba1,0x8bb0,0x65e2,0x5fcc,
  0x9645,0x5993,0x7ee7,0x7eaa, 0x5609,0x67b7,0x5939,0x4f73,
  0x5bb6,0x52a0,0x835a,0x988a, 0x8d3e,0x7532,0x94be,0x5047,
  0x7a3c,0x4ef7,0x67b6,0x9a7e, 0x5ac1,0x6b7c,0x76d1,0x575a,
  0x5c16,0x7b3a,0x95f4,0x714e, 0x517c,0x80a9,0x8270,0x5978,
  0x7f04,0x8327,0x68c0,0x67ec, 0x78b1,0x7877,0x62e3,0x6361,
  0x7b80,0x4fed,0x526a,0x51cf, 0x8350,0x69db,0x9274,0x8df5,
  0x8d31,0x89c1,0x952e,0x7bad, 0x4ef6,0x0000,
/* 0x4f41(i:2660) */
  0x5065,0x8230,0x5251,0x996f, 0x6e10,0x6e85,0x6da7,0x5efa,
  0x50f5,0x59dc,0x5c06,0x6d46, 0x6c5f,0x7586,0x848b,0x6868,
  0x5956,0x8bb2,0x5320,0x9171, 0x964d,0x8549,0x6912,0x7901,
  0x7126,0x80f6,0x4ea4,0x90ca, 0x6d47,0x9a84,0x5a07,0x56bc,
  0x6405,0x94f0,0x77eb,0x4fa5, 0x811a,0x72e1,0x89d2,0x997a,
  0x7f34,0x7ede,0x527f,0x6559, 0x9175,0x8f7f,0x8f83,0x53eb,
  0x7a96,0x63ed,0x63a5,0x7686, 0x79f8,0x8857,0x9636,0x622a,
  0x52ab,0x8282,0x6854,0x6770, 0x6377,0x776b,0x7aed,0x0000,
  0x6d01,0x7ed3,0x89e3,0x59d0, 0x6212,0x85c9,0x82a5,0x754c,
  0x501f,0x4ecb,0x75a5,0x8beb, 0x5c4a,0x5dfe,0x7b4b,0x65a4,
  0x91d1,0x4eca,0x6d25,0x895f, 0x7d27,0x9526,0x4ec5,0x8c28,
  0x8fdb,0x9773,0x664b,0x7981, 0x8fd1,0x70ec,0x6d78,0x5c3d,
  0x52b2,0x8346,0x5162,0x830e, 0x775b,0x6676,0x9cb8,0x4eac,
  0x60ca,0x7cbe,0x7cb3,0x7ecf, 0x4e95,0x8b66,0x666f,0x9888,
  0x9759,0x5883,0x656c,0x955c, 0x5f84,0x75c9,0x9756,0x7adf,
  0x7ade,0x51c0,0x70af,0x7a98, 0x63ea,0x7a76,0x7ea0,0x7396,
  0x97ed,0x4e45,0x7078,0x4e5d, 0x9152,0x53a9,0x6551,0x65e7,
  0x81fc,0x8205,0x548e,0x5c31, 0x759a,0x97a0,0x62d8,0x72d9,
  0x75bd,0x5c45,0x9a79,0x83ca, 0x5c40,0x5480,0x77e9,0x4e3e,
  0x6cae,0x805a,0x62d2,0x636e, 0x5de8,0x5177,0x8ddd,0x8e1e,
  0x952f,0x4ff1,0x53e5,0x60e7, 0x70ac,0x5267,0x6350,0x9e43,
  0x5a1f,0x5026,0x7737,0x5377, 0x7ee2,0x6485,0x652b,0x6289,
  0x6398,0x5014,0x7235,0x89c9, 0x51b3,0x8bc0,0x7edd,0x5747,
  0x83cc,0x94a7,0x519b,0x541b, 0x5cfb,0x0000,
/* 0x5041(i:2850) */
  0x4fca,0x7ae3,0x6d5a,0x90e1, 0x9a8f,0x5580,0x5496,0x5361,
  0x54af,0x5f00,0x63e9,0x6977, 0x51ef,0x6168,0x520a,0x582a,
  0x52d8,0x574e,0x780d,0x770b, 0x5eb7,0x6177,0x7ce0,0x625b,
  0x6297,0x4ea2,0x7095,0x8003, 0x62f7,0x70e4,0x9760,0x5777,
  0x82db,0x67ef,0x68f5,0x78d5, 0x9897,0x79d1,0x58f3,0x54b3,
  0x53ef,0x6e34,0x514b,0x523b, 0x5ba2,0x8bfe,0x80af,0x5543,
  0x57a6,0x6073,0x5751,0x542d, 0x7a7a,0x6050,0x5b54,0x63a7,
  0x62a0,0x53e3,0x6263,0x5bc7, 0x67af,0x54ed,0x7a9f,0x0000,
  0x82e6,0x9177,0x5e93,0x88e4, 0x5938,0x57ae,0x630e,0x8de8,
  0x80ef,0x5757,0x7b77,0x4fa9, 0x5feb,0x5bbd,0x6b3e,0x5321,
  0x7b50,0x72c2,0x6846,0x77ff, 0x7736,0x65f7,0x51b5,0x4e8f,
  0x76d4,0x5cbf,0x7aa5,0x8475, 0x594e,0x9b41,0x5080,0x9988,
  0x6127,0x6e83,0x5764,0x6606, 0x6346,0x56f0,0x62ec,0x6269,
  0x5ed3,0x9614,0x5783,0x62c9, 0x5587,0x8721,0x814a,0x8fa3,
  0x5566,0x83b1,0x6765,0x8d56, 0x84dd,0x5a6a,0x680f,0x62e6,
  0x7bee,0x9611,0x5170,0x6f9c, 0x8c30,0x63fd,0x89c8,0x61d2,
  0x7f06,0x70c2,0x6ee5,0x7405, 0x6994,0x72fc,0x5eca,0x90ce,
  0x6717,0x6d6a,0x635e,0x52b3, 0x7262,0x8001,0x4f6c,0x59e5,
  0x916a,0x70d9,0x6d9d,0x52d2, 0x4e50,0x96f7,0x956d,0x857e,
  0x78ca,0x7d2f,0x5121,0x5792, 0x64c2,0x808b,0x7c7b,0x6cea,
  0x68f1,0x695e,0x51b7,0x5398, 0x68a8,0x7281,0x9ece,0x7bf1,
  0x72f8,0x79bb,0x6f13,0x7406, 0x674e,0x91cc,0x9ca4,0x793c,
  0x8389,0x8354,0x540f,0x6817, 0x4e3d,0x5389,0x52b1,0x783e,
  0x5386,0x5229,0x5088,0x4f8b, 0x4fd0,0x0000,
/* 0x5141(i:3040) */
  0x75e2,0x7acb,0x7c92,0x6ca5, 0x96b6,0x529b,0x7483,0x54e9,
  0x4fe9,0x8054,0x83b2,0x8fde, 0x9570,0x5ec9,0x601c,0x6d9f,
  0x5e18,0x655b,0x8138,0x94fe, 0x604b,0x70bc,0x7ec3,0x7cae,
  0x51c9,0x6881,0x7cb1,0x826f, 0x4e24,0x8f86,0x91cf,0x667e,
  0x4eae,0x8c05,0x64a9,0x804a, 0x50da,0x7597,0x71ce,0x5be5,
  0x8fbd,0x6f66,0x4e86,0x6482, 0x9563,0x5ed6,0x6599,0x5217,
  0x88c2,0x70c8,0x52a3,0x730e, 0x7433,0x6797,0x78f7,0x9716,
  0x4e34,0x90bb,0x9cde,0x6dcb, 0x51db,0x8d41,0x541d,0x0000,
  0x62ce,0x73b2,0x83f1,0x96f6, 0x9f84,0x94c3,0x4f36,0x7f9a,
  0x51cc,0x7075,0x9675,0x5cad, 0x9886,0x53e6,0x4ee4,0x6e9c,
  0x7409,0x69b4,0x786b,0x998f, 0x7559,0x5218,0x7624,0x6d41,
  0x67f3,0x516d,0x9f99,0x804b, 0x5499,0x7b3c,0x7abf,0x9686,
  0x5784,0x62e2,0x9647,0x697c, 0x5a04,0x6402,0x7bd3,0x6f0f,
  0x964b,0x82a6,0x5362,0x9885, 0x5e90,0x7089,0x63b3,0x5364,
  0x864f,0x9c81,0x9e93,0x788c, 0x9732,0x8def,0x8d42,0x9e7f,
  0x6f5e,0x7984,0x5f55,0x9646, 0x622e,0x9a74,0x5415,0x94dd,
  0x4fa3,0x65c5,0x5c65,0x5c61, 0x7f15,0x8651,0x6c2f,0x5f8b,
  0x7387,0x6ee4,0x7eff,0x5ce6, 0x631b,0x5b6a,0x6ee6,0x5375,
  0x4e71,0x63a0,0x7565,0x62a1, 0x8f6e,0x4f26,0x4ed1,0x6ca6,
  0x7eb6,0x8bba,0x841d,0x87ba, 0x7f57,0x903b,0x9523,0x7ba9,
  0x9aa1,0x88f8,0x843d,0x6d1b, 0x9a86,0x7edc,0x5988,0x9ebb,
  0x739b,0x7801,0x8682,0x9a6c, 0x9a82,0x561b,0x5417,0x57cb,
  0x4e70,0x9ea6,0x5356,0x8fc8, 0x8109,0x7792,0x9992,0x86ee,
  0x6ee1,0x8513,0x66fc,0x6162, 0x6f2b,0x0000,
/* 0x5241(i:3230) */
  0x8c29,0x8292,0x832b,0x76f2, 0x6c13,0x5fd9,0x83bd,0x732b,
  0x8305,0x951a,0x6bdb,0x77db, 0x94c6,0x536f,0x8302,0x5192,
  0x5e3d,0x8c8c,0x8d38,0x4e48, 0x73ab,0x679a,0x6885,0x9176,
  0x9709,0x7164,0x6ca1,0x7709, 0x5a92,0x9541,0x6bcf,0x7f8e,
  0x6627,0x5bd0,0x59b9,0x5a9a, 0x95e8,0x95f7,0x4eec,0x840c,
  0x8499,0x6aac,0x76df,0x9530, 0x731b,0x68a6,0x5b5f,0x772f,
  0x919a,0x9761,0x7cdc,0x8ff7, 0x8c1c,0x5f25,0x7c73,0x79d8,
  0x89c5,0x6ccc,0x871c,0x5bc6, 0x5e42,0x68c9,0x7720,0x0000,
  0x7ef5,0x5195,0x514d,0x52c9, 0x5a29,0x7f05,0x9762,0x82d7,
  0x63cf,0x7784,0x85d0,0x79d2, 0x6e3a,0x5e99,0x5999,0x8511,
  0x706d,0x6c11,0x62bf,0x76bf, 0x654f,0x60af,0x95fd,0x660e,
  0x879f,0x9e23,0x94ed,0x540d, 0x547d,0x8c2c,0x6478,0x6479,
  0x8611,0x6a21,0x819c,0x78e8, 0x6469,0x9b54,0x62b9,0x672b,
  0x83ab,0x58a8,0x9ed8,0x6cab, 0x6f20,0x5bde,0x964c,0x8c0b,
  0x725f,0x67d0,0x62c7,0x7261, 0x4ea9,0x59c6,0x6bcd,0x5893,
  0x66ae,0x5e55,0x52df,0x6155, 0x6728,0x76ee,0x7766,0x7267,
  0x7a46,0x62ff,0x54ea,0x5450, 0x94a0,0x90a3,0x5a1c,0x7eb3,
  0x6c16,0x4e43,0x5976,0x8010, 0x5948,0x5357,0x7537,0x96be,
  0x56ca,0x6320,0x8111,0x607c, 0x95f9,0x6dd6,0x5462,0x9981,
  0x5185,0x5ae9,0x80fd,0x59ae, 0x9713,0x502a,0x6ce5,0x5c3c,
  0x62df,0x4f60,0x533f,0x817b, 0x9006,0x6eba,0x852b,0x62c8,
  0x5e74,0x78be,0x64b5,0x637b, 0x5ff5,0x5a18,0x917f,0x9e1f,
  0x5c3f,0x634f,0x8042,0x5b7d, 0x556e,0x954a,0x954d,0x6d85,
  0x60a8,0x67e0,0x72de,0x51dd, 0x5b81,0x0000,
/* 0x5341(i:3420) */
  0x62e7,0x6cde,0x725b,0x626d, 0x94ae,0x7ebd,0x8113,0x6d53,
  0x519c,0x5f04,0x5974,0x52aa, 0x6012,0x5973,0x6696,0x8650,
  0x759f,0x632a,0x61e6,0x7cef, 0x8bfa,0x54e6,0x6b27,0x9e25,
  0x6bb4,0x85d5,0x5455,0x5076, 0x6ca4,0x556a,0x8db4,0x722c,
  0x5e15,0x6015,0x7436,0x62cd, 0x6392,0x724c,0x5f98,0x6e43,
  0x6d3e,0x6500,0x6f58,0x76d8, 0x78d0,0x76fc,0x7554,0x5224,
  0x53db,0x4e53,0x5e9e,0x65c1, 0x802a,0x80d6,0x629b,0x5486,
  0x5228,0x70ae,0x888d,0x8dd1, 0x6ce1,0x5478,0x80da,0x0000,
  0x57f9,0x88f4,0x8d54,0x966a, 0x914d,0x4f69,0x6c9b,0x55b7,
  0x76c6,0x7830,0x62a8,0x70f9, 0x6f8e,0x5f6d,0x84ec,0x68da,
  0x787c,0x7bf7,0x81a8,0x670b, 0x9e4f,0x6367,0x78b0,0x576f,
  0x7812,0x9739,0x6279,0x62ab, 0x5288,0x7435,0x6bd7,0x5564,
  0x813e,0x75b2,0x76ae,0x5339, 0x75de,0x50fb,0x5c41,0x8b6c,
  0x7bc7,0x504f,0x7247,0x9a97, 0x98d8,0x6f02,0x74e2,0x7968,
  0x6487,0x77a5,0x62fc,0x9891, 0x8d2b,0x54c1,0x8058,0x4e52,
  0x576a,0x82f9,0x840d,0x5e73, 0x51ed,0x74f6,0x8bc4,0x5c4f,
  0x5761,0x6cfc,0x9887,0x5a46, 0x7834,0x9b44,0x8feb,0x7c95,
  0x5256,0x6251,0x94fa,0x4ec6, 0x8386,0x8461,0x83e9,0x84b2,
  0x57d4,0x6734,0x5703,0x666e, 0x6d66,0x8c31,0x66dd,0x7011,
  0x671f,0x6b3a,0x6816,0x621a, 0x59bb,0x4e03,0x51c4,0x6f06,
  0x67d2,0x6c8f,0x5176,0x68cb, 0x5947,0x6b67,0x7566,0x5d0e,
  0x8110,0x9f50,0x65d7,0x7948, 0x7941,0x9a91,0x8d77,0x5c82,
  0x4e5e,0x4f01,0x542f,0x5951, 0x780c,0x5668,0x6c14,0x8fc4,
  0x5f03,0x6c7d,0x6ce3,0x8bab, 0x6390,0x0000,
/* 0x5441(i:3610) */
  0x6070,0x6d3d,0x7275,0x6266, 0x948e,0x94c5,0x5343,0x8fc1,
  0x7b7e,0x4edf,0x8c26,0x4e7e, 0x9ed4,0x94b1,0x94b3,0x524d,
  0x6f5c,0x9063,0x6d45,0x8c34, 0x5811,0x5d4c,0x6b20,0x6b49,
  0x67aa,0x545b,0x8154,0x7f8c, 0x5899,0x8537,0x5f3a,0x62a2,
  0x6a47,0x9539,0x6572,0x6084, 0x6865,0x77a7,0x4e54,0x4fa8,
  0x5de7,0x9798,0x64ac,0x7fd8, 0x5ced,0x4fcf,0x7a8d,0x5207,
  0x8304,0x4e14,0x602f,0x7a83, 0x94a6,0x4fb5,0x4eb2,0x79e6,
  0x7434,0x52e4,0x82b9,0x64d2, 0x79bd,0x5bdd,0x6c81,0x0000,
  0x9752,0x8f7b,0x6c22,0x503e, 0x537f,0x6e05,0x64ce,0x6674,
  0x6c30,0x60c5,0x9877,0x8bf7, 0x5e86,0x743c,0x7a77,0x79cb,
  0x4e18,0x90b1,0x7403,0x6c42, 0x56da,0x914b,0x6cc5,0x8d8b,
  0x533a,0x86c6,0x66f2,0x8eaf, 0x5c48,0x9a71,0x6e20,0x53d6,
  0x5a36,0x9f8b,0x8da3,0x53bb, 0x5708,0x98a7,0x6743,0x919b,
  0x6cc9,0x5168,0x75ca,0x62f3, 0x72ac,0x5238,0x529d,0x7f3a,
  0x7094,0x7638,0x5374,0x9e4a, 0x69b7,0x786e,0x96c0,0x88d9,
  0x7fa4,0x7136,0x71c3,0x5189, 0x67d3,0x74e4,0x58e4,0x6518,
  0x56b7,0x8ba9,0x9976,0x6270, 0x7ed5,0x60f9,0x70ed,0x58ec,
  0x4ec1,0x4eba,0x5fcd,0x97e7, 0x4efb,0x8ba4,0x5203,0x598a,
  0x7eab,0x6254,0x4ecd,0x65e5, 0x620e,0x8338,0x84c9,0x8363,
  0x878d,0x7194,0x6eb6,0x5bb9, 0x7ed2,0x5197,0x63c9,0x67d4,
  0x8089,0x8339,0x8815,0x5112, 0x5b7a,0x5982,0x8fb1,0x4e73,
  0x6c5d,0x5165,0x8925,0x8f6f, 0x962e,0x854a,0x745e,0x9510,
  0x95f0,0x6da6,0x82e5,0x5f31, 0x6492,0x6d12,0x8428,0x816e,
  0x9cc3,0x585e,0x8d5b,0x4e09, 0x53c1,0x0000,
/* 0x5541(i:3800) */
  0x4f1e,0x6563,0x6851,0x55d3, 0x4e27,0x6414,0x9a9a,0x626b,
  0x5ac2,0x745f,0x8272,0x6da9, 0x68ee,0x50e7,0x838e,0x7802,
  0x6740,0x5239,0x6c99,0x7eb1, 0x50bb,0x5565,0x715e,0x7b5b,
  0x6652,0x73ca,0x82eb,0x6749, 0x5c71,0x5220,0x717d,0x886b,
  0x95ea,0x9655,0x64c5,0x8d61, 0x81b3,0x5584,0x6c55,0x6247,
  0x7f2e,0x5892,0x4f24,0x5546, 0x8d4f,0x664c,0x4e0a,0x5c1a,
  0x88f3,0x68a2,0x634e,0x7a0d, 0x70e7,0x828d,0x52fa,0x97f6,
  0x5c11,0x54e8,0x90b5,0x7ecd, 0x5962,0x8d4a,0x86c7,0x0000,
  0x820c,0x820d,0x8d66,0x6444, 0x5c04,0x6151,0x6d89,0x793e,
  0x8bbe,0x7837,0x7533,0x547b, 0x4f38,0x8eab,0x6df1,0x5a20,
  0x7ec5,0x795e,0x6c88,0x5ba1, 0x5a76,0x751a,0x80be,0x614e,
  0x6e17,0x58f0,0x751f,0x7525, 0x7272,0x5347,0x7ef3,0x7701,
  0x76db,0x5269,0x80dc,0x5723, 0x5e08,0x5931,0x72ee,0x65bd,
  0x6e7f,0x8bd7,0x5c38,0x8671, 0x5341,0x77f3,0x62fe,0x65f6,
  0x4ec0,0x98df,0x8680,0x5b9e, 0x8bc6,0x53f2,0x77e2,0x4f7f,
  0x5c4e,0x9a76,0x59cb,0x5f0f, 0x793a,0x58eb,0x4e16,0x67ff,
  0x4e8b,0x62ed,0x8a93,0x901d, 0x52bf,0x662f,0x55dc,0x566c,
  0x9002,0x4ed5,0x4f8d,0x91ca, 0x9970,0x6c0f,0x5e02,0x6043,
  0x5ba4,0x89c6,0x8bd5,0x6536, 0x624b,0x9996,0x5b88,0x5bff,
  0x6388,0x552e,0x53d7,0x7626, 0x517d,0x852c,0x67a2,0x68b3,
  0x6b8a,0x6292,0x8f93,0x53d4, 0x8212,0x6dd1,0x758f,0x4e66,
  0x8d4e,0x5b70,0x719f,0x85af, 0x6691,0x66d9,0x7f72,0x8700,
  0x9ecd,0x9f20,0x5c5e,0x672f, 0x8ff0,0x6811,0x675f,0x620d,
  0x7ad6,0x5885,0x5eb6,0x6570, 0x6f31,0x0000,
/* 0x5641(i:3990) */
  0x6055,0x5237,0x800d,0x6454, 0x8870,0x7529,0x5e05,0x6813,
  0x62f4,0x971c,0x53cc,0x723d, 0x8c01,0x6c34,0x7761,0x7a0e,
  0x542e,0x77ac,0x987a,0x821c, 0x8bf4,0x7855,0x6714,0x70c1,
  0x65af,0x6495,0x5636,0x601d, 0x79c1,0x53f8,0x4e1d,0x6b7b,
  0x8086,0x5bfa,0x55e3,0x56db, 0x4f3a,0x4f3c,0x9972,0x5df3,
  0x677e,0x8038,0x6002,0x9882, 0x9001,0x5b8b,0x8bbc,0x8bf5,
  0x641c,0x8258,0x64de,0x55fd, 0x82cf,0x9165,0x4fd7,0x7d20,
  0x901f,0x7c9f,0x50f3,0x5851, 0x6eaf,0x5bbf,0x8bc9,0x0000,
  0x8083,0x9178,0x849c,0x7b97, 0x867d,0x968b,0x968f,0x7ee5,
  0x9ad3,0x788e,0x5c81,0x7a57, 0x9042,0x96a7,0x795f,0x5b59,
  0x635f,0x7b0b,0x84d1,0x68ad, 0x5506,0x7f29,0x7410,0x7d22,
  0x9501,0x6240,0x584c,0x4ed6, 0x5b83,0x5979,0x5854,0x736d,
  0x631e,0x8e4b,0x8e0f,0x80ce, 0x82d4,0x62ac,0x53f0,0x6cf0,
  0x915e,0x592a,0x6001,0x6c70, 0x574d,0x644a,0x8d2a,0x762b,
  0x6ee9,0x575b,0x6a80,0x75f0, 0x6f6d,0x8c2d,0x8c08,0x5766,
  0x6bef,0x8892,0x78b3,0x63a2, 0x53f9,0x70ad,0x6c64,0x5858,
  0x642a,0x5802,0x68e0,0x819b, 0x5510,0x7cd6,0x5018,0x8eba,
  0x6dcc,0x8d9f,0x70eb,0x638f, 0x6d9b,0x6ed4,0x7ee6,0x8404,
  0x6843,0x9003,0x6dd8,0x9676, 0x8ba8,0x5957,0x7279,0x85e4,
  0x817e,0x75bc,0x8a8a,0x68af, 0x5254,0x8e22,0x9511,0x63d0,
  0x9898,0x8e44,0x557c,0x4f53, 0x66ff,0x568f,0x60d5,0x6d95,
  0x5243,0x5c49,0x5929,0x6dfb, 0x586b,0x7530,0x751c,0x606c,
  0x8214,0x8146,0x6311,0x6761, 0x8fe2,0x773a,0x8df3,0x8d34,
  0x94c1,0x5e16,0x5385,0x542c, 0x70c3,0x0000,
/* 0x5741(i:4180) */
  0x6c40,0x5ef7,0x505c,0x4ead, 0x5ead,0x633a,0x8247,0x901a,
  0x6850,0x916e,0x77b3,0x540c, 0x94dc,0x5f64,0x7ae5,0x6876,
  0x6345,0x7b52,0x7edf,0x75db, 0x5077,0x6295,0x5934,0x900f,
  0x51f8,0x79c3,0x7a81,0x56fe, 0x5f92,0x9014,0x6d82,0x5c60,
  0x571f,0x5410,0x5154,0x6e4d, 0x56e2,0x63a8,0x9893,0x817f,
  0x8715,0x892a,0x9000,0x541e, 0x5c6f,0x81c0,0x62d6,0x6258,
  0x8131,0x9e35,0x9640,0x9a6e, 0x9a7c,0x692d,0x59a5,0x62d3,
  0x553e,0x6316,0x54c7,0x86d9, 0x6d3c,0x5a03,0x74e6,0x0000,
  0x889c,0x6b6a,0x5916,0x8c4c, 0x5f2f,0x6e7e,0x73a9,0x987d,
  0x4e38,0x70f7,0x5b8c,0x7897, 0x633d,0x665a,0x7696,0x60cb,
  0x5b9b,0x5a49,0x4e07,0x8155, 0x6c6a,0x738b,0x4ea1,0x6789,
  0x7f51,0x5f80,0x65fa,0x671b, 0x5fd8,0x5984,0x5a01,0x5dcd,
  0x5fae,0x5371,0x97e6,0x8fdd, 0x6845,0x56f4,0x552f,0x60df,
  0x4e3a,0x6f4d,0x7ef4,0x82c7, 0x840e,0x59d4,0x4f1f,0x4f2a,
  0x5c3e,0x7eac,0x672a,0x851a, 0x5473,0x754f,0x80c3,0x5582,
  0x9b4f,0x4f4d,0x6e2d,0x8c13, 0x5c09,0x6170,0x536b,0x761f,
  0x6e29,0x868a,0x6587,0x95fb, 0x7eb9,0x543b,0x7a33,0x7d0a,
  0x95ee,0x55e1,0x7fc1,0x74ee, 0x631d,0x8717,0x6da1,0x7a9d,
  0x6211,0x65a1,0x5367,0x63e1, 0x6c83,0x5deb,0x545c,0x94a8,
  0x4e4c,0x6c61,0x8bec,0x5c4b, 0x65e0,0x829c,0x68a7,0x543e,
  0x5434,0x6bcb,0x6b66,0x4e94, 0x6342,0x5348,0x821e,0x4f0d,
  0x4fae,0x575e,0x620a,0x96fe, 0x6664,0x7269,0x52ff,0x52a1,
  0x609f,0x8bef,0x6614,0x7199, 0x6790,0x897f,0x7852,0x77fd,
  0x6670,0x563b,0x5438,0x9521, 0x727a,0x0000,
/* 0x5841(i:4370) */
  0x7a00,0x606f,0x5e0c,0x6089, 0x819d,0x5915,0x60dc,0x7184,
  0x70ef,0x6eaa,0x6c50,0x7280, 0x6a84,0x88ad,0x5e2d,0x4e60,
  0x5ab3,0x559c,0x94e3,0x6d17, 0x7cfb,0x9699,0x620f,0x7ec6,
  0x778e,0x867e,0x5323,0x971e, 0x8f96,0x6687,0x5ce1,0x4fa0,
  0x72ed,0x4e0b,0x53a6,0x590f, 0x5413,0x6380,0x9528,0x5148,
  0x4ed9,0x9c9c,0x7ea4,0x54b8, 0x8d24,0x8854,0x8237,0x95f2,
  0x6d8e,0x5f26,0x5acc,0x663e, 0x9669,0x73b0,0x732e,0x53bf,
  0x817a,0x9985,0x7fa1,0x5baa, 0x9677,0x9650,0x7ebf,0x0000,
  0x76f8,0x53a2,0x9576,0x9999, 0x7bb1,0x8944,0x6e58,0x4e61,
  0x7fd4,0x7965,0x8be6,0x60f3, 0x54cd,0x4eab,0x9879,0x5df7,
  0x6a61,0x50cf,0x5411,0x8c61, 0x8427,0x785d,0x9704,0x524a,
  0x54ee,0x56a3,0x9500,0x6d88, 0x5bb5,0x6dc6,0x6653,0x5c0f,
  0x5b5d,0x6821,0x8096,0x5578, 0x7b11,0x6548,0x6954,0x4e9b,
  0x6b47,0x874e,0x978b,0x534f, 0x631f,0x643a,0x90aa,0x659c,
  0x80c1,0x8c10,0x5199,0x68b0, 0x5378,0x87f9,0x61c8,0x6cc4,
  0x6cfb,0x8c22,0x5c51,0x85aa, 0x82af,0x950c,0x6b23,0x8f9b,
  0x65b0,0x5ffb,0x5fc3,0x4fe1, 0x8845,0x661f,0x8165,0x7329,
  0x60fa,0x5174,0x5211,0x578b, 0x5f62,0x90a2,0x884c,0x9192,
  0x5e78,0x674f,0x6027,0x59d3, 0x5144,0x51f6,0x80f8,0x5308,
  0x6c79,0x96c4,0x718a,0x4f11, 0x4fee,0x7f9e,0x673d,0x55c5,
  0x9508,0x79c0,0x8896,0x7ee3, 0x589f,0x620c,0x9700,0x865a,
  0x5618,0x987b,0x5f90,0x8bb8, 0x84c4,0x9157,0x53d9,0x65ed,
  0x5e8f,0x755c,0x6064,0x7d6e, 0x5a7f,0x7eea,0x7eed,0x8f69,
  0x55a7,0x5ba3,0x60ac,0x65cb, 0x7384,0x0000,
/* 0x5941(i:4560) */
  0x9009,0x7663,0x7729,0x7eda, 0x9774,0x859b,0x5b66,0x7a74,
  0x96ea,0x8840,0x52cb,0x718f, 0x5faa,0x65ec,0x8be2,0x5bfb,
  0x9a6f,0x5de1,0x6b89,0x6c5b, 0x8bad,0x8baf,0x900a,0x8fc5,
  0x538b,0x62bc,0x9e26,0x9e2d, 0x5440,0x4e2b,0x82bd,0x7259,
  0x869c,0x5d16,0x8859,0x6daf, 0x96c5,0x54d1,0x4e9a,0x8bb6,
  0x7109,0x54bd,0x9609,0x70df, 0x6df9,0x76d0,0x4e25,0x7814,
  0x8712,0x5ca9,0x5ef6,0x8a00, 0x989c,0x960e,0x708e,0x6cbf,
  0x5944,0x63a9,0x773c,0x884d, 0x6f14,0x8273,0x5830,0x0000,
  0x71d5,0x538c,0x781a,0x96c1, 0x5501,0x5f66,0x7130,0x5bb4,
  0x8c1a,0x9a8c,0x6b83,0x592e, 0x9e2f,0x79e7,0x6768,0x626c,
  0x4f6f,0x75a1,0x7f8a,0x6d0b, 0x9633,0x6c27,0x4ef0,0x75d2,
  0x517b,0x6837,0x6f3e,0x9080, 0x8170,0x5996,0x7476,0x6447,
  0x5c27,0x9065,0x7a91,0x8c23, 0x59da,0x54ac,0x8200,0x836f,
  0x8981,0x8000,0x6930,0x564e, 0x8036,0x7237,0x91ce,0x51b6,
  0x4e5f,0x9875,0x6396,0x4e1a, 0x53f6,0x66f3,0x814b,0x591c,
  0x6db2,0x4e00,0x58f9,0x533b, 0x63d6,0x94f1,0x4f9d,0x4f0a,
  0x8863,0x9890,0x5937,0x9057, 0x79fb,0x4eea,0x80f0,0x7591,
  0x6c82,0x5b9c,0x59e8,0x5f5d, 0x6905,0x8681,0x501a,0x5df2,
  0x4e59,0x77e3,0x4ee5,0x827a, 0x6291,0x6613,0x9091,0x5c79,
  0x4ebf,0x5f79,0x81c6,0x9038, 0x8084,0x75ab,0x4ea6,0x88d4,
  0x610f,0x6bc5,0x5fc6,0x4e49, 0x76ca,0x6ea2,0x8be3,0x8bae,
  0x8c0a,0x8bd1,0x5f02,0x7ffc, 0x7fcc,0x7ece,0x8335,0x836b,
  0x56e0,0x6bb7,0x97f3,0x9634, 0x59fb,0x541f,0x94f6,0x6deb,
  0x5bc5,0x996e,0x5c39,0x5f15, 0x9690,0x0000,
/* 0x5a41(i:4750) */
  0x5370,0x82f1,0x6a31,0x5a74, 0x9e70,0x5e94,0x7f28,0x83b9,
  0x8424,0x8425,0x8367,0x8747, 0x8fce,0x8d62,0x76c8,0x5f71,
  0x9896,0x786c,0x6620,0x54df, 0x62e5,0x4f63,0x81c3,0x75c8,
  0x5eb8,0x96cd,0x8e0a,0x86f9, 0x548f,0x6cf3,0x6d8c,0x6c38,
  0x607f,0x52c7,0x7528,0x5e7d, 0x4f18,0x60a0,0x5fe7,0x5c24,
  0x7531,0x90ae,0x94c0,0x72b9, 0x6cb9,0x6e38,0x9149,0x6709,
  0x53cb,0x53f3,0x4f51,0x91c9, 0x8bf1,0x53c8,0x5e7c,0x8fc2,
  0x6de4,0x4e8e,0x76c2,0x6986, 0x865e,0x611a,0x8206,0x0000,
  0x4f59,0x4fde,0x903e,0x9c7c, 0x6109,0x6e1d,0x6e14,0x9685,
  0x4e88,0x5a31,0x96e8,0x4e0e, 0x5c7f,0x79b9,0x5b87,0x8bed,
  0x7fbd,0x7389,0x57df,0x828b, 0x90c1,0x5401,0x9047,0x55bb,
  0x5cea,0x5fa1,0x6108,0x6b32, 0x72f1,0x80b2,0x8a89,0x6d74,
  0x5bd3,0x88d5,0x9884,0x8c6b, 0x9a6d,0x9e33,0x6e0a,0x51a4,
  0x5143,0x57a3,0x8881,0x539f, 0x63f4,0x8f95,0x56ed,0x5458,
  0x5706,0x733f,0x6e90,0x7f18, 0x8fdc,0x82d1,0x613f,0x6028,
  0x9662,0x66f0,0x7ea6,0x8d8a, 0x8dc3,0x94a5,0x5cb3,0x7ca4,
  0x6708,0x60a6,0x9605,0x8018, 0x4e91,0x90e7,0x5300,0x9668,
  0x5141,0x8fd0,0x8574,0x915d, 0x6655,0x97f5,0x5b55,0x531d,
  0x7838,0x6742,0x683d,0x54c9, 0x707e,0x5bb0,0x8f7d,0x518d,
  0x5728,0x54b1,0x6512,0x6682, 0x8d5e,0x8d43,0x810f,0x846c,
  0x906d,0x7cdf,0x51ff,0x85fb, 0x67a3,0x65e9,0x6fa1,0x86a4,
  0x8e81,0x566a,0x9020,0x7682, 0x7076,0x71e5,0x8d23,0x62e9,
  0x5219,0x6cfd,0x8d3c,0x600e, 0x589e,0x618e,0x66fe,0x8d60,
  0x624e,0x55b3,0x6e23,0x672d, 0x8f67,0x0000,
/* 0x5b41(i:4940) */
  0x94e1,0x95f8,0x7728,0x6805, 0x69a8,0x548b,0x4e4d,0x70b8,
  0x8bc8,0x6458,0x658b,0x5b85, 0x7a84,0x503a,0x5be8,0x77bb,
  0x6be1,0x8a79,0x7c98,0x6cbe, 0x76cf,0x65a9,0x8f97,0x5d2d,
  0x5c55,0x8638,0x6808,0x5360, 0x6218,0x7ad9,0x6e5b,0x7efd,
  0x6a1f,0x7ae0,0x5f70,0x6f33, 0x5f20,0x638c,0x6da8,0x6756,
  0x4e08,0x5e10,0x8d26,0x4ed7, 0x80c0,0x7634,0x969c,0x62db,
  0x662d,0x627e,0x6cbc,0x8d75, 0x7167,0x7f69,0x5146,0x8087,
  0x53ec,0x906e,0x6298,0x54f2, 0x86f0,0x8f99,0x8005,0x0000,
  0x9517,0x8517,0x8fd9,0x6d59, 0x73cd,0x659f,0x771f,0x7504,
  0x7827,0x81fb,0x8d1e,0x9488, 0x4fa6,0x6795,0x75b9,0x8bca,
  0x9707,0x632f,0x9547,0x9635, 0x84b8,0x6323,0x7741,0x5f81,
  0x72f0,0x4e89,0x6014,0x6574, 0x62ef,0x6b63,0x653f,0x5e27,
  0x75c7,0x90d1,0x8bc1,0x829d, 0x679d,0x652f,0x5431,0x8718,
  0x77e5,0x80a2,0x8102,0x6c41, 0x4e4b,0x7ec7,0x804c,0x76f4,
  0x690d,0x6b96,0x6267,0x503c, 0x4f84,0x5740,0x6307,0x6b62,
  0x8dbe,0x53ea,0x65e8,0x7eb8, 0x5fd7,0x631a,0x63b7,0x81f3,
  0x81f4,0x7f6e,0x5e1c,0x5cd9, 0x5236,0x667a,0x79e9,0x7a1a,
  0x8d28,0x7099,0x75d4,0x6ede, 0x6cbb,0x7a92,0x4e2d,0x76c5,
  0x5fe0,0x949f,0x8877,0x7ec8, 0x79cd,0x80bf,0x91cd,0x4ef2,
  0x4f17,0x821f,0x5468,0x5dde, 0x6d32,0x8bcc,0x7ca5,0x8f74,
  0x8098,0x5e1a,0x5492,0x76b1, 0x5b99,0x663c,0x9aa4,0x73e0,
  0x682a,0x86db,0x6731,0x732a, 0x8bf8,0x8bdb,0x9010,0x7af9,
  0x70db,0x716e,0x62c4,0x77a9, 0x5631,0x4e3b,0x8457,0x67f1,
  0x52a9,0x86c0,0x8d2e,0x94f8, 0x7b51,0x0000,
/* 0x5c41(i:5130) */
  0x4f4f,0x6ce8,0x795d,0x9a7b, 0x6293,0x722a,0x62fd,0x4e13,
  0x7816,0x8f6c,0x64b0,0x8d5a, 0x7bc6,0x6869,0x5e84,0x88c5,
  0x5986,0x649e,0x58ee,0x72b6, 0x690e,0x9525,0x8ffd,0x8d58,
  0x5760,0x7f00,0x8c06,0x51c6, 0x6349,0x62d9,0x5353,0x684c,
  0x7422,0x8301,0x914c,0x5544, 0x7740,0x707c,0x6d4a,0x5179,
  0x54a8,0x8d44,0x59ff,0x6ecb, 0x6dc4,0x5b5c,0x7d2b,0x4ed4,
  0x7c7d,0x6ed3,0x5b50,0x81ea, 0x6e0d,0x5b57,0x9b03,0x68d5,
  0x8e2a,0x5b97,0x7efc,0x603b, 0x7eb5,0x90b9,0x8d70,0x0000,
  0x594f,0x63cd,0x79df,0x8db3, 0x5352,0x65cf,0x7956,0x8bc5,
  0x963b,0x7ec4,0x94bb,0x7e82, 0x5634,0x9189,0x6700,0x7f6a,
  0x5c0a,0x9075,0x6628,0x5de6, 0x4f50,0x67de,0x505a,0x4f5c,
  0x5750,0x5ea7,0x0000,0x0000, 0x0000,0x0000,0x0000,0x4e8d,
  0x4e0c,0x5140,0x4e10,0x5eff, 0x5345,0x4e15,0x4e98,0x4e1e,
  0x9b32,0x5b6c,0x5669,0x4e28, 0x79ba,0x4e3f,0x5315,0x4e47,
  0x592d,0x723b,0x536e,0x6c10, 0x56df,0x80e4,0x9997,0x6bd3,
  0x777e,0x9f17,0x4e36,0x4e9f, 0x9f10,0x4e5c,0x4e69,0x4e93,
  0x8288,0x5b5b,0x556c,0x560f, 0x4ec4,0x538d,0x539d,0x53a3,
  0x53a5,0x53ae,0x9765,0x8d5d, 0x531a,0x53f5,0x5326,0x532e,
  0x533e,0x8d5c,0x5366,0x5363, 0x5202,0x5208,0x520e,0x522d,
  0x5233,0x523f,0x5240,0x524c, 0x525e,0x5261,0x525c,0x84af,
  0x527d,0x5282,0x5281,0x5290, 0x5293,0x5182,0x7f54,0x4ebb,
  0x4ec3,0x4ec9,0x4ec2,0x4ee8, 0x4ee1,0x4eeb,0x4ede,0x4f1b,
  0x4ef3,0x4f22,0x4f64,0x4ef5, 0x4f25,0x4f27,0x4f09,0x4f2b,
  0x4f5e,0x4f67,0x6538,0x4f5a, 0x4f5d,0x0000,
/* 0x5d41(i:5320) */
  0x4f5f,0x4f57,0x4f32,0x4f3d, 0x4f76,0x4f74,0x4f91,0x4f89,
  0x4f83,0x4f8f,0x4f7e,0x4f7b, 0x4faa,0x4f7c,0x4fac,0x4f94,
  0x4fe6,0x4fe8,0x4fea,0x4fc5, 0x4fda,0x4fe3,0x4fdc,0x4fd1,
  0x4fdf,0x4ff8,0x5029,0x504c, 0x4ff3,0x502c,0x500f,0x502e,
  0x502d,0x4ffe,0x501c,0x500c, 0x5025,0x5028,0x507e,0x5043,
  0x5055,0x5048,0x504e,0x506c, 0x507b,0x50a5,0x50a7,0x50a9,
  0x50ba,0x50d6,0x5106,0x50ed, 0x50ec,0x50e6,0x50ee,0x5107,
  0x510b,0x4edd,0x6c3d,0x4f58, 0x4f65,0x4fce,0x9fa0,0x0000,
  0x6c46,0x7c74,0x516e,0x5dfd, 0x9ec9,0x9998,0x5181,0x5914,
  0x52f9,0x530d,0x8a07,0x5310, 0x51eb,0x5919,0x5155,0x4ea0,
  0x5156,0x4eb3,0x886e,0x88a4, 0x4eb5,0x8114,0x88d2,0x7980,
  0x5b34,0x8803,0x7fb8,0x51ab, 0x51b1,0x51bd,0x51bc,0x51c7,
  0x5196,0x51a2,0x51a5,0x8ba0, 0x8ba6,0x8ba7,0x8baa,0x8bb4,
  0x8bb5,0x8bb7,0x8bc2,0x8bc3, 0x8bcb,0x8bcf,0x8bce,0x8bd2,
  0x8bd3,0x8bd4,0x8bd6,0x8bd8, 0x8bd9,0x8bdc,0x8bdf,0x8be0,
  0x8be4,0x8be8,0x8be9,0x8bee, 0x8bf0,0x8bf3,0x8bf6,0x8bf9,
  0x8bfc,0x8bff,0x8c00,0x8c02, 0x8c04,0x8c07,0x8c0c,0x8c0f,
  0x8c11,0x8c12,0x8c14,0x8c15, 0x8c16,0x8c19,0x8c1b,0x8c18,
  0x8c1d,0x8c1f,0x8c20,0x8c21, 0x8c25,0x8c27,0x8c2a,0x8c2b,
  0x8c2e,0x8c2f,0x8c32,0x8c33, 0x8c35,0x8c36,0x5369,0x537a,
  0x961d,0x9622,0x9621,0x9631, 0x962a,0x963d,0x963c,0x9642,
  0x9649,0x9654,0x965f,0x9667, 0x966c,0x9672,0x9674,0x9688,
  0x968d,0x9697,0x96b0,0x9097, 0x909b,0x909d,0x9099,0x90ac,
  0x90a1,0x90b4,0x90b3,0x90b6, 0x90ba,0x0000,
/* 0x5e41(i:5510) */
  0x90b8,0x90b0,0x90cf,0x90c5, 0x90be,0x90d0,0x90c4,0x90c7,
  0x90d3,0x90e6,0x90e2,0x90dc, 0x90d7,0x90db,0x90eb,0x90ef,
  0x90fe,0x9104,0x9122,0x911e, 0x9123,0x9131,0x912f,0x9139,
  0x9143,0x9146,0x520d,0x5942, 0x52a2,0x52ac,0x52ad,0x52be,
  0x54ff,0x52d0,0x52d6,0x52f0, 0x53df,0x71ee,0x77cd,0x5ef4,
  0x51f5,0x51fc,0x9b2f,0x53b6, 0x5f01,0x755a,0x5def,0x574c,
  0x57a9,0x57a1,0x587e,0x58bc, 0x58c5,0x58d1,0x5729,0x572c,
  0x572a,0x5733,0x5739,0x572e, 0x572f,0x575c,0x573b,0x0000,
  0x5742,0x5769,0x5785,0x576b, 0x5786,0x577c,0x577b,0x5768,
  0x576d,0x5776,0x5773,0x57ad, 0x57a4,0x578c,0x57b2,0x57cf,
  0x57a7,0x57b4,0x5793,0x57a0, 0x57d5,0x57d8,0x57da,0x57d9,
  0x57d2,0x57b8,0x57f4,0x57ef, 0x57f8,0x57e4,0x57dd,0x580b,
  0x580d,0x57fd,0x57ed,0x5800, 0x581e,0x5819,0x5844,0x5820,
  0x5865,0x586c,0x5881,0x5889, 0x589a,0x5880,0x99a8,0x9f19,
  0x61ff,0x8279,0x827d,0x827f, 0x828f,0x828a,0x82a8,0x8284,
  0x828e,0x8291,0x8297,0x8299, 0x82ab,0x82b8,0x82be,0x82b0,
  0x82c8,0x82ca,0x82e3,0x8298, 0x82b7,0x82ae,0x82cb,0x82cc,
  0x82c1,0x82a9,0x82b4,0x82a1, 0x82aa,0x829f,0x82c4,0x82ce,
  0x82a4,0x82e1,0x8309,0x82f7, 0x82e4,0x830f,0x8307,0x82dc,
  0x82f4,0x82d2,0x82d8,0x830c, 0x82fb,0x82d3,0x8311,0x831a,
  0x8306,0x8314,0x8315,0x82e0, 0x82d5,0x831c,0x8351,0x835b,
  0x835c,0x8308,0x8392,0x833c, 0x8334,0x8331,0x839b,0x835e,
  0x832f,0x834f,0x8347,0x8343, 0x835f,0x8340,0x8317,0x8360,
  0x832d,0x833a,0x8333,0x8366, 0x8365,0x0000,
/* 0x5f41(i:5700) */
  0x8368,0x831b,0x8369,0x836c, 0x836a,0x836d,0x836e,0x83b0,
  0x8378,0x83b3,0x83b4,0x83a0, 0x83aa,0x8393,0x839c,0x8385,
  0x837c,0x83b6,0x83a9,0x837d, 0x83b8,0x837b,0x8398,0x839e,
  0x83a8,0x83ba,0x83bc,0x83c1, 0x8401,0x83e5,0x83d8,0x5807,
  0x8418,0x840b,0x83dd,0x83fd, 0x83d6,0x841c,0x8438,0x8411,
  0x8406,0x83d4,0x83df,0x840f, 0x8403,0x83f8,0x83f9,0x83ea,
  0x83c5,0x83c0,0x8426,0x83f0, 0x83e1,0x845c,0x8451,0x845a,
  0x8459,0x8473,0x8487,0x8488, 0x847a,0x8489,0x8478,0x0000,
  0x843c,0x8446,0x8469,0x8476, 0x848c,0x848e,0x8431,0x846d,
  0x84c1,0x84cd,0x84d0,0x84e6, 0x84bd,0x84d3,0x84ca,0x84bf,
  0x84ba,0x84e0,0x84a1,0x84b9, 0x84b4,0x8497,0x84e5,0x84e3,
  0x850c,0x750d,0x8538,0x84f0, 0x8539,0x851f,0x853a,0x8556,
  0x853b,0x84ff,0x84fc,0x8559, 0x8548,0x8568,0x8564,0x855e,
  0x857a,0x77a2,0x8543,0x8572, 0x857b,0x85a4,0x85a8,0x8587,
  0x858f,0x8579,0x85ae,0x859c, 0x8585,0x85b9,0x85b7,0x85b0,
  0x85d3,0x85c1,0x85dc,0x85ff, 0x8627,0x8605,0x8629,0x8616,
  0x863c,0x5efe,0x5f08,0x593c, 0x5941,0x8037,0x5955,0x595a,
  0x5958,0x530f,0x5c22,0x5c25, 0x5c2c,0x5c34,0x624c,0x626a,
  0x629f,0x62bb,0x62ca,0x62da, 0x62d7,0x62ee,0x6322,0x62f6,
  0x6339,0x634b,0x6343,0x63ad, 0x63f6,0x6371,0x637a,0x638e,
  0x63b4,0x636d,0x63ac,0x638a, 0x6369,0x63ae,0x63bc,0x63f2,
  0x63f8,0x63e0,0x63ff,0x63c4, 0x63de,0x63ce,0x6452,0x63c6,
  0x63be,0x6445,0x6441,0x640b, 0x641b,0x6420,0x640c,0x6426,
  0x6421,0x645e,0x6484,0x646d, 0x6496,0x0000,
/* 0x6041(i:5890) */
  0x647a,0x64b7,0x64b8,0x6499, 0x64ba,0x64c0,0x64d0,0x64d7,
  0x64e4,0x64e2,0x6509,0x6525, 0x652e,0x5f0b,0x5fd2,0x7519,
  0x5f11,0x535f,0x53f1,0x53fd, 0x53e9,0x53e8,0x53fb,0x5412,
  0x5416,0x5406,0x544b,0x5452, 0x5453,0x5454,0x5456,0x5443,
  0x5421,0x5457,0x5459,0x5423, 0x5432,0x5482,0x5494,0x5477,
  0x5471,0x5464,0x549a,0x549b, 0x5484,0x5476,0x5466,0x549d,
  0x54d0,0x54ad,0x54c2,0x54b4, 0x54d2,0x54a7,0x54a6,0x54d3,
  0x54d4,0x5472,0x54a3,0x54d5, 0x54bb,0x54bf,0x54cc,0x0000,
  0x54d9,0x54da,0x54dc,0x54a9, 0x54aa,0x54a4,0x54dd,0x54cf,
  0x54de,0x551b,0x54e7,0x5520, 0x54fd,0x5514,0x54f3,0x5522,
  0x5523,0x550f,0x5511,0x5527, 0x552a,0x5567,0x558f,0x55b5,
  0x5549,0x556d,0x5541,0x5555, 0x553f,0x5550,0x553c,0x5537,
  0x5556,0x5575,0x5576,0x5577, 0x5533,0x5530,0x555c,0x558b,
  0x55d2,0x5583,0x55b1,0x55b9, 0x5588,0x5581,0x559f,0x557e,
  0x55d6,0x5591,0x557b,0x55df, 0x55bd,0x55be,0x5594,0x5599,
  0x55ea,0x55f7,0x55c9,0x561f, 0x55d1,0x55eb,0x55ec,0x55d4,
  0x55e6,0x55dd,0x55c4,0x55ef, 0x55e5,0x55f2,0x55f3,0x55cc,
  0x55cd,0x55e8,0x55f5,0x55e4, 0x8f94,0x561e,0x5608,0x560c,
  0x5601,0x5624,0x5623,0x55fe, 0x5600,0x5627,0x562d,0x5658,
  0x5639,0x5657,0x562c,0x564d, 0x5662,0x5659,0x565c,0x564c,
  0x5654,0x5686,0x5664,0x5671, 0x566b,0x567b,0x567c,0x5685,
  0x5693,0x56af,0x56d4,0x56d7, 0x56dd,0x56e1,0x56f5,0x56eb,
  0x56f9,0x56ff,0x5704,0x570a, 0x5709,0x571c,0x5e0f,0x5e19,
  0x5e14,0x5e11,0x5e31,0x5e3b, 0x5e3c,0x0000,
/* 0x6141(i:6080) */
  0x5e37,0x5e44,0x5e54,0x5e5b, 0x5e5e,0x5e61,0x5c8c,0x5c7a,
  0x5c8d,0x5c90,0x5c96,0x5c88, 0x5c98,0x5c99,0x5c91,0x5c9a,
  0x5c9c,0x5cb5,0x5ca2,0x5cbd, 0x5cac,0x5cab,0x5cb1,0x5ca3,
  0x5cc1,0x5cb7,0x5cc4,0x5cd2, 0x5ce4,0x5ccb,0x5ce5,0x5d02,
  0x5d03,0x5d27,0x5d26,0x5d2e, 0x5d24,0x5d1e,0x5d06,0x5d1b,
  0x5d58,0x5d3e,0x5d34,0x5d3d, 0x5d6c,0x5d5b,0x5d6f,0x5d5d,
  0x5d6b,0x5d4b,0x5d4a,0x5d69, 0x5d74,0x5d82,0x5d99,0x5d9d,
  0x8c73,0x5db7,0x5dc5,0x5f73, 0x5f77,0x5f82,0x5f87,0x0000,
  0x5f89,0x5f8c,0x5f95,0x5f99, 0x5f9c,0x5fa8,0x5fad,0x5fb5,
  0x5fbc,0x8862,0x5f61,0x72ad, 0x72b0,0x72b4,0x72b7,0x72b8,
  0x72c3,0x72c1,0x72ce,0x72cd, 0x72d2,0x72e8,0x72ef,0x72e9,
  0x72f2,0x72f4,0x72f7,0x7301, 0x72f3,0x7303,0x72fa,0x72fb,
  0x7317,0x7313,0x7321,0x730a, 0x731e,0x731d,0x7315,0x7322,
  0x7339,0x7325,0x732c,0x7338, 0x7331,0x7350,0x734d,0x7357,
  0x7360,0x736c,0x736f,0x737e, 0x821b,0x5925,0x98e7,0x5924,
  0x5902,0x9963,0x9967,0x9968, 0x9969,0x996a,0x996b,0x996c,
  0x9974,0x9977,0x997d,0x9980, 0x9984,0x9987,0x998a,0x998d,
  0x9990,0x9991,0x9993,0x9994, 0x9995,0x5e80,0x5e91,0x5e8b,
  0x5e96,0x5ea5,0x5ea0,0x5eb9, 0x5eb5,0x5ebe,0x5eb3,0x8d53,
  0x5ed2,0x5ed1,0x5edb,0x5ee8, 0x5eea,0x81ba,0x5fc4,0x5fc9,
  0x5fd6,0x5fcf,0x6003,0x5fee, 0x6004,0x5fe1,0x5fe4,0x5ffe,
  0x6005,0x6006,0x5fea,0x5fed, 0x5ff8,0x6019,0x6035,0x6026,
  0x601b,0x600f,0x600d,0x6029, 0x602b,0x600a,0x603f,0x6021,
  0x6078,0x6079,0x607b,0x607a, 0x6042,0x0000,
/* 0x6241(i:6270) */
  0x606a,0x607d,0x6096,0x609a, 0x60ad,0x609d,0x6083,0x6092,
  0x608c,0x609b,0x60ec,0x60bb, 0x60b1,0x60dd,0x60d8,0x60c6,
  0x60da,0x60b4,0x6120,0x6126, 0x6115,0x6123,0x60f4,0x6100,
  0x610e,0x612b,0x614a,0x6175, 0x61ac,0x6194,0x61a7,0x61b7,
  0x61d4,0x61f5,0x5fdd,0x96b3, 0x95e9,0x95eb,0x95f1,0x95f3,
  0x95f5,0x95f6,0x95fc,0x95fe, 0x9603,0x9604,0x9606,0x9608,
  0x960a,0x960b,0x960c,0x960d, 0x960f,0x9612,0x9615,0x9616,
  0x9617,0x9619,0x961a,0x4e2c, 0x723f,0x6215,0x6c35,0x0000,
  0x6c54,0x6c5c,0x6c4a,0x6ca3, 0x6c85,0x6c90,0x6c94,0x6c8c,
  0x6c68,0x6c69,0x6c74,0x6c76, 0x6c86,0x6ca9,0x6cd0,0x6cd4,
  0x6cad,0x6cf7,0x6cf8,0x6cf1, 0x6cd7,0x6cb2,0x6ce0,0x6cd6,
  0x6cfa,0x6ceb,0x6cee,0x6cb1, 0x6cd3,0x6cef,0x6cfe,0x6d39,
  0x6d27,0x6d0c,0x6d43,0x6d48, 0x6d07,0x6d04,0x6d19,0x6d0e,
  0x6d2b,0x6d4d,0x6d2e,0x6d35, 0x6d1a,0x6d4f,0x6d52,0x6d54,
  0x6d33,0x6d91,0x6d6f,0x6d9e, 0x6da0,0x6d5e,0x6d93,0x6d94,
  0x6d5c,0x6d60,0x6d7c,0x6d63, 0x6e1a,0x6dc7,0x6dc5,0x6dde,
  0x6e0e,0x6dbf,0x6de0,0x6e11, 0x6de6,0x6ddd,0x6dd9,0x6e16,
  0x6dab,0x6e0c,0x6dae,0x6e2b, 0x6e6e,0x6e4e,0x6e6b,0x6eb2,
  0x6e5f,0x6e86,0x6e53,0x6e54, 0x6e32,0x6e25,0x6e44,0x6edf,
  0x6eb1,0x6e98,0x6ee0,0x6f2d, 0x6ee2,0x6ea5,0x6ea7,0x6ebd,
  0x6ebb,0x6eb7,0x6ed7,0x6eb4, 0x6ecf,0x6e8f,0x6ec2,0x6e9f,
  0x6f62,0x6f46,0x6f47,0x6f24, 0x6f15,0x6ef9,0x6f2f,0x6f36,
  0x6f4b,0x6f74,0x6f2a,0x6f09, 0x6f29,0x6f89,0x6f8d,0x6f8c,
  0x6f78,0x6f72,0x6f7c,0x6f7a, 0x6fd1,0x0000,
/* 0x6341(i:6460) */
  0x6fc9,0x6fa7,0x6fb9,0x6fb6, 0x6fc2,0x6fe1,0x6fee,0x6fde,
  0x6fe0,0x6fef,0x701a,0x7023, 0x701b,0x7039,0x7035,0x704f,
  0x705e,0x5b80,0x5b84,0x5b95, 0x5b93,0x5ba5,0x5bb8,0x752f,
  0x9a9e,0x6434,0x5be4,0x5bee, 0x8930,0x5bf0,0x8e47,0x8b07,
  0x8fb6,0x8fd3,0x8fd5,0x8fe5, 0x8fee,0x8fe4,0x8fe9,0x8fe6,
  0x8ff3,0x8fe8,0x9005,0x9004, 0x900b,0x9026,0x9011,0x900d,
  0x9016,0x9021,0x9035,0x9036, 0x902d,0x902f,0x9044,0x9051,
  0x9052,0x9050,0x9068,0x9058, 0x9062,0x905b,0x66b9,0x0000,
  0x9074,0x907d,0x9082,0x9088, 0x9083,0x908b,0x5f50,0x5f57,
  0x5f56,0x5f58,0x5c3b,0x54ab, 0x5c50,0x5c59,0x5b71,0x5c63,
  0x5c66,0x7fbc,0x5f2a,0x5f29, 0x5f2d,0x8274,0x5f3c,0x9b3b,
  0x5c6e,0x5981,0x5983,0x598d, 0x59a9,0x59aa,0x59a3,0x5997,
  0x59ca,0x59ab,0x599e,0x59a4, 0x59d2,0x59b2,0x59af,0x59d7,
  0x59be,0x5a05,0x5a06,0x59dd, 0x5a08,0x59e3,0x59d8,0x59f9,
  0x5a0c,0x5a09,0x5a32,0x5a34, 0x5a11,0x5a23,0x5a13,0x5a40,
  0x5a67,0x5a4a,0x5a55,0x5a3c, 0x5a62,0x5a75,0x80ec,0x5aaa,
  0x5a9b,0x5a77,0x5a7a,0x5abe, 0x5aeb,0x5ab2,0x5ad2,0x5ad4,
  0x5ab8,0x5ae0,0x5ae3,0x5af1, 0x5ad6,0x5ae6,0x5ad8,0x5adc,
  0x5b09,0x5b17,0x5b16,0x5b32, 0x5b37,0x5b40,0x5c15,0x5c1c,
  0x5b5a,0x5b65,0x5b73,0x5b51, 0x5b53,0x5b62,0x9a75,0x9a77,
  0x9a78,0x9a7a,0x9a7f,0x9a7d, 0x9a80,0x9a81,0x9a85,0x9a88,
  0x9a8a,0x9a90,0x9a92,0x9a93, 0x9a96,0x9a98,0x9a9b,0x9a9c,
  0x9a9d,0x9a9f,0x9aa0,0x9aa2, 0x9aa3,0x9aa5,0x9aa7,0x7e9f,
  0x7ea1,0x7ea3,0x7ea5,0x7ea8, 0x7ea9,0x0000,
/* 0x6441(i:6650) */
  0x7ead,0x7eb0,0x7ebe,0x7ec0, 0x7ec1,0x7ec2,0x7ec9,0x7ecb,
  0x7ecc,0x7ed0,0x7ed4,0x7ed7, 0x7edb,0x7ee0,0x7ee1,0x7ee8,
  0x7eeb,0x7eee,0x7eef,0x7ef1, 0x7ef2,0x7f0d,0x7ef6,0x7efa,
  0x7efb,0x7efe,0x7f01,0x7f02, 0x7f03,0x7f07,0x7f08,0x7f0b,
  0x7f0c,0x7f0f,0x7f11,0x7f12, 0x7f17,0x7f19,0x7f1c,0x7f1b,
  0x7f1f,0x7f21,0x7f22,0x7f23, 0x7f24,0x7f25,0x7f26,0x7f27,
  0x7f2a,0x7f2b,0x7f2c,0x7f2d, 0x7f2f,0x7f30,0x7f31,0x7f32,
  0x7f33,0x7f35,0x5e7a,0x757f, 0x5ddb,0x753e,0x9095,0x0000,
  0x738e,0x7391,0x73ae,0x73a2, 0x739f,0x73cf,0x73c2,0x73d1,
  0x73b7,0x73b3,0x73c0,0x73c9, 0x73c8,0x73e5,0x73d9,0x987c,
  0x740a,0x73e9,0x73e7,0x73de, 0x73ba,0x73f2,0x740f,0x742a,
  0x745b,0x7426,0x7425,0x7428, 0x7430,0x742e,0x742c,0x741b,
  0x741a,0x7441,0x745c,0x7457, 0x7455,0x7459,0x7477,0x746d,
  0x747e,0x749c,0x748e,0x7480, 0x7481,0x7487,0x748b,0x749e,
  0x74a8,0x74a9,0x7490,0x74a7, 0x74d2,0x74ba,0x97ea,0x97eb,
  0x97ec,0x674c,0x6753,0x675e, 0x6748,0x6769,0x67a5,0x6787,
  0x676a,0x6773,0x6798,0x67a7, 0x6775,0x67a8,0x679e,0x67ad,
  0x678b,0x6777,0x677c,0x67f0, 0x6809,0x67d8,0x680a,0x67e9,
  0x67b0,0x680c,0x67d9,0x67b5, 0x67da,0x67b3,0x67dd,0x6800,
  0x67c3,0x67b8,0x67e2,0x680e, 0x67c1,0x67fd,0x6832,0x6833,
  0x6860,0x6861,0x684e,0x6862, 0x6844,0x6864,0x6883,0x681d,
  0x6855,0x6866,0x6841,0x6867, 0x6840,0x683e,0x684a,0x6849,
  0x6829,0x68b5,0x688f,0x6874, 0x6877,0x6893,0x686b,0x68c2,
  0x696e,0x68fc,0x691f,0x6920, 0x68f9,0x0000,
/* 0x6541(i:6840) */
  0x6924,0x68f0,0x690b,0x6901, 0x6957,0x68e3,0x6910,0x6971,
  0x6939,0x6960,0x6942,0x695d, 0x6984,0x696b,0x6980,0x6998,
  0x6978,0x6934,0x69cc,0x6987, 0x6988,0x69ce,0x6989,0x6966,
  0x6963,0x6979,0x699b,0x69a7, 0x69bb,0x69ab,0x69ad,0x69d4,
  0x69b1,0x69c1,0x69ca,0x69df, 0x6995,0x69e0,0x698d,0x69ff,
  0x6a2f,0x69ed,0x6a17,0x6a18, 0x6a65,0x69f2,0x6a44,0x6a3e,
  0x6aa0,0x6a50,0x6a5b,0x6a35, 0x6a8e,0x6a79,0x6a3d,0x6a28,
  0x6a58,0x6a7c,0x6a91,0x6a90, 0x6aa9,0x6a97,0x6aab,0x0000,
  0x7337,0x7352,0x6b81,0x6b82, 0x6b87,0x6b84,0x6b92,0x6b93,
  0x6b8d,0x6b9a,0x6b9b,0x6ba1, 0x6baa,0x8f6b,0x8f6d,0x8f71,
  0x8f72,0x8f73,0x8f75,0x8f76, 0x8f78,0x8f77,0x8f79,0x8f7a,
  0x8f7c,0x8f7e,0x8f81,0x8f82, 0x8f84,0x8f87,0x8f8b,0x8f8d,
  0x8f8e,0x8f8f,0x8f98,0x8f9a, 0x8ece,0x620b,0x6217,0x621b,
  0x621f,0x6222,0x6221,0x6225, 0x6224,0x622c,0x81e7,0x74ef,
  0x74f4,0x74ff,0x750f,0x7511, 0x7513,0x6534,0x65ee,0x65ef,
  0x65f0,0x660a,0x6619,0x6772, 0x6603,0x6615,0x6600,0x7085,
  0x66f7,0x661d,0x6634,0x6631, 0x6636,0x6635,0x8006,0x665f,
  0x6654,0x6641,0x664f,0x6656, 0x6661,0x6657,0x6677,0x6684,
  0x668c,0x66a7,0x669d,0x66be, 0x66db,0x66dc,0x66e6,0x66e9,
  0x8d32,0x8d33,0x8d36,0x8d3b, 0x8d3d,0x8d40,0x8d45,0x8d46,
  0x8d48,0x8d49,0x8d47,0x8d4d, 0x8d55,0x8d59,0x89c7,0x89ca,
  0x89cb,0x89cc,0x89ce,0x89cf, 0x89d0,0x89d1,0x726e,0x729f,
  0x725d,0x7266,0x726f,0x727e, 0x727f,0x7284,0x728b,0x728d,
  0x728f,0x7292,0x6308,0x6332, 0x63b0,0x0000,
/* 0x6641(i:7030) */
  0x643f,0x64d8,0x8004,0x6bea, 0x6bf3,0x6bfd,0x6bf5,0x6bf9,
  0x6c05,0x6c07,0x6c06,0x6c0d, 0x6c15,0x6c18,0x6c19,0x6c1a,
  0x6c21,0x6c29,0x6c24,0x6c2a, 0x6c32,0x6535,0x6555,0x656b,
  0x724d,0x7252,0x7256,0x7230, 0x8662,0x5216,0x809f,0x809c,
  0x8093,0x80bc,0x670a,0x80bd, 0x80b1,0x80ab,0x80ad,0x80b4,
  0x80b7,0x80e7,0x80e8,0x80e9, 0x80ea,0x80db,0x80c2,0x80c4,
  0x80d9,0x80cd,0x80d7,0x6710, 0x80dd,0x80eb,0x80f1,0x80f4,
  0x80ed,0x810d,0x810e,0x80f2, 0x80fc,0x6715,0x8112,0x0000,
  0x8c5a,0x8136,0x811e,0x812c, 0x8118,0x8132,0x8148,0x814c,
  0x8153,0x8174,0x8159,0x815a, 0x8171,0x8160,0x8169,0x817c,
  0x817d,0x816d,0x8167,0x584d, 0x5ab5,0x8188,0x8182,0x8191,
  0x6ed5,0x81a3,0x81aa,0x81cc, 0x6726,0x81ca,0x81bb,0x81c1,
  0x81a6,0x6b24,0x6b37,0x6b39, 0x6b43,0x6b46,0x6b59,0x98d1,
  0x98d2,0x98d3,0x98d5,0x98d9, 0x98da,0x6bb3,0x5f40,0x6bc2,
  0x89f3,0x6590,0x9f51,0x6593, 0x65bc,0x65c6,0x65c4,0x65c3,
  0x65cc,0x65ce,0x65d2,0x65d6, 0x7080,0x709c,0x7096,0x709d,
  0x70bb,0x70c0,0x70b7,0x70ab, 0x70b1,0x70e8,0x70ca,0x7110,
  0x7113,0x7116,0x712f,0x7131, 0x7173,0x715c,0x7168,0x7145,
  0x7172,0x714a,0x7178,0x717a, 0x7198,0x71b3,0x71b5,0x71a8,
  0x71a0,0x71e0,0x71d4,0x71e7, 0x71f9,0x721d,0x7228,0x706c,
  0x7118,0x7166,0x71b9,0x623e, 0x623d,0x6243,0x6248,0x6249,
  0x793b,0x7940,0x7946,0x7949, 0x795b,0x795c,0x7953,0x795a,
  0x7962,0x7957,0x7960,0x796f, 0x7967,0x797a,0x7985,0x798a,
  0x799a,0x79a7,0x79b3,0x5fd1, 0x5fd0,0x0000,
/* 0x6741(i:7220) */
  0x603c,0x605d,0x605a,0x6067, 0x6041,0x6059,0x6063,0x60ab,
  0x6106,0x610d,0x615d,0x61a9, 0x619d,0x61cb,0x61d1,0x6206,
  0x8080,0x807f,0x6c93,0x6cf6, 0x6dfc,0x77f6,0x77f8,0x7800,
  0x7809,0x7817,0x7818,0x7811, 0x65ab,0x782d,0x781c,0x781d,
  0x7839,0x783a,0x783b,0x781f, 0x783c,0x7825,0x782c,0x7823,
  0x7829,0x784e,0x786d,0x7856, 0x7857,0x7826,0x7850,0x7847,
  0x784c,0x786a,0x789b,0x7893, 0x789a,0x7887,0x789c,0x78a1,
  0x78a3,0x78b2,0x78b9,0x78a5, 0x78d4,0x78d9,0x78c9,0x0000,
  0x78ec,0x78f2,0x7905,0x78f4, 0x7913,0x7924,0x791e,0x7934,
  0x9f9b,0x9ef9,0x9efb,0x9efc, 0x76f1,0x7704,0x770d,0x76f9,
  0x7707,0x7708,0x771a,0x7722, 0x7719,0x772d,0x7726,0x7735,
  0x7738,0x7750,0x7751,0x7747, 0x7743,0x775a,0x7768,0x7762,
  0x7765,0x777f,0x778d,0x777d, 0x7780,0x778c,0x7791,0x779f,
  0x77a0,0x77b0,0x77b5,0x77bd, 0x753a,0x7540,0x754e,0x754b,
  0x7548,0x755b,0x7572,0x7579, 0x7583,0x7f58,0x7f61,0x7f5f,
  0x8a48,0x7f68,0x7f74,0x7f71, 0x7f79,0x7f81,0x7f7e,0x76cd,
  0x76e5,0x8832,0x9485,0x9486, 0x9487,0x948b,0x948a,0x948c,
  0x948d,0x948f,0x9490,0x9494, 0x9497,0x9495,0x949a,0x949b,
  0x949c,0x94a3,0x94a4,0x94ab, 0x94aa,0x94ad,0x94ac,0x94af,
  0x94b0,0x94b2,0x94b4,0x94b6, 0x94b7,0x94b8,0x94b9,0x94ba,
  0x94bc,0x94bd,0x94bf,0x94c4, 0x94c8,0x94c9,0x94ca,0x94cb,
  0x94cc,0x94cd,0x94ce,0x94d0, 0x94d1,0x94d2,0x94d5,0x94d6,
  0x94d7,0x94d9,0x94d8,0x94db, 0x94de,0x94df,0x94e0,0x94e2,
  0x94e4,0x94e5,0x94e7,0x94e8, 0x94ea,0x0000,
/* 0x6841(i:7410) */
  0x94e9,0x94eb,0x94ee,0x94ef, 0x94f3,0x94f4,0x94f5,0x94f7,
  0x94f9,0x94fc,0x94fd,0x94ff, 0x9503,0x9502,0x9506,0x9507,
  0x9509,0x950a,0x950d,0x950e, 0x950f,0x9512,0x9513,0x9514,
  0x9515,0x9516,0x9518,0x951b, 0x951d,0x951e,0x951f,0x9522,
  0x952a,0x952b,0x9529,0x952c, 0x9531,0x9532,0x9534,0x9536,
  0x9537,0x9538,0x953c,0x953e, 0x953f,0x9542,0x9535,0x9544,
  0x9545,0x9546,0x9549,0x954c, 0x954e,0x954f,0x9552,0x9553,
  0x9554,0x9556,0x9557,0x9558, 0x9559,0x955b,0x955e,0x0000,
  0x955f,0x955d,0x9561,0x9562, 0x9564,0x9565,0x9566,0x9567,
  0x9568,0x9569,0x956a,0x956b, 0x956c,0x956f,0x9571,0x9572,
  0x9573,0x953a,0x77e7,0x77ec, 0x96c9,0x79d5,0x79ed,0x79e3,
  0x79eb,0x7a06,0x5d47,0x7a03, 0x7a02,0x7a1e,0x7a14,0x7a39,
  0x7a37,0x7a51,0x9ecf,0x99a5, 0x7a70,0x7688,0x768e,0x7693,
  0x7699,0x76a4,0x74de,0x74e0, 0x752c,0x9e20,0x9e22,0x9e28,
  0x9e29,0x9e2a,0x9e2b,0x9e2c, 0x9e32,0x9e31,0x9e36,0x9e38,
  0x9e37,0x9e39,0x9e3a,0x9e3e, 0x9e41,0x9e42,0x9e44,0x9e46,
  0x9e47,0x9e48,0x9e49,0x9e4b, 0x9e4c,0x9e4e,0x9e51,0x9e55,
  0x9e57,0x9e5a,0x9e5b,0x9e5c, 0x9e5e,0x9e63,0x9e66,0x9e67,
  0x9e68,0x9e69,0x9e6a,0x9e6b, 0x9e6c,0x9e71,0x9e6d,0x9e73,
  0x7592,0x7594,0x7596,0x75a0, 0x759d,0x75ac,0x75a3,0x75b3,
  0x75b4,0x75b8,0x75c4,0x75b1, 0x75b0,0x75c3,0x75c2,0x75d6,
  0x75cd,0x75e3,0x75e8,0x75e6, 0x75e4,0x75eb,0x75e7,0x7603,
  0x75f1,0x75fc,0x75ff,0x7610, 0x7600,0x7605,0x760c,0x7617,
  0x760a,0x7625,0x7618,0x7615, 0x7619,0x0000,
/* 0x6941(i:7600) */
  0x761b,0x763c,0x7622,0x7620, 0x7640,0x762d,0x7630,0x763f,
  0x7635,0x7643,0x763e,0x7633, 0x764d,0x765e,0x7654,0x765c,
  0x7656,0x766b,0x766f,0x7fca, 0x7ae6,0x7a78,0x7a79,0x7a80,
  0x7a86,0x7a88,0x7a95,0x7aa6, 0x7aa0,0x7aac,0x7aa8,0x7aad,
  0x7ab3,0x8864,0x8869,0x8872, 0x887d,0x887f,0x8882,0x88a2,
  0x88c6,0x88b7,0x88bc,0x88c9, 0x88e2,0x88ce,0x88e3,0x88e5,
  0x88f1,0x891a,0x88fc,0x88e8, 0x88fe,0x88f0,0x8921,0x8919,
  0x8913,0x891b,0x890a,0x8934, 0x892b,0x8936,0x8941,0x0000,
  0x8966,0x897b,0x758b,0x80e5, 0x76b2,0x76b4,0x77dc,0x8012,
  0x8014,0x8016,0x801c,0x8020, 0x8022,0x8025,0x8026,0x8027,
  0x8029,0x8028,0x8031,0x800b, 0x8035,0x8043,0x8046,0x804d,
  0x8052,0x8069,0x8071,0x8983, 0x9878,0x9880,0x9883,0x9889,
  0x988c,0x988d,0x988f,0x9894, 0x989a,0x989b,0x989e,0x989f,
  0x98a1,0x98a2,0x98a5,0x98a6, 0x864d,0x8654,0x866c,0x866e,
  0x867f,0x867a,0x867c,0x867b, 0x86a8,0x868d,0x868b,0x86ac,
  0x869d,0x86a7,0x86a3,0x86aa, 0x8693,0x86a9,0x86b6,0x86c4,
  0x86b5,0x86ce,0x86b0,0x86ba, 0x86b1,0x86af,0x86c9,0x86cf,
  0x86b4,0x86e9,0x86f1,0x86f2, 0x86ed,0x86f3,0x86d0,0x8713,
  0x86de,0x86f4,0x86df,0x86d8, 0x86d1,0x8703,0x8707,0x86f8,
  0x8708,0x870a,0x870d,0x8709, 0x8723,0x873b,0x871e,0x8725,
  0x872e,0x871a,0x873e,0x8748, 0x8734,0x8731,0x8729,0x8737,
  0x873f,0x8782,0x8722,0x877d, 0x877e,0x877b,0x8760,0x8770,
  0x874c,0x876e,0x878b,0x8753, 0x8763,0x877c,0x8764,0x8759,
  0x8765,0x8793,0x87af,0x87a8, 0x87d2,0x0000,
/* 0x6a41(i:7790) */
  0x87c6,0x8788,0x8785,0x87ad, 0x8797,0x8783,0x87ab,0x87e5,
  0x87ac,0x87b5,0x87b3,0x87cb, 0x87d3,0x87bd,0x87d1,0x87c0,
  0x87ca,0x87db,0x87ea,0x87e0, 0x87ee,0x8816,0x8813,0x87fe,
  0x880a,0x881b,0x8821,0x8839, 0x883c,0x7f36,0x7f42,0x7f44,
  0x7f45,0x8210,0x7afa,0x7afd, 0x7b08,0x7b03,0x7b04,0x7b15,
  0x7b0a,0x7b2b,0x7b0f,0x7b47, 0x7b38,0x7b2a,0x7b19,0x7b2e,
  0x7b31,0x7b20,0x7b25,0x7b24, 0x7b33,0x7b3e,0x7b1e,0x7b58,
  0x7b5a,0x7b45,0x7b75,0x7b4c, 0x7b5d,0x7b60,0x7b6e,0x0000,
  0x7b7b,0x7b62,0x7b72,0x7b71, 0x7b90,0x7ba6,0x7ba7,0x7bb8,
  0x7bac,0x7b9d,0x7ba8,0x7b85, 0x7baa,0x7b9c,0x7ba2,0x7bab,
  0x7bb4,0x7bd1,0x7bc1,0x7bcc, 0x7bdd,0x7bda,0x7be5,0x7be6,
  0x7bea,0x7c0c,0x7bfe,0x7bfc, 0x7c0f,0x7c16,0x7c0b,0x7c1f,
  0x7c2a,0x7c26,0x7c38,0x7c41, 0x7c40,0x81fe,0x8201,0x8202,
  0x8204,0x81ec,0x8844,0x8221, 0x8222,0x8223,0x822d,0x822f,
  0x8228,0x822b,0x8238,0x823b, 0x8233,0x8234,0x823e,0x8244,
  0x8249,0x824b,0x824f,0x825a, 0x825f,0x8268,0x887e,0x8885,
  0x8888,0x88d8,0x88df,0x895e, 0x7f9d,0x7f9f,0x7fa7,0x7faf,
  0x7fb0,0x7fb2,0x7c7c,0x6549, 0x7c91,0x7c9d,0x7c9c,0x7c9e,
  0x7ca2,0x7cb2,0x7cbc,0x7cbd, 0x7cc1,0x7cc7,0x7ccc,0x7ccd,
  0x7cc8,0x7cc5,0x7cd7,0x7ce8, 0x826e,0x66a8,0x7fbf,0x7fce,
  0x7fd5,0x7fe5,0x7fe1,0x7fe6, 0x7fe9,0x7fee,0x7ff3,0x7cf8,
  0x7d77,0x7da6,0x7dae,0x7e47, 0x7e9b,0x9eb8,0x9eb4,0x8d73,
  0x8d84,0x8d94,0x8d91,0x8db1, 0x8d67,0x8d6d,0x8c47,0x8c49,
  0x914a,0x9150,0x914e,0x914f, 0x9164,0x0000,
/* 0x6b41(i:7980) */
  0x9162,0x9161,0x9170,0x9169, 0x916f,0x917d,0x917e,0x9172,
  0x9174,0x9179,0x918c,0x9185, 0x9190,0x918d,0x9191,0x91a2,
  0x91a3,0x91aa,0x91ad,0x91ae, 0x91af,0x91b5,0x91b4,0x91ba,
  0x8c55,0x9e7e,0x8db8,0x8deb, 0x8e05,0x8e59,0x8e69,0x8db5,
  0x8dbf,0x8dbc,0x8dba,0x8dc4, 0x8dd6,0x8dd7,0x8dda,0x8dde,
  0x8dce,0x8dcf,0x8ddb,0x8dc6, 0x8dec,0x8df7,0x8df8,0x8de3,
  0x8df9,0x8dfb,0x8de4,0x8e09, 0x8dfd,0x8e14,0x8e1d,0x8e1f,
  0x8e2c,0x8e2e,0x8e23,0x8e2f, 0x8e3a,0x8e40,0x8e39,0x0000,
  0x8e35,0x8e3d,0x8e31,0x8e49, 0x8e41,0x8e42,0x8e51,0x8e52,
  0x8e4a,0x8e70,0x8e76,0x8e7c, 0x8e6f,0x8e74,0x8e85,0x8e8f,
  0x8e94,0x8e90,0x8e9c,0x8e9e, 0x8c78,0x8c82,0x8c8a,0x8c85,
  0x8c98,0x8c94,0x659b,0x89d6, 0x89de,0x89da,0x89dc,0x89e5,
  0x89eb,0x89ef,0x8a3e,0x8b26, 0x9753,0x96e9,0x96f3,0x96ef,
  0x9706,0x9701,0x9708,0x970f, 0x970e,0x972a,0x972d,0x9730,
  0x973e,0x9f80,0x9f83,0x9f85, 0x9f86,0x9f87,0x9f88,0x9f89,
  0x9f8a,0x9f8c,0x9efe,0x9f0b, 0x9f0d,0x96b9,0x96bc,0x96bd,
  0x96ce,0x96d2,0x77bf,0x96e0, 0x928e,0x92ae,0x92c8,0x933e,
  0x936a,0x93ca,0x938f,0x943e, 0x946b,0x9c7f,0x9c82,0x9c85,
  0x9c86,0x9c87,0x9c88,0x7a23, 0x9c8b,0x9c8e,0x9c90,0x9c91,
  0x9c92,0x9c94,0x9c95,0x9c9a, 0x9c9b,0x9c9e,0x9c9f,0x9ca0,
  0x9ca1,0x9ca2,0x9ca3,0x9ca5, 0x9ca6,0x9ca7,0x9ca8,0x9ca9,
  0x9cab,0x9cad,0x9cae,0x9cb0, 0x9cb1,0x9cb2,0x9cb3,0x9cb4,
  0x9cb5,0x9cb6,0x9cb7,0x9cba, 0x9cbb,0x9cbc,0x9cbd,0x9cc4,
  0x9cc5,0x9cc6,0x9cc7,0x9cca, 0x9ccb,0x0000,
/* 0x6c41(i:8170) */
  0x9ccc,0x9ccd,0x9cce,0x9ccf, 0x9cd0,0x9cd3,0x9cd4,0x9cd5,
  0x9cd7,0x9cd8,0x9cd9,0x9cdc, 0x9cdd,0x9cdf,0x9ce2,0x977c,
  0x9785,0x9791,0x9792,0x9794, 0x97af,0x97ab,0x97a3,0x97b2,
  0x97b4,0x9ab1,0x9ab0,0x9ab7, 0x9e58,0x9ab6,0x9aba,0x9abc,
  0x9ac1,0x9ac0,0x9ac5,0x9ac2, 0x9acb,0x9acc,0x9ad1,0x9b45,
  0x9b43,0x9b47,0x9b49,0x9b48, 0x9b4d,0x9b51,0x98e8,0x990d,
  0x992e,0x9955,0x9954,0x9adf, 0x9ae1,0x9ae6,0x9aef,0x9aeb,
  0x9afb,0x9aed,0x9af9,0x9b08, 0x9b0f,0x9b13,0x9b1f,0x0000,
  0x9b23,0x9ebd,0x9ebe,0x7e3b, 0x9e82,0x9e87,0x9e88,0x9e8b,
  0x9e92,0x93d6,0x9e9d,0x9e9f, 0x9edb,0x9edc,0x9edd,0x9ee0,
  0x9edf,0x9ee2,0x9ee9,0x9ee7, 0x9ee5,0x9eea,0x9eef,0x9f22,
  0x9f2c,0x9f2f,0x9f39,0x9f37, 0x9f3d,0x9f3e,0x9f44,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x6d41(i:8360) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x6e41(i:8550) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x6f41(i:8740) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x7041(i:8930) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x7141(i:9120) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x7241(i:9310) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x7341(i:9500) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x7441(i:9690) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x7541(i:9880) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x7641(i:10070) */
  0xe000,0xe001,0xe002,0xe003, 0xe004,0xe005,0xe006,0xe007,
  0xe008,0xe009,0xe00a,0xe00b, 0xe00c,0xe00d,0xe00e,0xe00f,
  0xe010,0xe011,0xe012,0xe013, 0xe014,0xe015,0xe016,0xe017,
  0xe018,0xe019,0xe01a,0xe01b, 0xe01c,0xe01d,0xe01e,0xe01f,
  0xe020,0xe021,0xe022,0xe023, 0xe024,0xe025,0xe026,0xe027,
  0xe028,0xe029,0xe02a,0xe02b, 0xe02c,0xe02d,0xe02e,0xe02f,
  0xe030,0xe031,0xe032,0xe033, 0xe034,0xe035,0xe036,0xe037,
  0xe038,0xe039,0xe03a,0xe03b, 0xe03c,0xe03d,0xe03e,0x0000,
  0xe03f,0xe040,0xe041,0xe042, 0xe043,0xe044,0xe045,0xe046,
  0xe047,0xe048,0xe049,0xe04a, 0xe04b,0xe04c,0xe04d,0xe04e,
  0xe04f,0xe050,0xe051,0xe052, 0xe053,0xe054,0xe055,0xe056,
  0xe057,0xe058,0xe059,0xe05a, 0xe05b,0xe05c,0xe05d,0xe05e,
  0xe05f,0xe060,0xe061,0xe062, 0xe063,0xe064,0xe065,0xe066,
  0xe067,0xe068,0xe069,0xe06a, 0xe06b,0xe06c,0xe06d,0xe06e,
  0xe06f,0xe070,0xe071,0xe072, 0xe073,0xe074,0xe075,0xe076,
  0xe077,0xe078,0xe079,0xe07a, 0xe07b,0xe07c,0xe07d,0xe07e,
  0xe07f,0xe080,0xe081,0xe082, 0xe083,0xe084,0xe085,0xe086,
  0xe087,0xe088,0xe089,0xe08a, 0xe08b,0xe08c,0xe08d,0xe08e,
  0xe08f,0xe090,0xe091,0xe092, 0xe093,0xe094,0xe095,0xe096,
  0xe097,0xe098,0xe099,0xe09a, 0xe09b,0xe09c,0xe09d,0xe09e,
  0xe09f,0xe0a0,0xe0a1,0xe0a2, 0xe0a3,0xe0a4,0xe0a5,0xe0a6,
  0xe0a7,0xe0a8,0xe0a9,0xe0aa, 0xe0ab,0xe0ac,0xe0ad,0xe0ae,
  0xe0af,0xe0b0,0xe0b1,0xe0b2, 0xe0b3,0xe0b4,0xe0b5,0xe0b6,
  0xe0b7,0xe0b8,0xe0b9,0xe0ba, 0xe0bb,0x0000,
/* 0x7741(i:10260) */
  0xe0bc,0xe0bd,0xe0be,0xe0bf, 0xe0c0,0xe0c1,0xe0c2,0xe0c3,
  0xe0c4,0xe0c5,0xe0c6,0xe0c7, 0xe0c8,0xe0c9,0xe0ca,0xe0cb,
  0xe0cc,0xe0cd,0xe0ce,0xe0cf, 0xe0d0,0xe0d1,0xe0d2,0xe0d3,
  0xe0d4,0xe0d5,0xe0d6,0xe0d7, 0xe0d8,0xe0d9,0xe0da,0xe0db,
  0xe0dc,0xe0dd,0xe0de,0xe0df, 0xe0e0,0xe0e1,0xe0e2,0xe0e3,
  0xe0e4,0xe0e5,0xe0e6,0xe0e7, 0xe0e8,0xe0e9,0xe0ea,0xe0eb,
  0xe0ec,0xe0ed,0xe0ee,0xe0ef, 0xe0f0,0xe0f1,0xe0f2,0xe0f3,
  0xe0f4,0xe0f5,0xe0f6,0xe0f7, 0xe0f8,0xe0f9,0xe0fa,0x0000,
  0xe0fb,0xe0fc,0xe0fd,0xe0fe, 0xe0ff,0xe100,0xe101,0xe102,
  0xe103,0xe104,0xe105,0xe106, 0xe107,0xe108,0xe109,0xe10a,
  0xe10b,0xe10c,0xe10d,0xe10e, 0xe10f,0xe110,0xe111,0xe112,
  0xe113,0xe114,0xe115,0xe116, 0xe117,0xe118,0xe119,0xe11a,
  0xe11b,0xe11c,0xe11d,0xe11e, 0xe11f,0xe120,0xe121,0xe122,
  0xe123,0xe124,0xe125,0xe126, 0xe127,0xe128,0xe129,0xe12a,
  0xe12b,0xe12c,0xe12d,0xe12e, 0xe12f,0xe130,0xe131,0xe132,
  0xe133,0xe134,0xe135,0xe136, 0xe137,0xe138,0xe139,0xe13a,
  0xe13b,0xe13c,0xe13d,0xe13e, 0xe13f,0xe140,0xe141,0xe142,
  0xe143,0xe144,0xe145,0xe146, 0xe147,0xe148,0xe149,0xe14a,
  0xe14b,0xe14c,0xe14d,0xe14e, 0xe14f,0xe150,0xe151,0xe152,
  0xe153,0xe154,0xe155,0xe156, 0xe157,0xe158,0xe159,0xe15a,
  0xe15b,0xe15c,0xe15d,0xe15e, 0xe15f,0xe160,0xe161,0xe162,
  0xe163,0xe164,0xe165,0xe166, 0xe167,0xe168,0xe169,0xe16a,
  0xe16b,0xe16c,0xe16d,0xe16e, 0xe16f,0xe170,0xe171,0xe172,
  0xe173,0xe174,0xe175,0xe176, 0xe177,0x0000,
/* 0x7841(i:10450) */
  0xe178,0xe179,0xe17a,0xe17b, 0xe17c,0xe17d,0xe17e,0xe17f,
  0xe180,0xe181,0xe182,0xe183, 0xe184,0xe185,0xe186,0xe187,
  0xe188,0xe189,0xe18a,0xe18b, 0xe18c,0xe18d,0xe18e,0xe18f,
  0xe190,0xe191,0xe192,0xe193, 0xe194,0xe195,0xe196,0xe197,
  0xe198,0xe199,0xe19a,0xe19b, 0xe19c,0xe19d,0xe19e,0xe19f,
  0xe1a0,0xe1a1,0xe1a2,0xe1a3, 0xe1a4,0xe1a5,0xe1a6,0xe1a7,
  0xe1a8,0xe1a9,0xe1aa,0xe1ab, 0xe1ac,0xe1ad,0xe1ae,0xe1af,
  0xe1b0,0xe1b1,0xe1b2,0xe1b3, 0xe1b4,0xe1b5,0xe1b6,0x0000,
  0xe1b7,0xe1b8,0xe1b9,0xe1ba, 0xe1bb,0xe1bc,0xe1bd,0xe1be,
  0xe1bf,0xe1c0,0xe1c1,0xe1c2, 0xe1c3,0xe1c4,0xe1c5,0xe1c6,
  0xe1c7,0xe1c8,0xe1c9,0xe1ca, 0xe1cb,0xe1cc,0xe1cd,0xe1ce,
  0xe1cf,0xe1d0,0xe1d1,0xe1d2, 0xe1d3,0xe1d4,0xe1d5,0xe1d6,
  0xe1d7,0xe1d8,0xe1d9,0xe1da, 0xe1db,0xe1dc,0xe1dd,0xe1de,
  0xe1df,0xe1e0,0xe1e1,0xe1e2, 0xe1e3,0xe1e4,0xe1e5,0xe1e6,
  0xe1e7,0xe1e8,0xe1e9,0xe1ea, 0xe1eb,0xe1ec,0xe1ed,0xe1ee,
  0xe1ef,0xe1f0,0xe1f1,0xe1f2, 0xe1f3,0xe1f4,0xe1f5,0xe1f6,
  0xe1f7,0xe1f8,0xe1f9,0xe1fa, 0xe1fb,0xe1fc,0xe1fd,0xe1fe,
  0xe1ff,0xe200,0xe201,0xe202, 0xe203,0xe204,0xe205,0xe206,
  0xe207,0xe208,0xe209,0xe20a, 0xe20b,0xe20c,0xe20d,0xe20e,
  0xe20f,0xe210,0xe211,0xe212, 0xe213,0xe214,0xe215,0xe216,
  0xe217,0xe218,0xe219,0xe21a, 0xe21b,0xe21c,0xe21d,0xe21e,
  0xe21f,0xe220,0xe221,0xe222, 0xe223,0xe224,0xe225,0xe226,
  0xe227,0xe228,0xe229,0xe22a, 0xe22b,0xe22c,0xe22d,0xe22e,
  0xe22f,0xe230,0xe231,0xe232, 0xe233,0x0000,
/* 0x7941(i:10640) */
  0xe234,0xe235,0xe236,0xe237, 0xe238,0xe239,0xe23a,0xe23b,
  0xe23c,0xe23d,0xe23e,0xe23f, 0xe240,0xe241,0xe242,0xe243,
  0xe244,0xe245,0xe246,0xe247, 0xe248,0xe249,0xe24a,0xe24b,
  0xe24c,0xe24d,0xe24e,0xe24f, 0xe250,0xe251,0xe252,0xe253,
  0xe254,0xe255,0xe256,0xe257, 0xe258,0xe259,0xe25a,0xe25b,
  0xe25c,0xe25d,0xe25e,0xe25f, 0xe260,0xe261,0xe262,0xe263,
  0xe264,0xe265,0xe266,0xe267, 0xe268,0xe269,0xe26a,0xe26b,
  0xe26c,0xe26d,0xe26e,0xe26f, 0xe270,0xe271,0xe272,0x0000,
  0xe273,0xe274,0xe275,0xe276, 0xe277,0xe278,0xe279,0xe27a,
  0xe27b,0xe27c,0xe27d,0xe27e, 0xe27f,0xe280,0xe281,0xe282,
  0xe283,0xe284,0xe285,0xe286, 0xe287,0xe288,0xe289,0xe28a,
  0xe28b,0xe28c,0xe28d,0xe28e, 0xe28f,0xe290,0xe291,0xe292,
  0xe293,0xe294,0xe295,0xe296, 0xe297,0xe298,0xe299,0xe29a,
  0xe29b,0xe29c,0xe29d,0xe29e, 0xe29f,0xe2a0,0xe2a1,0xe2a2,
  0xe2a3,0xe2a4,0xe2a5,0xe2a6, 0xe2a7,0xe2a8,0xe2a9,0xe2aa,
  0xe2ab,0xe2ac,0xe2ad,0xe2ae, 0xe2af,0xe2b0,0xe2b1,0xe2b2,
  0xe2b3,0xe2b4,0xe2b5,0xe2b6, 0xe2b7,0xe2b8,0xe2b9,0xe2ba,
  0xe2bb,0xe2bc,0xe2bd,0xe2be, 0xe2bf,0xe2c0,0xe2c1,0xe2c2,
  0xe2c3,0xe2c4,0xe2c5,0xe2c6, 0xe2c7,0xe2c8,0xe2c9,0xe2ca,
  0xe2cb,0xe2cc,0xe2cd,0xe2ce, 0xe2cf,0xe2d0,0xe2d1,0xe2d2,
  0xe2d3,0xe2d4,0xe2d5,0xe2d6, 0xe2d7,0xe2d8,0xe2d9,0xe2da,
  0xe2db,0xe2dc,0xe2dd,0xe2de, 0xe2df,0xe2e0,0xe2e1,0xe2e2,
  0xe2e3,0xe2e4,0xe2e5,0xe2e6, 0xe2e7,0xe2e8,0xe2e9,0xe2ea,
  0xe2eb,0xe2ec,0xe2ed,0xe2ee, 0xe2ef,0x0000,
/* 0x7a41(i:10830) */
  0xe2f0,0xe2f1,0xe2f2,0xe2f3, 0xe2f4,0xe2f5,0xe2f6,0xe2f7,
  0xe2f8,0xe2f9,0xe2fa,0xe2fb, 0xe2fc,0xe2fd,0xe2fe,0xe2ff,
  0xe300,0xe301,0xe302,0xe303, 0xe304,0xe305,0xe306,0xe307,
  0xe308,0xe309,0xe30a,0xe30b, 0xe30c,0xe30d,0xe30e,0xe30f,
  0xe310,0xe311,0xe312,0xe313, 0xe314,0xe315,0xe316,0xe317,
  0xe318,0xe319,0xe31a,0xe31b, 0xe31c,0xe31d,0xe31e,0xe31f,
  0xe320,0xe321,0xe322,0xe323, 0xe324,0xe325,0xe326,0xe327,
  0xe328,0xe329,0xe32a,0xe32b, 0xe32c,0xe32d,0xe32e,0x0000,
  0xe32f,0xe330,0xe331,0xe332, 0xe333,0xe334,0xe335,0xe336,
  0xe337,0xe338,0xe339,0xe33a, 0xe33b,0xe33c,0xe33d,0xe33e,
  0xe33f,0xe340,0xe341,0xe342, 0xe343,0xe344,0xe345,0xe346,
  0xe347,0xe348,0xe349,0xe34a, 0xe34b,0xe34c,0xe34d,0xe34e,
  0xe34f,0xe350,0xe351,0xe352, 0xe353,0xe354,0xe355,0xe356,
  0xe357,0xe358,0xe359,0xe35a, 0xe35b,0xe35c,0xe35d,0xe35e,
  0xe35f,0xe360,0xe361,0xe362, 0xe363,0xe364,0xe365,0xe366,
  0xe367,0xe368,0xe369,0xe36a, 0xe36b,0xe36c,0xe36d,0xe36e,
  0xe36f,0xe370,0xe371,0xe372, 0xe373,0xe374,0xe375,0xe376,
  0xe377,0xe378,0xe379,0xe37a, 0xe37b,0xe37c,0xe37d,0xe37e,
  0xe37f,0xe380,0xe381,0xe382, 0xe383,0xe384,0xe385,0xe386,
  0xe387,0xe388,0xe389,0xe38a, 0xe38b,0xe38c,0xe38d,0xe38e,
  0xe38f,0xe390,0xe391,0xe392, 0xe393,0xe394,0xe395,0xe396,
  0xe397,0xe398,0xe399,0xe39a, 0xe39b,0xe39c,0xe39d,0xe39e,
  0xe39f,0xe3a0,0xe3a1,0xe3a2, 0xe3a3,0xe3a4,0xe3a5,0xe3a6,
  0xe3a7,0xe3a8,0xe3a9,0xe3aa, 0xe3ab,0x0000,
/* 0x7b41(i:11020) */
  0xe3ac,0xe3ad,0xe3ae,0xe3af, 0xe3b0,0xe3b1,0xe3b2,0xe3b3,
  0xe3b4,0xe3b5,0xe3b6,0xe3b7, 0xe3b8,0xe3b9,0xe3ba,0xe3bb,
  0xe3bc,0xe3bd,0xe3be,0xe3bf, 0xe3c0,0xe3c1,0xe3c2,0xe3c3,
  0xe3c4,0xe3c5,0xe3c6,0xe3c7, 0xe3c8,0xe3c9,0xe3ca,0xe3cb,
  0xe3cc,0xe3cd,0xe3ce,0xe3cf, 0xe3d0,0xe3d1,0xe3d2,0xe3d3,
  0xe3d4,0xe3d5,0xe3d6,0xe3d7, 0xe3d8,0xe3d9,0xe3da,0xe3db,
  0xe3dc,0xe3dd,0xe3de,0xe3df, 0xe3e0,0xe3e1,0xe3e2,0xe3e3,
  0xe3e4,0xe3e5,0xe3e6,0xe3e7, 0xe3e8,0xe3e9,0xe3ea,0x0000,
  0xe3eb,0xe3ec,0xe3ed,0xe3ee, 0xe3ef,0xe3f0,0xe3f1,0xe3f2,
  0xe3f3,0xe3f4,0xe3f5,0xe3f6, 0xe3f7,0xe3f8,0xe3f9,0xe3fa,
  0xe3fb,0xe3fc,0xe3fd,0xe3fe, 0xe3ff,0xe400,0xe401,0xe402,
  0xe403,0xe404,0xe405,0xe406, 0xe407,0xe408,0xe409,0xe40a,
  0xe40b,0xe40c,0xe40d,0xe40e, 0xe40f,0xe410,0xe411,0xe412,
  0xe413,0xe414,0xe415,0xe416, 0xe417,0xe418,0xe419,0xe41a,
  0xe41b,0xe41c,0xe41d,0xe41e, 0xe41f,0xe420,0xe421,0xe422,
  0xe423,0xe424,0xe425,0xe426, 0xe427,0xe428,0xe429,0xe42a,
  0xe42b,0xe42c,0xe42d,0xe42e, 0xe42f,0xe430,0xe431,0xe432,
  0xe433,0xe434,0xe435,0xe436, 0xe437,0xe438,0xe439,0xe43a,
  0xe43b,0xe43c,0xe43d,0xe43e, 0xe43f,0xe440,0xe441,0xe442,
  0xe443,0xe444,0xe445,0xe446, 0xe447,0xe448,0xe449,0xe44a,
  0xe44b,0xe44c,0xe44d,0xe44e, 0xe44f,0xe450,0xe451,0xe452,
  0xe453,0xe454,0xe455,0xe456, 0xe457,0xe458,0xe459,0xe45a,
  0xe45b,0xe45c,0xe45d,0xe45e, 0xe45f,0xe460,0xe461,0xe462,
  0xe463,0xe464,0xe465,0xe466, 0xe467,0x0000,
/* 0x7c41(i:11210) */
  0xe468,0xe469,0xe46a,0xe46b, 0xe46c,0xe46d,0xe46e,0xe46f,
  0xe470,0xe471,0xe472,0xe473, 0xe474,0xe475,0xe476,0xe477,
  0xe478,0xe479,0xe47a,0xe47b, 0xe47c,0xe47d,0xe47e,0xe47f,
  0xe480,0xe481,0xe482,0xe483, 0xe484,0xe485,0xe486,0xe487,
  0xe488,0xe489,0xe48a,0xe48b, 0xe48c,0xe48d,0xe48e,0xe48f,
  0xe490,0xe491,0xe492,0xe493, 0xe494,0xe495,0xe496,0xe497,
  0xe498,0xe499,0xe49a,0xe49b, 0xe49c,0xe49d,0xe49e,0xe49f,
  0xe4a0,0xe4a1,0xe4a2,0xe4a3, 0xe4a4,0xe4a5,0xe4a6,0x0000,
  0xe4a7,0xe4a8,0xe4a9,0xe4aa, 0xe4ab,0xe4ac,0xe4ad,0xe4ae,
  0xe4af,0xe4b0,0xe4b1,0xe4b2, 0xe4b3,0xe4b4,0xe4b5,0xe4b6,
  0xe4b7,0xe4b8,0xe4b9,0xe4ba, 0xe4bb,0xe4bc,0xe4bd,0xe4be,
  0xe4bf,0xe4c0,0xe4c1,0xe4c2, 0xe4c3,0xe4c4,0xe4c5,0xe4c6,
  0xe4c7,0xe4c8,0xe4c9,0xe4ca, 0xe4cb,0xe4cc,0xe4cd,0xe4ce,
  0xe4cf,0xe4d0,0xe4d1,0xe4d2, 0xe4d3,0xe4d4,0xe4d5,0xe4d6,
  0xe4d7,0xe4d8,0xe4d9,0xe4da, 0xe4db,0xe4dc,0xe4dd,0xe4de,
  0xe4df,0xe4e0,0xe4e1,0xe4e2, 0xe4e3,0xe4e4,0xe4e5,0xe4e6,
  0xe4e7,0xe4e8,0xe4e9,0xe4ea, 0xe4eb,0xe4ec,0xe4ed,0xe4ee,
  0xe4ef,0xe4f0,0xe4f1,0xe4f2, 0xe4f3,0xe4f4,0xe4f5,0xe4f6,
  0xe4f7,0xe4f8,0xe4f9,0xe4fa, 0xe4fb,0xe4fc,0xe4fd,0xe4fe,
  0xe4ff,0xe500,0xe501,0xe502, 0xe503,0xe504,0xe505,0xe506,
  0xe507,0xe508,0xe509,0xe50a, 0xe50b,0xe50c,0xe50d,0xe50e,
  0xe50f,0xe510,0xe511,0xe512, 0xe513,0xe514,0xe515,0xe516,
  0xe517,0xe518,0xe519,0xe51a, 0xe51b,0xe51c,0xe51d,0xe51e,
  0xe51f,0xe520,0xe521,0xe522, 0xe523,0x0000,
/* 0x7d41(i:11400) */
  0xe524,0xe525,0xe526,0xe527, 0xe528,0xe529,0xe52a,0xe52b,
  0xe52c,0xe52d,0xe52e,0xe52f, 0xe530,0xe531,0xe532,0xe533,
  0xe534,0xe535,0xe536,0xe537, 0xe538,0xe539,0xe53a,0xe53b,
  0xe53c,0xe53d,0xe53e,0xe53f, 0xe540,0xe541,0xe542,0xe543,
  0xe544,0xe545,0xe546,0xe547, 0xe548,0xe549,0xe54a,0xe54b,
  0xe54c,0xe54d,0xe54e,0xe54f, 0xe550,0xe551,0xe552,0xe553,
  0xe554,0xe555,0xe556,0xe557, 0xe558,0xe559,0xe55a,0xe55b,
  0xe55c,0xe55d,0xe55e,0xe55f, 0xe560,0xe561,0xe562,0x0000,
  0xe563,0xe564,0xe565,0xe566, 0xe567,0xe568,0xe569,0xe56a,
  0xe56b,0xe56c,0xe56d,0xe56e, 0xe56f,0xe570,0xe571,0xe572,
  0xe573,0xe574,0xe575,0xe576, 0xe577,0xe578,0xe579,0xe57a,
  0xe57b,0xe57c,0xe57d,0xe57e, 0xe57f,0xe580,0xe581,0xe582,
  0xe583,0xe584,0xe585,0xe586, 0xe587,0xe588,0xe589,0xe58a,
  0xe58b,0xe58c,0xe58d,0xe58e, 0xe58f,0xe590,0xe591,0xe592,
  0xe593,0xe594,0xe595,0xe596, 0xe597,0xe598,0xe599,0xe59a,
  0xe59b,0xe59c,0xe59d,0xe59e, 0xe59f,0xe5a0,0xe5a1,0xe5a2,
  0xe5a3,0xe5a4,0xe5a5,0xe5a6, 0xe5a7,0xe5a8,0xe5a9,0xe5aa,
  0xe5ab,0xe5ac,0xe5ad,0xe5ae, 0xe5af,0xe5b0,0xe5b1,0xe5b2,
  0xe5b3,0xe5b4,0xe5b5,0xe5b6, 0xe5b7,0xe5b8,0xe5b9,0xe5ba,
  0xe5bb,0xe5bc,0xe5bd,0xe5be, 0xe5bf,0xe5c0,0xe5c1,0xe5c2,
  0xe5c3,0xe5c4,0xe5c5,0xe5c6, 0xe5c7,0xe5c8,0xe5c9,0xe5ca,
  0xe5cb,0xe5cc,0xe5cd,0xe5ce, 0xe5cf,0xe5d0,0xe5d1,0xe5d2,
  0xe5d3,0xe5d4,0xe5d5,0xe5d6, 0xe5d7,0xe5d8,0xe5d9,0xe5da,
  0xe5db,0xe5dc,0xe5dd,0xe5de, 0xe5df,0x0000,
/* 0x7e41(i:11590) */
  0xe5e0,0xe5e1,0xe5e2,0xe5e3, 0xe5e4,0xe5e5,0xe5e6,0xe5e7,
  0xe5e8,0xe5e9,0xe5ea,0xe5eb, 0xe5ec,0xe5ed,0xe5ee,0xe5ef,
  0xe5f0,0xe5f1,0xe5f2,0xe5f3, 0xe5f4,0xe5f5,0xe5f6,0xe5f7,
  0xe5f8,0xe5f9,0xe5fa,0xe5fb, 0xe5fc,0xe5fd,0xe5fe,0xe5ff,
  0xe600,0xe601,0xe602,0xe603, 0xe604,0xe605,0xe606,0xe607,
  0xe608,0xe609,0xe60a,0xe60b, 0xe60c,0xe60d,0xe60e,0xe60f,
  0xe610,0xe611,0xe612,0xe613, 0xe614,0xe615,0xe616,0xe617,
  0xe618,0xe619,0xe61a,0xe61b, 0xe61c,0xe61d,0xe61e,0x0000,
  0xe61f,0xe620,0xe621,0xe622, 0xe623,0xe624,0xe625,0xe626,
  0xe627,0xe628,0xe629,0xe62a, 0xe62b,0xe62c,0xe62d,0xe62e,
  0xe62f,0xe630,0xe631,0xe632, 0xe633,0xe634,0xe635,0xe636,
  0xe637,0xe638,0xe639,0xe63a, 0xe63b,0xe63c,0xe63d,0xe63e,
  0xe63f,0xe640,0xe641,0xe642, 0xe643,0xe644,0xe645,0xe646,
  0xe647,0xe648,0xe649,0xe64a, 0xe64b,0xe64c,0xe64d,0xe64e,
  0xe64f,0xe650,0xe651,0xe652, 0xe653,0xe654,0xe655,0xe656,
  0xe657,0xe658,0xe659,0xe65a, 0xe65b,0xe65c,0xe65d,0xe65e,
  0xe65f,0xe660,0xe661,0xe662, 0xe663,0xe664,0xe665,0xe666,
  0xe667,0xe668,0xe669,0xe66a, 0xe66b,0xe66c,0xe66d,0xe66e,
  0xe66f,0xe670,0xe671,0xe672, 0xe673,0xe674,0xe675,0xe676,
  0xe677,0xe678,0xe679,0xe67a, 0xe67b,0xe67c,0xe67d,0xe67e,
  0xe67f,0xe680,0xe681,0xe682, 0xe683,0xe684,0xe685,0xe686,
  0xe687,0xe688,0xe689,0xe68a, 0xe68b,0xe68c,0xe68d,0xe68e,
  0xe68f,0xe690,0xe691,0xe692, 0xe693,0xe694,0xe695,0xe696,
  0xe697,0xe698,0xe699,0xe69a, 0xe69b,0x0000,
/* 0x7f41(i:11780) */
  0xe69c,0xe69d,0xe69e,0xe69f, 0xe6a0,0xe6a1,0xe6a2,0xe6a3,
  0xe6a4,0xe6a5,0xe6a6,0xe6a7, 0xe6a8,0xe6a9,0xe6aa,0xe6ab,
  0xe6ac,0xe6ad,0xe6ae,0xe6af, 0xe6b0,0xe6b1,0xe6b2,0xe6b3,
  0xe6b4,0xe6b5,0xe6b6,0xe6b7, 0xe6b8,0xe6b9,0xe6ba,0xe6bb,
  0xe6bc,0xe6bd,0xe6be,0xe6bf, 0xe6c0,0xe6c1,0xe6c2,0xe6c3,
  0xe6c4,0xe6c5,0xe6c6,0xe6c7, 0xe6c8,0xe6c9,0xe6ca,0xe6cb,
  0xe6cc,0xe6cd,0xe6ce,0xe6cf, 0xe6d0,0xe6d1,0xe6d2,0xe6d3,
  0xe6d4,0xe6d5,0xe6d6,0xe6d7, 0xe6d8,0xe6d9,0xe6da,0x0000,
  0xe6db,0xe6dc,0xe6dd,0xe6de, 0xe6df,0xe6e0,0xe6e1,0xe6e2,
  0xe6e3,0xe6e4,0xe6e5,0xe6e6, 0xe6e7,0xe6e8,0xe6e9,0xe6ea,
  0xe6eb,0xe6ec,0xe6ed,0xe6ee, 0xe6ef,0xe6f0,0xe6f1,0xe6f2,
  0xe6f3,0xe6f4,0xe6f5,0xe6f6, 0xe6f7,0xe6f8,0xe6f9,0xe6fa,
  0xe6fb,0xe6fc,0xe6fd,0xe6fe, 0xe6ff,0xe700,0xe701,0xe702,
  0xe703,0xe704,0xe705,0xe706, 0xe707,0xe708,0xe709,0xe70a,
  0xe70b,0xe70c,0xe70d,0xe70e, 0xe70f,0xe710,0xe711,0xe712,
  0xe713,0xe714,0xe715,0xe716, 0xe717,0xe718,0xe719,0xe71a,
  0xe71b,0xe71c,0xe71d,0xe71e, 0xe71f,0xe720,0xe721,0xe722,
  0xe723,0xe724,0xe725,0xe726, 0xe727,0xe728,0xe729,0xe72a,
  0xe72b,0xe72c,0xe72d,0xe72e, 0xe72f,0xe730,0xe731,0xe732,
  0xe733,0xe734,0xe735,0xe736, 0xe737,0xe738,0xe739,0xe73a,
  0xe73b,0xe73c,0xe73d,0xe73e, 0xe73f,0xe740,0xe741,0xe742,
  0xe743,0xe744,0xe745,0xe746, 0xe747,0xe748,0xe749,0xe74a,
  0xe74b,0xe74c,0xe74d,0xe74e, 0xe74f,0xe750,0xe751,0xe752,
  0xe753,0xe754,0xe755,0xe756, 0xe757,0x0000
};

unsigned short uni_t_ibm937[30970] = {
/* EBCDIK traditional chinese - codelimit: 30970 */
/* 0x4100(i:0) */
  0x03b1,0x03b2,0x03b3,0x03b4, 0x03b5,0x03b6,0x03b7,0x03b8,
  0x03b9,0x03ba,0x03bb,0x03bc, 0x03bd,0x03be,0x03bf,0x03c0,
  0x03c1,0x03c3,0x03c4,0x03c5, 0x03c6,0x03c7,0x03c8,0x03c9,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0391,0x0392,0x0393,0x0394, 0x0395,0x0396,0x0397,0x0398,
  0x0399,0x039a,0x039b,0x039c, 0x039d,0x039e,0x039f,0x03a0,
  0x03a1,0x03a3,0x03a4,0x03a5, 0x03a6,0x03a7,0x03a8,0x03a9,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0430,
  0x0431,0x0432,0x0433,0x0434, 0x0435,0x0451,0x0436,0x0437,
  0x0438,0x0439,0x043a,0x043b, 0x043c,0x043d,0x043e,0x043f,
  0x0440,0x0441,0x0442,0x0443, 0x0444,0x0445,0x0446,0x0447,
  0x0448,0x0449,0x044a,0x044b, 0x044c,0x044d,0x044e,0x044f,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x2170,0x2171,0x2172,0x2173, 0x2174,0x2175,0x2176,0x2177,
  0x2178,0x2179,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0410,
  0x0411,0x0412,0x0413,0x0414, 0x0415,0x0401,0x0416,0x0417,
  0x0418,0x0419,0x041a,0x041b, 0x041c,0x041d,0x041e,0x041f,
  0x0420,0x0421,0x0422,0x0423, 0x0424,0x0425,0x0426,0x0427,
  0x0428,0x0429,0x042a,0x042b, 0x042c,0x042d,0x042e,0x042f,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x2160,0x2161,0x2162,0x2163, 0x2164,0x2165,0x2166,0x2167,
  0x2168,0x2169,0x0000,0x0000, 0x0000,0x0000,
/* 0x4241(i:190) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0xffe1,0xff0e,0xff1c, 0xff08,0xff0b,0xff5c,0xff06,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0xff01,0xffe5,0x273d, 0xff09,0xff1b,0xffe2,0xff0d,
  0xff0f,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0xffe4,0xff0c,0xff05, 0xff3f,0xff1e,0xff1f,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x2035,0xff1a,0xff03,0xff20, 0xff07,0xff1d,0xff02,0x0000,
  0xff41,0xff42,0xff43,0xff44, 0xff45,0xff46,0xff47,0xff48,
  0xff49,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xff4a,0xff4b,0xff4c,0xff4d, 0xff4e,0xff4f,0xff50,0xff51,
  0xff52,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x203e,0xff53,0xff54,0xff55, 0xff56,0xff57,0xff58,0xff59,
  0xff5a,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0xff5b,
  0xff21,0xff22,0xff23,0xff24, 0xff25,0xff26,0xff27,0xff28,
  0xff29,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0xff5d,
  0xff2a,0xff2b,0xff2c,0xff2d, 0xff2e,0xff2f,0xff30,0xff31,
  0xff32,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0xff04,
  0x0000,0xff33,0xff34,0xff35, 0xff36,0xff37,0xff38,0xff39,
  0xff3a,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0xff10,
  0xff11,0xff12,0xff13,0xff14, 0xff15,0xff16,0xff17,0xff18,
  0xff19,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x4341(i:380) */
  0x3002,0x300c,0x300d,0x3001, 0x2027,0x30f2,0x30a1,0x30a3,
  0x30a5,0xffe0,0x0000,0x0000, 0x2312,0x2202,0x2207,0x0000,
  0x30a7,0x30a9,0x30e3,0x30e5, 0x30e7,0x30c3,0x30ee,0x30fc,
  0x30f5,0x30f6,0x0000,0x0000, 0x226a,0x226b,0x0000,0x223d,
  0x221d,0x0000,0x222c,0x2208, 0x220b,0x2286,0x2287,0x2282,
  0x2283,0x0000,0x0000,0x2227, 0x2228,0x21d2,0x21d4,0x2200,
  0x2203,0x212b,0x2030,0x266f, 0x266d,0x266a,0x2020,0x2021,
  0x00b6,0x25ef,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x30a2,0x30a4,0x30a6,0x30a8, 0x30aa,0x30ab,0x30ad,0x30af,
  0x30b1,0x30b3,0x0000,0x30b5, 0x30b7,0x30b9,0x30bb,0x30bd,
  0x30bf,0x30c1,0x30c4,0x30c6, 0x30c8,0x30ca,0x30cb,0x30cc,
  0x30cd,0x30ce,0x0000,0x0000, 0x30cf,0x30d2,0x30d5,0x0000,
  0xff5e,0x30d8,0x30db,0x30de, 0x30df,0x30e0,0x30e1,0x30e2,
  0x30e4,0x30e6,0x0000,0x30e8, 0x30e9,0x30ea,0x30eb,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x2501,0x2503,
  0x250f,0x30ec,0x30ed,0x30ef, 0x30f3,0x309b,0x309c,0x30ac,
  0x30ae,0x30b0,0x30b2,0x30b4, 0x30b6,0x30b8,0x30ba,0x30bc,
  0x30be,0x30c0,0x30c2,0x30c5, 0x30c7,0x30c9,0x30d0,0x30d3,
  0x30d6,0x30d9,0x30dc,0x30f4, 0x30d1,0x30d4,0x30d7,0x30da,
  0x30dd,0x30f0,0x30f1,0x30fd, 0x30fe,0x0000,0x0000,0xff3c,
  0x2513,0x251b,0x2517,0x2523, 0x2533,0x252b,0x253b,0x254b,
  0x2520,0x252f,0x2528,0x2537, 0x253f,0x251d,0x2530,0x2525,
  0x2538,0x2542,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x4441(i:570) */
  0x0000,0x300e,0x300f,0xff3b, 0xff3d,0x3092,0x3041,0x3043,
  0x3045,0x2014,0x00b1,0x2260, 0x221e,0x2103,0x0000,0x2032,
  0x3047,0x3049,0x3083,0x3085, 0x3087,0x3063,0x308e,0x0000,
  0x0000,0x2010,0x02ba,0xf83e, 0x3005,0x3006,0x3007,0x00a8,
  0x2018,0x201c,0x3014,0x3008, 0x300a,0x3010,0x2266,0x2234,
  0x2642,0x00a7,0x203b,0x3012, 0x3231,0x2116,0x2121,0xff3e,
  0x2019,0x201d,0x3015,0x3009, 0x300b,0x3011,0x2267,0x2235,
  0x2640,0x00d7,0x00f7,0x2225, 0x3013,0x2025,0x2026,0x0000,
  0x3042,0x3044,0x3046,0x3048, 0x304a,0x304b,0x304d,0x304f,
  0x3051,0x3053,0x0000,0x3055, 0x3057,0x3059,0x305b,0x305d,
  0x305f,0x3061,0x3064,0x3066, 0x3068,0x306a,0x306b,0x306c,
  0x306d,0x306e,0x0000,0x0000, 0x306f,0x3072,0x3075,0x0000,
  0x0000,0x3078,0x307b,0x307e, 0x307f,0x3080,0x3081,0x3082,
  0x3084,0x3086,0x0000,0x3088, 0x3089,0x308a,0x308b,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x308c,0x308d,0x308f, 0x3093,0x0000,0x0000,0x304c,
  0x304e,0x3050,0x3052,0x3054, 0x3056,0x3058,0x305a,0x305c,
  0x305e,0x3060,0x3062,0x3065, 0x3067,0x3069,0x3070,0x3073,
  0x3076,0x3079,0x307c,0x0000, 0x3071,0x3074,0x3077,0x307a,
  0x307d,0x3090,0x3091,0x309d, 0x309e,0x0000,0x0000,0x25cb,
  0x25cf,0x25b3,0x25b2,0x25ce, 0x2606,0x2605,0x25c7,0x25c6,
  0x25a1,0x25a0,0x25bd,0x25bc, 0x00b0,0x00b4,0x2033,0x2192,
  0x2190,0x2191,0x2193,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x4541(i:760) */
  0x3021,0x3022,0x3023,0x3024, 0x3025,0x3026,0x3027,0x3028,
  0x3029,0x5341,0x5344,0x5345, 0x0000,0x0000,0x0000,0x0000,
  0x02c9,0x02ca,0x02c7,0x02cb, 0x02d9,0x3105,0x3106,0x3107,
  0x3108,0x3109,0x310a,0x310b, 0x310c,0x310d,0x310e,0x310f,
  0x3110,0x3111,0x3112,0x3113, 0x3114,0x3115,0x3116,0x3117,
  0x3118,0x3119,0x311a,0x311b, 0x311c,0x311d,0x311e,0x311f,
  0x3120,0x3121,0x3122,0x3123, 0x3124,0x3125,0x3126,0x3127,
  0x3128,0x3129,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x4641(i:950) */
  0x2460,0x2461,0x2462,0x2463, 0x2464,0x2465,0x2466,0x2467,
  0x2468,0x2469,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x2474,0x2475,0x2476,0x2477, 0x2478,0x2479,0x247a,0x247b,
  0x247c,0x247d,0x0000,0x0000, 0x0000,0x0000,0x0000,0x2581,
  0x2582,0x2583,0x2584,0x2585, 0x2586,0x2587,0x2588,0x258f,
  0x258e,0x258d,0x258c,0x258b, 0x258a,0x2589,0x253c,0x2534,
  0x252c,0x2524,0x251c,0x2594, 0x2500,0x2502,0x2595,0x250c,
  0x2510,0x2514,0x2518,0x256d, 0x256e,0x2570,0x256f,0x0000,
  0x2550,0x255e,0x256a,0x2561, 0x25e2,0x25e3,0x25e5,0x25e4,
  0x2571,0x2572,0x2573,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0xfe41,
  0xfe42,0xfe43,0xfe44,0xfe3b, 0xfe3c,0x0000,0xfe31,0xf83f,
  0xf840,0xf841,0xf842,0xfe35, 0xfe36,0xfe37,0xfe38,0xfe39,
  0xfe3a,0xfe3d,0xfe3e,0xfe3f, 0xfe40,0xfe33,0x2574,0xff0a,
  0x3003,0x32a3,0x2105,0xfe34, 0xfe4f,0xfe49,0xfe4a,0xfe4d,
  0xfe4e,0xfe4b,0xfe4c,0xfe61, 0x221a,0x2252,0x2261,0x2229,
  0x222a,0x22a5,0x2220,0x221f, 0x22bf,0x33d2,0x33d1,0x222b,
  0x222e,0x2295,0x2299,0x2196, 0x2197,0x2199,0x2198,0x0000,
  0x0000,0x2215,0x2109,0x33d5, 0x339c,0x339d,0x339e,0x33ce,
  0x33a1,0x338e,0x338f,0x33c4, 0x00b7,0x0000,0x0000,0x0000,
  0x301d,0x301e,0x0000,0x0000, 0x0000,0x21e7,0x21b8,0x21b9,
  0x5159,0x515b,0x515e,0x515d, 0x5161,0x5163,0x55e7,0x74e9,
  0x7cce,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x4741(i:1140) */
  0xfe30,0xfe50,0xfe51,0xfe52, 0xfe54,0xfe55,0xfe56,0xfe57,
  0xfe32,0xfe58,0xfe59,0xfe5a, 0xfe5b,0xfe5c,0xfe5d,0xfe5e,
  0xffe3,0x02cd,0xfe5f,0xfe60, 0xfe62,0xfe63,0xfe64,0xfe65,
  0xfe66,0xfe68,0xfe69,0xfe6a, 0xfe6b,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x2400,0x2401,0x2402,0x2403, 0x2404,0x2405,0x2406,0x2407,
  0x2408,0x2409,0x240a,0x240b, 0x240c,0x240d,0x240e,0x240f,
  0x2410,0x2411,0x2412,0x2413, 0x2414,0x2415,0x2416,0x2417,
  0x2418,0x2419,0x241a,0x241b, 0x241c,0x241d,0x241e,0x241f,
  0x2421,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x4841(i:1330) */
  0x4e00,0x4e28,0x4e36,0x4e3f, 0x4e59,0x4e85,0x4e8c,0x4ea0,
  0x4eba,0x513f,0x5165,0x516b, 0x5182,0x5196,0x51ab,0x51e0,
  0x51f5,0x5200,0x529b,0x52f9, 0x5315,0x531a,0x5338,0x5341,
  0x535c,0x5369,0x5382,0x53b6, 0x53c8,0x53e3,0x56d7,0x571f,
  0x58eb,0x590a,0x5915,0x5927, 0x5973,0x5b50,0x5b80,0x5bf8,
  0x5c0f,0x5c22,0x5c38,0x5c6e, 0x5c71,0x5ddb,0x5de5,0x5df1,
  0x5dfe,0x5e72,0x5e7a,0x5e7f, 0x5ef4,0x5efe,0x5f0b,0x5f13,
  0x5f50,0x5f61,0x5f73,0x5fc3, 0x6208,0x6236,0x624b,0x0000,
  0x652f,0x6534,0x6587,0x6597, 0x65a4,0x65b9,0x65e0,0x65e5,
  0x66f0,0x6708,0x6728,0x6b20, 0x6b62,0x6b79,0x6bb3,0x6bcb,
  0x6bd4,0x6bdb,0x6c0f,0x6c14, 0x6c34,0x706b,0x722a,0x7236,
  0x723b,0x723f,0x7247,0x7259, 0x725b,0x72ac,0x7384,0x7389,
  0x74dc,0x74e6,0x7518,0x751f, 0x7528,0x7530,0x758b,0x7592,
  0x7676,0x767d,0x76ae,0x76bf, 0x76ee,0x77db,0x77e2,0x77f3,
  0x793a,0x79b8,0x79be,0x7a74, 0x7acb,0x7af9,0x7c73,0x7cf8,
  0x7f36,0x7f51,0x7f8a,0x7fbd, 0x8001,0x800c,0x8012,0x8033,
  0x807f,0x8089,0x81e3,0x81ea, 0x81f3,0x81fc,0x820c,0x821b,
  0x821f,0x826e,0x8272,0x8278, 0x864d,0x866b,0x8840,0x884c,
  0x8863,0x897e,0x898b,0x89d2, 0x8a00,0x8c37,0x8c46,0x8c55,
  0x8c78,0x8c9d,0x8d64,0x8d70, 0x8db3,0x8eab,0x8eca,0x8f9b,
  0x8fb0,0x8fb5,0x9091,0x9149, 0x91c6,0x91cc,0x91d1,0x9577,
  0x9580,0x961c,0x96b6,0x96b9, 0x96e8,0x9752,0x975e,0x9762,
  0x9769,0x97cb,0x97ed,0x97f3, 0x9801,0x98a8,0x98db,0x98df,
  0x9996,0x9999,0x99ac,0x9aa8, 0x9ad8,0x0000,
/* 0x4941(i:1520) */
  0x9adf,0x9b25,0x9b2f,0x9b32, 0x9b3c,0x9b5a,0x9ce5,0x9e75,
  0x9e7f,0x9ea5,0x9ebb,0x9ec3, 0x9ecd,0x9ed1,0x9ef9,0x9efd,
  0x9f0e,0x9f13,0x9f20,0x9f3b, 0x9f4a,0x9f52,0x9f8d,0x9f9c,
  0x9fa0,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x4a41(i:1710) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x4b41(i:1900) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x4c41(i:2090) */
  0x4e00,0x4e59,0x4e01,0x4e03, 0x4e43,0x4e5d,0x4e86,0x4e8c,
  0x4eba,0x513f,0x5165,0x516b, 0x51e0,0x5200,0x5201,0x529b,
  0x5315,0x5341,0x535c,0x53c8, 0x4e09,0x4e0b,0x4e08,0x4e0a,
  0x4e2b,0x4e38,0x51e1,0x4e45, 0x4e48,0x4e5f,0x4e5e,0x4e8e,
  0x4ea1,0x5140,0x5203,0x52fa, 0x5343,0x53c9,0x53e3,0x571f,
  0x58eb,0x5915,0x5927,0x5973, 0x5b50,0x5b51,0x5b53,0x5bf8,
  0x5c0f,0x5c22,0x5c38,0x5c71, 0x5ddd,0x5de5,0x5df1,0x5df2,
  0x5df3,0x5dfe,0x5e72,0x5efe, 0x5f0b,0x5f13,0x624d,0x0000,
  0x4e11,0x4e10,0x4e0d,0x4e2d, 0x4e30,0x4e39,0x4e4b,0x5c39,
  0x4e88,0x4e91,0x4e95,0x4e92, 0x4e94,0x4ea2,0x4ec1,0x4ec0,
  0x4ec3,0x4ec6,0x4ec7,0x4ecd, 0x4eca,0x4ecb,0x4ec4,0x5143,
  0x5141,0x5167,0x516d,0x516e, 0x516c,0x5197,0x51f6,0x5206,
  0x5207,0x5208,0x52fb,0x52fe, 0x52ff,0x5316,0x5339,0x5348,
  0x5347,0x5345,0x535e,0x5384, 0x53cb,0x53ca,0x53cd,0x58ec,
  0x5929,0x592b,0x592a,0x592d, 0x5b54,0x5c11,0x5c24,0x5c3a,
  0x5c6f,0x5df4,0x5e7b,0x5eff, 0x5f14,0x5f15,0x5fc3,0x6208,
  0x6236,0x624b,0x624e,0x652f, 0x6587,0x6597,0x65a4,0x65b9,
  0x65e5,0x66f0,0x6708,0x6728, 0x6b20,0x6b62,0x6b79,0x6bcb,
  0x6bd4,0x6bdb,0x6c0f,0x6c34, 0x706b,0x722a,0x7236,0x723b,
  0x7247,0x7259,0x725b,0x72ac, 0x738b,0x4e19,0x4e16,0x4e15,
  0x4e14,0x4e18,0x4e3b,0x4e4d, 0x4e4f,0x4e4e,0x4ee5,0x4ed8,
  0x4ed4,0x4ed5,0x4ed6,0x4ed7, 0x4ee3,0x4ee4,0x4ed9,0x4ede,
  0x5145,0x5144,0x5189,0x518a, 0x51ac,0x51f9,0x51fa,0x51f8,
  0x520a,0x52a0,0x529f,0x5305, 0x5306,0x0000,
/* 0x4d41(i:2280) */
  0x5317,0x531d,0x4edf,0x534a, 0x5349,0x5361,0x5360,0x536f,
  0x536e,0x53bb,0x53ef,0x53e4, 0x53f3,0x53ec,0x53ee,0x53e9,
  0x53e8,0x53fc,0x53f8,0x53f5, 0x53eb,0x53e6,0x53ea,0x53f2,
  0x53f1,0x53f0,0x53e5,0x53ed, 0x53fb,0x56db,0x56da,0x5916,
  0x592e,0x5931,0x5974,0x5976, 0x5b55,0x5b83,0x5c3c,0x5de8,
  0x5de7,0x5de6,0x5e02,0x5e03, 0x5e73,0x5e7c,0x5f01,0x5f18,
  0x5f17,0x5fc5,0x620a,0x6253, 0x6254,0x6252,0x6251,0x65a5,
  0x65e6,0x672e,0x672c,0x672a, 0x672b,0x672d,0x6b63,0x0000,
  0x6bcd,0x6c11,0x6c10,0x6c38, 0x6c41,0x6c40,0x6c3e,0x72af,
  0x7384,0x7389,0x74dc,0x74e6, 0x7518,0x751f,0x7528,0x7529,
  0x7530,0x7531,0x7532,0x7533, 0x758b,0x767d,0x76ae,0x76bf,
  0x76ee,0x77db,0x77e2,0x77f3, 0x793a,0x79be,0x7a74,0x7acb,
  0x4e1e,0x4e1f,0x4e52,0x4e53, 0x4e69,0x4e99,0x4ea4,0x4ea6,
  0x4ea5,0x4eff,0x4f09,0x4f19, 0x4f0a,0x4f15,0x4f0d,0x4f10,
  0x4f11,0x4f0f,0x4ef2,0x4ef6, 0x4efb,0x4ef0,0x4ef3,0x4efd,
  0x4f01,0x4f0b,0x5149,0x5147, 0x5146,0x5148,0x5168,0x5171,
  0x518d,0x51b0,0x5217,0x5211, 0x5212,0x520e,0x5216,0x52a3,
  0x5308,0x5321,0x5320,0x5370, 0x5371,0x5409,0x540f,0x540c,
  0x540a,0x5410,0x5401,0x540b, 0x5404,0x5411,0x540d,0x5408,
  0x5403,0x540e,0x5406,0x5412, 0x56e0,0x56de,0x56dd,0x5733,
  0x5730,0x5728,0x572d,0x572c, 0x572f,0x5729,0x5919,0x591a,
  0x5937,0x5938,0x5984,0x5978, 0x5983,0x597d,0x5979,0x5982,
  0x5981,0x5b57,0x5b58,0x5b87, 0x5b88,0x5b85,0x5b89,0x5bfa,
  0x5c16,0x5c79,0x5dde,0x5e06, 0x5e76,0x0000,
/* 0x4e41(i:2470) */
  0x5e74,0x5f0f,0x5f1b,0x5fd9, 0x5fd6,0x620e,0x620c,0x620d,
  0x6210,0x6263,0x625b,0x6258, 0x6536,0x65e9,0x65e8,0x65ec,
  0x65ed,0x66f2,0x66f3,0x6709, 0x673d,0x6734,0x6731,0x6735,
  0x6b21,0x6b64,0x6b7b,0x6c16, 0x6c5d,0x6c57,0x6c59,0x6c5f,
  0x6c60,0x6c50,0x6c55,0x6c61, 0x6c5b,0x6c4d,0x6c4e,0x7070,
  0x725f,0x725d,0x767e,0x7af9, 0x7c73,0x7cf8,0x7f36,0x7f8a,
  0x7fbd,0x8001,0x8003,0x800c, 0x8012,0x8033,0x807f,0x8089,
  0x808b,0x808c,0x81e3,0x81ea, 0x81f3,0x81fc,0x820c,0x0000,
  0x821b,0x821f,0x826e,0x8272, 0x827e,0x866b,0x8840,0x884c,
  0x8863,0x897f,0x9621,0x4e32, 0x4ea8,0x4f4d,0x4f4f,0x4f47,
  0x4f57,0x4f5e,0x4f34,0x4f5b, 0x4f55,0x4f30,0x4f50,0x4f51,
  0x4f3d,0x4f3a,0x4f38,0x4f43, 0x4f54,0x4f3c,0x4f46,0x4f63,
  0x4f5c,0x4f60,0x4f2f,0x4f4e, 0x4f36,0x4f59,0x4f5d,0x4f48,
  0x4f5a,0x514c,0x514b,0x514d, 0x5175,0x51b6,0x51b7,0x5225,
  0x5224,0x5229,0x522a,0x5228, 0x52ab,0x52a9,0x52aa,0x52ac,
  0x5323,0x5373,0x5375,0x541d, 0x542d,0x541e,0x543e,0x5426,
  0x544e,0x5427,0x5446,0x5443, 0x5433,0x5448,0x5442,0x541b,
  0x5429,0x544a,0x5439,0x543b, 0x5438,0x542e,0x5435,0x5436,
  0x5420,0x543c,0x5440,0x5431, 0x542b,0x541f,0x542c,0x56ea,
  0x56f0,0x56e4,0x56eb,0x574a, 0x5751,0x5740,0x574d,0x5747,
  0x574e,0x573e,0x5750,0x574f, 0x573b,0x58ef,0x593e,0x599d,
  0x5992,0x59a8,0x599e,0x59a3, 0x5999,0x5996,0x598d,0x59a4,
  0x5993,0x598a,0x59a5,0x5b5d, 0x5b5c,0x5b5a,0x5b5b,0x5b8c,
  0x5b8b,0x5b8f,0x5c2c,0x5c40, 0x5c41,0x0000,
/* 0x4f41(i:2660) */
  0x5c3f,0x5c3e,0x5c90,0x5c91, 0x5c94,0x5c8c,0x5deb,0x5e0c,
  0x5e8f,0x5e87,0x5e8a,0x5ef7, 0x5f04,0x5f1f,0x5f64,0x5f62,
  0x5f77,0x5f79,0x5fd8,0x5fcc, 0x5fd7,0x5fcd,0x5ff1,0x5feb,
  0x5ff8,0x5fea,0x6212,0x6211, 0x6284,0x6297,0x6296,0x6280,
  0x6276,0x6289,0x626d,0x628a, 0x627c,0x627e,0x6279,0x6273,
  0x6292,0x626f,0x6298,0x626e, 0x6295,0x6293,0x6291,0x6286,
  0x6539,0x653b,0x6538,0x65f1, 0x66f4,0x675f,0x674e,0x674f,
  0x6750,0x6751,0x675c,0x6756, 0x675e,0x6749,0x6746,0x0000,
  0x6760,0x6753,0x6757,0x6b65, 0x6bcf,0x6c42,0x6c5e,0x6c99,
  0x6c81,0x6c88,0x6c89,0x6c85, 0x6c9b,0x6c6a,0x6c7a,0x6c90,
  0x6c70,0x6c8c,0x6c68,0x6c96, 0x6c92,0x6c7d,0x6c83,0x6c72,
  0x6c7e,0x6c74,0x6c86,0x6c76, 0x6c8d,0x6c94,0x6c98,0x6c82,
  0x7076,0x707c,0x707d,0x7078, 0x7262,0x7261,0x7260,0x72c4,
  0x72c2,0x7396,0x752c,0x752b, 0x7537,0x7538,0x7682,0x76ef,
  0x77e3,0x79c1,0x79c0,0x79bf, 0x7a76,0x7cfb,0x7f55,0x8096,
  0x8093,0x809d,0x8098,0x809b, 0x809a,0x80b2,0x826f,0x8292,
  0x828b,0x828d,0x898b,0x89d2, 0x8a00,0x8c37,0x8c46,0x8c55,
  0x8c9d,0x8d64,0x8d70,0x8db3, 0x8eab,0x8eca,0x8f9b,0x8fb0,
  0x8fc2,0x8fc6,0x8fc5,0x8fc4, 0x5de1,0x9091,0x90a2,0x90aa,
  0x90a6,0x90a3,0x9149,0x91c6, 0x91cc,0x9632,0x962e,0x9631,
  0x962a,0x962c,0x4e26,0x4e56, 0x4e73,0x4e8b,0x4e9b,0x4e9e,
  0x4eab,0x4eac,0x4f6f,0x4f9d, 0x4f8d,0x4f73,0x4f7f,0x4f6c,
  0x4f9b,0x4f8b,0x4f86,0x4f83, 0x4f70,0x4f75,0x4f88,0x4f69,
  0x4f7b,0x4f96,0x4f7e,0x4f8f, 0x4f91,0x0000,
/* 0x5041(i:2850) */
  0x4f7a,0x5154,0x5152,0x5155, 0x5169,0x5177,0x5176,0x5178,
  0x51bd,0x51fd,0x523b,0x5238, 0x5237,0x523a,0x5230,0x522e,
  0x5236,0x5241,0x52be,0x52bb, 0x5352,0x5354,0x5353,0x5351,
  0x5366,0x5377,0x5378,0x5379, 0x53d6,0x53d4,0x53d7,0x5473,
  0x5475,0x5496,0x5478,0x5495, 0x5480,0x547b,0x5477,0x5484,
  0x5492,0x5486,0x547c,0x5490, 0x5471,0x5476,0x548c,0x549a,
  0x5462,0x5468,0x548b,0x547d, 0x548e,0x56fa,0x5783,0x5777,
  0x576a,0x5769,0x5761,0x5766, 0x5764,0x577c,0x591c,0x0000,
  0x5949,0x5947,0x5948,0x5944, 0x5954,0x59be,0x59bb,0x59d4,
  0x59b9,0x59ae,0x59d1,0x59c6, 0x59d0,0x59cd,0x59cb,0x59d3,
  0x59ca,0x59af,0x59b3,0x59d2, 0x59c5,0x5b5f,0x5b64,0x5b63,
  0x5b97,0x5b9a,0x5b98,0x5b9c, 0x5b99,0x5b9b,0x5c1a,0x5c48,
  0x5c45,0x5c46,0x5cb7,0x5ca1, 0x5cb8,0x5ca9,0x5cab,0x5cb1,
  0x5cb3,0x5e18,0x5e1a,0x5e16, 0x5e15,0x5e1b,0x5e11,0x5e78,
  0x5e9a,0x5e97,0x5e9c,0x5e95, 0x5e96,0x5ef6,0x5f26,0x5f27,
  0x5f29,0x5f80,0x5f81,0x5f7f, 0x5f7c,0x5fdd,0x5fe0,0x5ffd,
  0x5ff5,0x5fff,0x600f,0x6014, 0x602f,0x6035,0x6016,0x602a,
  0x6015,0x6021,0x6027,0x6029, 0x602b,0x601b,0x6216,0x6215,
  0x623f,0x623e,0x6240,0x627f, 0x62c9,0x62cc,0x62c4,0x62bf,
  0x62c2,0x62b9,0x62d2,0x62db, 0x62ab,0x62d3,0x62d4,0x62cb,
  0x62c8,0x62a8,0x62bd,0x62bc, 0x62d0,0x62d9,0x62c7,0x62cd,
  0x62b5,0x62da,0x62b1,0x62d8, 0x62d6,0x62d7,0x62c6,0x62ac,
  0x62ce,0x653e,0x65a7,0x65bc, 0x65fa,0x6614,0x6613,0x660c,
  0x6606,0x6602,0x660e,0x6600, 0x660f,0x0000,
/* 0x5141(i:3040) */
  0x6615,0x660a,0x6607,0x670d, 0x670b,0x676d,0x678b,0x6795,
  0x6771,0x679c,0x6773,0x6777, 0x6787,0x679d,0x6797,0x676f,
  0x6770,0x677f,0x6789,0x677e, 0x6790,0x6775,0x679a,0x6793,
  0x677c,0x676a,0x6772,0x6b23, 0x6b66,0x6b67,0x6b7f,0x6c13,
  0x6c1b,0x6ce3,0x6ce8,0x6cf3, 0x6cb1,0x6ccc,0x6ce5,0x6cb3,
  0x6cbd,0x6cbe,0x6cbc,0x6ce2, 0x6cab,0x6cd5,0x6cd3,0x6cb8,
  0x6cc4,0x6cb9,0x6cc1,0x6cae, 0x6cd7,0x6cc5,0x6cf1,0x6cbf,
  0x6cbb,0x6ce1,0x6cdb,0x6cca, 0x6cac,0x6cef,0x6cdc,0x0000,
  0x6cd6,0x6ce0,0x7095,0x708e, 0x7092,0x708a,0x7099,0x722c,
  0x722d,0x7238,0x7248,0x7267, 0x7269,0x72c0,0x72ce,0x72d9,
  0x72d7,0x72d0,0x73a9,0x73a8, 0x739f,0x73ab,0x73a5,0x753d,
  0x759d,0x7599,0x759a,0x7684, 0x76c2,0x76f2,0x76f4,0x77e5,
  0x77fd,0x793e,0x7940,0x7941, 0x79c9,0x79c8,0x7a7a,0x7a79,
  0x7afa,0x7cfe,0x7f54,0x7f8c, 0x7f8b,0x8005,0x80ba,0x80a5,
  0x80a2,0x80b1,0x80a1,0x80ab, 0x80a9,0x80b4,0x80aa,0x80af,
  0x81e5,0x81fe,0x820d,0x82b3, 0x829d,0x8299,0x82ad,0x82bd,
  0x829f,0x82b9,0x82b1,0x82ac, 0x82a5,0x82af,0x82b8,0x82a3,
  0x82b0,0x82be,0x82b7,0x864e, 0x8671,0x521d,0x8868,0x8ecb,
  0x8fce,0x8fd4,0x8fd1,0x90b5, 0x90b8,0x90b1,0x90b6,0x91c7,
  0x91d1,0x9577,0x9580,0x961c, 0x9640,0x963f,0x963b,0x9644,
  0x9642,0x96b9,0x96e8,0x9752, 0x975e,0x4e9f,0x4ead,0x4eae,
  0x4fe1,0x4fb5,0x4faf,0x4fbf, 0x4fe0,0x4fd1,0x4fcf,0x4fdd,
  0x4fc3,0x4fb6,0x4fd8,0x4fdf, 0x4fca,0x4fd7,0x4fae,0x4fd0,
  0x4fc4,0x4fc2,0x4fda,0x4fce, 0x4fde,0x0000,
/* 0x5241(i:3230) */
  0x4fb7,0x5157,0x5192,0x5191, 0x51a0,0x524e,0x5243,0x524a,
  0x524d,0x524c,0x524b,0x5247, 0x52c7,0x52c9,0x52c3,0x52c1,
  0x530d,0x5357,0x537b,0x539a, 0x53db,0x54ac,0x54c0,0x54a8,
  0x54ce,0x54c9,0x54b8,0x54a6, 0x54b3,0x54c7,0x54c2,0x54bd,
  0x54aa,0x54c1,0x54c4,0x54c8, 0x54af,0x54ab,0x54b1,0x54bb,
  0x54a9,0x54a7,0x54bf,0x56ff, 0x5782,0x578b,0x57a0,0x57a3,
  0x57a2,0x57ce,0x57ae,0x5793, 0x5955,0x5951,0x594f,0x594e,
  0x5950,0x59dc,0x59d8,0x59ff, 0x59e3,0x59e8,0x5a03,0x0000,
  0x59e5,0x59ea,0x59da,0x59e6, 0x5a01,0x59fb,0x5b69,0x5ba3,
  0x5ba6,0x5ba4,0x5ba2,0x5ba5, 0x5c01,0x5c4e,0x5c4f,0x5c4d,
  0x5c4b,0x5cd9,0x5cd2,0x5df7, 0x5e1d,0x5e25,0x5e1f,0x5e7d,
  0x5ea0,0x5ea6,0x5efa,0x5f08, 0x5f2d,0x5f65,0x5f88,0x5f85,
  0x5f8a,0x5f8b,0x5f87,0x5f8c, 0x5f89,0x6012,0x601d,0x6020,
  0x6025,0x600e,0x6028,0x604d, 0x6070,0x6068,0x6062,0x6046,
  0x6043,0x606c,0x606b,0x606a, 0x6064,0x6241,0x62dc,0x6316,
  0x6309,0x62fc,0x62ed,0x6301, 0x62ee,0x62fd,0x6307,0x62f1,
  0x62f7,0x62ef,0x62ec,0x62fe, 0x62f4,0x6311,0x6302,0x653f,
  0x6545,0x65ab,0x65bd,0x65e2, 0x6625,0x662d,0x6620,0x6627,
  0x662f,0x661f,0x6628,0x6631, 0x6624,0x66f7,0x67ff,0x67d3,
  0x67f1,0x67d4,0x67d0,0x67ec, 0x67b6,0x67af,0x67f5,0x67e9,
  0x67ef,0x67c4,0x67d1,0x67b4, 0x67da,0x67e5,0x67b8,0x67cf,
  0x67de,0x67f3,0x67b0,0x67d9, 0x67e2,0x67dd,0x67d2,0x6b6a,
  0x6b83,0x6b86,0x6bb5,0x6bd2, 0x6bd7,0x6c1f,0x6cc9,0x6d0b,
  0x6d32,0x6d2a,0x6d41,0x6d25, 0x6d0c,0x0000,
/* 0x5341(i:3420) */
  0x6d31,0x6d1e,0x6d17,0x6d3b, 0x6d3d,0x6d3e,0x6d36,0x6d1b,
  0x6cf5,0x6d39,0x6d27,0x6d38, 0x6d29,0x6d2e,0x6d35,0x6d0e,
  0x6d2b,0x70ab,0x70ba,0x70b3, 0x70ac,0x70af,0x70ad,0x70b8,
  0x70ae,0x70a4,0x7230,0x7272, 0x726f,0x7274,0x72e9,0x72e0,
  0x72e1,0x73b7,0x73ca,0x73bb, 0x73b2,0x73cd,0x73c0,0x73b3,
  0x751a,0x752d,0x754f,0x754c, 0x754e,0x754b,0x75ab,0x75a4,
  0x75a5,0x75a2,0x75a3,0x7678, 0x7686,0x7687,0x7688,0x76c8,
  0x76c6,0x76c3,0x76c5,0x7701, 0x76f9,0x76f8,0x7709,0x0000,
  0x770b,0x76fe,0x76fc,0x7707, 0x77dc,0x7802,0x7814,0x780c,
  0x780d,0x7946,0x7949,0x7948, 0x7947,0x79b9,0x79ba,0x79d1,
  0x79d2,0x79cb,0x7a7f,0x7a81, 0x7aff,0x7afd,0x7c7d,0x7d02,
  0x7d05,0x7d00,0x7d09,0x7d07, 0x7d04,0x7d06,0x7f38,0x7f8e,
  0x7fbf,0x8004,0x8010,0x800d, 0x8011,0x8036,0x80d6,0x80e5,
  0x80da,0x80c3,0x80c4,0x80cc, 0x80e1,0x80db,0x80ce,0x80de,
  0x80e4,0x80dd,0x81f4,0x8222, 0x82e7,0x8303,0x8305,0x82e3,
  0x82db,0x82e6,0x8304,0x82e5, 0x8302,0x8309,0x82d2,0x82d7,
  0x82f1,0x8301,0x82dc,0x82d4, 0x82d1,0x82de,0x82d3,0x82df,
  0x82ef,0x8306,0x8650,0x8679, 0x867b,0x867a,0x884d,0x886b,
  0x8981,0x89d4,0x8a08,0x8a02, 0x8a03,0x8c9e,0x8ca0,0x8d74,
  0x8d73,0x8db4,0x8ecd,0x8ecc, 0x8ff0,0x8fe6,0x8fe2,0x8fea,
  0x8fe5,0x8fed,0x8feb,0x8fe4, 0x8fe8,0x90ca,0x90ce,0x90c1,
  0x90c3,0x914b,0x914a,0x91cd, 0x9582,0x9650,0x964b,0x964c,
  0x964d,0x9762,0x9769,0x97cb, 0x97ed,0x97f3,0x9801,0x98a8,
  0x98db,0x98df,0x9996,0x9999, 0x4e58,0x0000,
/* 0x5441(i:3610) */
  0x4eb3,0x500c,0x500d,0x5023, 0x4fef,0x5026,0x5025,0x4ff8,
  0x5029,0x5016,0x5006,0x503c, 0x501f,0x501a,0x5012,0x5011,
  0x4ffa,0x5000,0x5014,0x5028, 0x4ff1,0x5021,0x500b,0x5019,
  0x5018,0x4ff3,0x4fee,0x502d, 0x502a,0x4ffe,0x502b,0x5009,
  0x517c,0x51a4,0x51a5,0x51a2, 0x51cd,0x51cc,0x51c6,0x51cb,
  0x5256,0x525c,0x5254,0x525b, 0x525d,0x532a,0x537f,0x539f,
  0x539d,0x53df,0x54e8,0x5510, 0x5501,0x5537,0x54fc,0x54e5,
  0x54f2,0x5506,0x54fa,0x5514, 0x54e9,0x54ed,0x54e1,0x0000,
  0x5509,0x54ee,0x54ea,0x54e6, 0x5527,0x5507,0x54fd,0x550f,
  0x5703,0x5704,0x57c2,0x57d4, 0x57cb,0x57c3,0x5809,0x590f,
  0x5957,0x5958,0x595a,0x5a11, 0x5a18,0x5a1c,0x5a1f,0x5a1b,
  0x5a13,0x59ec,0x5a20,0x5a23, 0x5a29,0x5a25,0x5a0c,0x5a09,
  0x5b6b,0x5c58,0x5bb0,0x5bb3, 0x5bb6,0x5bb4,0x5bae,0x5bb5,
  0x5bb9,0x5bb8,0x5c04,0x5c51, 0x5c55,0x5c50,0x5ced,0x5cfd,
  0x5cfb,0x5cea,0x5ce8,0x5cf0, 0x5cf6,0x5d01,0x5cf4,0x5dee,
  0x5e2d,0x5e2b,0x5eab,0x5ead, 0x5ea7,0x5f31,0x5f92,0x5f91,
  0x5f90,0x6059,0x6063,0x6065, 0x6050,0x6055,0x606d,0x6069,
  0x606f,0x6084,0x609f,0x609a, 0x608d,0x6094,0x608c,0x6085,
  0x6096,0x6247,0x62f3,0x6308, 0x62ff,0x634e,0x633e,0x632f,
  0x6355,0x6342,0x6346,0x634f, 0x6349,0x633a,0x6350,0x633d,
  0x632a,0x632b,0x6328,0x634d, 0x634c,0x6548,0x6549,0x6599,
  0x65c1,0x65c5,0x6642,0x6649, 0x664f,0x6643,0x6652,0x664c,
  0x6645,0x6641,0x66f8,0x6714, 0x6715,0x6717,0x6821,0x6838,
  0x6848,0x6846,0x6853,0x6839, 0x6842,0x0000,
/* 0x5541(i:3800) */
  0x6854,0x6829,0x68b3,0x6817, 0x684c,0x6851,0x683d,0x67f4,
  0x6850,0x6840,0x683c,0x6843, 0x682a,0x6845,0x6813,0x6818,
  0x6841,0x6b8a,0x6b89,0x6bb7, 0x6c23,0x6c27,0x6c28,0x6c26,
  0x6c24,0x6cf0,0x6d6a,0x6d95, 0x6d88,0x6d87,0x6d66,0x6d78,
  0x6d77,0x6d59,0x6d93,0x6d6c, 0x6d89,0x6d6e,0x6d5a,0x6d74,
  0x6d69,0x6d8c,0x6d8a,0x6d79, 0x6d85,0x6d65,0x6d94,0x70ca,
  0x70d8,0x70e4,0x70d9,0x70c8, 0x70cf,0x7239,0x7279,0x72fc,
  0x72f9,0x72fd,0x72f8,0x72f7, 0x7386,0x73ed,0x7409,0x0000,
  0x73ee,0x73e0,0x73ea,0x73de, 0x7554,0x755d,0x755c,0x755a,
  0x7559,0x75be,0x75c5,0x75c7, 0x75b2,0x75b3,0x75bd,0x75bc,
  0x75b9,0x75c2,0x75b8,0x768b, 0x76b0,0x76ca,0x76cd,0x76ce,
  0x7729,0x771f,0x7720,0x7728, 0x77e9,0x7830,0x7827,0x7838,
  0x781d,0x7834,0x7837,0x7825, 0x782d,0x7820,0x781f,0x7832,
  0x7955,0x7950,0x7960,0x795f, 0x7956,0x795e,0x795d,0x7957,
  0x795a,0x79e4,0x79e3,0x79e7, 0x79df,0x79e6,0x79e9,0x79d8,
  0x7a84,0x7a88,0x7ad9,0x7b06, 0x7b11,0x7c89,0x7d21,0x7d17,
  0x7d0b,0x7d0a,0x7d20,0x7d22, 0x7d14,0x7d10,0x7d15,0x7d1a,
  0x7d1c,0x7d0d,0x7d19,0x7d1b, 0x7f3a,0x7f5f,0x7f94,0x7fc5,
  0x7fc1,0x8006,0x8018,0x8015, 0x8019,0x8017,0x803d,0x803f,
  0x80f1,0x8102,0x80f0,0x8105, 0x80ed,0x80f4,0x8106,0x80f8,
  0x80f3,0x8108,0x80fd,0x810a, 0x80fc,0x80ef,0x81ed,0x81ec,
  0x8200,0x8210,0x822a,0x822b, 0x8228,0x822c,0x82bb,0x832b,
  0x8352,0x8354,0x834a,0x8338, 0x8350,0x8349,0x8335,0x8334,
  0x834f,0x8332,0x8339,0x8336, 0x8317,0x0000,
/* 0x5641(i:3990) */
  0x8340,0x8331,0x8328,0x8343, 0x8654,0x868a,0x86aa,0x8693,
  0x86a4,0x86a9,0x868c,0x86a3, 0x869c,0x8870,0x8877,0x8881,
  0x8882,0x887d,0x8879,0x8a18, 0x8a10,0x8a0e,0x8a0c,0x8a15,
  0x8a0a,0x8a17,0x8a13,0x8a16, 0x8a0f,0x8a11,0x8c48,0x8c7a,
  0x8c79,0x8ca1,0x8ca2,0x8d77, 0x8eac,0x8ed2,0x8ed4,0x8ecf,
  0x8fb1,0x9001,0x9006,0x8ff7, 0x9000,0x8ffa,0x8ff4,0x9003,
  0x8ffd,0x9005,0x8ff8,0x9095, 0x90e1,0x90dd,0x90e2,0x9152,
  0x914d,0x914c,0x91d8,0x91dd, 0x91d7,0x91dc,0x91d9,0x0000,
  0x9583,0x9662,0x9663,0x9661, 0x965b,0x965d,0x9664,0x9658,
  0x965e,0x96bb,0x98e2,0x99ac, 0x9aa8,0x9ad8,0x9b25,0x9b32,
  0x9b3c,0x4e7e,0x507a,0x507d, 0x505c,0x5047,0x5043,0x504c,
  0x505a,0x5049,0x5065,0x5076, 0x504e,0x5055,0x5075,0x5074,
  0x5077,0x504f,0x500f,0x506f, 0x506d,0x515c,0x5195,0x51f0,
  0x526a,0x526f,0x52d2,0x52d9, 0x52d8,0x52d5,0x5310,0x530f,
  0x5319,0x533f,0x5340,0x533e, 0x53c3,0x66fc,0x5546,0x556a,
  0x5566,0x5544,0x555e,0x5561, 0x5543,0x554a,0x5531,0x5556,
  0x554f,0x5555,0x552f,0x5564, 0x5538,0x552e,0x555c,0x552c,
  0x5563,0x5533,0x5541,0x5557, 0x5708,0x570b,0x5709,0x57df,
  0x5805,0x580a,0x5806,0x57e0, 0x57e4,0x57fa,0x5802,0x5835,
  0x57f7,0x57f9,0x5920,0x5962, 0x5a36,0x5a41,0x5a49,0x5a66,
  0x5a6a,0x5a40,0x5a3c,0x5a62, 0x5a5a,0x5a46,0x5a4a,0x5b70,
  0x5bc7,0x5bc5,0x5bc4,0x5bc2, 0x5bbf,0x5bc6,0x5c09,0x5c08,
  0x5c07,0x5c60,0x5c5c,0x5c5d, 0x5d07,0x5d06,0x5d0e,0x5d1b,
  0x5d16,0x5d22,0x5d11,0x5d29, 0x5d14,0x0000,
/* 0x5741(i:4180) */
  0x5d19,0x5d24,0x5d27,0x5d17, 0x5de2,0x5e38,0x5e36,0x5e33,
  0x5e37,0x5eb7,0x5eb8,0x5eb6, 0x5eb5,0x5ebe,0x5f35,0x5f37,
  0x5f57,0x5f6c,0x5f69,0x5f6b, 0x5f97,0x5f99,0x5f9e,0x5f98,
  0x5fa1,0x5fa0,0x5f9c,0x607f, 0x60a3,0x6089,0x60a0,0x60a8,
  0x60cb,0x60b4,0x60e6,0x60bd, 0x60c5,0x60bb,0x60b5,0x60dc,
  0x60bc,0x60d8,0x60d5,0x60c6, 0x60df,0x60b8,0x60da,0x60c7,
  0x621a,0x621b,0x6248,0x63a0, 0x63a7,0x6372,0x6396,0x63a2,
  0x63a5,0x6377,0x6367,0x6398, 0x63aa,0x6371,0x63a9,0x0000,
  0x6389,0x6383,0x639b,0x636b, 0x63a8,0x6384,0x6388,0x6399,
  0x63a1,0x63ac,0x6392,0x638f, 0x6380,0x637b,0x6369,0x6368,
  0x637a,0x655d,0x6556,0x6551, 0x6559,0x6557,0x555f,0x654f,
  0x6558,0x6555,0x6554,0x659c, 0x659b,0x65ac,0x65cf,0x65cb,
  0x65cc,0x65ce,0x665d,0x665a, 0x6664,0x6668,0x6666,0x665e,
  0x66f9,0x52d7,0x671b,0x6881, 0x68af,0x68a2,0x6893,0x68b5,
  0x687f,0x6876,0x68b1,0x68a7, 0x6897,0x68b0,0x6883,0x68c4,
  0x68ad,0x6886,0x6885,0x6894, 0x689d,0x68a8,0x689f,0x68a1,
  0x6882,0x6b32,0x6bba,0x6beb, 0x6bec,0x6c2b,0x6d8e,0x6dbc,
  0x6df3,0x6dd9,0x6db2,0x6de1, 0x6dcc,0x6de4,0x6dfb,0x6dfa,
  0x6e05,0x6dc7,0x6dcb,0x6daf, 0x6dd1,0x6dae,0x6dde,0x6df9,
  0x6db8,0x6df7,0x6df5,0x6dc5, 0x6dd2,0x6e1a,0x6db5,0x6dda,
  0x6deb,0x6dd8,0x6dea,0x6df1, 0x6dee,0x6de8,0x6dc6,0x6dc4,
  0x6daa,0x6dec,0x6dbf,0x6de6, 0x70f9,0x7109,0x710a,0x70fd,
  0x70ef,0x723d,0x727d,0x7281, 0x731c,0x731b,0x7316,0x7313,
  0x7319,0x7387,0x7405,0x740a, 0x7403,0x0000,
/* 0x5841(i:4370) */
  0x7406,0x73fe,0x740d,0x74e0, 0x74f6,0x74f7,0x751c,0x7522,
  0x7565,0x7566,0x7562,0x7570, 0x758f,0x75d4,0x75d5,0x75b5,
  0x75ca,0x75cd,0x768e,0x76d4, 0x76d2,0x76db,0x7737,0x773e,
  0x773c,0x7736,0x7738,0x773a, 0x786b,0x7843,0x784e,0x7965,
  0x7968,0x796d,0x79fb,0x7a92, 0x7a95,0x7b20,0x7b28,0x7b1b,
  0x7b2c,0x7b26,0x7b19,0x7b1e, 0x7b2e,0x7c92,0x7c97,0x7c95,
  0x7d46,0x7d43,0x7d71,0x7d2e, 0x7d39,0x7d3c,0x7d40,0x7d30,
  0x7d33,0x7d44,0x7d2f,0x7d42, 0x7d32,0x7d31,0x7f3d,0x0000,
  0x7f9e,0x7f9a,0x7fcc,0x7fce, 0x7fd2,0x801c,0x804a,0x8046,
  0x812f,0x8116,0x8123,0x812b, 0x8129,0x8130,0x8124,0x8202,
  0x8235,0x8237,0x8236,0x8239, 0x838e,0x839e,0x8398,0x8378,
  0x83a2,0x8396,0x83bd,0x83ab, 0x8392,0x838a,0x8393,0x8389,
  0x83a0,0x8377,0x837b,0x837c, 0x8386,0x83a7,0x8655,0x5f6a,
  0x86c7,0x86c0,0x86b6,0x86c4, 0x86b5,0x86c6,0x86cb,0x86b1,
  0x86af,0x86c9,0x8853,0x889e, 0x8888,0x88ab,0x8892,0x8896,
  0x888d,0x888b,0x8993,0x898f, 0x8a2a,0x8a1d,0x8a23,0x8a25,
  0x8a31,0x8a2d,0x8a1f,0x8a1b, 0x8a22,0x8c49,0x8c5a,0x8ca9,
  0x8cac,0x8cab,0x8ca8,0x8caa, 0x8ca7,0x8d67,0x8d66,0x8dbe,
  0x8dba,0x8edb,0x8edf,0x9019, 0x900d,0x901a,0x9017,0x9023,
  0x901f,0x901d,0x9010,0x9015, 0x901e,0x9020,0x900f,0x9022,
  0x9016,0x901b,0x9014,0x90e8, 0x90ed,0x90fd,0x9157,0x91ce,
  0x91f5,0x91e6,0x91e3,0x91e7, 0x91ed,0x91e9,0x9589,0x966a,
  0x9675,0x9673,0x9678,0x9670, 0x9674,0x9676,0x9677,0x966c,
  0x96c0,0x96ea,0x96e9,0x7ae0, 0x7adf,0x0000,
/* 0x5941(i:4560) */
  0x9802,0x9803,0x9b5a,0x9ce5, 0x9e75,0x9e7f,0x9ea5,0x9ebb,
  0x50a2,0x508d,0x5085,0x5099, 0x5091,0x5080,0x5096,0x5098,
  0x509a,0x6700,0x51f1,0x5272, 0x5274,0x5275,0x5269,0x52de,
  0x52dd,0x52db,0x535a,0x53a5, 0x557b,0x5580,0x55a7,0x557c,
  0x558a,0x559d,0x5598,0x5582, 0x559c,0x55aa,0x5594,0x5587,
  0x558b,0x5583,0x55b3,0x55ae, 0x559f,0x553e,0x55b2,0x559a,
  0x55bb,0x55ac,0x55b1,0x557e, 0x5589,0x55ab,0x5599,0x570d,
  0x582f,0x582a,0x5834,0x5824, 0x5830,0x5831,0x5821,0x0000,
  0x581d,0x5820,0x58f9,0x58fa, 0x5960,0x5a77,0x5a9a,0x5a7f,
  0x5a92,0x5a9b,0x5aa7,0x5b73, 0x5b71,0x5bd2,0x5bcc,0x5bd3,
  0x5bd0,0x5c0a,0x5c0b,0x5c31, 0x5d4c,0x5d50,0x5d34,0x5d47,
  0x5dfd,0x5e45,0x5e3d,0x5e40, 0x5e43,0x5e7e,0x5eca,0x5ec1,
  0x5ec2,0x5ec4,0x5f3c,0x5f6d, 0x5fa9,0x5faa,0x5fa8,0x60d1,
  0x60e1,0x60b2,0x60b6,0x60e0, 0x611c,0x6123,0x60fa,0x6115,
  0x60f0,0x60fb,0x60f4,0x6168, 0x60f1,0x610e,0x60f6,0x6109,
  0x6100,0x6112,0x621f,0x6249, 0x63a3,0x638c,0x63cf,0x63c0,
  0x63e9,0x63c9,0x63c6,0x63cd, 0x63d2,0x63e3,0x63d0,0x63e1,
  0x63d6,0x63ed,0x63ee,0x6376, 0x63f4,0x63ea,0x63db,0x6452,
  0x63da,0x63f9,0x655e,0x6566, 0x6562,0x6563,0x6591,0x6590,
  0x65af,0x666e,0x6670,0x6674, 0x6676,0x666f,0x6691,0x667a,
  0x667e,0x6677,0x66fe,0x66ff, 0x671f,0x671d,0x68fa,0x68d5,
  0x68e0,0x68d8,0x68d7,0x6905, 0x68df,0x68f5,0x68ee,0x68e7,
  0x68f9,0x68d2,0x68f2,0x68e3, 0x68cb,0x68cd,0x690d,0x6912,
  0x690e,0x68c9,0x68da,0x696e, 0x68fb,0x0000,
/* 0x5a41(i:4750) */
  0x6b3e,0x6b3a,0x6b3d,0x6b98, 0x6b96,0x6bbc,0x6bef,0x6c2e,
  0x6c2f,0x6c2c,0x6e2f,0x6e38, 0x6e54,0x6e21,0x6e32,0x6e67,
  0x6e4a,0x6e20,0x6e25,0x6e23, 0x6e1b,0x6e5b,0x6e58,0x6e24,
  0x6e56,0x6e6e,0x6e2d,0x6e26, 0x6e6f,0x6e34,0x6e4d,0x6e3a,
  0x6e2c,0x6e43,0x6e1d,0x6e3e, 0x6ecb,0x6e89,0x6e19,0x6e4e,
  0x6e63,0x6e44,0x6e72,0x6e69, 0x6e5f,0x7119,0x711a,0x7126,
  0x7130,0x7121,0x7136,0x716e, 0x711c,0x724c,0x7284,0x7280,
  0x7336,0x7325,0x7334,0x7329, 0x743a,0x742a,0x7433,0x0000,
  0x7422,0x7425,0x7435,0x7436, 0x7434,0x742f,0x741b,0x7426,
  0x7428,0x7525,0x7526,0x756b, 0x756a,0x75e2,0x75db,0x75e3,
  0x75d9,0x75d8,0x75de,0x75e0, 0x767b,0x767c,0x7696,0x7693,
  0x76b4,0x76dc,0x774f,0x77ed, 0x785d,0x786c,0x786f,0x7a0d,
  0x7a08,0x7a0b,0x7a05,0x7a00, 0x7a98,0x7a97,0x7a96,0x7ae5,
  0x7ae3,0x7b49,0x7b56,0x7b46, 0x7b50,0x7b52,0x7b54,0x7b4d,
  0x7b4b,0x7b4f,0x7b51,0x7c9f, 0x7ca5,0x7d5e,0x7d50,0x7d68,
  0x7d55,0x7d2b,0x7d6e,0x7d72, 0x7d61,0x7d66,0x7d62,0x7d70,
  0x7d73,0x5584,0x7fd4,0x7fd5, 0x800b,0x8052,0x8085,0x8155,
  0x8154,0x814b,0x8151,0x814e, 0x8139,0x8146,0x813e,0x814c,
  0x8153,0x8174,0x8212,0x821c, 0x83e9,0x8403,0x83f8,0x840d,
  0x83e0,0x83c5,0x840b,0x83c1, 0x83ef,0x83f1,0x83f4,0x8457,
  0x840a,0x83f0,0x840c,0x83cc, 0x83fd,0x83f2,0x83ca,0x8438,
  0x840e,0x8404,0x83dc,0x8407, 0x83d4,0x83df,0x865b,0x86df,
  0x86d9,0x86ed,0x86d4,0x86db, 0x86e4,0x86d0,0x86de,0x8857,
  0x88c1,0x88c2,0x88b1,0x8983, 0x8996,0x0000,
/* 0x5b41(i:4940) */
  0x8a3b,0x8a60,0x8a55,0x8a5e, 0x8a3c,0x8a41,0x8a54,0x8a5b,
  0x8a50,0x8a46,0x8a34,0x8a3a, 0x8a36,0x8a56,0x8c61,0x8c82,
  0x8caf,0x8cbc,0x8cb3,0x8cbd, 0x8cc1,0x8cbb,0x8cc0,0x8cb4,
  0x8cb7,0x8cb6,0x8cbf,0x8cb8, 0x8d8a,0x8d85,0x8d81,0x8dce,
  0x8ddd,0x8dcb,0x8dda,0x8dd1, 0x8dcc,0x8ddb,0x8dc6,0x8efb,
  0x8ef8,0x8efc,0x8f9c,0x902e, 0x9035,0x9031,0x9038,0x9032,
  0x9036,0x9102,0x90f5,0x9109, 0x90fe,0x9163,0x9165,0x91cf,
  0x9214,0x9215,0x9223,0x9209, 0x921e,0x920d,0x9210,0x0000,
  0x9207,0x9211,0x9594,0x958f, 0x958b,0x9591,0x9593,0x9592,
  0x958e,0x968a,0x968e,0x968b, 0x967d,0x9685,0x9686,0x968d,
  0x9672,0x9684,0x96c1,0x96c5, 0x96c4,0x96c6,0x96c7,0x96ef,
  0x96f2,0x97cc,0x9805,0x9806, 0x9808,0x98e7,0x98ea,0x98ef,
  0x98e9,0x98f2,0x98ed,0x99ae, 0x99ad,0x9ec3,0x9ecd,0x9ed1,
  0x4e82,0x50ad,0x50b5,0x50b2, 0x50b3,0x50c5,0x50be,0x50ac,
  0x50b7,0x50bb,0x50af,0x50c7, 0x527f,0x5277,0x527d,0x52df,
  0x52e6,0x52e4,0x52e2,0x52e3, 0x532f,0x55df,0x55e8,0x55d3,
  0x55e6,0x55ce,0x55dc,0x55c7, 0x55d1,0x55e3,0x55e4,0x55ef,
  0x55da,0x55e1,0x55c5,0x55c6, 0x55e5,0x55c9,0x5712,0x5713,
  0x585e,0x5851,0x5858,0x5857, 0x585a,0x5854,0x586b,0x584c,
  0x586d,0x584a,0x5862,0x5852, 0x584b,0x5967,0x5ac1,0x5ac9,
  0x5acc,0x5abe,0x5abd,0x5abc, 0x5ab3,0x5ac2,0x5ab2,0x5d69,
  0x5d6f,0x5e4c,0x5e79,0x5ec9, 0x5ec8,0x5f12,0x5f59,0x5fac,
  0x5fae,0x611a,0x610f,0x6148, 0x611f,0x60f3,0x611b,0x60f9,
  0x6101,0x6108,0x614e,0x614c, 0x6144,0x0000,
/* 0x5c41(i:5130) */
  0x614d,0x613e,0x6134,0x6127, 0x610d,0x6106,0x6137,0x6221,
  0x6222,0x6413,0x643e,0x641e, 0x642a,0x642d,0x643d,0x642c,
  0x640f,0x641c,0x6414,0x640d, 0x6436,0x6416,0x6417,0x6406,
  0x656c,0x659f,0x65b0,0x6697, 0x6689,0x6687,0x6688,0x6696,
  0x6684,0x6698,0x668d,0x6703, 0x6994,0x696d,0x695a,0x6977,
  0x6960,0x6954,0x6975,0x6930, 0x6982,0x694a,0x6968,0x696b,
  0x695e,0x6953,0x6979,0x6986, 0x695d,0x6963,0x695b,0x6b47,
  0x6b72,0x6bc0,0x6bbf,0x6bd3, 0x6bfd,0x6ea2,0x6eaf,0x0000,
  0x6ed3,0x6eb6,0x6ec2,0x6e90, 0x6e9d,0x6ec7,0x6ec5,0x6ea5,
  0x6e98,0x6ebc,0x6eba,0x6eab, 0x6ed1,0x6e96,0x6e9c,0x6ec4,
  0x6ed4,0x6eaa,0x6ea7,0x6eb4, 0x714e,0x7159,0x7169,0x7164,
  0x7149,0x7167,0x715c,0x716c, 0x7166,0x714c,0x7165,0x715e,
  0x7146,0x7168,0x7156,0x723a, 0x7252,0x7337,0x7345,0x733f,
  0x733e,0x746f,0x745a,0x7455, 0x745f,0x745e,0x7441,0x743f,
  0x7459,0x745b,0x745c,0x7576, 0x7578,0x7600,0x75f0,0x7601,
  0x75f2,0x75f1,0x75fa,0x75ff, 0x75f4,0x75f3,0x76de,0x76df,
  0x775b,0x776b,0x7766,0x775e, 0x7763,0x7779,0x776a,0x776c,
  0x775c,0x7765,0x7768,0x7762, 0x77ee,0x788e,0x78b0,0x7897,
  0x7898,0x788c,0x7889,0x787c, 0x7891,0x7893,0x787f,0x797a,
  0x797f,0x7981,0x842c,0x79bd, 0x7a1c,0x7a1a,0x7a20,0x7a14,
  0x7a1f,0x7a1e,0x7a9f,0x7aa0, 0x7b77,0x7bc0,0x7b60,0x7b6e,
  0x7b67,0x7cb1,0x7cb3,0x7cb5, 0x7d93,0x7d79,0x7d91,0x7d81,
  0x7d8f,0x7d5b,0x7f6e,0x7f69, 0x7f6a,0x7f72,0x7fa9,0x7fa8,
  0x7fa4,0x8056,0x8058,0x8086, 0x8084,0x0000,
/* 0x5d41(i:5320) */
  0x8171,0x8170,0x8178,0x8165, 0x816e,0x8173,0x816b,0x8179,
  0x817a,0x8166,0x8205,0x8247, 0x8482,0x8477,0x843d,0x8431,
  0x8475,0x8466,0x846b,0x8449, 0x846c,0x845b,0x843c,0x8435,
  0x8461,0x8463,0x8469,0x846d, 0x8446,0x865e,0x865c,0x865f,
  0x86f9,0x8713,0x8708,0x8707, 0x8700,0x86fe,0x86fb,0x8702,
  0x8703,0x8706,0x870a,0x8859, 0x88df,0x88d4,0x88d9,0x88dc,
  0x88d8,0x88dd,0x88e1,0x88ca, 0x88d5,0x88d2,0x899c,0x89e3,
  0x8a6b,0x8a72,0x8a73,0x8a66, 0x8a69,0x8a70,0x8a87,0x0000,
  0x8a7c,0x8a63,0x8aa0,0x8a71, 0x8a85,0x8a6d,0x8a62,0x8a6e,
  0x8a6c,0x8a79,0x8a7b,0x8a3e, 0x8a68,0x8c62,0x8c8a,0x8c89,
  0x8cca,0x8cc7,0x8cc8,0x8cc4, 0x8cb2,0x8cc3,0x8cc2,0x8cc5,
  0x8de1,0x8ddf,0x8de8,0x8def, 0x8df3,0x8dfa,0x8dea,0x8de4,
  0x8de6,0x8eb2,0x8f03,0x8f09, 0x8efe,0x8f0a,0x8f9f,0x8fb2,
  0x904b,0x904a,0x9053,0x9042, 0x9054,0x903c,0x9055,0x9050,
  0x9047,0x904f,0x904e,0x904d, 0x9051,0x903e,0x9041,0x9112,
  0x9117,0x916c,0x916a,0x9169, 0x91c9,0x9237,0x9257,0x9238,
  0x923d,0x9240,0x923e,0x925b, 0x924b,0x9264,0x9251,0x9234,
  0x9249,0x924d,0x9245,0x9239, 0x923f,0x925a,0x9598,0x9698,
  0x9694,0x9695,0x96cd,0x96cb, 0x96c9,0x96ca,0x96f7,0x96fb,
  0x96f9,0x96f6,0x9756,0x9774, 0x9776,0x9810,0x9811,0x9813,
  0x980a,0x9812,0x980c,0x98fc, 0x98f4,0x98fd,0x98fe,0x99b3,
  0x99b1,0x99b4,0x9ae1,0x9ce9, 0x9e82,0x9f0e,0x9f13,0x9f20,
  0x50e7,0x50ee,0x50e5,0x50d6, 0x50ed,0x50da,0x50d5,0x50cf,
  0x50d1,0x50f1,0x50ce,0x50e9, 0x5162,0x0000,
/* 0x5e41(i:5510) */
  0x51f3,0x5283,0x5282,0x5331, 0x53ad,0x55fe,0x5600,0x561b,
  0x5617,0x55fd,0x5614,0x5606, 0x5609,0x560d,0x560e,0x55f7,
  0x5616,0x561f,0x5608,0x5610, 0x55f6,0x5718,0x5716,0x5875,
  0x587e,0x5883,0x5893,0x588a, 0x5879,0x5885,0x587d,0x58fd,
  0x5925,0x5922,0x5924,0x596a, 0x5969,0x5ae1,0x5ae6,0x5ae9,
  0x5ad7,0x5ad6,0x5ad8,0x5ae3, 0x5b75,0x5bde,0x5be7,0x5be1,
  0x5be5,0x5be6,0x5be8,0x5be2, 0x5be4,0x5bdf,0x5c0d,0x5c62,
  0x5d84,0x5d87,0x5e5b,0x5e63, 0x5e55,0x5e57,0x5e54,0x0000,
  0x5ed3,0x5ed6,0x5f0a,0x5f46, 0x5f70,0x5fb9,0x6147,0x613f,
  0x614b,0x6177,0x6162,0x6163, 0x615f,0x615a,0x6158,0x6175,
  0x622a,0x6487,0x6458,0x6454, 0x64a4,0x6478,0x645f,0x647a,
  0x6451,0x6467,0x6434,0x646d, 0x647b,0x6572,0x65a1,0x65d7,
  0x65d6,0x66a2,0x66a8,0x669d, 0x699c,0x69a8,0x6995,0x69c1,
  0x69ae,0x69d3,0x69cb,0x699b, 0x69b7,0x69bb,0x69ab,0x69b4,
  0x69d0,0x69cd,0x69ad,0x69cc, 0x69a6,0x69c3,0x69a3,0x6b49,
  0x6b4c,0x6c33,0x6f33,0x6f14, 0x6efe,0x6f13,0x6ef4,0x6f29,
  0x6f3e,0x6f20,0x6f2c,0x6f0f, 0x6f02,0x6f22,0x6eff,0x6eef,
  0x6f06,0x6f31,0x6f38,0x6f32, 0x6f23,0x6f15,0x6f2b,0x6f2f,
  0x6f88,0x6f2a,0x6eec,0x6f01, 0x6ef2,0x6ecc,0x6ef7,0x7194,
  0x7199,0x717d,0x718a,0x7184, 0x7192,0x723e,0x7292,0x7296,
  0x7344,0x7350,0x7464,0x7463, 0x746a,0x7470,0x746d,0x7504,
  0x7591,0x7627,0x760d,0x760b, 0x7609,0x7613,0x76e1,0x76e3,
  0x7784,0x777d,0x777f,0x7761, 0x78c1,0x789f,0x78a7,0x78b3,
  0x78a9,0x78a3,0x798e,0x798f, 0x798d,0x0000,
/* 0x5f41(i:5700) */
  0x7a2e,0x7a31,0x7aaa,0x7aa9, 0x7aed,0x7aef,0x7ba1,0x7b95,
  0x7b8b,0x7b75,0x7b97,0x7b9d, 0x7b94,0x7b8f,0x7bb8,0x7b87,
  0x7b84,0x7cb9,0x7cbd,0x7cbe, 0x7dbb,0x7db0,0x7d9c,0x7dbd,
  0x7dbe,0x7da0,0x7dca,0x7db4, 0x7db2,0x7db1,0x7dba,0x7da2,
  0x7dbf,0x7db5,0x7db8,0x7dad, 0x7dd2,0x7dc7,0x7dac,0x7f70,
  0x7fe0,0x7fe1,0x7fdf,0x805e, 0x805a,0x8087,0x8150,0x8180,
  0x818f,0x8188,0x818a,0x817f, 0x8182,0x81e7,0x81fa,0x8207,
  0x8214,0x821e,0x824b,0x84c9, 0x84bf,0x84c6,0x84c4,0x0000,
  0x8499,0x849e,0x84b2,0x849c, 0x84cb,0x84b8,0x84c0,0x84d3,
  0x8490,0x84bc,0x84d1,0x84ca, 0x873f,0x871c,0x873b,0x8722,
  0x8725,0x8734,0x8718,0x8755, 0x8737,0x8729,0x88f3,0x8902,
  0x88f4,0x88f9,0x88f8,0x88fd, 0x88e8,0x891a,0x88ef,0x8aa6,
  0x8a8c,0x8a9e,0x8aa3,0x8a8d, 0x8aa1,0x8a93,0x8aa4,0x8aaa,
  0x8aa5,0x8aa8,0x8a98,0x8a91, 0x8a9a,0x8aa7,0x8c6a,0x8c8d,
  0x8c8c,0x8cd3,0x8cd1,0x8cd2, 0x8d6b,0x8d99,0x8d95,0x8dfc,
  0x8f14,0x8f12,0x8f15,0x8f13, 0x8fa3,0x9060,0x9058,0x905c,
  0x9063,0x9059,0x905e,0x9062, 0x905d,0x905b,0x9119,0x9118,
  0x911e,0x9175,0x9178,0x9177, 0x9174,0x9278,0x9280,0x9285,
  0x9298,0x9296,0x927b,0x9293, 0x929c,0x92a8,0x927c,0x9291,
  0x95a1,0x95a8,0x95a9,0x95a3, 0x95a5,0x95a4,0x9699,0x969c,
  0x969b,0x96cc,0x96d2,0x9700, 0x977c,0x9785,0x97f6,0x9817,
  0x9818,0x98af,0x98b1,0x9903, 0x9905,0x990c,0x9909,0x99c1,
  0x9aaf,0x9ab0,0x9ae6,0x9b41, 0x9b42,0x9cf4,0x9cf6,0x9cf3,
  0x9ebc,0x9f3b,0x9f4a,0x5104, 0x5100,0x0000,
/* 0x6041(i:5890) */
  0x50fb,0x50f5,0x50f9,0x5102, 0x5108,0x5109,0x5105,0x51dc,
  0x5287,0x5288,0x5289,0x528d, 0x528a,0x52f0,0x53b2,0x562e,
  0x563b,0x5639,0x5632,0x563f, 0x5634,0x5629,0x5653,0x564e,
  0x5657,0x5674,0x5636,0x562f, 0x5630,0x5880,0x589f,0x589e,
  0x58b3,0x589c,0x58ae,0x58a9, 0x58a6,0x596d,0x5b09,0x5afb,
  0x5b0b,0x5af5,0x5b0c,0x5b08, 0x5bee,0x5bec,0x5be9,0x5beb,
  0x5c64,0x5c65,0x5d9d,0x5d94, 0x5e62,0x5e5f,0x5e61,0x5ee2,
  0x5eda,0x5edf,0x5edd,0x5ee3, 0x5ee0,0x5f48,0x5f71,0x0000,
  0x5fb7,0x5fb5,0x6176,0x6167, 0x616e,0x615d,0x6155,0x6182,
  0x617c,0x6170,0x616b,0x617e, 0x61a7,0x6190,0x61ab,0x618e,
  0x61ac,0x619a,0x61a4,0x6194, 0x61ae,0x622e,0x6469,0x646f,
  0x6479,0x649e,0x64b2,0x6488, 0x6490,0x64b0,0x64a5,0x6493,
  0x6495,0x64a9,0x6492,0x64ae, 0x64ad,0x64ab,0x649a,0x64ac,
  0x6499,0x64a2,0x64b3,0x6575, 0x6577,0x6578,0x66ae,0x66ab,
  0x66b4,0x66b1,0x6a23,0x6a1f, 0x69e8,0x6a01,0x6a1e,0x6a19,
  0x69fd,0x6a21,0x6a13,0x6a0a, 0x69f3,0x6a02,0x6a05,0x69ed,
  0x6a11,0x6b50,0x6b4e,0x6ba4, 0x6bc5,0x6bc6,0x6f3f,0x6f7c,
  0x6f84,0x6f51,0x6f66,0x6f54, 0x6f86,0x6f6d,0x6f5b,0x6f78,
  0x6f6e,0x6f8e,0x6f7a,0x6f70, 0x6f64,0x6f97,0x6f58,0x6ed5,
  0x6f6f,0x6f60,0x6f5f,0x719f, 0x71ac,0x71b1,0x71a8,0x7256,
  0x729b,0x734e,0x7357,0x7469, 0x748b,0x7483,0x747e,0x7480,
  0x757f,0x7620,0x7629,0x761f, 0x7624,0x7626,0x7621,0x7622,
  0x769a,0x76ba,0x76e4,0x778e, 0x7787,0x778c,0x7791,0x778b,
  0x78cb,0x78c5,0x78ba,0x78ca, 0x78be,0x0000,
/* 0x6141(i:6080) */
  0x78d5,0x78bc,0x78d0,0x7a3f, 0x7a3c,0x7a40,0x7a3d,0x7a37,
  0x7a3b,0x7aaf,0x7aae,0x7bad, 0x7bb1,0x7bc4,0x7bb4,0x7bc6,
  0x7bc7,0x7bc1,0x7ba0,0x7bcc, 0x7cca,0x7de0,0x7df4,0x7def,
  0x7dfb,0x7dd8,0x7dec,0x7ddd, 0x7de8,0x7de3,0x7dda,0x7dde,
  0x7de9,0x7d9e,0x7dd9,0x7df2, 0x7df9,0x7f75,0x7f77,0x7faf,
  0x7fe9,0x8026,0x819b,0x819c, 0x819d,0x81a0,0x819a,0x8198,
  0x8517,0x853d,0x851a,0x84ee, 0x852c,0x852d,0x8513,0x8511,
  0x8523,0x8521,0x8514,0x84ec, 0x8525,0x84ff,0x8506,0x0000,
  0x8782,0x8774,0x8776,0x8760, 0x8766,0x8778,0x8768,0x8759,
  0x8757,0x874c,0x8753,0x885b, 0x885d,0x8910,0x8907,0x8912,
  0x8913,0x8915,0x890a,0x8abc, 0x8ad2,0x8ac7,0x8ac4,0x8a95,
  0x8acb,0x8af8,0x8ab2,0x8ac9, 0x8ac2,0x8abf,0x8ab0,0x8ad6,
  0x8acd,0x8ab6,0x8ab9,0x8adb, 0x8c4c,0x8c4e,0x8c6c,0x8ce0,
  0x8cde,0x8ce6,0x8ce4,0x8cec, 0x8ced,0x8ce2,0x8ce3,0x8cdc,
  0x8cea,0x8ce1,0x8d6d,0x8d9f, 0x8da3,0x8e2b,0x8e10,0x8e1d,
  0x8e22,0x8e0f,0x8e29,0x8e1f, 0x8e21,0x8e1e,0x8eba,0x8f1d,
  0x8f1b,0x8f1f,0x8f29,0x8f26, 0x8f2a,0x8f1c,0x8f1e,0x8f25,
  0x9069,0x906e,0x9068,0x906d, 0x9077,0x9130,0x912d,0x9127,
  0x9131,0x9187,0x9189,0x918b, 0x9183,0x92c5,0x92bb,0x92b7,
  0x92ea,0x92ac,0x92e4,0x92c1, 0x92b3,0x92bc,0x92d2,0x92c7,
  0x92f0,0x92b2,0x95ad,0x95b1, 0x9704,0x9706,0x9707,0x9709,
  0x9760,0x978d,0x978b,0x978f, 0x9821,0x982b,0x981c,0x98b3,
  0x990a,0x9913,0x9912,0x9918, 0x99dd,0x99d0,0x99df,0x99db,
  0x99d1,0x99d5,0x99d2,0x99d9, 0x9ab7,0x0000,
/* 0x6241(i:6270) */
  0x9aee,0x9aef,0x9b27,0x9b45, 0x9b44,0x9b77,0x9b6f,0x9d06,
  0x9d09,0x9d03,0x9ea9,0x9ebe, 0x9ece,0x58a8,0x9f52,0x5112,
  0x5118,0x5114,0x5110,0x5115, 0x5180,0x51aa,0x51dd,0x5291,
  0x5293,0x52f3,0x5659,0x566b, 0x5679,0x5669,0x5664,0x5678,
  0x566a,0x5668,0x5665,0x5671, 0x566f,0x566c,0x5662,0x5676,
  0x58c1,0x58be,0x58c7,0x58c5, 0x596e,0x5b1d,0x5b34,0x5b78,
  0x5bf0,0x5c0e,0x5f4a,0x61b2, 0x6191,0x61a9,0x618a,0x61cd,
  0x61b6,0x61be,0x61ca,0x61c8, 0x6230,0x64c5,0x64c1,0x0000,
  0x64cb,0x64bb,0x64bc,0x64da, 0x64c4,0x64c7,0x64c2,0x64cd,
  0x64bf,0x64d2,0x64d4,0x64be, 0x6574,0x66c6,0x66c9,0x66b9,
  0x66c4,0x66c7,0x66b8,0x6a3d, 0x6a38,0x6a3a,0x6a59,0x6a6b,
  0x6a58,0x6a39,0x6a44,0x6a62, 0x6a61,0x6a4b,0x6a47,0x6a35,
  0x6a5f,0x6a48,0x6b59,0x6b77, 0x6c05,0x6fc2,0x6fb1,0x6fa1,
  0x6fc3,0x6fa4,0x6fc1,0x6fa7, 0x6fb3,0x6fc0,0x6fb9,0x6fb6,
  0x6fa6,0x6fa0,0x6fb4,0x71be, 0x71c9,0x71d0,0x71d2,0x71c8,
  0x71d5,0x71b9,0x71ce,0x71d9, 0x71dc,0x71c3,0x71c4,0x7368,
  0x749c,0x74a3,0x7498,0x749f, 0x749e,0x74e2,0x750c,0x750d,
  0x7634,0x7638,0x763a,0x76e7, 0x76e5,0x77a0,0x779e,0x779f,
  0x77a5,0x78e8,0x78da,0x78ec, 0x78e7,0x79a6,0x7a4d,0x7a4e,
  0x7a46,0x7a4c,0x7a4b,0x7aba, 0x7bd9,0x7c11,0x7bc9,0x7be4,
  0x7bdb,0x7be1,0x7be9,0x7be6, 0x7cd5,0x7cd6,0x7e0a,0x7e11,
  0x7e08,0x7e1b,0x7e23,0x7e1e, 0x7e1d,0x7e09,0x7e10,0x7f79,
  0x7fb2,0x7ff0,0x7ff1,0x7fee, 0x8028,0x81b3,0x81a9,0x81a8,
  0x81fb,0x8208,0x8258,0x8259, 0x854a,0x0000,
/* 0x6341(i:6460) */
  0x8559,0x8548,0x8568,0x8569, 0x8543,0x8549,0x856d,0x856a,
  0x855e,0x8783,0x879f,0x879e, 0x87a2,0x878d,0x8861,0x892a,
  0x8932,0x8925,0x892b,0x8921, 0x89aa,0x89a6,0x8ae6,0x8afa,
  0x8aeb,0x8af1,0x8b00,0x8adc, 0x8ae7,0x8aee,0x8afe,0x8b01,
  0x8b02,0x8af7,0x8aed,0x8af3, 0x8af6,0x8afc,0x8c6b,0x8c6d,
  0x8c93,0x8cf4,0x8e44,0x8e31, 0x8e34,0x8e42,0x8e39,0x8e35,
  0x8f3b,0x8f2f,0x8f38,0x8f33, 0x8fa8,0x8fa6,0x9075,0x9074,
  0x9078,0x9072,0x907c,0x907a, 0x9134,0x9192,0x9320,0x0000,
  0x9336,0x92f8,0x9333,0x932f, 0x9322,0x92fc,0x932b,0x9304,
  0x931a,0x9310,0x9326,0x9321, 0x9315,0x932e,0x9319,0x95bb,
  0x96a7,0x96a8,0x96aa,0x96d5, 0x970e,0x9711,0x9716,0x970d,
  0x9713,0x970f,0x975b,0x975c, 0x9766,0x9798,0x9830,0x9838,
  0x983b,0x9837,0x982d,0x9839, 0x9824,0x9910,0x9928,0x991e,
  0x991b,0x9921,0x991a,0x99ed, 0x99e2,0x99f1,0x9ab8,0x9abc,
  0x9afb,0x9aed,0x9b28,0x9b91, 0x9d15,0x9d23,0x9d26,0x9d28,
  0x9d12,0x9d1b,0x9ed8,0x9ed4, 0x9f8d,0x9f9c,0x512a,0x511f,
  0x5121,0x5132,0x52f5,0x568e, 0x5680,0x5690,0x5685,0x5687,
  0x568f,0x58d5,0x58d3,0x58d1, 0x58ce,0x5b30,0x5b2a,0x5b24,
  0x5b7a,0x5c37,0x5c68,0x5dbc, 0x5dba,0x5dbd,0x5db8,0x5e6b,
  0x5f4c,0x5fbd,0x61c9,0x61c2, 0x61c7,0x61e6,0x61cb,0x6232,
  0x6234,0x64ce,0x64ca,0x64d8, 0x64e0,0x64f0,0x64e6,0x64ec,
  0x64f1,0x64e2,0x64ed,0x6582, 0x6583,0x66d9,0x66d6,0x6a80,
  0x6a94,0x6a84,0x6aa2,0x6a9c, 0x6adb,0x6aa3,0x6a7e,0x6a97,
  0x6a90,0x6aa0,0x6b5c,0x6bae, 0x6bda,0x0000,
/* 0x6441(i:6650) */
  0x0000,0x6fd8,0x6ff1,0x6fdf, 0x6fe0,0x6fdb,0x6fe4,0x6feb,
  0x6fef,0x6f80,0x6fec,0x6fe1, 0x6fe9,0x6fd5,0x6fee,0x6ff0,
  0x71e7,0x71df,0x71ee,0x71e6, 0x71e5,0x71ed,0x71ec,0x71f4,
  0x71e0,0x7235,0x7246,0x7370, 0x7372,0x74a9,0x74b0,0x74a6,
  0x74a8,0x7646,0x7642,0x764c, 0x76ea,0x77b3,0x77aa,0x77b0,
  0x77ac,0x77a7,0x77ad,0x77ef, 0x78f7,0x78fa,0x78f4,0x78ef,
  0x7901,0x79a7,0x79aa,0x7a57, 0x7abf,0x7c07,0x7c0d,0x7bfe,
  0x7bf7,0x7c0c,0x7be0,0x7ce0, 0x7cdc,0x7cde,0x7ce2,0x0000,
  0x7cdf,0x7cd9,0x7cdd,0x7e2e, 0x7e3e,0x7e46,0x7e37,0x7e32,
  0x7e43,0x7e2b,0x7e3d,0x7e31, 0x7e45,0x7e41,0x7e34,0x7e39,
  0x7e48,0x7e35,0x7e3f,0x7e2f, 0x7f44,0x7ff3,0x7ffc,0x8071,
  0x8072,0x8070,0x806f,0x8073, 0x81c6,0x81c3,0x81ba,0x81c2,
  0x81c0,0x81bf,0x81bd,0x81c9, 0x81be,0x81e8,0x8209,0x8271,
  0x85aa,0x8584,0x857e,0x859c, 0x8591,0x8594,0x85af,0x859b,
  0x8587,0x85a8,0x858a,0x8667, 0x87c0,0x87d1,0x87b3,0x87d2,
  0x87c6,0x87ab,0x87bb,0x87ba, 0x87c8,0x87cb,0x893b,0x8936,
  0x8944,0x8938,0x893d,0x89ac, 0x8b0e,0x8b17,0x8b19,0x8b1b,
  0x8b0a,0x8b20,0x8b1d,0x8b04, 0x8b10,0x8c41,0x8c3f,0x8c73,
  0x8cfa,0x8cfd,0x8cfc,0x8cf8, 0x8cfb,0x8da8,0x8e49,0x8e4b,
  0x8e48,0x8e4a,0x8f44,0x8f3e, 0x8f42,0x8f45,0x8f3f,0x907f,
  0x907d,0x9084,0x9081,0x9082, 0x9080,0x9139,0x91a3,0x919e,
  0x919c,0x934d,0x9382,0x9328, 0x9375,0x934a,0x9365,0x934b,
  0x9318,0x937e,0x936c,0x935b, 0x9370,0x935a,0x9354,0x95ca,
  0x95cb,0x95cc,0x95c8,0x95c6, 0x96b1,0x0000,
/* 0x6541(i:6840) */
  0x96b8,0x96d6,0x971c,0x971e, 0x97a0,0x97d3,0x9846,0x98b6,
  0x9935,0x9a01,0x99ff,0x9bae, 0x9bab,0x9baa,0x9bad,0x9d3b,
  0x9d3f,0x9e8b,0x9ecf,0x9ede, 0x9edc,0x9edd,0x9edb,0x9f3e,
  0x9f4b,0x53e2,0x5695,0x56ae, 0x58d9,0x58d8,0x5b38,0x5f5e,
  0x61e3,0x6233,0x64f4,0x64f2, 0x64fe,0x6506,0x64fa,0x64fb,
  0x64f7,0x65b7,0x66dc,0x6726, 0x6ab3,0x6aac,0x6ac3,0x6abb,
  0x6ab8,0x6ac2,0x6aae,0x6aaf, 0x6b5f,0x6b78,0x6baf,0x7009,
  0x700b,0x6ffe,0x7006,0x6ffa, 0x7011,0x700f,0x71fb,0x0000,
  0x71fc,0x71fe,0x71f8,0x7377, 0x7375,0x74a7,0x74bf,0x7515,
  0x7656,0x7658,0x7652,0x77bd, 0x77bf,0x77bb,0x77bc,0x790e,
  0x79ae,0x7a61,0x7a62,0x7a60, 0x7ac4,0x7ac5,0x7c2b,0x7c27,
  0x7c2a,0x7c1e,0x7c23,0x7c21, 0x7ce7,0x7e54,0x7e55,0x7e5e,
  0x7e5a,0x7e61,0x7e52,0x7e59, 0x7f48,0x7ff9,0x7ffb,0x8077,
  0x8076,0x81cd,0x81cf,0x820a, 0x85cf,0x85a9,0x85cd,0x85d0,
  0x85c9,0x85b0,0x85ba,0x85b9, 0x85a6,0x87ef,0x87ec,0x87f2,
  0x87e0,0x8986,0x89b2,0x89f4, 0x8b28,0x8b39,0x8b2c,0x8b2b,
  0x8c50,0x8d05,0x8e59,0x8e63, 0x8e66,0x8e64,0x8e5f,0x8e55,
  0x8ec0,0x8f49,0x8f4d,0x9087, 0x9083,0x9088,0x91ab,0x91ac,
  0x91d0,0x9394,0x938a,0x9396, 0x93a2,0x93b3,0x93ae,0x93ac,
  0x93b0,0x9398,0x939a,0x9397, 0x95d4,0x95d6,0x95d0,0x95d5,
  0x96e2,0x96dc,0x96d9,0x96db, 0x96de,0x9724,0x97a3,0x97a6,
  0x97ad,0x97f9,0x984d,0x984f, 0x984c,0x984e,0x9853,0x98ba,
  0x993e,0x993f,0x993d,0x992e, 0x99a5,0x9a0e,0x9ac1,0x9b03,
  0x9b06,0x9b4f,0x9b4e,0x9b4d, 0x9bca,0x0000,
/* 0x6641(i:7030) */
  0x9bc9,0x9bfd,0x9bc8,0x9bc0, 0x9d51,0x9d5d,0x9d60,0x9ee0,
  0x9f15,0x9f2c,0x5133,0x56a5, 0x58de,0x58df,0x58e2,0x5bf5,
  0x9f90,0x5eec,0x61f2,0x61f7, 0x61f6,0x61f5,0x6500,0x650f,
  0x66e0,0x66dd,0x6ae5,0x6add, 0x6ada,0x6ad3,0x701b,0x701f,
  0x7028,0x701a,0x701d,0x7015, 0x7018,0x7206,0x720d,0x7258,
  0x72a2,0x7378,0x737a,0x74bd, 0x74ca,0x74e3,0x7587,0x7586,
  0x765f,0x7661,0x77c7,0x7919, 0x79b1,0x7a6b,0x7a69,0x7c3e,
  0x7c3f,0x7c38,0x7c3d,0x7c37, 0x7c40,0x7e6b,0x7e6d,0x0000,
  0x7e79,0x7e69,0x7e6a,0x7f85, 0x7e73,0x7fb6,0x7fb9,0x7fb8,
  0x81d8,0x85e9,0x85dd,0x85ea, 0x85d5,0x85e4,0x85e5,0x85f7,
  0x87fb,0x8805,0x880d,0x87f9, 0x87fe,0x8960,0x895f,0x8956,
  0x895e,0x8b41,0x8b5c,0x8b58, 0x8b49,0x8b5a,0x8b4e,0x8b4f,
  0x8b46,0x8b59,0x8d08,0x8d0a, 0x8e7c,0x8e72,0x8e87,0x8e76,
  0x8e6c,0x8e7a,0x8e74,0x8f54, 0x8f4e,0x8fad,0x908a,0x908b,
  0x91b1,0x91ae,0x93e1,0x93d1, 0x93df,0x93c3,0x93c8,0x93dc,
  0x93dd,0x93d6,0x93e2,0x93cd, 0x93d8,0x93e4,0x93d7,0x93e8,
  0x95dc,0x96b4,0x96e3,0x972a, 0x9727,0x9761,0x97dc,0x97fb,
  0x985e,0x9858,0x985b,0x98bc, 0x9945,0x9949,0x9a16,0x9a19,
  0x9b0d,0x9be8,0x9be7,0x9bd6, 0x9bdb,0x9d89,0x9d61,0x9d72,
  0x9d6a,0x9d6c,0x9e92,0x9e97, 0x9e93,0x9eb4,0x52f8,0x56a8,
  0x56b7,0x56b6,0x56b4,0x56bc, 0x58e4,0x5b40,0x5b43,0x5b7d,
  0x5bf6,0x5dc9,0x61f8,0x61fa, 0x6518,0x6514,0x6519,0x66e6,
  0x6727,0x6aec,0x703e,0x7030, 0x7032,0x7210,0x737b,0x74cf,
  0x7662,0x7665,0x7926,0x792a, 0x792c,0x0000,
/* 0x6741(i:7220) */
  0x792b,0x7ac7,0x7af6,0x7c4c, 0x7c43,0x7c4d,0x7cef,0x7cf0,
  0x8fae,0x7e7d,0x7e7c,0x7e82, 0x7f4c,0x8000,0x81da,0x8266,
  0x85fb,0x85f9,0x8611,0x85fa, 0x8606,0x860b,0x8607,0x860a,
  0x8814,0x8815,0x8964,0x89ba, 0x89f8,0x8b70,0x8b6c,0x8b66,
  0x8b6f,0x8b5f,0x8b6b,0x8d0f, 0x8d0d,0x8e89,0x8e81,0x8e85,
  0x8e82,0x91b4,0x91cb,0x9418, 0x9403,0x93fd,0x95e1,0x9730,
  0x98c4,0x9952,0x9951,0x99a8, 0x9a2b,0x9a30,0x9a37,0x9a35,
  0x9c13,0x9c0d,0x9e79,0x9eb5, 0x9ee8,0x9f2f,0x9f5f,0x0000,
  0x9f63,0x9f61,0x5137,0x5138, 0x56c1,0x56c0,0x56c2,0x5914,
  0x5c6c,0x5dcd,0x61fc,0x61fe, 0x651d,0x651c,0x6595,0x66e9,
  0x6afb,0x6b04,0x6afa,0x6bb2, 0x704c,0x721b,0x72a7,0x74d6,
  0x74d4,0x7669,0x77d3,0x7c50, 0x7e8f,0x7e8c,0x7fbc,0x8617,
  0x862d,0x861a,0x8823,0x8822, 0x8821,0x881f,0x896a,0x896c,
  0x89bd,0x8b74,0x8b77,0x8b7d, 0x8d13,0x8e8a,0x8e8d,0x8e8b,
  0x8f5f,0x8faf,0x91ba,0x942e, 0x9433,0x9435,0x943a,0x9438,
  0x9432,0x942b,0x95e2,0x9738, 0x9739,0x9732,0x97ff,0x9867,
  0x9865,0x9957,0x9a45,0x9a43, 0x9a40,0x9a3e,0x9acf,0x9b54,
  0x9b51,0x9c2d,0x9c25,0x9daf, 0x9db4,0x9dc2,0x9db8,0x9e9d,
  0x9eef,0x9f19,0x9f5c,0x9f66, 0x9f67,0x513c,0x513b,0x56c8,
  0x56ca,0x56c9,0x5b7f,0x5dd4, 0x5dd2,0x5f4e,0x61ff,0x6524,
  0x6b0a,0x6b61,0x7051,0x7058, 0x7380,0x74e4,0x758a,0x766e,
  0x766c,0x79b3,0x7c60,0x7c5f, 0x807e,0x807d,0x81df,0x8972,
  0x896f,0x89fc,0x8b80,0x8d16, 0x8d17,0x8e91,0x8e93,0x8f61,
  0x9148,0x9444,0x9451,0x9452, 0x973d,0x0000,
/* 0x6841(i:7410) */
  0x973e,0x97c3,0x97c1,0x986b, 0x9955,0x9a55,0x9a4d,0x9ad2,
  0x9b1a,0x9c49,0x9c31,0x9c3e, 0x9c3b,0x9dd3,0x9dd7,0x9f34,
  0x9f6c,0x9f6a,0x9f94,0x56cc, 0x5dd6,0x6200,0x6523,0x652b,
  0x652a,0x66ec,0x6b10,0x74da, 0x7aca,0x7c64,0x7c63,0x7c65,
  0x7e93,0x7e96,0x7e94,0x81e2, 0x8638,0x863f,0x8831,0x8b8a,
  0x9090,0x908f,0x9463,0x9460, 0x9464,0x9768,0x986f,0x995c,
  0x9a5a,0x9a5b,0x9a57,0x9ad3, 0x9ad4,0x9ad1,0x9c54,0x9c57,
  0x9c56,0x9de5,0x9e9f,0x9ef4, 0x56d1,0x58e9,0x652c,0x0000,
  0x705e,0x7671,0x7672,0x77d7, 0x7f50,0x7f88,0x8836,0x8839,
  0x8862,0x8b93,0x8b92,0x8b96, 0x8277,0x8d1b,0x91c0,0x946a,
  0x9742,0x9748,0x9744,0x97c6, 0x9870,0x9a5f,0x9b22,0x9b58,
  0x9c5f,0x9df9,0x9dfa,0x9e7c, 0x9e7d,0x9f07,0x9f77,0x9f72,
  0x5ef3,0x6b16,0x7063,0x7c6c, 0x7c6e,0x883b,0x89c0,0x8ea1,
  0x91c1,0x9472,0x9470,0x9871, 0x995e,0x9ad6,0x9b23,0x9ecc,
  0x7064,0x77da,0x8b9a,0x9477, 0x97c9,0x9a62,0x9a65,0x7e9c,
  0x8b9c,0x8eaa,0x91c5,0x947d, 0x947e,0x947c,0x9c77,0x9c78,
  0x9ef7,0x8c54,0x947f,0x9e1a, 0x7228,0x9a6a,0x9b31,0x9e1b,
  0x9e1e,0x7c72,0x6491,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x6941(i:7600) */
  0x4e42,0x4e5c,0x51f5,0x531a, 0x5382,0x4e07,0x4e0c,0x4e47,
  0x4e8d,0x56d7,0xfa0c,0x5c6e, 0x5f73,0x4e0f,0x5187,0x4e0e,
  0x4e2e,0x4e93,0x4ec2,0x4ec9, 0x4ec8,0x5198,0x52fc,0x536c,
  0x53b9,0x5720,0x5903,0x592c, 0x5c10,0x5dff,0x65e1,0x6bb3,
  0x6bcc,0x6c14,0x723f,0x4e31, 0x4e3c,0x4ee8,0x4edc,0x4ee9,
  0x4ee1,0x4edd,0x4eda,0x520c, 0x531c,0x534c,0x5722,0x5723,
  0x5917,0x592f,0x5b81,0x5b84, 0x5c12,0x5c3b,0x5c74,0x5c73,
  0x5e04,0x5e80,0x5e82,0x5fc9, 0x6209,0x6250,0x6c15,0x0000,
  0x6c36,0x6c43,0x6c3f,0x6c3b, 0x72ae,0x72b0,0x738a,0x79b8,
  0x808a,0x961e,0x4f0e,0x4f18, 0x4f2c,0x4ef5,0x4f14,0x4ef1,
  0x4f00,0x4ef7,0x4f08,0x4f1d, 0x4f02,0x4f05,0x4f22,0x4f13,
  0x4f04,0x4ef4,0x4f12,0x51b1, 0x5213,0x5209,0x5210,0x52a6,
  0x5322,0x531f,0x534d,0x538a, 0x5407,0x56e1,0x56df,0x572e,
  0x572a,0x5734,0x593c,0x5980, 0x597c,0x5985,0x597b,0x597e,
  0x5977,0x597f,0x5b56,0x5c15, 0x5c25,0x5c7c,0x5c7a,0x5c7b,
  0x5c7e,0x5ddf,0x5e75,0x5e84, 0x5f02,0x5f1a,0x5f74,0x5fd5,
  0x5fd4,0x5fcf,0x6265,0x625c, 0x625e,0x6264,0x6261,0x6266,
  0x6262,0x6259,0x6260,0x625a, 0x65ef,0x65ee,0x673e,0x6739,
  0x6738,0x673b,0x673a,0x673f, 0x673c,0x6733,0x6c18,0x6c46,
  0x6c52,0x6c5c,0x6c4f,0x6c4a, 0x6c54,0x6c4b,0x6c4c,0x7071,
  0x725e,0x72b4,0x72b5,0x738e, 0x752a,0x767f,0x7a75,0x7f51,
  0x8278,0x827c,0x8280,0x827d, 0x827f,0x864d,0x897e,0x9099,
  0x9097,0x9098,0x909b,0x9094, 0x9622,0x9624,0x9620,0x9623,
  0x4f56,0x4f3b,0x4f62,0x4f49, 0x4f53,0x0000,
/* 0x6a41(i:7790) */
  0x4f64,0x4f3e,0x4f67,0x4f52, 0x4f5f,0x4f41,0x4f58,0x4f2d,
  0x4f33,0x4f3f,0x4f61,0x518f, 0x51b9,0x521c,0x521e,0x5221,
  0x52ad,0x52ae,0x5309,0x5363, 0x5372,0x538e,0x538f,0x5430,
  0x5437,0x542a,0x5454,0x5445, 0x5419,0x541c,0x5425,0x5418,
  0x543d,0x544f,0x5441,0x5428, 0x5424,0x5447,0x56ee,0x56e7,
  0x56e5,0x5741,0x5745,0x574c, 0x5749,0x574b,0x5752,0x5906,
  0x5940,0x59a6,0x5998,0x59a0, 0x5997,0x598e,0x59a2,0x5990,
  0x598f,0x59a7,0x59a1,0x5b8e, 0x5b92,0x5c28,0x5c2a,0x0000,
  0x5c8d,0x5c8f,0x5c88,0x5c8b, 0x5c89,0x5c92,0x5c8a,0x5c86,
  0x5c93,0x5c95,0x5de0,0x5e0a, 0x5e0e,0x5e8b,0x5e89,0x5e8c,
  0x5e88,0x5e8d,0x5f05,0x5f1d, 0x5f78,0x5f76,0x5fd2,0x5fd1,
  0x5fd0,0x5fed,0x5fe8,0x5fee, 0x5ff3,0x5fe1,0x5fe4,0x5fe3,
  0x5ffa,0x5fef,0x5ff7,0x5ffb, 0x6000,0x5ff4,0x623a,0x6283,
  0x628c,0x628e,0x628f,0x6294, 0x6287,0x6271,0x627b,0x627a,
  0x6270,0x6281,0x6288,0x6277, 0x627d,0x6272,0x6274,0x6537,
  0x65f0,0x65f4,0x65f3,0x65f2, 0x65f5,0x6745,0x6747,0x6759,
  0x6755,0x674c,0x6748,0x675d, 0x674d,0x675a,0x674b,0x6bd0,
  0x6c19,0x6c1a,0x6c78,0x6c67, 0x6c6b,0x6c84,0x6c8b,0x6c8f,
  0x6c71,0x6c6f,0x6c69,0x6c9a, 0x6c6d,0x6c87,0x6c95,0x6c9c,
  0x6c66,0x6c73,0x6c65,0x6c7b, 0x6c8e,0x7074,0x707a,0x7263,
  0x72bf,0x72bd,0x72c3,0x72c6, 0x72c1,0x72ba,0x72c5,0x7395,
  0x7397,0x7393,0x7394,0x7392, 0x753a,0x7539,0x7594,0x7595,
  0x7681,0x793d,0x8034,0x8095, 0x8099,0x8090,0x8092,0x809c,
  0x8290,0x828f,0x8285,0x828e, 0x8291,0x0000,
/* 0x6b41(i:7980) */
  0x8293,0x828a,0x8283,0x8284, 0x8c78,0x8fc9,0x8fbf,0x909f,
  0x90a1,0x90a5,0x909e,0x90a7, 0x90a0,0x9630,0x9628,0x962f,
  0x962d,0x4e33,0x4f98,0x4f7c, 0x4f85,0x4f7d,0x4f80,0x4f87,
  0x4f76,0x4f74,0x4f89,0x4f84, 0x4f77,0x4f4c,0x4f97,0x4f6a,
  0x4f9a,0x4f79,0x4f81,0x4f78, 0x4f90,0x4f9c,0x4f94,0x4f9e,
  0x4f92,0x4f82,0x4f95,0x4f6b, 0x4f6e,0x519e,0x51bc,0x51be,
  0x5235,0x5232,0x5233,0x5246, 0x5231,0x52bc,0x530a,0x530b,
  0x533c,0x5392,0x5394,0x5487, 0x547f,0x5481,0x5491,0x0000,
  0x5482,0x5488,0x546b,0x547a, 0x547e,0x5465,0x546c,0x5474,
  0x5466,0x548d,0x546f,0x5461, 0x5460,0x5498,0x5463,0x5467,
  0x5464,0x56f7,0x56f9,0x576f, 0x5772,0x576d,0x576b,0x5771,
  0x5770,0x5776,0x5780,0x5775, 0x577b,0x5773,0x5774,0x5762,
  0x5768,0x577d,0x590c,0x5945, 0x59b5,0x59ba,0x59cf,0x59ce,
  0x59b2,0x59cc,0x59c1,0x59b6, 0x59bc,0x59c3,0x59d6,0x59b1,
  0x59bd,0x59c0,0x59c8,0x59b4, 0x59c7,0x5b62,0x5b65,0x5b93,
  0x5b95,0x5c44,0x5c47,0x5cae, 0x5ca4,0x5ca0,0x5cb5,0x5caf,
  0x5ca8,0x5cac,0x5c9f,0x5ca3, 0x5cad,0x5ca2,0x5caa,0x5ca7,
  0x5c9d,0x5ca5,0x5cb6,0x5cb0, 0x5ca6,0x5e17,0x5e14,0x5e19,
  0x5f28,0x5f22,0x5f23,0x5f24, 0x5f54,0x5f82,0x5f7e,0x5f7d,
  0x5fde,0x5fe5,0x602d,0x6026, 0x6019,0x6032,0x600b,0x6034,
  0x600a,0x6017,0x6033,0x601a, 0x601e,0x602c,0x6022,0x600d,
  0x6010,0x602e,0x6013,0x6011, 0x600c,0x6009,0x601c,0x6214,
  0x623d,0x62ad,0x62b4,0x62d1, 0x62be,0x62aa,0x62b6,0x62ca,
  0x62ae,0x62b3,0x62af,0x62bb, 0x62a9,0x0000,
/* 0x6c41(i:8170) */
  0x62b0,0x62b8,0x653d,0x65a8, 0x65bb,0x6609,0x65fc,0x6604,
  0x6612,0x6608,0x65fb,0x6603, 0x660b,0x660d,0x6605,0x65fd,
  0x6611,0x6610,0x66f6,0x670a, 0x6785,0x676c,0x678e,0x6792,
  0x6776,0x677b,0x6798,0x6786, 0x6784,0x6774,0x678d,0x678c,
  0x677a,0x679f,0x6791,0x6799, 0x6783,0x677d,0x6781,0x6778,
  0x6779,0x6794,0x6b25,0x6b80, 0x6b7e,0x6bde,0x6c1d,0x6c93,
  0x6cec,0x6ceb,0x6cee,0x6cd9, 0x6cb6,0x6cd4,0x6cad,0x6ce7,
  0x6cb7,0x6cd0,0x6cc2,0x6cba, 0x6cc3,0x6cc6,0x6ced,0x0000,
  0x6cf2,0x6cd2,0x6cdd,0x6cb4, 0x6c8a,0x6c9d,0x6c80,0x6cde,
  0x6cc0,0x6d30,0x6ccd,0x6cc7, 0x6cb0,0x6cf9,0x6ccf,0x6ce9,
  0x6cd1,0x7094,0x7098,0x7085, 0x7093,0x7086,0x7084,0x7091,
  0x7096,0x7082,0x709a,0x7083, 0x726a,0x72d6,0x72cb,0x72d8,
  0x72c9,0x72dc,0x72d2,0x72d4, 0x72da,0x72cc,0x72d1,0x73a4,
  0x73a1,0x73ad,0x73a6,0x73a2, 0x73a0,0x73ac,0x739d,0x74dd,
  0x74e8,0x753f,0x7540,0x753e, 0x758c,0x7598,0x76af,0x76f3,
  0x76f1,0x76f0,0x76f5,0x77f8, 0x77fc,0x77f9,0x77fb,0x77fa,
  0x77f7,0x7942,0x793f,0x79c5, 0x7a78,0x7a7b,0x7afb,0x7c75,
  0x7cfd,0x8035,0x808f,0x80ae, 0x80a3,0x80b8,0x80b5,0x80ad,
  0x8220,0x82a0,0x82c0,0x82ab, 0x829a,0x8298,0x829b,0x82b5,
  0x82a7,0x82ae,0x82bc,0x829e, 0x82ba,0x82b4,0x82a8,0x82a1,
  0x82a9,0x82c2,0x82a4,0x82c3, 0x82b6,0x82a2,0x8670,0x866f,
  0x866d,0x866e,0x8c56,0x8fd2, 0x8fcb,0x8fd3,0x8fcd,0x8fd6,
  0x8fd5,0x8fd7,0x90b2,0x90b4, 0x90af,0x90b3,0x90b0,0x9639,
  0x963d,0x963c,0x963a,0x9643, 0x4fcd,0x0000,
/* 0x6d41(i:8360) */
  0x4fc5,0x4fd3,0x4fb2,0x4fc9, 0x4fcb,0x4fc1,0x4fd4,0x4fdc,
  0x4fd9,0x4fbb,0x4fb3,0x4fdb, 0x4fc7,0x4fd6,0x4fba,0x4fc0,
  0x4fb9,0x4fec,0x5244,0x5249, 0x52c0,0x52c2,0x533d,0x537c,
  0x5397,0x5396,0x5399,0x5398, 0x54ba,0x54a1,0x54ad,0x54a5,
  0x54cf,0x54c3,0x830d,0x54b7, 0x54ae,0x54d6,0x54b6,0x54c5,
  0x54c6,0x54a0,0x5470,0x54bc, 0x54a2,0x54be,0x5472,0x54de,
  0x54b0,0x57b5,0x579e,0x579f, 0x57a4,0x578c,0x5797,0x579d,
  0x579b,0x5794,0x5798,0x578f, 0x5799,0x57a5,0x579a,0x0000,
  0x5795,0x58f4,0x590d,0x5953, 0x59e1,0x59de,0x59ee,0x5a00,
  0x59f1,0x59dd,0x59fa,0x59fd, 0x59fc,0x59f6,0x59e4,0x59f2,
  0x59f7,0x59db,0x59e9,0x59f3, 0x59f5,0x59e0,0x59fe,0x59f4,
  0x59ed,0x5ba8,0x5c4c,0x5cd0, 0x5cd8,0x5ccc,0x5cd7,0x5ccb,
  0x5cdb,0x5cde,0x5cda,0x5cc9, 0x5cc7,0x5cca,0x5cd6,0x5cd3,
  0x5cd4,0x5ccf,0x5cc8,0x5cc6, 0x5cce,0x5cdf,0x5cf8,0x5df9,
  0x5e21,0x5e22,0x5e23,0x5e20, 0x5e24,0x5eb0,0x5ea4,0x5ea2,
  0x5e9b,0x5ea3,0x5ea5,0x5f07, 0x5f2e,0x5f56,0x5f86,0x6037,
  0x6039,0x6054,0x6072,0x605e, 0x6045,0x6053,0x6047,0x6049,
  0x605b,0x604c,0x6040,0x6042, 0x605f,0x6024,0x6044,0x6058,
  0x6066,0x606e,0x6242,0x6243, 0x62cf,0x630d,0x630b,0x62f5,
  0x630e,0x6303,0x62eb,0x62f9, 0x630f,0x630c,0x62f8,0x62f6,
  0x6300,0x6313,0x6314,0x62fa, 0x6315,0x62fb,0x62f0,0x6541,
  0x6543,0x65aa,0x65bf,0x6636, 0x6621,0x6632,0x6635,0x661c,
  0x6626,0x6622,0x6633,0x662b, 0x663a,0x661d,0x6634,0x6639,
  0x662e,0x670f,0x6710,0x67c1, 0x67f2,0x0000,
/* 0x6e41(i:8550) */
  0x67c8,0x67ba,0x67dc,0x67bb, 0x67f8,0x67d8,0x67c0,0x67b7,
  0x67c5,0x67eb,0x67e4,0x67df, 0x67b5,0x67cd,0x67b3,0x67f7,
  0x67f6,0x67ee,0x67e3,0x67c2, 0x67b9,0x67ce,0x67e7,0x67f0,
  0x67b2,0x67fc,0x67c6,0x67ed, 0x67cc,0x67ae,0x67e6,0x67db,
  0x67fa,0x67c9,0x67ca,0x67c3, 0x67ea,0x67cb,0x6b28,0x6b82,
  0x6b84,0x6bb6,0x6bd6,0x6bd8, 0x6be0,0x6c20,0x6c21,0x6d28,
  0x6d34,0x6d2d,0x6d1f,0x6d3c, 0x6d3f,0x6d12,0x6d0a,0x6cda,
  0x6d33,0x6d04,0x6d19,0x6d3a, 0x6d1a,0x6d11,0x6d00,0x0000,
  0x6d1d,0x6d42,0x6d01,0x6d18, 0x6d37,0x6d03,0x6d0f,0x6d40,
  0x6d07,0x6d20,0x6d2c,0x6d08, 0x6d22,0x6d09,0x6d10,0x70b7,
  0x709f,0x70be,0x70b1,0x70b0, 0x70a1,0x70b4,0x70b5,0x70a9,
  0x7241,0x7249,0x724a,0x726c, 0x7270,0x7273,0x726e,0x72ca,
  0x72e4,0x72e8,0x72eb,0x72df, 0x72ea,0x72e6,0x72e3,0x7385,
  0x73cc,0x73c2,0x73c8,0x73c5, 0x73b9,0x73b6,0x73b5,0x73b4,
  0x73eb,0x73bf,0x73c7,0x73be, 0x73c3,0x73c6,0x73b8,0x73cb,
  0x74ec,0x74ee,0x752e,0x7547, 0x7548,0x75a7,0x75aa,0x7679,
  0x76c4,0x7708,0x7703,0x7704, 0x7705,0x770a,0x76f7,0x76fb,
  0x76fa,0x77e7,0x77e8,0x7806, 0x7811,0x7812,0x7805,0x7810,
  0x780f,0x780e,0x7809,0x7803, 0x7813,0x794a,0x794c,0x794b,
  0x7945,0x7944,0x79d5,0x79cd, 0x79cf,0x79d6,0x79ce,0x7a80,
  0x7a7e,0x7ad1,0x7b00,0x7b01, 0x7c7a,0x7c78,0x7c79,0x7c7f,
  0x7c80,0x7c81,0x7d03,0x7d08, 0x7d01,0x7f58,0x7f91,0x7f8d,
  0x7fbe,0x8007,0x800e,0x800f, 0x8014,0x8037,0x80d8,0x80c7,
  0x80e0,0x80d1,0x80c8,0x80c2, 0x80d0,0x0000,
/* 0x6f41(i:8740) */
  0x80c5,0x80e3,0x80d9,0x80dc, 0x80ca,0x80d5,0x80c9,0x80cf,
  0x80d7,0x80e6,0x80cd,0x81ff, 0x8221,0x8294,0x82d9,0x82fe,
  0x82f9,0x8307,0x82e8,0x8300, 0x82d5,0x833a,0x82eb,0x82d6,
  0x82f4,0x82ec,0x82e1,0x82f2, 0x82f5,0x830c,0x82fb,0x82f6,
  0x82f0,0x82ea,0x82e4,0x82e0, 0x82fa,0x82f3,0x82ed,0x8677,
  0x8674,0x867c,0x8673,0x8841, 0x884e,0x8867,0x886a,0x8869,
  0x89d3,0x8a04,0x8a07,0x8d72, 0x8fe3,0x8fe1,0x8fee,0x8fe0,
  0x90f1,0x90bd,0x90bf,0x90d5, 0x90c5,0x90be,0x90c7,0x0000,
  0x90cb,0x90c8,0x91d4,0x91d3, 0x9654,0x964f,0x9651,0x9653,
  0x964a,0x964e,0x501e,0x5005, 0x5007,0x5013,0x5022,0x5030,
  0x501b,0x4ff5,0x4ff4,0x5033, 0x5037,0x502c,0x4ff6,0x4ff7,
  0x5017,0x501c,0x5020,0x5027, 0x5035,0x502f,0x5031,0x500e,
  0x515a,0x5194,0x5193,0x51ca, 0x51c4,0x51c5,0x51c8,0x51ce,
  0x5261,0x525a,0x5252,0x525e, 0x525f,0x5255,0x5262,0x52cd,
  0x530e,0x539e,0x5526,0x54e2, 0x5517,0x5512,0x54e7,0x54f3,
  0x54e4,0x551a,0x54ff,0x5504, 0x5508,0x54eb,0x5511,0x5505,
  0x54f1,0x550a,0x54fb,0x54f7, 0x54f8,0x54e0,0x550e,0x5503,
  0x550b,0x5701,0x5702,0x57cc, 0x5832,0x57d5,0x57d2,0x57ba,
  0x57c6,0x57bd,0x57bc,0x57b8, 0x57b6,0x57bf,0x57c7,0x57d0,
  0x57b9,0x57c1,0x590e,0x594a, 0x5a19,0x5a16,0x5a2d,0x5a2e,
  0x5a15,0x5a0f,0x5a17,0x5a0a, 0x5a1e,0x5a33,0x5b6c,0x5ba7,
  0x5bad,0x5bac,0x5c03,0x5c56, 0x5c54,0x5cec,0x5cff,0x5cee,
  0x5cf1,0x5cf7,0x5d00,0x5cf9, 0x5e29,0x5e28,0x5ea8,0x5eae,
  0x5eaa,0x5eac,0x5f33,0x5f30, 0x5f67,0x0000,
/* 0x7041(i:8930) */
  0x605d,0x605a,0x6067,0x6041, 0x60a2,0x6088,0x6080,0x6092,
  0x6081,0x609d,0x6083,0x6095, 0x609b,0x6097,0x6087,0x609c,
  0x608e,0x6219,0x6246,0x62f2, 0x6310,0x6356,0x632c,0x6344,
  0x6345,0x6336,0x6343,0x63e4, 0x6339,0x634b,0x634a,0x633c,
  0x6329,0x6341,0x6334,0x6358, 0x6354,0x6359,0x632d,0x6347,
  0x6333,0x635a,0x6351,0x6338, 0x6357,0x6340,0x6348,0x654a,
  0x6546,0x65c6,0x65c3,0x65c4, 0x65c2,0x664a,0x665f,0x6647,
  0x6651,0x6712,0x6713,0x681f, 0x681a,0x6849,0x6832,0x0000,
  0x6833,0x683b,0x684b,0x684f, 0x6816,0x6831,0x681c,0x6835,
  0x682b,0x682d,0x682f,0x684e, 0x6844,0x6834,0x681d,0x6812,
  0x6814,0x6826,0x6828,0x682e, 0x684d,0x683a,0x6825,0x6820,
  0x6b2c,0x6b2f,0x6b2d,0x6b31, 0x6b34,0x6b6d,0x8082,0x6b88,
  0x6be6,0x6be4,0x6be8,0x6be3, 0x6be2,0x6be7,0x6c25,0x6d7a,
  0x6d63,0x6d64,0x6d76,0x6d0d, 0x6d61,0x6d92,0x6d58,0x6d62,
  0x6d6d,0x6d6f,0x6d91,0x6d8d, 0x6def,0x6d7f,0x6d86,0x6d5e,
  0x6d67,0x6d60,0x6d97,0x6d70, 0x6d7c,0x6d5f,0x6d82,0x6d98,
  0x6d2f,0x6d68,0x6d8b,0x6d7e, 0x6d80,0x6d84,0x6d16,0x6d83,
  0x6d7b,0x6d7d,0x6d75,0x6d90, 0x70dc,0x70d3,0x70d1,0x70dd,
  0x70cb,0x7f39,0x70e2,0x70d7, 0x70d2,0x70de,0x70e0,0x70d4,
  0x70cd,0x70c5,0x70c6,0x70c7, 0x70da,0x70ce,0x70e1,0x7242,
  0x7278,0x7277,0x7276,0x7300, 0x72fa,0x72f4,0x72fe,0x72f6,
  0x72f3,0x72fb,0x7301,0x73d3, 0x73d9,0x73e5,0x73d6,0x73bc,
  0x73e7,0x73e3,0x73e9,0x73dc, 0x73d2,0x73db,0x73d4,0x73dd,
  0x73da,0x73d7,0x73d8,0x73e8, 0x74de,0x0000,
/* 0x7141(i:9120) */
  0x74df,0x74f4,0x74f5,0x7521, 0x755b,0x755f,0x75b0,0x75c1,
  0x75bb,0x75c4,0x75c0,0x75bf, 0x75b6,0x75ba,0x768a,0x76c9,
  0x771d,0x771b,0x7710,0x7713, 0x7712,0x7723,0x7711,0x7715,
  0x7719,0x771a,0x7722,0x7727, 0x7823,0x782c,0x7822,0x7835,
  0x782f,0x7828,0x782e,0x782b, 0x7821,0x7829,0x7833,0x782a,
  0x7831,0x7954,0x795b,0x794f, 0x795c,0x7953,0x7952,0x7951,
  0x79eb,0x79ec,0x79e0,0x79ee, 0x79ed,0x79ea,0x79dc,0x79de,
  0x79dd,0x7a86,0x7a89,0x7a85, 0x7a8b,0x7a8c,0x7a8a,0x0000,
  0x7a87,0x7ad8,0x7b10,0x7b04, 0x7b13,0x7b05,0x7b0f,0x7b08,
  0x7b0a,0x7b0e,0x7b09,0x7b12, 0x7c84,0x7c91,0x7c8a,0x7c8c,
  0x7c88,0x7c8d,0x7c85,0x7d1e, 0x7d1d,0x7d11,0x7d0e,0x7d18,
  0x7d16,0x7d13,0x7d1f,0x7d12, 0x7d0f,0x7d0c,0x7f5c,0x7f61,
  0x7f5e,0x7f60,0x7f5d,0x7f5b, 0x7f96,0x7f92,0x7fc3,0x7fc2,
  0x7fc0,0x8016,0x803e,0x8039, 0x80fa,0x80f2,0x80f9,0x80f5,
  0x8101,0x80fb,0x8100,0x8201, 0x822f,0x8225,0x8333,0x832d,
  0x8344,0x8319,0x8351,0x8325, 0x8356,0x833f,0x8341,0x8326,
  0x831c,0x8322,0x8342,0x834e, 0x831b,0x832a,0x8308,0x833c,
  0x834d,0x8316,0x8324,0x8320, 0x8337,0x832f,0x8329,0x8347,
  0x8345,0x834c,0x8353,0x831e, 0x832c,0x834b,0x8327,0x8348,
  0x8653,0x8652,0x86a2,0x86a8, 0x8696,0x868d,0x8691,0x869e,
  0x8687,0x8697,0x8686,0x868b, 0x869a,0x8685,0x86a5,0x8699,
  0x86a1,0x86a7,0x8695,0x8698, 0x868e,0x869d,0x8690,0x8694,
  0x8843,0x8844,0x886d,0x8875, 0x8876,0x8872,0x8880,0x8871,
  0x887f,0x886f,0x8883,0x887e, 0x8874,0x0000,
/* 0x7241(i:9310) */
  0x887c,0x8a12,0x8c47,0x8c57, 0x8c7b,0x8ca4,0x8ca3,0x8d76,
  0x8d78,0x8db5,0x8db7,0x8db6, 0x8ed1,0x8ed3,0x8ffe,0x8ff5,
  0x9002,0x8fff,0x8ffb,0x9004, 0x8ffc,0x8ff6,0x90d6,0x90e0,
  0x90d9,0x90da,0x90e3,0x90df, 0x90e5,0x90d8,0x90db,0x90d7,
  0x90dc,0x90e4,0x9150,0x914e, 0x914f,0x91d5,0x91e2,0x91da,
  0x965c,0x965f,0x96bc,0x98e3, 0x9adf,0x9b2f,0x4e7f,0x5070,
  0x506a,0x5061,0x505e,0x5060, 0x5053,0x504b,0x505d,0x5072,
  0x5048,0x504d,0x5041,0x505b, 0x504a,0x5062,0x5015,0x0000,
  0x5045,0x505f,0x5069,0x506b, 0x5063,0x5064,0x5046,0x5040,
  0x506e,0x5073,0x5057,0x5051, 0x51d0,0x526b,0x526d,0x526c,
  0x526e,0x52d6,0x52d3,0x532d, 0x539c,0x5575,0x5576,0x553c,
  0x554d,0x5550,0x5534,0x552a, 0x5551,0x5562,0x5536,0x5535,
  0x5530,0x5552,0x5545,0x550c, 0x5532,0x5565,0x554e,0x5539,
  0x5548,0x552d,0x553b,0x5540, 0x554b,0x570a,0x5707,0x57fb,
  0x5814,0x57e2,0x57f6,0x57dc, 0x57f4,0x5800,0x57ed,0x57fd,
  0x5808,0x57f8,0x580b,0x57f3, 0x57cf,0x5807,0x57ee,0x57e3,
  0x57f2,0x57e5,0x57ec,0x57e1, 0x580e,0x57fc,0x5810,0x57e7,
  0x5801,0x580c,0x57f1,0x57e9, 0x57f0,0x580d,0x5804,0x595c,
  0x5a60,0x5a58,0x5a55,0x5a67, 0x5a5e,0x5a38,0x5a35,0x5a6d,
  0x5a50,0x5a5f,0x5a65,0x5a6c, 0x5a53,0x5a64,0x5a57,0x5a43,
  0x5a5d,0x5a52,0x5a44,0x5a5b, 0x5a48,0x5a8e,0x5a3e,0x5a4d,
  0x5a39,0x5a4c,0x5a70,0x5a69, 0x5a47,0x5a51,0x5a56,0x5a42,
  0x5a5c,0x5b72,0x5b6e,0x5bc1, 0x5bc0,0x5c59,0x5d1e,0x5d0b,
  0x5d1d,0x5d1a,0x5d20,0x5d0c, 0x5d28,0x0000,
/* 0x7341(i:9500) */
  0x5d0d,0x5d26,0x5d25,0x5d0f, 0x5d30,0x5d12,0x5d23,0x5d1f,
  0x5d2e,0x5e3e,0x5e34,0x5eb1, 0x5eb4,0x5eb9,0x5eb2,0x5eb3,
  0x5f36,0x5f38,0x5f9b,0x5f96, 0x5f9f,0x608a,0x6090,0x6086,
  0x60be,0x60b0,0x60ba,0x60d3, 0x60d4,0x60cf,0x60e4,0x60d9,
  0x60dd,0x60c8,0x60b1,0x60db, 0x60b7,0x60ca,0x60bf,0x60c3,
  0x60cd,0x60c0,0x6332,0x6365, 0x638a,0x6382,0x637d,0x63bd,
  0x639e,0x63ad,0x639d,0x6397, 0x63ab,0x638e,0x636f,0x6387,
  0x6390,0x636e,0x63af,0x6375, 0x639c,0x636d,0x63ae,0x0000,
  0x637c,0x63a4,0x633b,0x639f, 0x6378,0x6385,0x6381,0x6391,
  0x638d,0x6370,0x6553,0x65cd, 0x6665,0x6661,0x665b,0x6659,
  0x665c,0x6662,0x6718,0x6879, 0x6887,0x6890,0x689c,0x686d,
  0x686e,0x68ae,0x68ab,0x6956, 0x686f,0x68a3,0x68ac,0x68a9,
  0x6875,0x6874,0x68b2,0x688f, 0x6877,0x6892,0x687c,0x686b,
  0x6872,0x68aa,0x6880,0x6871, 0x687e,0x689b,0x6896,0x688b,
  0x68a0,0x6889,0x68a4,0x6878, 0x687b,0x6891,0x688c,0x688a,
  0x687d,0x6b36,0x6b33,0x6b37, 0x6b38,0x6b91,0x6b8f,0x6b8d,
  0x6b8e,0x6b8c,0x6c2a,0x6dc0, 0x6dab,0x6db4,0x6db3,0x6e74,
  0x6dac,0x6de9,0x6de2,0x6db7, 0x6df6,0x6dd4,0x6e00,0x6dc8,
  0x6de0,0x6ddf,0x6dd6,0x6dbe, 0x6de5,0x6ddc,0x6ddd,0x6ddb,
  0x6df4,0x6dca,0x6dbd,0x6ded, 0x6df0,0x6dba,0x6dd5,0x6dc2,
  0x6dcf,0x6dc9,0x6dd0,0x6df2, 0x6dd3,0x6dfd,0x6dd7,0x6dcd,
  0x6de3,0x6dbb,0x70fa,0x710d, 0x70f7,0x7117,0x70f4,0x710c,
  0x70f0,0x7104,0x70f3,0x7110, 0x70fc,0x70ff,0x7106,0x7113,
  0x7100,0x70f8,0x70f6,0x710b, 0x7102,0x0000,
/* 0x7441(i:9690) */
  0x710e,0x727e,0x727b,0x727c, 0x727f,0x731d,0x7317,0x7307,
  0x7311,0x7318,0x730a,0x7308, 0x72ff,0x730f,0x731e,0x7388,
  0x73f6,0x73f8,0x73f5,0x7404, 0x7401,0x73fd,0x7407,0x7400,
  0x73fa,0x73fc,0x73ff,0x740c, 0x740b,0x73f4,0x7408,0x7564,
  0x7563,0x75ce,0x75d2,0x75cf, 0x75cb,0x75cc,0x75d1,0x75d0,
  0x768f,0x7689,0x76d3,0x7739, 0x772f,0x772d,0x7731,0x7732,
  0x7734,0x7733,0x773d,0x7725, 0x773b,0x7735,0x7848,0x7852,
  0x7849,0x784d,0x784a,0x784c, 0x7826,0x7845,0x7850,0x0000,
  0x7964,0x7967,0x7969,0x796a, 0x7963,0x796b,0x7961,0x79bb,
  0x79fa,0x79f8,0x79f6,0x79f7, 0x7a8f,0x7a94,0x7a90,0x7b35,
  0x7b47,0x7b34,0x7b25,0x7b30, 0x7b22,0x7b24,0x7b33,0x7b18,
  0x7b2a,0x7b1d,0x7b31,0x7b2b, 0x7b2d,0x7b2f,0x7b32,0x7b38,
  0x7b1a,0x7b23,0x7c94,0x7c98, 0x7c96,0x7ca3,0x7d35,0x7d3d,
  0x7d38,0x7d36,0x7d3a,0x7d45, 0x7d2c,0x7d29,0x7d41,0x7d47,
  0x7d3e,0x7d3f,0x7d4a,0x7d3b, 0x7d28,0x7f63,0x7f95,0x7f9c,
  0x7f9d,0x7f9b,0x7fca,0x7fcb, 0x7fcd,0x7fd0,0x7fd1,0x7fc7,
  0x7fcf,0x7fc9,0x801f,0x801e, 0x801b,0x8047,0x8043,0x8048,
  0x8118,0x8125,0x8119,0x811b, 0x812d,0x811f,0x812c,0x811e,
  0x8121,0x8115,0x8127,0x811d, 0x8122,0x8211,0x8238,0x8233,
  0x823a,0x8234,0x8232,0x8274, 0x8390,0x83a3,0x83a8,0x838d,
  0x837a,0x8373,0x83a4,0x8374, 0x838f,0x8381,0x8395,0x8399,
  0x8375,0x8394,0x83a9,0x837d, 0x8383,0x838c,0x839d,0x839b,
  0x83aa,0x838b,0x837e,0x83a5, 0x83af,0x8388,0x8397,0x83b0,
  0x837f,0x83a6,0x8387,0x83ae, 0x8376,0x0000,
/* 0x7541(i:9880) */
  0x839a,0x8659,0x8656,0x86bf, 0x86b7,0x86c2,0x86c1,0x86c5,
  0x86ba,0x86b0,0x86c8,0x86b9, 0x86b3,0x86b8,0x86cc,0x86b4,
  0x86bb,0x86bc,0x86c3,0x86bd, 0x86be,0x8852,0x8889,0x8895,
  0x88a8,0x88a2,0x88aa,0x889a, 0x8891,0x88a1,0x889f,0x8898,
  0x88a7,0x8899,0x889b,0x8897, 0x88a4,0x88ac,0x888c,0x8893,
  0x888e,0x8982,0x89d6,0x89d9, 0x89d5,0x8a30,0x8a27,0x8a2c,
  0x8a1e,0x8c39,0x8c3b,0x8c5c, 0x8c5d,0x8c7d,0x8ca5,0x8d7d,
  0x8d7b,0x8d79,0x8dbc,0x8dc2, 0x8db9,0x8dbf,0x8dc1,0x0000,
  0x8ed8,0x8ede,0x8edd,0x8edc, 0x8ed7,0x8ee0,0x8ee1,0x9024,
  0x900b,0x9011,0x901c,0x900c, 0x9021,0x90ef,0x90ea,0x90f0,
  0x90f4,0x90f2,0x90f3,0x90d4, 0x90eb,0x90ec,0x90e9,0x9156,
  0x9158,0x915a,0x9153,0x9155, 0x91ec,0x91f4,0x91f1,0x91f3,
  0x91f8,0x91e4,0x91f9,0x91ea, 0x91eb,0x91f7,0x91e8,0x91ee,
  0x957a,0x9586,0x9588,0x967c, 0x966d,0x966b,0x9671,0x966f,
  0x96bf,0x976a,0x9804,0x98e5, 0x9997,0x509b,0x5095,0x5094,
  0x509e,0x508b,0x50a3,0x5083, 0x508c,0x508e,0x509d,0x5068,
  0x509c,0x5092,0x5082,0x5087, 0x515f,0x51d4,0x5312,0x5311,
  0x53a4,0x53a7,0x5591,0x55a8, 0x55a5,0x55ad,0x5577,0x5645,
  0x55a2,0x5593,0x5588,0x558f, 0x55b5,0x5581,0x55a3,0x5592,
  0x55a4,0x557d,0x558c,0x55a6, 0x557f,0x5595,0x55a1,0x558e,
  0x570c,0x5829,0x5837,0x5819, 0x581e,0x5827,0x5823,0x5828,
  0x57f5,0x5848,0x5825,0x581c, 0x581b,0x5833,0x583f,0x5836,
  0x582e,0x5839,0x5838,0x582d, 0x582c,0x583b,0x5961,0x5aaf,
  0x5a94,0x5a9f,0x5a7a,0x5aa2, 0x5a9e,0x0000,
/* 0x7641(i:10070) */
  0x5a78,0x5aa6,0x5a7c,0x5aa5, 0x5aac,0x5a95,0x5aae,0x5a37,
  0x5a84,0x5a8a,0x5a97,0x5a83, 0x5a8b,0x5aa9,0x5a7b,0x5a7d,
  0x5a8c,0x5a9c,0x5a8f,0x5a93, 0x5a9d,0x5bea,0x5bcd,0x5bcb,
  0x5bd4,0x5bd1,0x5bca,0x5bce, 0x5c0c,0x5c30,0x5d37,0x5d43,
  0x5d6b,0x5d41,0x5d4b,0x5d3f, 0x5d35,0x5d51,0x5d4e,0x5d55,
  0x5d33,0x5d3a,0x5d52,0x5d3d, 0x5d31,0x5d59,0x5d42,0x5d39,
  0x5d49,0x5d38,0x5d3c,0x5d32, 0x5d36,0x5d40,0x5d45,0x5e44,
  0x5e41,0x5f58,0x5fa6,0x5fa5, 0x5fab,0x60c9,0x60b9,0x0000,
  0x60cc,0x60e2,0x60ce,0x60c4, 0x6114,0x60f2,0x610a,0x6116,
  0x6105,0x60f5,0x6113,0x60f8, 0x60fc,0x60fe,0x60c1,0x6103,
  0x6118,0x611d,0x6110,0x60ff, 0x6104,0x610b,0x624a,0x6394,
  0x63b1,0x63b0,0x63ce,0x63e5, 0x63e8,0x63ef,0x63c3,0x649d,
  0x63f3,0x63ca,0x63e0,0x63f6, 0x63d5,0x63f2,0x63f5,0x6461,
  0x63df,0x63be,0x63dd,0x63dc, 0x63c4,0x63d8,0x63d3,0x63c2,
  0x63c7,0x63cc,0x63cb,0x63c8, 0x63f0,0x63d7,0x63d9,0x6532,
  0x6567,0x656a,0x6564,0x655c, 0x6568,0x6565,0x658c,0x659d,
  0x659e,0x65ae,0x65d0,0x65d2, 0x667c,0x666c,0x667b,0x6680,
  0x6671,0x6679,0x666a,0x6672, 0x6701,0x690c,0x68d3,0x6904,
  0x68dc,0x692a,0x68ec,0x68ea, 0x68f1,0x690f,0x68d6,0x68f7,
  0x68eb,0x68e4,0x68f6,0x6913, 0x6910,0x68f3,0x68e1,0x6907,
  0x68cc,0x6908,0x6970,0x68b4, 0x6911,0x68ef,0x68c6,0x6914,
  0x68f8,0x68d0,0x68fd,0x68fc, 0x68e8,0x690b,0x690a,0x6917,
  0x68ce,0x68c8,0x68dd,0x68de, 0x68e6,0x68f4,0x68d1,0x6906,
  0x68d4,0x68e9,0x6915,0x6925, 0x68c7,0x0000,
/* 0x7741(i:10260) */
  0x6b39,0x6b3b,0x6b3f,0x6b3c, 0x6b94,0x6b97,0x6b99,0x6b95,
  0x6bbd,0x6bf0,0x6bf2,0x6bf3, 0x6c30,0x6dfc,0x6e46,0x6e47,
  0x6e1f,0x6e49,0x6e88,0x6e3c, 0x6e3d,0x6e45,0x6e62,0x6e2b,
  0x6e3f,0x6e41,0x6e5d,0x6e73, 0x6e1c,0x6e33,0x6e4b,0x6e40,
  0x6e51,0x6e3b,0x6e03,0x6e2e, 0x6e5e,0x6e68,0x6e5c,0x6e61,
  0x6e31,0x6e28,0x6e60,0x6e71, 0x6e6b,0x6e39,0x6e22,0x6e30,
  0x6e53,0x6e65,0x6e27,0x6e78, 0x6e64,0x6e77,0x6e55,0x6e79,
  0x6e52,0x6e66,0x6e35,0x6e36, 0x6e5a,0x7120,0x711e,0x0000,
  0x712f,0x70fb,0x712e,0x7131, 0x7123,0x7125,0x7122,0x7132,
  0x711f,0x7128,0x713a,0x711b, 0x724b,0x725a,0x7288,0x7289,
  0x7286,0x7285,0x728b,0x7312, 0x730b,0x7330,0x7322,0x7331,
  0x7333,0x7327,0x7332,0x732d, 0x7326,0x7323,0x7335,0x730c,
  0x742e,0x742c,0x7430,0x742b, 0x7416,0x741a,0x7421,0x742d,
  0x7431,0x7424,0x7423,0x741d, 0x7429,0x7420,0x7432,0x74fb,
  0x752f,0x756f,0x756c,0x75e7, 0x75da,0x75e1,0x75e6,0x75dd,
  0x75df,0x75e4,0x75d7,0x7695, 0x7692,0x76da,0x7746,0x7747,
  0x7744,0x774d,0x7745,0x774a, 0x774e,0x774b,0x774c,0x77de,
  0x77ec,0x7860,0x7864,0x7865, 0x785c,0x786d,0x7871,0x786a,
  0x786e,0x7870,0x7869,0x7868, 0x785e,0x7862,0x7974,0x7973,
  0x7972,0x7970,0x7a02,0x7a0a, 0x7a03,0x7a0c,0x7a04,0x7a99,
  0x7ae6,0x7ae4,0x7b4a,0x7b3b, 0x7b44,0x7b48,0x7b4c,0x7b4e,
  0x7b40,0x7b58,0x7b45,0x7ca2, 0x7c9e,0x7ca8,0x7ca1,0x7d58,
  0x7d6f,0x7d63,0x7d53,0x7d56, 0x7d67,0x7d6a,0x7d4f,0x7d6d,
  0x7d5c,0x7d6b,0x7d52,0x7d54, 0x7d69,0x0000,
/* 0x7841(i:10450) */
  0x7d51,0x7d5f,0x7d4e,0x7f3e, 0x7f3f,0x7f65,0x7f66,0x7fa2,
  0x7fa0,0x7fa1,0x7fd7,0x8051, 0x804f,0x8050,0x80fe,0x80d4,
  0x8143,0x814a,0x8152,0x814f, 0x8147,0x813d,0x814d,0x813a,
  0x81e6,0x81ee,0x81f7,0x81f8, 0x81f9,0x8204,0x823c,0x823d,
  0x823f,0x8275,0x833b,0x83cf, 0x83f9,0x8423,0x83c0,0x83e8,
  0x8412,0x83e7,0x83e4,0x83fc, 0x83f6,0x8410,0x83c6,0x83c8,
  0x83eb,0x83e3,0x83bf,0x8401, 0x83dd,0x83e5,0x83d8,0x83ff,
  0x83e1,0x83cb,0x83ce,0x83d6, 0x83f5,0x83c9,0x8409,0x0000,
  0x840f,0x83de,0x8411,0x8406, 0x83c2,0x83f3,0x83d5,0x83fa,
  0x83c7,0x83d1,0x83ea,0x8413, 0x83c3,0x83ec,0x83ee,0x83c4,
  0x83fb,0x83d7,0x83e2,0x841b, 0x83db,0x83fe,0x86d8,0x86e2,
  0x86e6,0x86d3,0x86e3,0x86da, 0x86ea,0x86dd,0x86eb,0x86dc,
  0x86ec,0x86e9,0x86d7,0x86e8, 0x86d1,0x8848,0x8856,0x8855,
  0x88ba,0x88d7,0x88b9,0x88b8, 0x88c0,0x88be,0x88b6,0x88bc,
  0x88b7,0x88bd,0x88b2,0x8901, 0x88c9,0x8995,0x8998,0x8997,
  0x89dd,0x89da,0x89db,0x8a4e, 0x8a4d,0x8a39,0x8a59,0x8a40,
  0x8a57,0x8a58,0x8a44,0x8a45, 0x8a52,0x8a48,0x8a51,0x8a4a,
  0x8a4c,0x8a4f,0x8c5f,0x8c81, 0x8c80,0x8cba,0x8cbe,0x8cb0,
  0x8cb9,0x8cb5,0x8d84,0x8d80, 0x8d89,0x8dd8,0x8dd3,0x8dcd,
  0x8dc7,0x8dd6,0x8ddc,0x8dcf, 0x8dd5,0x8dd9,0x8dc8,0x8dd7,
  0x8dc5,0x8eef,0x8ef7,0x8efa, 0x8ef9,0x8ee6,0x8eee,0x8ee5,
  0x8ef5,0x8ee7,0x8ee8,0x8ef6, 0x8eeb,0x8ef1,0x8eec,0x8ef4,
  0x8ee9,0x902d,0x9034,0x902f, 0x9106,0x912c,0x9104,0x90ff,
  0x90fc,0x9108,0x90f9,0x90fb, 0x9101,0x0000,
/* 0x7941(i:10640) */
  0x9100,0x9107,0x9105,0x9103, 0x9161,0x9164,0x915f,0x9162,
  0x9160,0x9201,0x920a,0x9225, 0x9203,0x921a,0x9226,0x920f,
  0x920c,0x9200,0x9212,0x91ff, 0x91fd,0x9206,0x9204,0x9227,
  0x9202,0x921c,0x9224,0x9219, 0x9217,0x9205,0x9216,0x957b,
  0x958d,0x958c,0x9590,0x9687, 0x967e,0x9688,0x9689,0x9683,
  0x9680,0x96c2,0x96c8,0x96c3, 0x96f1,0x96f0,0x976c,0x9770,
  0x976e,0x9807,0x98a9,0x98eb, 0x9ce6,0x9ef9,0x4e83,0x4e84,
  0x4eb6,0x50bd,0x50bf,0x50c6, 0x50ae,0x50c4,0x50ca,0x0000,
  0x50b4,0x50c8,0x50c2,0x50b0, 0x50c1,0x50ba,0x50b1,0x50cb,
  0x50c9,0x50b6,0x50b8,0x51d7, 0x527a,0x5278,0x527b,0x527c,
  0x55c3,0x55db,0x55cc,0x55d0, 0x55cb,0x55ca,0x55dd,0x55c0,
  0x55d4,0x55c4,0x55e9,0x55bf, 0x55d2,0x558d,0x55cf,0x55d5,
  0x55e2,0x55d6,0x55c8,0x55f2, 0x55cd,0x55d9,0x55c2,0x5714,
  0x5853,0x5868,0x5864,0x584f, 0x584d,0x5849,0x586f,0x5855,
  0x584e,0x585d,0x5859,0x5865, 0x585b,0x583d,0x5863,0x5871,
  0x58fc,0x5ac7,0x5ac4,0x5acb, 0x5aba,0x5ab8,0x5ab1,0x5ab5,
  0x5ab0,0x5abf,0x5ac8,0x5abb, 0x5ac6,0x5ab7,0x5ac0,0x5aca,
  0x5ab4,0x5ab6,0x5acd,0x5ab9, 0x5a90,0x5bd6,0x5bd8,0x5bd9,
  0x5c1f,0x5c33,0x5d71,0x5d63, 0x5d4a,0x5d65,0x5d72,0x5d6c,
  0x5d5e,0x5d68,0x5d67,0x5d62, 0x5df0,0x5e4f,0x5e4e,0x5e4a,
  0x5e4d,0x5e4b,0x5ec5,0x5ecc, 0x5ec6,0x5ecb,0x5ec7,0x5f40,
  0x5faf,0x5fad,0x60f7,0x6149, 0x614a,0x612b,0x6145,0x6136,
  0x6132,0x612e,0x6146,0x612f, 0x614f,0x6129,0x6140,0x6220,
  0x9168,0x6223,0x6225,0x6224, 0x63c5,0x0000,
/* 0x7a41(i:10830) */
  0x63f1,0x63eb,0x6410,0x6412, 0x6409,0x6420,0x6424,0x6433,
  0x6443,0x641f,0x6415,0x6418, 0x6439,0x6437,0x6422,0x6423,
  0x640c,0x6426,0x6430,0x6428, 0x6441,0x6435,0x642f,0x640a,
  0x641a,0x6440,0x6425,0x6427, 0x640b,0x63e7,0x641b,0x642e,
  0x6421,0x640e,0x656f,0x6592, 0x65d3,0x6686,0x668c,0x6695,
  0x6690,0x668b,0x668a,0x6699, 0x6694,0x6678,0x6720,0x6966,
  0x695f,0x6938,0x694e,0x6962, 0x6971,0x693f,0x6945,0x696a,
  0x6939,0x6942,0x6957,0x6959, 0x697a,0x6948,0x6949,0x0000,
  0x6935,0x696c,0x6933,0x693d, 0x6965,0x68f0,0x6978,0x6934,
  0x6969,0x6940,0x696f,0x6944, 0x6976,0x6958,0x6941,0x6974,
  0x694c,0x693b,0x694b,0x6937, 0x695c,0x694f,0x6951,0x6932,
  0x6952,0x692f,0x697b,0x693c, 0x6b46,0x6b45,0x6b43,0x6b42,
  0x6b48,0x6b41,0x6b9b,0xfa0d, 0x6bfb,0x6bfc,0x6bf9,0x6bf7,
  0x6bf8,0x6e9b,0x6ed6,0x6ec8, 0x6e8f,0x6ec0,0x6e9f,0x6e93,
  0x6e94,0x6ea0,0x6eb1,0x6eb9, 0x6ec6,0x6ed2,0x6ebd,0x6ec1,
  0x6e9e,0x6ec9,0x6eb7,0x6eb0, 0x6ecd,0x6ea6,0x6ecf,0x6eb2,
  0x6ebe,0x6ec3,0x6edc,0x6ed8, 0x6e99,0x6e92,0x6e8e,0x6e8d,
  0x6ea4,0x6ea1,0x6ebf,0x6eb3, 0x6ed0,0x6eca,0x6e97,0x6eae,
  0x6ea3,0x7147,0x7154,0x7152, 0x7163,0x7160,0x7141,0x715d,
  0x7162,0x7172,0x7178,0x716a, 0x7161,0x7142,0x7158,0x7143,
  0x714b,0x7170,0x715f,0x7150, 0x7153,0x7144,0x714d,0x715a,
  0x724f,0x728d,0x728c,0x7291, 0x7290,0x728e,0x733c,0x7342,
  0x733b,0x733a,0x7340,0x734a, 0x7349,0x7444,0x744a,0x744b,
  0x7452,0x7451,0x7457,0x7440, 0x744f,0x0000,
/* 0x7b41(i:11020) */
  0x7450,0x744e,0x7442,0x7446, 0x744d,0x7454,0x74e1,0x74ff,
  0x74fe,0x74fd,0x751d,0x7579, 0x7577,0x6983,0x75ef,0x760f,
  0x7603,0x75f7,0x75fe,0x75fc, 0x75f9,0x75f8,0x7610,0x75fb,
  0x75f6,0x75ed,0x75f5,0x75fd, 0x7699,0x76b5,0x76dd,0x7755,
  0x775f,0x7760,0x7752,0x7756, 0x775a,0x7769,0x7767,0x7754,
  0x7759,0x776d,0x77e0,0x7887, 0x789a,0x7894,0x788f,0x7884,
  0x7895,0x7885,0x7886,0x78a1, 0x7883,0x7879,0x7899,0x7880,
  0x7896,0x787b,0x797c,0x7982, 0x797d,0x7979,0x7a11,0x0000,
  0x7a18,0x7a19,0x7a12,0x7a17, 0x7a15,0x7a22,0x7a13,0x7a1b,
  0x7a10,0x7aa3,0x7aa2,0x7a9e, 0x7aeb,0x7b66,0x7b64,0x7b6d,
  0x7b74,0x7b69,0x7b72,0x7b65, 0x7b73,0x7b71,0x7b70,0x7b61,
  0x7b78,0x7b76,0x7b63,0x7cb2, 0x7cb4,0x7caf,0x7d88,0x7d86,
  0x7d80,0x7d8d,0x7d7f,0x7d85, 0x7d7a,0x7d8e,0x7d7b,0x7d83,
  0x7d7c,0x7d8c,0x7d94,0x7d84, 0x7d7d,0x7d92,0x7f6d,0x7f6b,
  0x7f67,0x7f68,0x7f6c,0x7fa6, 0x7fa5,0x7fa7,0x7fdb,0x7fdc,
  0x8021,0x8164,0x8160,0x8177, 0x815c,0x8169,0x815b,0x8162,
  0x8172,0x6721,0x815e,0x8176, 0x8167,0x816f,0x8144,0x8161,
  0x821d,0x8249,0x8244,0x8240, 0x8242,0x8245,0x84f1,0x843f,
  0x8456,0x8476,0x8479,0x848f, 0x848d,0x8465,0x8451,0x8440,
  0x8486,0x8467,0x8430,0x844d, 0x847d,0x845a,0x8459,0x8474,
  0x8473,0x845d,0x8507,0x845e, 0x8437,0x843a,0x8434,0x847a,
  0x8443,0x8478,0x8432,0x8445, 0x8429,0x83d9,0x844b,0x842f,
  0x8442,0x842d,0x845f,0x8470, 0x8439,0x844e,0x844c,0x8452,
  0x846f,0x84c5,0x848e,0x843b, 0x8447,0x0000,
/* 0x7c41(i:11210) */
  0x8436,0x8433,0x8468,0x847e, 0x8444,0x842b,0x8460,0x8454,
  0x846e,0x8450,0x870b,0x8704, 0x86f7,0x870c,0x86fa,0x86d6,
  0x86f5,0x874d,0x86f8,0x870e, 0x8709,0x8701,0x86f6,0x870d,
  0x8705,0x88d6,0x88cb,0x88cd, 0x88ce,0x88de,0x88db,0x88da,
  0x88cc,0x88d0,0x8985,0x899b, 0x89df,0x89e5,0x89e4,0x89e1,
  0x89e0,0x89e2,0x89dc,0x89e6, 0x8a76,0x8a86,0x8a7f,0x8a61,
  0x8a3f,0x8a77,0x8a82,0x8a84, 0x8a75,0x8a83,0x8a81,0x8a74,
  0x8a7a,0x8c3c,0x8c4b,0x8c4a, 0x8c65,0x8c64,0x8c66,0x0000,
  0x8c86,0x8c84,0x8c85,0x8ccc, 0x8d68,0x8d69,0x8d91,0x8d8c,
  0x8d8e,0x8d8f,0x8d8d,0x8d93, 0x8d94,0x8d90,0x8d92,0x8df0,
  0x8de0,0x8dec,0x8df1,0x8dee, 0x8dd0,0x8de9,0x8de3,0x8de2,
  0x8de7,0x8df2,0x8deb,0x8df4, 0x8f06,0x8eff,0x8f01,0x8f00,
  0x8f05,0x8f07,0x8f08,0x8f02, 0x8f0b,0x9052,0x903f,0x9044,
  0x9049,0x903d,0x9110,0x910d, 0x910f,0x9111,0x9116,0x9114,
  0x910b,0x910e,0x916e,0x916f, 0x9248,0x9252,0x9230,0x923a,
  0x9266,0x9233,0x9265,0x925e, 0x9283,0x922e,0x924a,0x9246,
  0x926d,0x926c,0x924f,0x9260, 0x9267,0x926f,0x9236,0x9261,
  0x9270,0x9231,0x9254,0x9263, 0x9250,0x9272,0x924e,0x9253,
  0x924c,0x9256,0x9232,0x959f, 0x959c,0x959e,0x959b,0x9692,
  0x9693,0x9691,0x9697,0x96ce, 0x96fa,0x96fd,0x96f8,0x96f5,
  0x9773,0x9777,0x9778,0x9772, 0x980f,0x980d,0x980e,0x98ac,
  0x98f6,0x98f9,0x99af,0x99b2, 0x99b0,0x99b5,0x9aad,0x9aab,
  0x9b5b,0x9cea,0x9ced,0x9ce7, 0x9e80,0x9efd,0x50e6,0x50d4,
  0x50d7,0x50e8,0x50f3,0x50db, 0x50ea,0x0000,
/* 0x7d41(i:11400) */
  0x50dd,0x50e4,0x50d3,0x50ec, 0x50f0,0x50ef,0x50e3,0x50e0,
  0x51d8,0x5280,0x5281,0x52e9, 0x52eb,0x5330,0x53ac,0x5627,
  0x5615,0x560c,0x5612,0x55fc, 0x560f,0x561c,0x5601,0x5613,
  0x5602,0x55fa,0x561d,0x5604, 0x55ff,0x55f9,0x5889,0x587c,
  0x5890,0x5898,0x5886,0x5881, 0x587f,0x5874,0x588b,0x587a,
  0x5887,0x5891,0x588e,0x5876, 0x5882,0x5888,0x587b,0x5894,
  0x588f,0x58fe,0x596b,0x5adc, 0x5aee,0x5ae5,0x5ad5,0x5aea,
  0x5ada,0x5aed,0x5aeb,0x5af3, 0x5ae2,0x5ae0,0x5adb,0x0000,
  0x5aec,0x5ade,0x5add,0x5ad9, 0x5ae8,0x5adf,0x5b77,0x5be0,
  0x5be3,0x5c63,0x5d82,0x5d80, 0x5d7d,0x5d86,0x5d7a,0x5d81,
  0x5d77,0x5d8a,0x5d89,0x5d88, 0x5d7e,0x5d7c,0x5d8d,0x5d79,
  0x5d7f,0x5e58,0x5e59,0x5e53, 0x5ed8,0x5ed1,0x5ed7,0x5ece,
  0x5edc,0x5ed5,0x5ed9,0x5ed2, 0x5ed4,0x5f44,0x5f43,0x5f6f,
  0x5fb6,0x612c,0x6128,0x6141, 0x615e,0x6171,0x6173,0x6152,
  0x6153,0x6172,0x616c,0x6180, 0x6174,0x6154,0x617a,0x615b,
  0x6165,0x613b,0x616a,0x6161, 0x6156,0x6229,0x6227,0x622b,
  0x642b,0x644d,0x645b,0x645d, 0x6474,0x6476,0x6472,0x6473,
  0x647d,0x6475,0x6466,0x64a6, 0x644e,0x6482,0x645e,0x645c,
  0x644b,0x6453,0x6460,0x6450, 0x647f,0x643f,0x646c,0x646b,
  0x6459,0x6465,0x6477,0x6573, 0x65a0,0x66a1,0x66a0,0x669f,
  0x6705,0x6704,0x6722,0x69b1, 0x69b6,0x69c9,0x69a0,0x69ce,
  0x6996,0x69b0,0x69ac,0x69bc, 0x6991,0x6999,0x698e,0x69a7,
  0x698d,0x69a9,0x69be,0x69af, 0x69bf,0x69c4,0x69bd,0x69a4,
  0x69d4,0x69b9,0x69ca,0x699a, 0x69cf,0x0000,
/* 0x7e41(i:11590) */
  0x69b3,0x6993,0x69aa,0x69a1, 0x699e,0x69d9,0x6997,0x6990,
  0x69c2,0x69b5,0x69a5,0x69c6, 0x6b4a,0x6b4d,0x6b4b,0x6b9e,
  0x6b9f,0x6ba0,0x6bc3,0x6bc4, 0x6bfe,0x6ece,0x6ef5,0x6ef1,
  0x6f03,0x6f25,0x6ef8,0x6f37, 0x6efb,0x6f2e,0x6f09,0x6f4e,
  0x6f19,0x6f1a,0x6f27,0x6f18, 0x6f3b,0x6f12,0x6eed,0x6f0a,
  0x6f36,0x6f73,0x6ef9,0x6eee, 0x6f2d,0x6f40,0x6f30,0x6f3c,
  0x6f35,0x6eeb,0x6f07,0x6f0e, 0x6f43,0x6f05,0x6efd,0x6ef6,
  0x6f39,0x6f1c,0x6efc,0x6f3a, 0x6f1f,0x6f0d,0x6f1e,0x0000,
  0x6f08,0x6f21,0x7187,0x7190, 0x7189,0x7180,0x7185,0x7182,
  0x718f,0x717b,0x7186,0x7181, 0x7197,0x7244,0x7253,0x7297,
  0x7295,0x7293,0x7343,0x734d, 0x7351,0x734c,0x7462,0x7473,
  0x7471,0x7475,0x7472,0x7467, 0x746e,0x7500,0x7502,0x7503,
  0x757d,0x7590,0x7616,0x7608, 0x760c,0x7615,0x7611,0x760a,
  0x7614,0x76b8,0x7781,0x777c, 0x7785,0x7782,0x776e,0x7780,
  0x776f,0x777e,0x7783,0x78b2, 0x78aa,0x78b4,0x78ad,0x78a8,
  0x787e,0x78ab,0x789e,0x78a5, 0x78a0,0x78ac,0x78a2,0x78a4,
  0x7998,0x798a,0x798b,0x7996, 0x7995,0x7994,0x7993,0x7997,
  0x7988,0x7992,0x7990,0x7a2b, 0x7a4a,0x7a30,0x7a2f,0x7a28,
  0x7a26,0x7aa8,0x7aab,0x7aac, 0x7aee,0x7b88,0x7b9c,0x7b8a,
  0x7b91,0x7b90,0x7b96,0x7b8d, 0x7b8c,0x7b9b,0x7b8e,0x7b85,
  0x7b98,0x5284,0x7b99,0x7ba4, 0x7b82,0x7cbb,0x7cbf,0x7cbc,
  0x7cba,0x7da7,0x7db7,0x7dc2, 0x7da3,0x7daa,0x7dc1,0x7dc0,
  0x7dc5,0x7d9d,0x7dce,0x7dc4, 0x7dc6,0x7dcb,0x7dcc,0x7daf,
  0x7db9,0x7d96,0x7dbc,0x7d9f, 0x7da6,0x0000,
/* 0x7f41(i:11780) */
  0x7dae,0x7da9,0x7da1,0x7dc9, 0x7f73,0x7fe2,0x7fe3,0x7fe5,
  0x7fde,0x8024,0x805d,0x805c, 0x8189,0x8186,0x8183,0x8187,
  0x818d,0x818c,0x818b,0x8215, 0x8497,0x84a4,0x84a1,0x849f,
  0x84ba,0x84ce,0x84c2,0x84ac, 0x84ae,0x84ab,0x84b9,0x84b4,
  0x84c1,0x84cd,0x84aa,0x849a, 0x84b1,0x84d0,0x849d,0x84a7,
  0x84bb,0x84a2,0x8494,0x84c7, 0x84cc,0x849b,0x84a9,0x84af,
  0x84a8,0x84d6,0x8498,0x84b6, 0x84cf,0x84a0,0x84d7,0x84d4,
  0x84d2,0x84db,0x84b0,0x8491, 0x8661,0x8733,0x8723,0x0000,
  0x8728,0x876b,0x8740,0x872e, 0x871e,0x8721,0x8719,0x871b,
  0x8743,0x872c,0x8741,0x873e, 0x8746,0x8720,0x8732,0x872a,
  0x872d,0x873c,0x8712,0x873a, 0x8731,0x8735,0x8742,0x8726,
  0x8727,0x8738,0x8724,0x871a, 0x8730,0x8711,0x88f7,0x88e7,
  0x88f1,0x88f2,0x88fa,0x88fe, 0x88ee,0x88fc,0x88f6,0x88fb,
  0x88f0,0x88ec,0x88eb,0x899d, 0x89a1,0x899f,0x899e,0x89e9,
  0x89eb,0x89e8,0x8aab,0x8a99, 0x8a8b,0x8a92,0x8a8f,0x8a96,
  0x8c3d,0x8c68,0x8c69,0x8cd5, 0x8ccf,0x8cd7,0x8d96,0x8e09,
  0x8e02,0x8dff,0x8e0d,0x8dfd, 0x8e0a,0x8e03,0x8e07,0x8e06,
  0x8e05,0x8dfe,0x8e00,0x8e04, 0x8f10,0x8f11,0x8f0e,0x8f0d,
  0x9123,0x911c,0x9120,0x9122, 0x911f,0x911d,0x911a,0x9124,
  0x9121,0x911b,0x917a,0x9172, 0x9179,0x9173,0x92a5,0x92a4,
  0x9276,0x929b,0x927a,0x92a0, 0x9294,0x92aa,0x928d,0x92a6,
  0x929a,0x92ab,0x9279,0x9297, 0x927f,0x92a3,0x92ee,0x928e,
  0x9282,0x9295,0x92a2,0x927d, 0x9288,0x92a1,0x928a,0x9286,
  0x928c,0x9299,0x92a7,0x927e, 0x9287,0x0000,
/* 0x8041(i:11970) */
  0x92a9,0x929d,0x928b,0x922d, 0x969e,0x96a1,0x96ff,0x9758,
  0x977d,0x977a,0x977e,0x9783, 0x9780,0x9782,0x977b,0x9784,
  0x9781,0x977f,0x97ce,0x97cd, 0x9816,0x98ad,0x98ae,0x9902,
  0x9900,0x9907,0x999d,0x999c, 0x99c3,0x99b9,0x99bb,0x99ba,
  0x99c2,0x99bd,0x99c7,0x9ab1, 0x9ae3,0x9ae7,0x9b3e,0x9b3f,
  0x9b60,0x9b61,0x9b5f,0x9cf1, 0x9cf2,0x9cf5,0x9ea7,0x50ff,
  0x5103,0x5130,0x50f8,0x5106, 0x5107,0x50f6,0x50fe,0x510b,
  0x510c,0x50fd,0x510a,0x528b, 0x528c,0x52f1,0x52ef,0x0000,
  0x5648,0x5642,0x564c,0x5635, 0x5641,0x564a,0x5649,0x5646,
  0x5658,0x565a,0x5640,0x5633, 0x563d,0x562c,0x563e,0x5638,
  0x562a,0x563a,0x571a,0x58ab, 0x589d,0x58b1,0x58a0,0x58a3,
  0x58af,0x58ac,0x58a5,0x58a1, 0x58ff,0x5aff,0x5af4,0x5afd,
  0x5af7,0x5af6,0x5b03,0x5af8, 0x5b02,0x5af9,0x5b01,0x5b07,
  0x5b05,0x5b0f,0x5c67,0x5d99, 0x5d97,0x5d9f,0x5d92,0x5da2,
  0x5d93,0x5d95,0x5da0,0x5d9c, 0x5da1,0x5d9a,0x5d9e,0x5e69,
  0x5e5d,0x5e60,0x5e5c,0x7df3, 0x5edb,0x5ede,0x5ee1,0x5f49,
  0x5fb2,0x618b,0x6183,0x6179, 0x61b1,0x61b0,0x61a2,0x6189,
  0x619b,0x6193,0x61af,0x61ad, 0x619f,0x6192,0x61aa,0x61a1,
  0x618d,0x6166,0x61b3,0x622d, 0x646e,0x6470,0x6496,0x64a0,
  0x6485,0x6497,0x649c,0x648f, 0x648b,0x648a,0x648c,0x64a3,
  0x649f,0x6468,0x64b1,0x6498, 0x6576,0x657a,0x6579,0x657b,
  0x65b2,0x65b3,0x66b5,0x66b0, 0x66a9,0x66b2,0x66b7,0x66aa,
  0x66af,0x6a00,0x6a06,0x6a17, 0x69e5,0x69f8,0x6a15,0x69f1,
  0x69e4,0x6a20,0x69ff,0x69ec, 0x69e2,0x0000,
/* 0x8141(i:12160) */
  0x6a1b,0x6a1d,0x69fe,0x6a27, 0x69f2,0x69ee,0x6a14,0x69f7,
  0x69e7,0x6a40,0x6a08,0x69e6, 0x69fb,0x6a0d,0x69fc,0x69eb,
  0x6a09,0x6a04,0x6a18,0x6a25, 0x6a0f,0x69f6,0x6a26,0x6a07,
  0x69f4,0x6a16,0x6b51,0x6ba5, 0x6ba3,0x6ba2,0x6ba6,0x6c01,
  0x6c00,0x6bff,0x6c02,0x6f41, 0x6f26,0x6f7e,0x6f87,0x6fc6,
  0x6f92,0x6f8d,0x6f89,0x6f8c, 0x6f62,0x6f4f,0x6f85,0x6f5a,
  0x6f96,0x6f76,0x6f6c,0x6f82, 0x6f55,0x6f72,0x6f52,0x6f50,
  0x6f57,0x6f94,0x6f93,0x6f5d, 0x6f00,0x6f61,0x6f6b,0x0000,
  0x6f7d,0x6f67,0x6f90,0x6f53, 0x6f8b,0x6f69,0x6f7f,0x6f95,
  0x6f63,0x6f77,0x6f6a,0x6f7b, 0x71b2,0x71af,0x719b,0x71b0,
  0x71a0,0x719a,0x71a9,0x71b5, 0x719d,0x71a5,0x719e,0x71a4,
  0x71a1,0x71aa,0x719c,0x71a7, 0x71b3,0x7298,0x729a,0x7358,
  0x7352,0x735e,0x735f,0x7360, 0x735d,0x735b,0x7361,0x735a,
  0x7359,0x7362,0x7487,0x7489, 0x748a,0x7486,0x7481,0x747d,
  0x7485,0x7488,0x747c,0x7479, 0x7508,0x7507,0x757e,0x7625,
  0x761e,0x7619,0x761d,0x761c, 0x7623,0x761a,0x7628,0x761b,
  0x769c,0x769d,0x769e,0x769b, 0x778d,0x778f,0x7789,0x7788,
  0x78cd,0x78bb,0x78cf,0x78cc, 0x78d1,0x78ce,0x78d4,0x78c8,
  0x78c3,0x78c4,0x78c9,0x799a, 0x79a1,0x79a0,0x799c,0x79a2,
  0x799b,0x6b76,0x7a39,0x7ab2, 0x7ab4,0x7ab3,0x7bb7,0x7bcb,
  0x7bbe,0x7bac,0x7bce,0x7baf, 0x7bb9,0x7bca,0x7bb5,0x7cc5,
  0x7cc8,0x7ccc,0x7ccb,0x7df7, 0x7ddb,0x7dea,0x7de7,0x7dd7,
  0x7de1,0x7e03,0x7dfa,0x7de6, 0x7df6,0x7df1,0x7df0,0x7dee,
  0x7ddf,0x7f76,0x7fac,0x7fb0, 0x7fad,0x0000,
/* 0x8241(i:12350) */
  0x7fed,0x7feb,0x7fea,0x7fec, 0x7fe6,0x7fe8,0x8064,0x8067,
  0x81a3,0x819f,0x819e,0x8195, 0x81a2,0x8199,0x8197,0x8216,
  0x824f,0x8253,0x8252,0x8250, 0x824e,0x8251,0x8524,0x853b,
  0x850f,0x8500,0x8529,0x850e, 0x8509,0x850d,0x851f,0x850a,
  0x8527,0x851c,0x84fb,0x852b, 0x84fa,0x8508,0x850c,0x84f4,
  0x852a,0x84f2,0x8515,0x84f7, 0x84eb,0x84f3,0x84fc,0x8512,
  0x84ea,0x84e9,0x8516,0x84fe, 0x8528,0x851d,0x852e,0x8502,
  0x84fd,0x851e,0x84f6,0x8531, 0x8526,0x84e7,0x84e8,0x0000,
  0x84f0,0x84ef,0x84f9,0x8518, 0x8520,0x8530,0x850b,0x8519,
  0x852f,0x8662,0x8756,0x8763, 0x8764,0x8777,0x87e1,0x8773,
  0x8758,0x8754,0x875b,0x8752, 0x8761,0x875a,0x8751,0x875e,
  0x876d,0x876a,0x8750,0x874e, 0x875f,0x875d,0x876f,0x876c,
  0x877a,0x876e,0x875c,0x8765, 0x874f,0x877b,0x8775,0x8762,
  0x8767,0x8769,0x885a,0x8905, 0x890c,0x8914,0x890b,0x8917,
  0x8918,0x8919,0x8906,0x8916, 0x8911,0x890e,0x8909,0x89a2,
  0x89a4,0x89a3,0x89ed,0x89f0, 0x89ec,0x8acf,0x8ac6,0x8ab8,
  0x8ad3,0x8ad1,0x8ad4,0x8ad5, 0x8abb,0x8ad7,0x8abe,0x8ac0,
  0x8ac5,0x8ad8,0x8ac3,0x8aba, 0x8abd,0x8ad9,0x8c3e,0x8c4d,
  0x8c8f,0x8ce5,0x8cdf,0x8cd9, 0x8ce8,0x8cda,0x8cdd,0x8ce7,
  0x8da0,0x8d9c,0x8da1,0x8d9b, 0x8e20,0x8e23,0x8e25,0x8e24,
  0x8e2e,0x8e15,0x8e1b,0x8e16, 0x8e11,0x8e19,0x8e26,0x8e27,
  0x8e14,0x8e12,0x8e18,0x8e13, 0x8e1c,0x8e17,0x8e1a,0x8f2c,
  0x8f24,0x8f18,0x8f1a,0x8f20, 0x8f23,0x8f16,0x8f17,0x9073,
  0x9070,0x906f,0x9067,0x906b, 0x912f,0x0000,
/* 0x8341(i:12540) */
  0x912b,0x9129,0x912a,0x9132, 0x9126,0x912e,0x9185,0x9186,
  0x918a,0x9181,0x9182,0x9184, 0x9180,0x92d0,0x92c3,0x92c4,
  0x92c0,0x92d9,0x92b6,0x92cf, 0x92f1,0x92df,0x92d8,0x92e9,
  0x92d7,0x92dd,0x92cc,0x92ef, 0x92c2,0x92e8,0x92ca,0x92c8,
  0x92ce,0x92e6,0x92cd,0x92d5, 0x92c9,0x92e0,0x92de,0x92e7,
  0x92d1,0x92d3,0x92b5,0x92e1, 0x92c6,0x92b4,0x957c,0x95ac,
  0x95ab,0x95ae,0x95b0,0x96a4, 0x96a2,0x96d3,0x9705,0x9708,
  0x9702,0x975a,0x978a,0x978e, 0x9788,0x97d0,0x97cf,0x0000,
  0x981e,0x981d,0x9826,0x9829, 0x9828,0x9820,0x981b,0x9827,
  0x98b2,0x9908,0x98fa,0x9911, 0x9914,0x9916,0x9917,0x9915,
  0x99dc,0x99cd,0x99cf,0x99d3, 0x99d4,0x99ce,0x99c9,0x99d6,
  0x99d8,0x99cb,0x99d7,0x99cc, 0x9ab3,0x9aec,0x9aeb,0x9af3,
  0x9af2,0x9af1,0x9b46,0x9b43, 0x9b67,0x9b74,0x9b71,0x9b66,
  0x9b76,0x9b75,0x9b70,0x9b68, 0x9b64,0x9b6c,0x9cfc,0x9cfa,
  0x9cfd,0x9cff,0x9cf7,0x9d07, 0x9d00,0x9cf9,0x9cfb,0x9d08,
  0x9d05,0x9d04,0x9e83,0x9ed3, 0x9f0f,0x9f10,0x511c,0x5113,
  0x5117,0x511a,0x5111,0x51de, 0x5334,0x53e1,0x5670,0x5660,
  0x566e,0x5673,0x5666,0x5663, 0x566d,0x5672,0x565e,0x5677,
  0x571c,0x571b,0x58c8,0x58bd, 0x58c9,0x58bf,0x58ba,0x58c2,
  0x58bc,0x58c6,0x5b17,0x5b19, 0x5b1b,0x5b21,0x5b14,0x5b13,
  0x5b10,0x5b16,0x5b28,0x5b1a, 0x5b20,0x5b1e,0x5bef,0x5dac,
  0x5db1,0x5da9,0x5da7,0x5db5, 0x5db0,0x5dae,0x5daa,0x5da8,
  0x5db2,0x5dad,0x5daf,0x5db4, 0x5e67,0x5e68,0x5e66,0x5e6f,
  0x5ee9,0x5ee7,0x5ee6,0x5ee8, 0x5ee5,0x0000,
/* 0x8441(i:12730) */
  0x5f4b,0x5fbc,0x619d,0x61a8, 0x6196,0x61c5,0x61b4,0x61c6,
  0x61c1,0x61cc,0x61ba,0x61bf, 0x61b8,0x618c,0x64d7,0x64d6,
  0x64d0,0x64cf,0x64c9,0x64bd, 0x6489,0x64c3,0x64db,0x64f3,
  0x64d9,0x6533,0x657f,0x657c, 0x65a2,0x66c8,0x66be,0x66c0,
  0x66ca,0x66cb,0x66cf,0x66bd, 0x66bb,0x66ba,0x66cc,0x6723,
  0x6a34,0x6a66,0x6a49,0x6a67, 0x6a32,0x6a68,0x6a3e,0x6a5d,
  0x6a6d,0x6a76,0x6a5b,0x6a51, 0x6a28,0x6a5a,0x6a3b,0x6a3f,
  0x6a41,0x6a6a,0x6a64,0x6a50, 0x6a4f,0x6a54,0x6a6f,0x0000,
  0x6a69,0x6a60,0x6a3c,0x6a5e, 0x6a56,0x6a55,0x6a4d,0x6a4e,
  0x6a46,0x6b55,0x6b54,0x6b56, 0x6ba7,0x6baa,0x6bab,0x6bc8,
  0x6bc7,0x6c04,0x6c03,0x6c06, 0x6fad,0x6fcb,0x6fa3,0x6fc7,
  0x6fbc,0x6fce,0x6fc8,0x6f5e, 0x6fc4,0x6fbd,0x6f9e,0x6fca,
  0x6fa8,0x7004,0x6fa5,0x6fae, 0x6fba,0x6fac,0x6faa,0x6fcf,
  0x6fbf,0x6fb8,0x6fa2,0x6fc9, 0x6fab,0x6fcd,0x6faf,0x6fb2,
  0x6fb0,0x71c5,0x71c2,0x71bf, 0x71b8,0x71d6,0x71c0,0x71c1,
  0x71cb,0x71d4,0x71ca,0x71c7, 0x71cf,0x71bd,0x71d8,0x71bc,
  0x71c6,0x71da,0x71db,0x729d, 0x729e,0x7369,0x7366,0x7367,
  0x736c,0x7365,0x736b,0x736a, 0x747f,0x749a,0x74a0,0x7494,
  0x7492,0x7495,0x74a1,0x750b, 0x7580,0x762f,0x762d,0x7631,
  0x763d,0x7633,0x763c,0x7635, 0x7632,0x7630,0x76bb,0x76e6,
  0x779a,0x779d,0x77a1,0x779c, 0x779b,0x77a2,0x77a3,0x7795,
  0x7799,0x7797,0x78dd,0x78e9, 0x78e5,0x78ea,0x78de,0x78e3,
  0x78db,0x78e1,0x78e2,0x78ed, 0x78df,0x78e0,0x79a4,0x7a44,
  0x7a48,0x7a47,0x7ab6,0x7ab8, 0x7ab5,0x0000,
/* 0x8541(i:12920) */
  0x7ab1,0x7ab7,0x7bde,0x7be3, 0x7be7,0x7bdd,0x7bd5,0x7be5,
  0x7bda,0x7be8,0x7bf9,0x7bd4, 0x7bea,0x7be2,0x7bdc,0x7beb,
  0x7bd8,0x7bdf,0x7cd2,0x7cd4, 0x7cd7,0x7cd0,0x7cd1,0x7e12,
  0x7e21,0x7e17,0x7e0c,0x7e1f, 0x7e20,0x7e13,0x7e0e,0x7e1c,
  0x7e15,0x7e1a,0x7e22,0x7e0b, 0x7e0f,0x7e16,0x7e0d,0x7e14,
  0x7e25,0x7e24,0x7f43,0x7f7b, 0x7f7c,0x7f7a,0x7fb1,0x7fef,
  0x802a,0x8029,0x806c,0x81b1, 0x81a6,0x81ae,0x81b9,0x81b5,
  0x81ab,0x81b0,0x81ac,0x81b4, 0x81b2,0x81b7,0x81a7,0x0000,
  0x81f2,0x8255,0x8256,0x8257, 0x8556,0x8545,0x856b,0x854d,
  0x8553,0x8561,0x8558,0x8540, 0x8546,0x8564,0x8541,0x8562,
  0x8544,0x8551,0x8547,0x8563, 0x853e,0x855b,0x8571,0x854e,
  0x856e,0x8575,0x8555,0x8567, 0x8560,0x858c,0x8566,0x855d,
  0x8554,0x8565,0x856c,0x8663, 0x8665,0x8664,0x879b,0x878f,
  0x8797,0x8793,0x8792,0x8788, 0x8781,0x8796,0x8798,0x8779,
  0x8787,0x87a3,0x8785,0x8790, 0x8791,0x879d,0x8784,0x8794,
  0x879c,0x879a,0x8789,0x891e, 0x8926,0x8930,0x892d,0x892e,
  0x8927,0x8931,0x8922,0x8929, 0x8923,0x892f,0x892c,0x891f,
  0x89f1,0x8ae0,0x8ae2,0x8af2, 0x8af4,0x8af5,0x8add,0x8b14,
  0x8ae4,0x8adf,0x8af0,0x8ac8, 0x8ade,0x8ae1,0x8ae8,0x8aff,
  0x8aef,0x8afb,0x8c91,0x8c92, 0x8c90,0x8cf5,0x8cee,0x8cf1,
  0x8cf0,0x8cf3,0x8d6c,0x8d6e, 0x8da5,0x8da7,0x8e33,0x8e3e,
  0x8e38,0x8e40,0x8e45,0x8e36, 0x8e3c,0x8e3d,0x8e41,0x8e30,
  0x8e3f,0x8ebd,0x8f36,0x8f2e, 0x8f35,0x8f32,0x8f39,0x8f37,
  0x8f34,0x9076,0x9079,0x907b, 0x9086,0x0000,
/* 0x8641(i:13110) */
  0x90fa,0x9133,0x9135,0x9136, 0x9193,0x9190,0x9191,0x918d,
  0x918f,0x9327,0x931e,0x9308, 0x931f,0x9306,0x930f,0x937a,
  0x9338,0x933c,0x931b,0x9323, 0x9312,0x9301,0x9346,0x932d,
  0x930e,0x930d,0x92cb,0x931d, 0x92fa,0x9325,0x9313,0x92f9,
  0x92f7,0x9334,0x9302,0x9324, 0x92ff,0x9329,0x9339,0x9335,
  0x932a,0x9314,0x930c,0x930b, 0x92fe,0x9309,0x9300,0x92fb,
  0x9316,0x95bc,0x95cd,0x95be, 0x95b9,0x95ba,0x95b6,0x95bf,
  0x95b5,0x95bd,0x96a9,0x96d4, 0x970b,0x9712,0x9710,0x0000,
  0x9799,0x9797,0x9794,0x97f0, 0x97f8,0x9835,0x982f,0x9832,
  0x9924,0x991f,0x9927,0x9929, 0x999e,0x99ee,0x99ec,0x99e5,
  0x99e4,0x99f0,0x99e3,0x99ea, 0x99e9,0x99e7,0x9ab9,0x9abf,
  0x9ab4,0x9abb,0x9af6,0x9afa, 0x9af9,0x9af7,0x9b33,0x9b80,
  0x9b85,0x9b87,0x9b7c,0x9b7e, 0x9b7b,0x9b82,0x9b93,0x9b92,
  0x9b90,0x9b7a,0x9b95,0x9b7d, 0x9b88,0x9d25,0x9d17,0x9d20,
  0x9d1e,0x9d14,0x9d29,0x9d1d, 0x9d18,0x9d22,0x9d10,0x9d19,
  0x9d1f,0x9e88,0x9e86,0x9e87, 0x9eae,0x9ead,0x9ed5,0x9ed6,
  0x9efa,0x9f12,0x9f3d,0x5126, 0x5125,0x5122,0x5124,0x5120,
  0x5129,0x52f4,0x5693,0x568c, 0x568d,0x5686,0x5684,0x5683,
  0x567e,0x5682,0x567f,0x5681, 0x58d6,0x58d4,0x58cf,0x58d2,
  0x5b2d,0x5b25,0x5b32,0x5b23, 0x5b2c,0x5b27,0x5b26,0x5b2f,
  0x5b2e,0x5b7b,0x5bf1,0x5bf2, 0x5db7,0x5e6c,0x5e6a,0x5fbe,
  0x5fbb,0x61c3,0x61b5,0x61bc, 0x61e7,0x61e0,0x61e5,0x61e4,
  0x61e8,0x61de,0x64ef,0x64e9, 0x64e3,0x64eb,0x64e4,0x64e8,
  0x6581,0x6580,0x65b6,0x65da, 0x66d2,0x0000,
/* 0x8741(i:13300) */
  0x6a8d,0x6a96,0x6a81,0x6aa5, 0x6a89,0x6a9f,0x6a9b,0x6aa1,
  0x6a9e,0x6a87,0x6a93,0x6a8e, 0x6a95,0x6a83,0x6aa8,0x6aa4,
  0x6a91,0x6a7f,0x6aa6,0x6a9a, 0x6a85,0x6a8c,0x6a92,0x6b5b,
  0x6bad,0x6c09,0x6fcc,0x6fa9, 0x6ff4,0x6fd4,0x6fe3,0x6fdc,
  0x6fed,0x6fe7,0x6fe6,0x6fde, 0x6ff2,0x6fdd,0x6fe2,0x6fe8,
  0x71e1,0x71f1,0x71e8,0x71f2, 0x71e4,0x71f0,0x71e2,0x7373,
  0x736e,0x736f,0x7497,0x74b2, 0x74ab,0x7490,0x74aa,0x74ad,
  0x74b1,0x74a5,0x74af,0x7510, 0x7511,0x7512,0x750f,0x0000,
  0x7584,0x7643,0x7648,0x7649, 0x7647,0x76a4,0x76e9,0x77b5,
  0x77ab,0x77b2,0x77b7,0x77b6, 0x77b4,0x77b1,0x77a8,0x77f0,
  0x78f3,0x78fd,0x7902,0x78fb, 0x78fc,0x78f2,0x7905,0x78f9,
  0x78fe,0x7904,0x79ab,0x79a8, 0x7a5c,0x7a5b,0x7a56,0x7a58,
  0x7a54,0x7a5a,0x7abe,0x7ac0, 0x7ac1,0x7c05,0x7c0f,0x7bf2,
  0x7c00,0x7bff,0x7bfb,0x7c0e, 0x7bf4,0x7c0b,0x7bf3,0x7c02,
  0x7c09,0x7c03,0x7c01,0x7bf8, 0x7bfd,0x7c06,0x7bf0,0x7bf1,
  0x7c10,0x7c0a,0x7ce8,0x7e2d, 0x7e3c,0x7e42,0x7e33,0x9848,
  0x7e38,0x7e2a,0x7e49,0x7e40, 0x7e47,0x7e29,0x7e4c,0x7e30,
  0x7e3b,0x7e36,0x7e44,0x7e3a, 0x7f45,0x7f7f,0x7f7e,0x7f7d,
  0x7ff4,0x7ff2,0x802c,0x81bb, 0x81c4,0x81cc,0x81ca,0x81c5,
  0x81c7,0x81bc,0x81e9,0x825b, 0x825a,0x825c,0x8583,0x8580,
  0x858f,0x85a7,0x8595,0x85a0, 0x858b,0x85a3,0x857b,0x85a4,
  0x859a,0x859e,0x8577,0x857c, 0x8589,0x85a1,0x857a,0x8578,
  0x8557,0x858e,0x8596,0x8586, 0x858d,0x8599,0x859d,0x8581,
  0x85a2,0x8582,0x8588,0x8585, 0x8579,0x0000,
/* 0x8841(i:13490) */
  0x8576,0x8598,0x8590,0x859f, 0x8668,0x87be,0x87aa,0x87ad,
  0x87c5,0x87b0,0x87ac,0x87b9, 0x87b5,0x87bc,0x87ae,0x87c9,
  0x87c3,0x87c2,0x87cc,0x87b7, 0x87af,0x87c4,0x87ca,0x87b4,
  0x87b6,0x87bf,0x87b8,0x87bd, 0x87de,0x87b2,0x8935,0x8933,
  0x893c,0x893e,0x8941,0x8952, 0x8937,0x8942,0x89ad,0x89af,
  0x89ae,0x89f2,0x89f3,0x8b1e, 0x8b18,0x8b16,0x8b11,0x8b05,
  0x8b0b,0x8b22,0x8b0f,0x8b12, 0x8b15,0x8b07,0x8b0d,0x8b08,
  0x8b06,0x8b1c,0x8b13,0x8b1a, 0x8c4f,0x8c70,0x8c72,0x0000,
  0x8c71,0x8c6f,0x8c95,0x8c94, 0x8cf9,0x8d6f,0x8e4e,0x8e4d,
  0x8e53,0x8e50,0x8e4c,0x8e47, 0x8f43,0x8f40,0x9085,0x907e,
  0x9138,0x919a,0x91a2,0x919b, 0x9199,0x919f,0x91a1,0x919d,
  0x91a0,0x93a1,0x9383,0x93af, 0x9364,0x9356,0x9347,0x937c,
  0x9358,0x935c,0x9376,0x9349, 0x9350,0x9351,0x9360,0x936d,
  0x938f,0x934c,0x936a,0x9379, 0x9357,0x9355,0x9352,0x934f,
  0x9371,0x9377,0x937b,0x9361, 0x935e,0x9363,0x9367,0x9380,
  0x934e,0x9359,0x95c7,0x95c0, 0x95c9,0x95c3,0x95c5,0x95b7,
  0x96ae,0x96b0,0x96ac,0x9720, 0x971f,0x9718,0x971d,0x9719,
  0x979a,0x97a1,0x979c,0x979e, 0x979d,0x97d5,0x97d4,0x97f1,
  0x9841,0x9844,0x984a,0x9849, 0x9845,0x9843,0x9925,0x992b,
  0x992c,0x992a,0x9933,0x9932, 0x992f,0x992d,0x9931,0x9930,
  0x9998,0x99a3,0x99a1,0x9a02, 0x99fa,0x99f4,0x99f7,0x99f9,
  0x99f8,0x99f6,0x99fb,0x99fd, 0x99fe,0x99fc,0x9a03,0x9abe,
  0x9afe,0x9afd,0x9b01,0x9afc, 0x9b48,0x9b9a,0x9ba8,0x9b9e,
  0x9b9b,0x9ba6,0x9ba1,0x9ba5, 0x9ba4,0x0000,
/* 0x8941(i:13680) */
  0x9b86,0x9ba2,0x9ba0,0x9baf, 0x9d33,0x9d41,0x9d67,0x9d36,
  0x9d2e,0x9d2f,0x9d31,0x9d38, 0x9d30,0x9d45,0x9d42,0x9d43,
  0x9d3e,0x9d37,0x9d40,0x9d3d, 0x7ff5,0x9d2d,0x9e8a,0x9e89,
  0x9e8d,0x9eb0,0x9ec8,0x9eda, 0x9efb,0x9eff,0x9f24,0x9f23,
  0x9f22,0x9f54,0x9fa0,0x5131, 0x512d,0x512e,0x5698,0x569c,
  0x5697,0x569a,0x569d,0x5699, 0x5970,0x5b3c,0x5c69,0x5c6a,
  0x5dc0,0x5e6d,0x5e6e,0x61d8, 0x61df,0x61ed,0x61ee,0x61f1,
  0x61ea,0x61f0,0x61eb,0x61d6, 0x61e9,0x64ff,0x6504,0x0000,
  0x64fd,0x64f8,0x6501,0x6503, 0x64fc,0x6594,0x65db,0x66da,
  0x66db,0x66d8,0x6ac5,0x6ab9, 0x6abd,0x6ae1,0x6ac6,0x6aba,
  0x6ab6,0x6ab7,0x6ac7,0x6ab4, 0x6aad,0x6b5e,0x6bc9,0x6c0b,
  0x7007,0x700c,0x700d,0x7001, 0x7005,0x7014,0x700e,0x6fff,
  0x7000,0x6ffb,0x7026,0x6ffc, 0x6ff7,0x700a,0x7201,0x71ff,
  0x71f9,0x7203,0x71fd,0x7376, 0x74b8,0x74c0,0x74b5,0x74c1,
  0x74be,0x74b6,0x74bb,0x74c2, 0x7514,0x7513,0x765c,0x7664,
  0x7659,0x7650,0x7653,0x7657, 0x765a,0x76a6,0x76bd,0x76ec,
  0x77c2,0x77ba,0x78ff,0x790c, 0x7913,0x7914,0x7909,0x7910,
  0x7912,0x7911,0x79ad,0x79ac, 0x7a5f,0x7c1c,0x7c29,0x7c19,
  0x7c20,0x7c1f,0x7c2d,0x7c1d, 0x7c26,0x7c28,0x7c22,0x7c25,
  0x7c30,0x7e5c,0x7e50,0x7e56, 0x7e63,0x7e58,0x7e62,0x7e5f,
  0x7e51,0x7e60,0x7e57,0x7e53, 0x7fb5,0x7fb3,0x7ff7,0x7ff8,
  0x8075,0x81d1,0x81d2,0x81d0, 0x825f,0x825e,0x85b4,0x85c6,
  0x85c0,0x85c3,0x85c2,0x85b3, 0x85b5,0x85bd,0x85c7,0x85c4,
  0x85bf,0x85cb,0x85ce,0x85c8, 0x85c5,0x0000,
/* 0x8a41(i:13870) */
  0x85b1,0x85b6,0x85d2,0x8624, 0x85b8,0x85b7,0x85be,0x8669,
  0x87e7,0x87e6,0x87e2,0x87db, 0x87eb,0x87ea,0x87e5,0x87df,
  0x87f3,0x87e4,0x87d4,0x87dc, 0x87d3,0x87ed,0x87d8,0x87e3,
  0x87a4,0x87d7,0x87d9,0x8801, 0x87f4,0x87e8,0x87dd,0x8953,
  0x894b,0x894f,0x894c,0x8946, 0x8950,0x8951,0x8949,0x8b2a,
  0x8b27,0x8b23,0x8b33,0x8b30, 0x8b35,0x8b47,0x8b2f,0x8b3c,
  0x8b3e,0x8b31,0x8b25,0x8b37, 0x8b26,0x8b36,0x8b2e,0x8b24,
  0x8b3b,0x8b3d,0x8b3a,0x8c42, 0x8c75,0x8c99,0x8c98,0x0000,
  0x8c97,0x8cfe,0x8d04,0x8d02, 0x8d00,0x8e5c,0x8e62,0x8e60,
  0x8e57,0x8e56,0x8e5e,0x8e65, 0x8e67,0x8e5b,0x8e5a,0x8e61,
  0x8e5d,0x8e69,0x8e54,0x8f46, 0x8f47,0x8f48,0x8f4b,0x9128,
  0x913a,0x913b,0x913e,0x91a8, 0x91a5,0x91a7,0x91af,0x91aa,
  0x93b5,0x938c,0x9392,0x93b7, 0x939b,0x939d,0x9389,0x93a7,
  0x938e,0x93aa,0x939e,0x93a6, 0x9395,0x9388,0x9399,0x939f,
  0x938d,0x93b1,0x9391,0x93b2, 0x93a4,0x93a8,0x93b4,0x93a3,
  0x93a5,0x95d2,0x95d3,0x95d1, 0x96b3,0x96d7,0x96da,0x5dc2,
  0x96df,0x96d8,0x96dd,0x9723, 0x9722,0x9725,0x97ac,0x97ae,
  0x97a8,0x97ab,0x97a4,0x97aa, 0x97a2,0x97a5,0x97d7,0x97d9,
  0x97d6,0x97d8,0x97fa,0x9850, 0x9851,0x9852,0x98b8,0x9941,
  0x993c,0x993a,0x9a0f,0x9a0b, 0x9a09,0x9a0d,0x9a04,0x9a11,
  0x9a0a,0x9a05,0x9a07,0x9a06, 0x9ac0,0x9adc,0x9b08,0x9b04,
  0x9b05,0x9b29,0x9b35,0x9b4a, 0x9b4c,0x9b4b,0x9bc7,0x9bc6,
  0x9bc3,0x9bbf,0x9bc1,0x9bb5, 0x9bb8,0x9bd3,0x9bb6,0x9bc4,
  0x9bb9,0x9bbd,0x9d5c,0x9d53, 0x9d4f,0x0000,
/* 0x8b41(i:14060) */
  0x9d4a,0x9d5b,0x9d4b,0x9d59, 0x9d56,0x9d4c,0x9d57,0x9d52,
  0x9d54,0x9d5f,0x9d58,0x9d5a, 0x9e8e,0x9e8c,0x9edf,0x9f01,
  0x9f00,0x9f16,0x9f25,0x9f2b, 0x9f2a,0x9f29,0x9f28,0x9f4c,
  0x9f55,0x5134,0x5135,0x5296, 0x52f7,0x53b4,0x56ab,0x56ad,
  0x56a6,0x56a7,0x56aa,0x56ac, 0x58da,0x58dd,0x58db,0x5912,
  0x5b3d,0x5b3e,0x5b3f,0x5dc3, 0x5e70,0x5fbf,0x61fb,0x6507,
  0x6510,0x650d,0x6509,0x650c, 0x650e,0x6584,0x65de,0x65dd,
  0x66de,0x6ae7,0x6ae0,0x6acc, 0x6ad1,0x6ad9,0x6acb,0x0000,
  0x6adf,0x6adc,0x6ad0,0x6aeb, 0x6acf,0x6acd,0x6ade,0x6b60,
  0x6bb0,0x6c0c,0x7019,0x7027, 0x7020,0x7016,0x702b,0x7021,
  0x7022,0x7023,0x7029,0x7017, 0x7024,0x701c,0x702a,0x720c,
  0x720a,0x7207,0x7202,0x7205, 0x72a5,0x72a6,0x72a4,0x72a3,
  0x72a1,0x74cb,0x74c5,0x74b7, 0x74c3,0x7516,0x7660,0x77c9,
  0x77ca,0x77c4,0x77f1,0x791d, 0x791b,0x7921,0x791c,0x7917,
  0x791e,0x79b0,0x7a67,0x7a68, 0x7c33,0x7c3c,0x7c39,0x7c2c,
  0x7c3b,0x7cec,0x7cea,0x7e76, 0x7e75,0x7e78,0x7e70,0x7e77,
  0x7e6f,0x7e7a,0x7e72,0x7e74, 0x7e68,0x7f4b,0x7f4a,0x7f83,
  0x7f86,0x7fb7,0x7ffd,0x7ffe, 0x8078,0x81d7,0x81d5,0x8264,
  0x8261,0x8263,0x85eb,0x85f1, 0x85ed,0x85d9,0x85e1,0x85e8,
  0x85da,0x85d7,0x85ec,0x85f2, 0x85f8,0x85d8,0x85df,0x85e3,
  0x85dc,0x85d1,0x85f0,0x85e6, 0x85ef,0x85de,0x85e2,0x8800,
  0x87fa,0x8803,0x87f6,0x87f7, 0x8809,0x880c,0x880b,0x8806,
  0x87fc,0x8808,0x87ff,0x880a, 0x8802,0x8962,0x895a,0x895b,
  0x8957,0x8961,0x895c,0x8958, 0x895d,0x0000,
/* 0x8c41(i:14250) */
  0x8959,0x8988,0x89b7,0x89b6, 0x89f6,0x8b50,0x8b48,0x8b4a,
  0x8b40,0x8b53,0x8b56,0x8b54, 0x8b4b,0x8b55,0x8b51,0x8b42,
  0x8b52,0x8b57,0x8c43,0x8c77, 0x8c76,0x8c9a,0x8d06,0x8d07,
  0x8d09,0x8dac,0x8daa,0x8dad, 0x8dab,0x8e6d,0x8e78,0x8e73,
  0x8e6a,0x8e6f,0x8e7b,0x8ec2, 0x8f52,0x8f51,0x8f4f,0x8f50,
  0x8f53,0x8fb4,0x9140,0x913f, 0x91b0,0x91ad,0x93de,0x93c7,
  0x93cf,0x93c2,0x93da,0x93d0, 0x93f9,0x93ec,0x93cc,0x93d9,
  0x93a9,0x93e6,0x93ca,0x93d4, 0x93ee,0x93e3,0x93d5,0x0000,
  0x93c4,0x93ce,0x93c0,0x93d2, 0x93e7,0x957d,0x95da,0x95db,
  0x96e1,0x9729,0x972b,0x972c, 0x9728,0x9726,0x97b3,0x97b7,
  0x97b6,0x97dd,0x97de,0x97df, 0x985c,0x9859,0x985d,0x9857,
  0x98bf,0x98bd,0x98bb,0x98be, 0x9948,0x9947,0x9943,0x99a6,
  0x99a7,0x9a1a,0x9a15,0x9a25, 0x9a1d,0x9a24,0x9a1b,0x9a22,
  0x9a20,0x9a27,0x9a23,0x9a1e, 0x9a1c,0x9a14,0x9ac2,0x9b0b,
  0x9b0a,0x9b0e,0x9b0c,0x9b37, 0x9bea,0x9beb,0x9be0,0x9bde,
  0x9be4,0x9be6,0x9be2,0x9bf0, 0x9bd4,0x9bd7,0x9bec,0x9bdc,
  0x9bd9,0x9be5,0x9bd5,0x9be1, 0x9bda,0x9d77,0x9d81,0x9d8a,
  0x9d84,0x9d88,0x9d71,0x9d80, 0x9d78,0x9d86,0x9d8b,0x9d8c,
  0x9d7d,0x9d6b,0x9d74,0x9d75, 0x9d70,0x9d69,0x9d85,0x9d73,
  0x9d7b,0x9d82,0x9d6f,0x9d79, 0x9d7f,0x9d87,0x9d68,0x9e94,
  0x9e91,0x9ec0,0x9efc,0x9f2d, 0x9f40,0x9f41,0x9f4d,0x9f56,
  0x9f57,0x9f58,0x5337,0x56b2, 0x56b5,0x56b3,0x58e3,0x5b45,
  0x5dc6,0x5dc7,0x5eee,0x5eef, 0x5fc0,0x5fc1,0x61f9,0x6517,
  0x6516,0x6515,0x6513,0x65df, 0x66e8,0x0000,
/* 0x8d41(i:14440) */
  0x66e3,0x66e4,0x6af3,0x6af0, 0x6aea,0x6ae8,0x6af9,0x6af1,
  0x6aee,0x6aef,0x703c,0x7035, 0x702f,0x7037,0x7034,0x7031,
  0x7042,0x7038,0x703f,0x703a, 0x7039,0x7040,0x703b,0x7033,
  0x7041,0x7213,0x7214,0x72a8, 0x737d,0x737c,0x74ba,0x76ab,
  0x76aa,0x76be,0x76ed,0x77cc, 0x77ce,0x77cf,0x77cd,0x77f2,
  0x7925,0x7923,0x7927,0x7928, 0x7924,0x7929,0x79b2,0x7a6e,
  0x7a6c,0x7a6d,0x7af7,0x7c49, 0x7c48,0x7c4a,0x7c47,0x7c45,
  0x7cee,0x7e7b,0x7e7e,0x7e81, 0x7e80,0x7fba,0x7fff,0x0000,
  0x8079,0x81db,0x81d9,0x820b, 0x8268,0x8269,0x8622,0x85ff,
  0x8601,0x85fe,0x861b,0x8600, 0x85f6,0x8604,0x8609,0x8605,
  0x860c,0x85fd,0x8819,0x8810, 0x8811,0x8817,0x8813,0x8816,
  0x8963,0x8966,0x89b9,0x89f7, 0x8b60,0x8b6a,0x8b5d,0x8b68,
  0x8b63,0x8b65,0x8b67,0x8b6d, 0x8dae,0x8e86,0x8e88,0x8e84,
  0x8f59,0x8f56,0x8f57,0x8f55, 0x8f58,0x8f5a,0x908d,0x9143,
  0x9141,0x91b7,0x91b5,0x91b2, 0x91b3,0x940b,0x9413,0x93fb,
  0x9420,0x940f,0x9414,0x93fe, 0x9415,0x9410,0x9428,0x9419,
  0x940d,0x93f5,0x9400,0x93f7, 0x9407,0x940e,0x9416,0x9412,
  0x93fa,0x9409,0x93f8,0x940a, 0x93ff,0x93fc,0x940c,0x93f6,
  0x9411,0x9406,0x95de,0x95e0, 0x95df,0x972e,0x972f,0x97b9,
  0x97bb,0x97fd,0x97fe,0x9860, 0x9862,0x9863,0x985f,0x98c1,
  0x98c2,0x9950,0x994e,0x9959, 0x994c,0x994b,0x9953,0x9a32,
  0x9a34,0x9a31,0x9a2c,0x9a2a, 0x9a36,0x9a29,0x9a2e,0x9a38,
  0x9a2d,0x9ac7,0x9aca,0x9ac6, 0x9b10,0x9b12,0x9b11,0x9c0b,
  0x9c08,0x9bf7,0x9c05,0x9c12, 0x9bf8,0x0000,
/* 0x8e41(i:14630) */
  0x9c40,0x9c07,0x9c0e,0x9c06, 0x9c17,0x9c14,0x9c09,0x9d9f,
  0x9d99,0x9da4,0x9d9d,0x9d92, 0x9d98,0x9d90,0x9d9b,0x9da0,
  0x9d94,0x9d9c,0x9daa,0x9d97, 0x9da1,0x9d9a,0x9da2,0x9da8,
  0x9d9e,0x9da3,0x9dbf,0x9da9, 0x9d96,0x9da6,0x9da7,0x9e99,
  0x9e9b,0x9e9a,0x9ee5,0x9ee4, 0x9ee7,0x9ee6,0x9f30,0x9f2e,
  0x9f5b,0x9f60,0x9f5e,0x9f5d, 0x9f59,0x9f91,0x513a,0x5139,
  0x5298,0x5297,0x56c3,0x56bd, 0x56be,0x5b48,0x5b47,0x5dcb,
  0x5dcf,0x5ef1,0x61fd,0x651b, 0x6b02,0x6afc,0x6b03,0x0000,
  0x6af8,0x6b00,0x7043,0x7044, 0x704a,0x7048,0x7049,0x7045,
  0x7046,0x721d,0x721a,0x7219, 0x737e,0x7517,0x766a,0x77d0,
  0x792d,0x7931,0x792f,0x7c54, 0x7c53,0x7cf2,0x7e8a,0x7e87,
  0x7e88,0x7e8b,0x7e86,0x7e8d, 0x7f4d,0x7fbb,0x8030,0x81dd,
  0x8618,0x862a,0x8626,0x861f, 0x8623,0x861c,0x8619,0x8627,
  0x862e,0x8621,0x8620,0x8629, 0x861e,0x8625,0x8829,0x881d,
  0x881b,0x8820,0x8824,0x881c, 0x882b,0x884a,0x896d,0x8969,
  0x896e,0x896b,0x89fa,0x8b79, 0x8b78,0x8b45,0x8b7a,0x8b7b,
  0x8d10,0x8d14,0x8daf,0x8e8e, 0x8e8c,0x8f5e,0x8f5b,0x8f5d,
  0x9146,0x9144,0x9145,0x91b9, 0x943f,0x943b,0x9436,0x9429,
  0x943d,0x943c,0x9430,0x9439, 0x942a,0x9437,0x942c,0x9440,
  0x9431,0x95e5,0x95e4,0x95e3, 0x9735,0x973a,0x97bf,0x97e1,
  0x9864,0x98c9,0x98c6,0x98c0, 0x9958,0x9956,0x9a39,0x9a3d,
  0x9a46,0x9a44,0x9a42,0x9a41, 0x9a3a,0x9a3f,0x9acd,0x9b15,
  0x9b17,0x9b18,0x9b16,0x9b3a, 0x9b52,0x9c2b,0x9c1d,0x9c1c,
  0x9c2c,0x9c23,0x9c28,0x9c29, 0x9c24,0x0000,
/* 0x8f41(i:14820) */
  0x9c21,0x9db7,0x9db6,0x9dbc, 0x9dc1,0x9dc7,0x9dca,0x9dcf,
  0x9dbe,0x9dc5,0x9dc3,0x9dbb, 0x9db5,0x9dce,0x9db9,0x9dba,
  0x9dac,0x9dc8,0x9db1,0x9dad, 0x9dcc,0x9db3,0x9dcd,0x9db2,
  0x9e7a,0x9e9c,0x9eeb,0x9eee, 0x9eed,0x9f1b,0x9f18,0x9f1a,
  0x9f31,0x9f4e,0x9f65,0x9f64, 0x9f92,0x4eb9,0x56c6,0x56c5,
  0x56cb,0x5971,0x5b4b,0x5b4c, 0x5dd5,0x5dd1,0x5ef2,0x6521,
  0x6520,0x6526,0x6522,0x6b0b, 0x6b08,0x6b09,0x6c0d,0x7055,
  0x7056,0x7057,0x7052,0x721e, 0x721f,0x72a9,0x737f,0x0000,
  0x74d8,0x74d5,0x74d9,0x74d7, 0x766d,0x76ad,0x7935,0x79b4,
  0x7a70,0x7a71,0x7c57,0x7c5c, 0x7c59,0x7c5b,0x7c5a,0x7cf4,
  0x7cf1,0x7e91,0x7f4f,0x7f87, 0x81de,0x826b,0x8634,0x8635,
  0x8633,0x862c,0x8632,0x8636, 0x882c,0x8828,0x8826,0x882a,
  0x8825,0x8971,0x89bf,0x89be, 0x89fb,0x8b7e,0x8b84,0x8b82,
  0x8b86,0x8b85,0x8b7f,0x8d15, 0x8e95,0x8e94,0x8e9a,0x8e92,
  0x8e90,0x8e96,0x8e97,0x8f60, 0x8f62,0x9147,0x944c,0x9450,
  0x944a,0x944b,0x944f,0x9447, 0x9445,0x9448,0x9449,0x9446,
  0x973f,0x97e3,0x986a,0x9869, 0x98cb,0x9954,0x995b,0x9a4e,
  0x9a53,0x9a54,0x9a4c,0x9a4f, 0x9a48,0x9a4a,0x9a49,0x9a52,
  0x9a50,0x9ad0,0x9b19,0x9b2b, 0x9b3b,0x9b56,0x9b55,0x9c46,
  0x9c48,0x9c3f,0x9c44,0x9c39, 0x9c33,0x9c41,0x9c3c,0x9c37,
  0x9c34,0x9c32,0x9c3d,0x9c36, 0x9ddb,0x9dd2,0x9dde,0x9dda,
  0x9dcb,0x9dd0,0x9ddc,0x9dd1, 0x9ddf,0x9de9,0x9dd9,0x9dd8,
  0x9dd6,0x9df5,0x9dd5,0x9ddd, 0x9eb6,0x9ef0,0x9f35,0x9f33,
  0x9f32,0x9f42,0x9f6b,0x9f95, 0x9fa2,0x0000,
/* 0x9041(i:15010) */
  0x513d,0x5299,0x58e8,0x58e7, 0x5972,0x5b4d,0x5dd8,0x882f,
  0x5f4f,0x6201,0x6203,0x6204, 0x6529,0x6525,0x6596,0x66eb,
  0x6b11,0x6b12,0x6b0f,0x6bca, 0x705b,0x705a,0x7222,0x7382,
  0x7381,0x7383,0x7670,0x77d4, 0x7c67,0x7c66,0x7e95,0x826c,
  0x863a,0x8640,0x8639,0x863c, 0x8631,0x863b,0x863e,0x8830,
  0x8832,0x882e,0x8833,0x8976, 0x8974,0x8973,0x89fe,0x8b8c,
  0x8b8e,0x8b8b,0x8b88,0x8c45, 0x8d19,0x8e98,0x8f64,0x8f63,
  0x91bc,0x9462,0x9455,0x945d, 0x9457,0x945e,0x97c4,0x0000,
  0x97c5,0x9800,0x9a56,0x9a59, 0x9b1e,0x9b1f,0x9b20,0x9c52,
  0x9c58,0x9c50,0x9c4a,0x9c4d, 0x9c4b,0x9c55,0x9c59,0x9c4c,
  0x9c4e,0x9dfb,0x9df7,0x9def, 0x9de3,0x9deb,0x9df8,0x9de4,
  0x9df6,0x9de1,0x9dee,0x9de6, 0x9df2,0x9df0,0x9de2,0x9dec,
  0x9df4,0x9df3,0x9de8,0x9ded, 0x9ec2,0x9ed0,0x9ef2,0x9ef3,
  0x9f06,0x9f1c,0x9f38,0x9f37, 0x9f36,0x9f43,0x9f4f,0x9f71,
  0x9f70,0x9f6e,0x9f6f,0x56d3, 0x56cd,0x5b4e,0x5c6d,0x652d,
  0x66ed,0x66ee,0x6b13,0x705f, 0x7061,0x705d,0x7060,0x7223,
  0x74db,0x74e5,0x77d5,0x7938, 0x79b7,0x79b6,0x7c6a,0x7e97,
  0x7f89,0x826d,0x8643,0x8838, 0x8837,0x8835,0x884b,0x8b94,
  0x8b95,0x8e9e,0x8e9f,0x8ea0, 0x8e9d,0x91be,0x91bd,0x91c2,
  0x946b,0x9468,0x9469,0x96e5, 0x9746,0x9743,0x9747,0x97c7,
  0x97e5,0x9a5e,0x9ad5,0x9b59, 0x9c63,0x9c67,0x9c66,0x9c62,
  0x9c5e,0x9c60,0x9e02,0x9dfe, 0x9e07,0x9e03,0x9e06,0x9e05,
  0x9e00,0x9e01,0x9e09,0x9dff, 0x9dfd,0x9e04,0x9ea0,0x9f1e,
  0x9f46,0x9f74,0x9f75,0x9f76, 0x56d4,0x0000,
/* 0x9141(i:15200) */
  0x652e,0x65b8,0x6b18,0x6b19, 0x6b17,0x6b1a,0x7062,0x7226,
  0x72aa,0x77d8,0x77d9,0x7939, 0x7c69,0x7c6b,0x7cf6,0x7e9a,
  0x7e98,0x7e9b,0x7e99,0x81e0, 0x81e1,0x8646,0x8647,0x8648,
  0x8979,0x897a,0x897c,0x897b, 0x89ff,0x8b98,0x8b99,0x8ea5,
  0x8ea4,0x8ea3,0x946e,0x946d, 0x946f,0x9471,0x9473,0x9749,
  0x9872,0x995f,0x9c68,0x9c6e, 0x9c6d,0x9e0b,0x9e0d,0x9e10,
  0x9e0f,0x9e12,0x9e11,0x9ea1, 0x9ef5,0x9f09,0x9f47,0x9f78,
  0x9f7b,0x9f7a,0x9f79,0x571e, 0x7066,0x7c6f,0x883c,0x0000,
  0x8db2,0x8ea6,0x91c3,0x9474, 0x9478,0x9476,0x9475,0x9a60,
  0x9c74,0x9c73,0x9c71,0x9c75, 0x9e14,0x9e13,0x9ef6,0x9f0a,
  0x9fa4,0x7068,0x7065,0x7cf7, 0x866a,0x883e,0x883d,0x883f,
  0x8b9e,0x8c9c,0x8ea9,0x8ec9, 0x974b,0x9873,0x9874,0x98cc,
  0x9961,0x99ab,0x9a64,0x9a66, 0x9a67,0x9b24,0x9e15,0x9e17,
  0x9f48,0x6207,0x6b1e,0x7227, 0x864c,0x8ea8,0x9482,0x9480,
  0x9481,0x9a69,0x9a68,0x9b2e, 0x9e19,0x7229,0x864b,0x8b9f,
  0x9483,0x9c79,0x9eb7,0x7675, 0x9a6b,0x9c7a,0x9e1d,0x7069,
  0x706a,0x9ea4,0x9f7e,0x9f49, 0x9f98,0x691e,0x6eb8,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x9241(i:15390) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x9341(i:15580) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x9441(i:15770) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x9541(i:15960) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x9641(i:16150) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x9741(i:16340) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x9841(i:16530) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x9941(i:16720) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x9a41(i:16910) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x9b41(i:17100) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x9c41(i:17290) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x9d41(i:17480) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x9e41(i:17670) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0x9f41(i:17860) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xa041(i:18050) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xa141(i:18240) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xa241(i:18430) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xa341(i:18620) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xa441(i:18810) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xa541(i:19000) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xa641(i:19190) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xa741(i:19380) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xa841(i:19570) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xa941(i:19760) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xaa41(i:19950) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xab41(i:20140) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xac41(i:20330) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xad41(i:20520) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xae41(i:20710) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xaf41(i:20900) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xb041(i:21090) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xb141(i:21280) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xb241(i:21470) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xb341(i:21660) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xb441(i:21850) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xb541(i:22040) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xb641(i:22230) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xb741(i:22420) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xb841(i:22610) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xb941(i:22800) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xba41(i:22990) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xbb41(i:23180) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xbc41(i:23370) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xbd41(i:23560) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xbe41(i:23750) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xbf41(i:23940) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xc041(i:24130) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xc141(i:24320) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* 0xc241(i:24510) */
  0xe000,0xe001,0xe002,0xe003, 0xe004,0xe005,0xe006,0xe007,
  0xe008,0xe009,0xe00a,0xe00b, 0xe00c,0xe00d,0xe00e,0xe00f,
  0xe010,0xe011,0xe012,0xe013, 0xe014,0xe015,0xe016,0xe017,
  0xe018,0xe019,0xe01a,0xe01b, 0xe01c,0xe01d,0xe01e,0xe01f,
  0xe020,0xe021,0xe022,0xe023, 0xe024,0xe025,0xe026,0xe027,
  0xe028,0xe029,0xe02a,0xe02b, 0xe02c,0xe02d,0xe02e,0xe02f,
  0xe030,0xe031,0xe032,0xe033, 0xe034,0xe035,0xe036,0xe037,
  0xe038,0xe039,0xe03a,0xe03b, 0xe03c,0xe03d,0xe03e,0x0000,
  0xe03f,0xe040,0xe041,0xe042, 0xe043,0xe044,0xe045,0xe046,
  0xe047,0xe048,0xe049,0xe04a, 0xe04b,0xe04c,0xe04d,0xe04e,
  0xe04f,0xe050,0xe051,0xe052, 0xe053,0xe054,0xe055,0xe056,
  0xe057,0xe058,0xe059,0xe05a, 0xe05b,0xe05c,0xe05d,0xe05e,
  0xe05f,0xe060,0xe061,0xe062, 0xe063,0xe064,0xe065,0xe066,
  0xe067,0xe068,0xe069,0xe06a, 0xe06b,0xe06c,0xe06d,0xe06e,
  0xe06f,0xe070,0xe071,0xe072, 0xe073,0xe074,0xe075,0xe076,
  0xe077,0xe078,0xe079,0xe07a, 0xe07b,0xe07c,0xe07d,0xe07e,
  0xe07f,0xe080,0xe081,0xe082, 0xe083,0xe084,0xe085,0xe086,
  0xe087,0xe088,0xe089,0xe08a, 0xe08b,0xe08c,0xe08d,0xe08e,
  0xe08f,0xe090,0xe091,0xe092, 0xe093,0xe094,0xe095,0xe096,
  0xe097,0xe098,0xe099,0xe09a, 0xe09b,0xe09c,0xe09d,0xe09e,
  0xe09f,0xe0a0,0xe0a1,0xe0a2, 0xe0a3,0xe0a4,0xe0a5,0xe0a6,
  0xe0a7,0xe0a8,0xe0a9,0xe0aa, 0xe0ab,0xe0ac,0xe0ad,0xe0ae,
  0xe0af,0xe0b0,0xe0b1,0xe0b2, 0xe0b3,0xe0b4,0xe0b5,0xe0b6,
  0xe0b7,0xe0b8,0xe0b9,0xe0ba, 0xe0bb,0x0000,
/* 0xc341(i:24700) */
  0xe0bc,0xe0bd,0xe0be,0xe0bf, 0xe0c0,0xe0c1,0xe0c2,0xe0c3,
  0xe0c4,0xe0c5,0xe0c6,0xe0c7, 0xe0c8,0xe0c9,0xe0ca,0xe0cb,
  0xe0cc,0xe0cd,0xe0ce,0xe0cf, 0xe0d0,0xe0d1,0xe0d2,0xe0d3,
  0xe0d4,0xe0d5,0xe0d6,0xe0d7, 0xe0d8,0xe0d9,0xe0da,0xe0db,
  0xe0dc,0xe0dd,0xe0de,0xe0df, 0xe0e0,0xe0e1,0xe0e2,0xe0e3,
  0xe0e4,0xe0e5,0xe0e6,0xe0e7, 0xe0e8,0xe0e9,0xe0ea,0xe0eb,
  0xe0ec,0xe0ed,0xe0ee,0xe0ef, 0xe0f0,0xe0f1,0xe0f2,0xe0f3,
  0xe0f4,0xe0f5,0xe0f6,0xe0f7, 0xe0f8,0xe0f9,0xe0fa,0x0000,
  0xe0fb,0xe0fc,0xe0fd,0xe0fe, 0xe0ff,0xe100,0xe101,0xe102,
  0xe103,0xe104,0xe105,0xe106, 0xe107,0xe108,0xe109,0xe10a,
  0xe10b,0xe10c,0xe10d,0xe10e, 0xe10f,0xe110,0xe111,0xe112,
  0xe113,0xe114,0xe115,0xe116, 0xe117,0xe118,0xe119,0xe11a,
  0xe11b,0xe11c,0xe11d,0xe11e, 0xe11f,0xe120,0xe121,0xe122,
  0xe123,0xe124,0xe125,0xe126, 0xe127,0xe128,0xe129,0xe12a,
  0xe12b,0xe12c,0xe12d,0xe12e, 0xe12f,0xe130,0xe131,0xe132,
  0xe133,0xe134,0xe135,0xe136, 0xe137,0xe138,0xe139,0xe13a,
  0xe13b,0xe13c,0xe13d,0xe13e, 0xe13f,0xe140,0xe141,0xe142,
  0xe143,0xe144,0xe145,0xe146, 0xe147,0xe148,0xe149,0xe14a,
  0xe14b,0xe14c,0xe14d,0xe14e, 0xe14f,0xe150,0xe151,0xe152,
  0xe153,0xe154,0xe155,0xe156, 0xe157,0xe158,0xe159,0xe15a,
  0xe15b,0xe15c,0xe15d,0xe15e, 0xe15f,0xe160,0xe161,0xe162,
  0xe163,0xe164,0xe165,0xe166, 0xe167,0xe168,0xe169,0xe16a,
  0xe16b,0xe16c,0xe16d,0xe16e, 0xe16f,0xe170,0xe171,0xe172,
  0xe173,0xe174,0xe175,0xe176, 0xe177,0x0000,
/* 0xc441(i:24890) */
  0xe178,0xe179,0xe17a,0xe17b, 0xe17c,0xe17d,0xe17e,0xe17f,
  0xe180,0xe181,0xe182,0xe183, 0xe184,0xe185,0xe186,0xe187,
  0xe188,0xe189,0xe18a,0xe18b, 0xe18c,0xe18d,0xe18e,0xe18f,
  0xe190,0xe191,0xe192,0xe193, 0xe194,0xe195,0xe196,0xe197,
  0xe198,0xe199,0xe19a,0xe19b, 0xe19c,0xe19d,0xe19e,0xe19f,
  0xe1a0,0xe1a1,0xe1a2,0xe1a3, 0xe1a4,0xe1a5,0xe1a6,0xe1a7,
  0xe1a8,0xe1a9,0xe1aa,0xe1ab, 0xe1ac,0xe1ad,0xe1ae,0xe1af,
  0xe1b0,0xe1b1,0xe1b2,0xe1b3, 0xe1b4,0xe1b5,0xe1b6,0x0000,
  0xe1b7,0xe1b8,0xe1b9,0xe1ba, 0xe1bb,0xe1bc,0xe1bd,0xe1be,
  0xe1bf,0xe1c0,0xe1c1,0xe1c2, 0xe1c3,0xe1c4,0xe1c5,0xe1c6,
  0xe1c7,0xe1c8,0xe1c9,0xe1ca, 0xe1cb,0xe1cc,0xe1cd,0xe1ce,
  0xe1cf,0xe1d0,0xe1d1,0xe1d2, 0xe1d3,0xe1d4,0xe1d5,0xe1d6,
  0xe1d7,0xe1d8,0xe1d9,0xe1da, 0xe1db,0xe1dc,0xe1dd,0xe1de,
  0xe1df,0xe1e0,0xe1e1,0xe1e2, 0xe1e3,0xe1e4,0xe1e5,0xe1e6,
  0xe1e7,0xe1e8,0xe1e9,0xe1ea, 0xe1eb,0xe1ec,0xe1ed,0xe1ee,
  0xe1ef,0xe1f0,0xe1f1,0xe1f2, 0xe1f3,0xe1f4,0xe1f5,0xe1f6,
  0xe1f7,0xe1f8,0xe1f9,0xe1fa, 0xe1fb,0xe1fc,0xe1fd,0xe1fe,
  0xe1ff,0xe200,0xe201,0xe202, 0xe203,0xe204,0xe205,0xe206,
  0xe207,0xe208,0xe209,0xe20a, 0xe20b,0xe20c,0xe20d,0xe20e,
  0xe20f,0xe210,0xe211,0xe212, 0xe213,0xe214,0xe215,0xe216,
  0xe217,0xe218,0xe219,0xe21a, 0xe21b,0xe21c,0xe21d,0xe21e,
  0xe21f,0xe220,0xe221,0xe222, 0xe223,0xe224,0xe225,0xe226,
  0xe227,0xe228,0xe229,0xe22a, 0xe22b,0xe22c,0xe22d,0xe22e,
  0xe22f,0xe230,0xe231,0xe232, 0xe233,0x0000,
/* 0xc541(i:25080) */
  0xe234,0xe235,0xe236,0xe237, 0xe238,0xe239,0xe23a,0xe23b,
  0xe23c,0xe23d,0xe23e,0xe23f, 0xe240,0xe241,0xe242,0xe243,
  0xe244,0xe245,0xe246,0xe247, 0xe248,0xe249,0xe24a,0xe24b,
  0xe24c,0xe24d,0xe24e,0xe24f, 0xe250,0xe251,0xe252,0xe253,
  0xe254,0xe255,0xe256,0xe257, 0xe258,0xe259,0xe25a,0xe25b,
  0xe25c,0xe25d,0xe25e,0xe25f, 0xe260,0xe261,0xe262,0xe263,
  0xe264,0xe265,0xe266,0xe267, 0xe268,0xe269,0xe26a,0xe26b,
  0xe26c,0xe26d,0xe26e,0xe26f, 0xe270,0xe271,0xe272,0x0000,
  0xe273,0xe274,0xe275,0xe276, 0xe277,0xe278,0xe279,0xe27a,
  0xe27b,0xe27c,0xe27d,0xe27e, 0xe27f,0xe280,0xe281,0xe282,
  0xe283,0xe284,0xe285,0xe286, 0xe287,0xe288,0xe289,0xe28a,
  0xe28b,0xe28c,0xe28d,0xe28e, 0xe28f,0xe290,0xe291,0xe292,
  0xe293,0xe294,0xe295,0xe296, 0xe297,0xe298,0xe299,0xe29a,
  0xe29b,0xe29c,0xe29d,0xe29e, 0xe29f,0xe2a0,0xe2a1,0xe2a2,
  0xe2a3,0xe2a4,0xe2a5,0xe2a6, 0xe2a7,0xe2a8,0xe2a9,0xe2aa,
  0xe2ab,0xe2ac,0xe2ad,0xe2ae, 0xe2af,0xe2b0,0xe2b1,0xe2b2,
  0xe2b3,0xe2b4,0xe2b5,0xe2b6, 0xe2b7,0xe2b8,0xe2b9,0xe2ba,
  0xe2bb,0xe2bc,0xe2bd,0xe2be, 0xe2bf,0xe2c0,0xe2c1,0xe2c2,
  0xe2c3,0xe2c4,0xe2c5,0xe2c6, 0xe2c7,0xe2c8,0xe2c9,0xe2ca,
  0xe2cb,0xe2cc,0xe2cd,0xe2ce, 0xe2cf,0xe2d0,0xe2d1,0xe2d2,
  0xe2d3,0xe2d4,0xe2d5,0xe2d6, 0xe2d7,0xe2d8,0xe2d9,0xe2da,
  0xe2db,0xe2dc,0xe2dd,0xe2de, 0xe2df,0xe2e0,0xe2e1,0xe2e2,
  0xe2e3,0xe2e4,0xe2e5,0xe2e6, 0xe2e7,0xe2e8,0xe2e9,0xe2ea,
  0xe2eb,0xe2ec,0xe2ed,0xe2ee, 0xe2ef,0x0000,
/* 0xc641(i:25270) */
  0xe2f0,0xe2f1,0xe2f2,0xe2f3, 0xe2f4,0xe2f5,0xe2f6,0xe2f7,
  0xe2f8,0xe2f9,0xe2fa,0xe2fb, 0xe2fc,0xe2fd,0xe2fe,0xe2ff,
  0xe300,0xe301,0xe302,0xe303, 0xe304,0xe305,0xe306,0xe307,
  0xe308,0xe309,0xe30a,0xe30b, 0xe30c,0xe30d,0xe30e,0xe30f,
  0xe310,0xe311,0xe312,0xe313, 0xe314,0xe315,0xe316,0xe317,
  0xe318,0xe319,0xe31a,0xe31b, 0xe31c,0xe31d,0xe31e,0xe31f,
  0xe320,0xe321,0xe322,0xe323, 0xe324,0xe325,0xe326,0xe327,
  0xe328,0xe329,0xe32a,0xe32b, 0xe32c,0xe32d,0xe32e,0x0000,
  0xe32f,0xe330,0xe331,0xe332, 0xe333,0xe334,0xe335,0xe336,
  0xe337,0xe338,0xe339,0xe33a, 0xe33b,0xe33c,0xe33d,0xe33e,
  0xe33f,0xe340,0xe341,0xe342, 0xe343,0xe344,0xe345,0xe346,
  0xe347,0xe348,0xe349,0xe34a, 0xe34b,0xe34c,0xe34d,0xe34e,
  0xe34f,0xe350,0xe351,0xe352, 0xe353,0xe354,0xe355,0xe356,
  0xe357,0xe358,0xe359,0xe35a, 0xe35b,0xe35c,0xe35d,0xe35e,
  0xe35f,0xe360,0xe361,0xe362, 0xe363,0xe364,0xe365,0xe366,
  0xe367,0xe368,0xe369,0xe36a, 0xe36b,0xe36c,0xe36d,0xe36e,
  0xe36f,0xe370,0xe371,0xe372, 0xe373,0xe374,0xe375,0xe376,
  0xe377,0xe378,0xe379,0xe37a, 0xe37b,0xe37c,0xe37d,0xe37e,
  0xe37f,0xe380,0xe381,0xe382, 0xe383,0xe384,0xe385,0xe386,
  0xe387,0xe388,0xe389,0xe38a, 0xe38b,0xe38c,0xe38d,0xe38e,
  0xe38f,0xe390,0xe391,0xe392, 0xe393,0xe394,0xe395,0xe396,
  0xe397,0xe398,0xe399,0xe39a, 0xe39b,0xe39c,0xe39d,0xe39e,
  0xe39f,0xe3a0,0xe3a1,0xe3a2, 0xe3a3,0xe3a4,0xe3a5,0xe3a6,
  0xe3a7,0xe3a8,0xe3a9,0xe3aa, 0xe3ab,0x0000,
/* 0xc741(i:25460) */
  0xe3ac,0xe3ad,0xe3ae,0xe3af, 0xe3b0,0xe3b1,0xe3b2,0xe3b3,
  0xe3b4,0xe3b5,0xe3b6,0xe3b7, 0xe3b8,0xe3b9,0xe3ba,0xe3bb,
  0xe3bc,0xe3bd,0xe3be,0xe3bf, 0xe3c0,0xe3c1,0xe3c2,0xe3c3,
  0xe3c4,0xe3c5,0xe3c6,0xe3c7, 0xe3c8,0xe3c9,0xe3ca,0xe3cb,
  0xe3cc,0xe3cd,0xe3ce,0xe3cf, 0xe3d0,0xe3d1,0xe3d2,0xe3d3,
  0xe3d4,0xe3d5,0xe3d6,0xe3d7, 0xe3d8,0xe3d9,0xe3da,0xe3db,
  0xe3dc,0xe3dd,0xe3de,0xe3df, 0xe3e0,0xe3e1,0xe3e2,0xe3e3,
  0xe3e4,0xe3e5,0xe3e6,0xe3e7, 0xe3e8,0xe3e9,0xe3ea,0x0000,
  0xe3eb,0xe3ec,0xe3ed,0xe3ee, 0xe3ef,0xe3f0,0xe3f1,0xe3f2,
  0xe3f3,0xe3f4,0xe3f5,0xe3f6, 0xe3f7,0xe3f8,0xe3f9,0xe3fa,
  0xe3fb,0xe3fc,0xe3fd,0xe3fe, 0xe3ff,0xe400,0xe401,0xe402,
  0xe403,0xe404,0xe405,0xe406, 0xe407,0xe408,0xe409,0xe40a,
  0xe40b,0xe40c,0xe40d,0xe40e, 0xe40f,0xe410,0xe411,0xe412,
  0xe413,0xe414,0xe415,0xe416, 0xe417,0xe418,0xe419,0xe41a,
  0xe41b,0xe41c,0xe41d,0xe41e, 0xe41f,0xe420,0xe421,0xe422,
  0xe423,0xe424,0xe425,0xe426, 0xe427,0xe428,0xe429,0xe42a,
  0xe42b,0xe42c,0xe42d,0xe42e, 0xe42f,0xe430,0xe431,0xe432,
  0xe433,0xe434,0xe435,0xe436, 0xe437,0xe438,0xe439,0xe43a,
  0xe43b,0xe43c,0xe43d,0xe43e, 0xe43f,0xe440,0xe441,0xe442,
  0xe443,0xe444,0xe445,0xe446, 0xe447,0xe448,0xe449,0xe44a,
  0xe44b,0xe44c,0xe44d,0xe44e, 0xe44f,0xe450,0xe451,0xe452,
  0xe453,0xe454,0xe455,0xe456, 0xe457,0xe458,0xe459,0xe45a,
  0xe45b,0xe45c,0xe45d,0xe45e, 0xe45f,0xe460,0xe461,0xe462,
  0xe463,0xe464,0xe465,0xe466, 0xe467,0x0000,
/* 0xc841(i:25650) */
  0xe468,0xe469,0xe46a,0xe46b, 0xe46c,0xe46d,0xe46e,0xe46f,
  0xe470,0xe471,0xe472,0xe473, 0xe474,0xe475,0xe476,0xe477,
  0xe478,0xe479,0xe47a,0xe47b, 0xe47c,0xe47d,0xe47e,0xe47f,
  0xe480,0xe481,0xe482,0xe483, 0xe484,0xe485,0xe486,0xe487,
  0xe488,0xe489,0xe48a,0xe48b, 0xe48c,0xe48d,0xe48e,0xe48f,
  0xe490,0xe491,0xe492,0xe493, 0xe494,0xe495,0xe496,0xe497,
  0xe498,0xe499,0xe49a,0xe49b, 0xe49c,0xe49d,0xe49e,0xe49f,
  0xe4a0,0xe4a1,0xe4a2,0xe4a3, 0xe4a4,0xe4a5,0xe4a6,0x0000,
  0xe4a7,0xe4a8,0xe4a9,0xe4aa, 0xe4ab,0xe4ac,0xe4ad,0xe4ae,
  0xe4af,0xe4b0,0xe4b1,0xe4b2, 0xe4b3,0xe4b4,0xe4b5,0xe4b6,
  0xe4b7,0xe4b8,0xe4b9,0xe4ba, 0xe4bb,0xe4bc,0xe4bd,0xe4be,
  0xe4bf,0xe4c0,0xe4c1,0xe4c2, 0xe4c3,0xe4c4,0xe4c5,0xe4c6,
  0xe4c7,0xe4c8,0xe4c9,0xe4ca, 0xe4cb,0xe4cc,0xe4cd,0xe4ce,
  0xe4cf,0xe4d0,0xe4d1,0xe4d2, 0xe4d3,0xe4d4,0xe4d5,0xe4d6,
  0xe4d7,0xe4d8,0xe4d9,0xe4da, 0xe4db,0xe4dc,0xe4dd,0xe4de,
  0xe4df,0xe4e0,0xe4e1,0xe4e2, 0xe4e3,0xe4e4,0xe4e5,0xe4e6,
  0xe4e7,0xe4e8,0xe4e9,0xe4ea, 0xe4eb,0xe4ec,0xe4ed,0xe4ee,
  0xe4ef,0xe4f0,0xe4f1,0xe4f2, 0xe4f3,0xe4f4,0xe4f5,0xe4f6,
  0xe4f7,0xe4f8,0xe4f9,0xe4fa, 0xe4fb,0xe4fc,0xe4fd,0xe4fe,
  0xe4ff,0xe500,0xe501,0xe502, 0xe503,0xe504,0xe505,0xe506,
  0xe507,0xe508,0xe509,0xe50a, 0xe50b,0xe50c,0xe50d,0xe50e,
  0xe50f,0xe510,0xe511,0xe512, 0xe513,0xe514,0xe515,0xe516,
  0xe517,0xe518,0xe519,0xe51a, 0xe51b,0xe51c,0xe51d,0xe51e,
  0xe51f,0xe520,0xe521,0xe522, 0xe523,0x0000,
/* 0xc941(i:25840) */
  0xe524,0xe525,0xe526,0xe527, 0xe528,0xe529,0xe52a,0xe52b,
  0xe52c,0xe52d,0xe52e,0xe52f, 0xe530,0xe531,0xe532,0xe533,
  0xe534,0xe535,0xe536,0xe537, 0xe538,0xe539,0xe53a,0xe53b,
  0xe53c,0xe53d,0xe53e,0xe53f, 0xe540,0xe541,0xe542,0xe543,
  0xe544,0xe545,0xe546,0xe547, 0xe548,0xe549,0xe54a,0xe54b,
  0xe54c,0xe54d,0xe54e,0xe54f, 0xe550,0xe551,0xe552,0xe553,
  0xe554,0xe555,0xe556,0xe557, 0xe558,0xe559,0xe55a,0xe55b,
  0xe55c,0xe55d,0xe55e,0xe55f, 0xe560,0xe561,0xe562,0x0000,
  0xe563,0xe564,0xe565,0xe566, 0xe567,0xe568,0xe569,0xe56a,
  0xe56b,0xe56c,0xe56d,0xe56e, 0xe56f,0xe570,0xe571,0xe572,
  0xe573,0xe574,0xe575,0xe576, 0xe577,0xe578,0xe579,0xe57a,
  0xe57b,0xe57c,0xe57d,0xe57e, 0xe57f,0xe580,0xe581,0xe582,
  0xe583,0xe584,0xe585,0xe586, 0xe587,0xe588,0xe589,0xe58a,
  0xe58b,0xe58c,0xe58d,0xe58e, 0xe58f,0xe590,0xe591,0xe592,
  0xe593,0xe594,0xe595,0xe596, 0xe597,0xe598,0xe599,0xe59a,
  0xe59b,0xe59c,0xe59d,0xe59e, 0xe59f,0xe5a0,0xe5a1,0xe5a2,
  0xe5a3,0xe5a4,0xe5a5,0xe5a6, 0xe5a7,0xe5a8,0xe5a9,0xe5aa,
  0xe5ab,0xe5ac,0xe5ad,0xe5ae, 0xe5af,0xe5b0,0xe5b1,0xe5b2,
  0xe5b3,0xe5b4,0xe5b5,0xe5b6, 0xe5b7,0xe5b8,0xe5b9,0xe5ba,
  0xe5bb,0xe5bc,0xe5bd,0xe5be, 0xe5bf,0xe5c0,0xe5c1,0xe5c2,
  0xe5c3,0xe5c4,0xe5c5,0xe5c6, 0xe5c7,0xe5c8,0xe5c9,0xe5ca,
  0xe5cb,0xe5cc,0xe5cd,0xe5ce, 0xe5cf,0xe5d0,0xe5d1,0xe5d2,
  0xe5d3,0xe5d4,0xe5d5,0xe5d6, 0xe5d7,0xe5d8,0xe5d9,0xe5da,
  0xe5db,0xe5dc,0xe5dd,0xe5de, 0xe5df,0x0000,
/* 0xca41(i:26030) */
  0xe5e0,0xe5e1,0xe5e2,0xe5e3, 0xe5e4,0xe5e5,0xe5e6,0xe5e7,
  0xe5e8,0xe5e9,0xe5ea,0xe5eb, 0xe5ec,0xe5ed,0xe5ee,0xe5ef,
  0xe5f0,0xe5f1,0xe5f2,0xe5f3, 0xe5f4,0xe5f5,0xe5f6,0xe5f7,
  0xe5f8,0xe5f9,0xe5fa,0xe5fb, 0xe5fc,0xe5fd,0xe5fe,0xe5ff,
  0xe600,0xe601,0xe602,0xe603, 0xe604,0xe605,0xe606,0xe607,
  0xe608,0xe609,0xe60a,0xe60b, 0xe60c,0xe60d,0xe60e,0xe60f,
  0xe610,0xe611,0xe612,0xe613, 0xe614,0xe615,0xe616,0xe617,
  0xe618,0xe619,0xe61a,0xe61b, 0xe61c,0xe61d,0xe61e,0x0000,
  0xe61f,0xe620,0xe621,0xe622, 0xe623,0xe624,0xe625,0xe626,
  0xe627,0xe628,0xe629,0xe62a, 0xe62b,0xe62c,0xe62d,0xe62e,
  0xe62f,0xe630,0xe631,0xe632, 0xe633,0xe634,0xe635,0xe636,
  0xe637,0xe638,0xe639,0xe63a, 0xe63b,0xe63c,0xe63d,0xe63e,
  0xe63f,0xe640,0xe641,0xe642, 0xe643,0xe644,0xe645,0xe646,
  0xe647,0xe648,0xe649,0xe64a, 0xe64b,0xe64c,0xe64d,0xe64e,
  0xe64f,0xe650,0xe651,0xe652, 0xe653,0xe654,0xe655,0xe656,
  0xe657,0xe658,0xe659,0xe65a, 0xe65b,0xe65c,0xe65d,0xe65e,
  0xe65f,0xe660,0xe661,0xe662, 0xe663,0xe664,0xe665,0xe666,
  0xe667,0xe668,0xe669,0xe66a, 0xe66b,0xe66c,0xe66d,0xe66e,
  0xe66f,0xe670,0xe671,0xe672, 0xe673,0xe674,0xe675,0xe676,
  0xe677,0xe678,0xe679,0xe67a, 0xe67b,0xe67c,0xe67d,0xe67e,
  0xe67f,0xe680,0xe681,0xe682, 0xe683,0xe684,0xe685,0xe686,
  0xe687,0xe688,0xe689,0xe68a, 0xe68b,0xe68c,0xe68d,0xe68e,
  0xe68f,0xe690,0xe691,0xe692, 0xe693,0xe694,0xe695,0xe696,
  0xe697,0xe698,0xe699,0xe69a, 0xe69b,0x0000,
/* 0xcb41(i:26220) */
  0xe69c,0xe69d,0xe69e,0xe69f, 0xe6a0,0xe6a1,0xe6a2,0xe6a3,
  0xe6a4,0xe6a5,0xe6a6,0xe6a7, 0xe6a8,0xe6a9,0xe6aa,0xe6ab,
  0xe6ac,0xe6ad,0xe6ae,0xe6af, 0xe6b0,0xe6b1,0xe6b2,0xe6b3,
  0xe6b4,0xe6b5,0xe6b6,0xe6b7, 0xe6b8,0xe6b9,0xe6ba,0xe6bb,
  0xe6bc,0xe6bd,0xe6be,0xe6bf, 0xe6c0,0xe6c1,0xe6c2,0xe6c3,
  0xe6c4,0xe6c5,0xe6c6,0xe6c7, 0xe6c8,0xe6c9,0xe6ca,0xe6cb,
  0xe6cc,0xe6cd,0xe6ce,0xe6cf, 0xe6d0,0xe6d1,0xe6d2,0xe6d3,
  0xe6d4,0xe6d5,0xe6d6,0xe6d7, 0xe6d8,0xe6d9,0xe6da,0x0000,
  0xe6db,0xe6dc,0xe6dd,0xe6de, 0xe6df,0xe6e0,0xe6e1,0xe6e2,
  0xe6e3,0xe6e4,0xe6e5,0xe6e6, 0xe6e7,0xe6e8,0xe6e9,0xe6ea,
  0xe6eb,0xe6ec,0xe6ed,0xe6ee, 0xe6ef,0xe6f0,0xe6f1,0xe6f2,
  0xe6f3,0xe6f4,0xe6f5,0xe6f6, 0xe6f7,0xe6f8,0xe6f9,0xe6fa,
  0xe6fb,0xe6fc,0xe6fd,0xe6fe, 0xe6ff,0xe700,0xe701,0xe702,
  0xe703,0xe704,0xe705,0xe706, 0xe707,0xe708,0xe709,0xe70a,
  0xe70b,0xe70c,0xe70d,0xe70e, 0xe70f,0xe710,0xe711,0xe712,
  0xe713,0xe714,0xe715,0xe716, 0xe717,0xe718,0xe719,0xe71a,
  0xe71b,0xe71c,0xe71d,0xe71e, 0xe71f,0xe720,0xe721,0xe722,
  0xe723,0xe724,0xe725,0xe726, 0xe727,0xe728,0xe729,0xe72a,
  0xe72b,0xe72c,0xe72d,0xe72e, 0xe72f,0xe730,0xe731,0xe732,
  0xe733,0xe734,0xe735,0xe736, 0xe737,0xe738,0xe739,0xe73a,
  0xe73b,0xe73c,0xe73d,0xe73e, 0xe73f,0xe740,0xe741,0xe742,
  0xe743,0xe744,0xe745,0xe746, 0xe747,0xe748,0xe749,0xe74a,
  0xe74b,0xe74c,0xe74d,0xe74e, 0xe74f,0xe750,0xe751,0xe752,
  0xe753,0xe754,0xe755,0xe756, 0xe757,0x0000,
/* 0xcc41(i:26410) */
  0xe758,0xe759,0xe75a,0xe75b, 0xe75c,0xe75d,0xe75e,0xe75f,
  0xe760,0xe761,0xe762,0xe763, 0xe764,0xe765,0xe766,0xe767,
  0xe768,0xe769,0xe76a,0xe76b, 0xe76c,0xe76d,0xe76e,0xe76f,
  0xe770,0xe771,0xe772,0xe773, 0xe774,0xe775,0xe776,0xe777,
  0xe778,0xe779,0xe77a,0xe77b, 0xe77c,0xe77d,0xe77e,0xe77f,
  0xe780,0xe781,0xe782,0xe783, 0xe784,0xe785,0xe786,0xe787,
  0xe788,0xe789,0xe78a,0xe78b, 0xe78c,0xe78d,0xe78e,0xe78f,
  0xe790,0xe791,0xe792,0xe793, 0xe794,0xe795,0xe796,0x0000,
  0xe797,0xe798,0xe799,0xe79a, 0xe79b,0xe79c,0xe79d,0xe79e,
  0xe79f,0xe7a0,0xe7a1,0xe7a2, 0xe7a3,0xe7a4,0xe7a5,0xe7a6,
  0xe7a7,0xe7a8,0xe7a9,0xe7aa, 0xe7ab,0xe7ac,0xe7ad,0xe7ae,
  0xe7af,0xe7b0,0xe7b1,0xe7b2, 0xe7b3,0xe7b4,0xe7b5,0xe7b6,
  0xe7b7,0xe7b8,0xe7b9,0xe7ba, 0xe7bb,0xe7bc,0xe7bd,0xe7be,
  0xe7bf,0xe7c0,0xe7c1,0xe7c2, 0xe7c3,0xe7c4,0xe7c5,0xe7c6,
  0xe7c7,0xe7c8,0xe7c9,0xe7ca, 0xe7cb,0xe7cc,0xe7cd,0xe7ce,
  0xe7cf,0xe7d0,0xe7d1,0xe7d2, 0xe7d3,0xe7d4,0xe7d5,0xe7d6,
  0xe7d7,0xe7d8,0xe7d9,0xe7da, 0xe7db,0xe7dc,0xe7dd,0xe7de,
  0xe7df,0xe7e0,0xe7e1,0xe7e2, 0xe7e3,0xe7e4,0xe7e5,0xe7e6,
  0xe7e7,0xe7e8,0xe7e9,0xe7ea, 0xe7eb,0xe7ec,0xe7ed,0xe7ee,
  0xe7ef,0xe7f0,0xe7f1,0xe7f2, 0xe7f3,0xe7f4,0xe7f5,0xe7f6,
  0xe7f7,0xe7f8,0xe7f9,0xe7fa, 0xe7fb,0xe7fc,0xe7fd,0xe7fe,
  0xe7ff,0xe800,0xe801,0xe802, 0xe803,0xe804,0xe805,0xe806,
  0xe807,0xe808,0xe809,0xe80a, 0xe80b,0xe80c,0xe80d,0xe80e,
  0xe80f,0xe810,0xe811,0xe812, 0xe813,0x0000,
/* 0xcd41(i:26600) */
  0xe814,0xe815,0xe816,0xe817, 0xe818,0xe819,0xe81a,0xe81b,
  0xe81c,0xe81d,0xe81e,0xe81f, 0xe820,0xe821,0xe822,0xe823,
  0xe824,0xe825,0xe826,0xe827, 0xe828,0xe829,0xe82a,0xe82b,
  0xe82c,0xe82d,0xe82e,0xe82f, 0xe830,0xe831,0xe832,0xe833,
  0xe834,0xe835,0xe836,0xe837, 0xe838,0xe839,0xe83a,0xe83b,
  0xe83c,0xe83d,0xe83e,0xe83f, 0xe840,0xe841,0xe842,0xe843,
  0xe844,0xe845,0xe846,0xe847, 0xe848,0xe849,0xe84a,0xe84b,
  0xe84c,0xe84d,0xe84e,0xe84f, 0xe850,0xe851,0xe852,0x0000,
  0xe853,0xe854,0xe855,0xe856, 0xe857,0xe858,0xe859,0xe85a,
  0xe85b,0xe85c,0xe85d,0xe85e, 0xe85f,0xe860,0xe861,0xe862,
  0xe863,0xe864,0xe865,0xe866, 0xe867,0xe868,0xe869,0xe86a,
  0xe86b,0xe86c,0xe86d,0xe86e, 0xe86f,0xe870,0xe871,0xe872,
  0xe873,0xe874,0xe875,0xe876, 0xe877,0xe878,0xe879,0xe87a,
  0xe87b,0xe87c,0xe87d,0xe87e, 0xe87f,0xe880,0xe881,0xe882,
  0xe883,0xe884,0xe885,0xe886, 0xe887,0xe888,0xe889,0xe88a,
  0xe88b,0xe88c,0xe88d,0xe88e, 0xe88f,0xe890,0xe891,0xe892,
  0xe893,0xe894,0xe895,0xe896, 0xe897,0xe898,0xe899,0xe89a,
  0xe89b,0xe89c,0xe89d,0xe89e, 0xe89f,0xe8a0,0xe8a1,0xe8a2,
  0xe8a3,0xe8a4,0xe8a5,0xe8a6, 0xe8a7,0xe8a8,0xe8a9,0xe8aa,
  0xe8ab,0xe8ac,0xe8ad,0xe8ae, 0xe8af,0xe8b0,0xe8b1,0xe8b2,
  0xe8b3,0xe8b4,0xe8b5,0xe8b6, 0xe8b7,0xe8b8,0xe8b9,0xe8ba,
  0xe8bb,0xe8bc,0xe8bd,0xe8be, 0xe8bf,0xe8c0,0xe8c1,0xe8c2,
  0xe8c3,0xe8c4,0xe8c5,0xe8c6, 0xe8c7,0xe8c8,0xe8c9,0xe8ca,
  0xe8cb,0xe8cc,0xe8cd,0xe8ce, 0xe8cf,0x0000,
/* 0xce41(i:26790) */
  0xe8d0,0xe8d1,0xe8d2,0xe8d3, 0xe8d4,0xe8d5,0xe8d6,0xe8d7,
  0xe8d8,0xe8d9,0xe8da,0xe8db, 0xe8dc,0xe8dd,0xe8de,0xe8df,
  0xe8e0,0xe8e1,0xe8e2,0xe8e3, 0xe8e4,0xe8e5,0xe8e6,0xe8e7,
  0xe8e8,0xe8e9,0xe8ea,0xe8eb, 0xe8ec,0xe8ed,0xe8ee,0xe8ef,
  0xe8f0,0xe8f1,0xe8f2,0xe8f3, 0xe8f4,0xe8f5,0xe8f6,0xe8f7,
  0xe8f8,0xe8f9,0xe8fa,0xe8fb, 0xe8fc,0xe8fd,0xe8fe,0xe8ff,
  0xe900,0xe901,0xe902,0xe903, 0xe904,0xe905,0xe906,0xe907,
  0xe908,0xe909,0xe90a,0xe90b, 0xe90c,0xe90d,0xe90e,0x0000,
  0xe90f,0xe910,0xe911,0xe912, 0xe913,0xe914,0xe915,0xe916,
  0xe917,0xe918,0xe919,0xe91a, 0xe91b,0xe91c,0xe91d,0xe91e,
  0xe91f,0xe920,0xe921,0xe922, 0xe923,0xe924,0xe925,0xe926,
  0xe927,0xe928,0xe929,0xe92a, 0xe92b,0xe92c,0xe92d,0xe92e,
  0xe92f,0xe930,0xe931,0xe932, 0xe933,0xe934,0xe935,0xe936,
  0xe937,0xe938,0xe939,0xe93a, 0xe93b,0xe93c,0xe93d,0xe93e,
  0xe93f,0xe940,0xe941,0xe942, 0xe943,0xe944,0xe945,0xe946,
  0xe947,0xe948,0xe949,0xe94a, 0xe94b,0xe94c,0xe94d,0xe94e,
  0xe94f,0xe950,0xe951,0xe952, 0xe953,0xe954,0xe955,0xe956,
  0xe957,0xe958,0xe959,0xe95a, 0xe95b,0xe95c,0xe95d,0xe95e,
  0xe95f,0xe960,0xe961,0xe962, 0xe963,0xe964,0xe965,0xe966,
  0xe967,0xe968,0xe969,0xe96a, 0xe96b,0xe96c,0xe96d,0xe96e,
  0xe96f,0xe970,0xe971,0xe972, 0xe973,0xe974,0xe975,0xe976,
  0xe977,0xe978,0xe979,0xe97a, 0xe97b,0xe97c,0xe97d,0xe97e,
  0xe97f,0xe980,0xe981,0xe982, 0xe983,0xe984,0xe985,0xe986,
  0xe987,0xe988,0xe989,0xe98a, 0xe98b,0x0000,
/* 0xcf41(i:26980) */
  0xe98c,0xe98d,0xe98e,0xe98f, 0xe990,0xe991,0xe992,0xe993,
  0xe994,0xe995,0xe996,0xe997, 0xe998,0xe999,0xe99a,0xe99b,
  0xe99c,0xe99d,0xe99e,0xe99f, 0xe9a0,0xe9a1,0xe9a2,0xe9a3,
  0xe9a4,0xe9a5,0xe9a6,0xe9a7, 0xe9a8,0xe9a9,0xe9aa,0xe9ab,
  0xe9ac,0xe9ad,0xe9ae,0xe9af, 0xe9b0,0xe9b1,0xe9b2,0xe9b3,
  0xe9b4,0xe9b5,0xe9b6,0xe9b7, 0xe9b8,0xe9b9,0xe9ba,0xe9bb,
  0xe9bc,0xe9bd,0xe9be,0xe9bf, 0xe9c0,0xe9c1,0xe9c2,0xe9c3,
  0xe9c4,0xe9c5,0xe9c6,0xe9c7, 0xe9c8,0xe9c9,0xe9ca,0x0000,
  0xe9cb,0xe9cc,0xe9cd,0xe9ce, 0xe9cf,0xe9d0,0xe9d1,0xe9d2,
  0xe9d3,0xe9d4,0xe9d5,0xe9d6, 0xe9d7,0xe9d8,0xe9d9,0xe9da,
  0xe9db,0xe9dc,0xe9dd,0xe9de, 0xe9df,0xe9e0,0xe9e1,0xe9e2,
  0xe9e3,0xe9e4,0xe9e5,0xe9e6, 0xe9e7,0xe9e8,0xe9e9,0xe9ea,
  0xe9eb,0xe9ec,0xe9ed,0xe9ee, 0xe9ef,0xe9f0,0xe9f1,0xe9f2,
  0xe9f3,0xe9f4,0xe9f5,0xe9f6, 0xe9f7,0xe9f8,0xe9f9,0xe9fa,
  0xe9fb,0xe9fc,0xe9fd,0xe9fe, 0xe9ff,0xea00,0xea01,0xea02,
  0xea03,0xea04,0xea05,0xea06, 0xea07,0xea08,0xea09,0xea0a,
  0xea0b,0xea0c,0xea0d,0xea0e, 0xea0f,0xea10,0xea11,0xea12,
  0xea13,0xea14,0xea15,0xea16, 0xea17,0xea18,0xea19,0xea1a,
  0xea1b,0xea1c,0xea1d,0xea1e, 0xea1f,0xea20,0xea21,0xea22,
  0xea23,0xea24,0xea25,0xea26, 0xea27,0xea28,0xea29,0xea2a,
  0xea2b,0xea2c,0xea2d,0xea2e, 0xea2f,0xea30,0xea31,0xea32,
  0xea33,0xea34,0xea35,0xea36, 0xea37,0xea38,0xea39,0xea3a,
  0xea3b,0xea3c,0xea3d,0xea3e, 0xea3f,0xea40,0xea41,0xea42,
  0xea43,0xea44,0xea45,0xea46, 0xea47,0x0000,
/* 0xd041(i:27170) */
  0xea48,0xea49,0xea4a,0xea4b, 0xea4c,0xea4d,0xea4e,0xea4f,
  0xea50,0xea51,0xea52,0xea53, 0xea54,0xea55,0xea56,0xea57,
  0xea58,0xea59,0xea5a,0xea5b, 0xea5c,0xea5d,0xea5e,0xea5f,
  0xea60,0xea61,0xea62,0xea63, 0xea64,0xea65,0xea66,0xea67,
  0xea68,0xea69,0xea6a,0xea6b, 0xea6c,0xea6d,0xea6e,0xea6f,
  0xea70,0xea71,0xea72,0xea73, 0xea74,0xea75,0xea76,0xea77,
  0xea78,0xea79,0xea7a,0xea7b, 0xea7c,0xea7d,0xea7e,0xea7f,
  0xea80,0xea81,0xea82,0xea83, 0xea84,0xea85,0xea86,0x0000,
  0xea87,0xea88,0xea89,0xea8a, 0xea8b,0xea8c,0xea8d,0xea8e,
  0xea8f,0xea90,0xea91,0xea92, 0xea93,0xea94,0xea95,0xea96,
  0xea97,0xea98,0xea99,0xea9a, 0xea9b,0xea9c,0xea9d,0xea9e,
  0xea9f,0xeaa0,0xeaa1,0xeaa2, 0xeaa3,0xeaa4,0xeaa5,0xeaa6,
  0xeaa7,0xeaa8,0xeaa9,0xeaaa, 0xeaab,0xeaac,0xeaad,0xeaae,
  0xeaaf,0xeab0,0xeab1,0xeab2, 0xeab3,0xeab4,0xeab5,0xeab6,
  0xeab7,0xeab8,0xeab9,0xeaba, 0xeabb,0xeabc,0xeabd,0xeabe,
  0xeabf,0xeac0,0xeac1,0xeac2, 0xeac3,0xeac4,0xeac5,0xeac6,
  0xeac7,0xeac8,0xeac9,0xeaca, 0xeacb,0xeacc,0xeacd,0xeace,
  0xeacf,0xead0,0xead1,0xead2, 0xead3,0xead4,0xead5,0xead6,
  0xead7,0xead8,0xead9,0xeada, 0xeadb,0xeadc,0xeadd,0xeade,
  0xeadf,0xeae0,0xeae1,0xeae2, 0xeae3,0xeae4,0xeae5,0xeae6,
  0xeae7,0xeae8,0xeae9,0xeaea, 0xeaeb,0xeaec,0xeaed,0xeaee,
  0xeaef,0xeaf0,0xeaf1,0xeaf2, 0xeaf3,0xeaf4,0xeaf5,0xeaf6,
  0xeaf7,0xeaf8,0xeaf9,0xeafa, 0xeafb,0xeafc,0xeafd,0xeafe,
  0xeaff,0xeb00,0xeb01,0xeb02, 0xeb03,0x0000,
/* 0xd141(i:27360) */
  0xeb04,0xeb05,0xeb06,0xeb07, 0xeb08,0xeb09,0xeb0a,0xeb0b,
  0xeb0c,0xeb0d,0xeb0e,0xeb0f, 0xeb10,0xeb11,0xeb12,0xeb13,
  0xeb14,0xeb15,0xeb16,0xeb17, 0xeb18,0xeb19,0xeb1a,0xeb1b,
  0xeb1c,0xeb1d,0xeb1e,0xeb1f, 0xeb20,0xeb21,0xeb22,0xeb23,
  0xeb24,0xeb25,0xeb26,0xeb27, 0xeb28,0xeb29,0xeb2a,0xeb2b,
  0xeb2c,0xeb2d,0xeb2e,0xeb2f, 0xeb30,0xeb31,0xeb32,0xeb33,
  0xeb34,0xeb35,0xeb36,0xeb37, 0xeb38,0xeb39,0xeb3a,0xeb3b,
  0xeb3c,0xeb3d,0xeb3e,0xeb3f, 0xeb40,0xeb41,0xeb42,0x0000,
  0xeb43,0xeb44,0xeb45,0xeb46, 0xeb47,0xeb48,0xeb49,0xeb4a,
  0xeb4b,0xeb4c,0xeb4d,0xeb4e, 0xeb4f,0xeb50,0xeb51,0xeb52,
  0xeb53,0xeb54,0xeb55,0xeb56, 0xeb57,0xeb58,0xeb59,0xeb5a,
  0xeb5b,0xeb5c,0xeb5d,0xeb5e, 0xeb5f,0xeb60,0xeb61,0xeb62,
  0xeb63,0xeb64,0xeb65,0xeb66, 0xeb67,0xeb68,0xeb69,0xeb6a,
  0xeb6b,0xeb6c,0xeb6d,0xeb6e, 0xeb6f,0xeb70,0xeb71,0xeb72,
  0xeb73,0xeb74,0xeb75,0xeb76, 0xeb77,0xeb78,0xeb79,0xeb7a,
  0xeb7b,0xeb7c,0xeb7d,0xeb7e, 0xeb7f,0xeb80,0xeb81,0xeb82,
  0xeb83,0xeb84,0xeb85,0xeb86, 0xeb87,0xeb88,0xeb89,0xeb8a,
  0xeb8b,0xeb8c,0xeb8d,0xeb8e, 0xeb8f,0xeb90,0xeb91,0xeb92,
  0xeb93,0xeb94,0xeb95,0xeb96, 0xeb97,0xeb98,0xeb99,0xeb9a,
  0xeb9b,0xeb9c,0xeb9d,0xeb9e, 0xeb9f,0xeba0,0xeba1,0xeba2,
  0xeba3,0xeba4,0xeba5,0xeba6, 0xeba7,0xeba8,0xeba9,0xebaa,
  0xebab,0xebac,0xebad,0xebae, 0xebaf,0xebb0,0xebb1,0xebb2,
  0xebb3,0xebb4,0xebb5,0xebb6, 0xebb7,0xebb8,0xebb9,0xebba,
  0xebbb,0xebbc,0xebbd,0xebbe, 0xebbf,0x0000,
/* 0xd241(i:27550) */
  0xebc0,0xebc1,0xebc2,0xebc3, 0xebc4,0xebc5,0xebc6,0xebc7,
  0xebc8,0xebc9,0xebca,0xebcb, 0xebcc,0xebcd,0xebce,0xebcf,
  0xebd0,0xebd1,0xebd2,0xebd3, 0xebd4,0xebd5,0xebd6,0xebd7,
  0xebd8,0xebd9,0xebda,0xebdb, 0xebdc,0xebdd,0xebde,0xebdf,
  0xebe0,0xebe1,0xebe2,0xebe3, 0xebe4,0xebe5,0xebe6,0xebe7,
  0xebe8,0xebe9,0xebea,0xebeb, 0xebec,0xebed,0xebee,0xebef,
  0xebf0,0xebf1,0xebf2,0xebf3, 0xebf4,0xebf5,0xebf6,0xebf7,
  0xebf8,0xebf9,0xebfa,0xebfb, 0xebfc,0xebfd,0xebfe,0x0000,
  0xebff,0xec00,0xec01,0xec02, 0xec03,0xec04,0xec05,0xec06,
  0xec07,0xec08,0xec09,0xec0a, 0xec0b,0xec0c,0xec0d,0xec0e,
  0xec0f,0xec10,0xec11,0xec12, 0xec13,0xec14,0xec15,0xec16,
  0xec17,0xec18,0xec19,0xec1a, 0xec1b,0xec1c,0xec1d,0xec1e,
  0xec1f,0xec20,0xec21,0xec22, 0xec23,0xec24,0xec25,0xec26,
  0xec27,0xec28,0xec29,0xec2a, 0xec2b,0xec2c,0xec2d,0xec2e,
  0xec2f,0xec30,0xec31,0xec32, 0xec33,0xec34,0xec35,0xec36,
  0xec37,0xec38,0xec39,0xec3a, 0xec3b,0xec3c,0xec3d,0xec3e,
  0xec3f,0xec40,0xec41,0xec42, 0xec43,0xec44,0xec45,0xec46,
  0xec47,0xec48,0xec49,0xec4a, 0xec4b,0xec4c,0xec4d,0xec4e,
  0xec4f,0xec50,0xec51,0xec52, 0xec53,0xec54,0xec55,0xec56,
  0xec57,0xec58,0xec59,0xec5a, 0xec5b,0xec5c,0xec5d,0xec5e,
  0xec5f,0xec60,0xec61,0xec62, 0xec63,0xec64,0xec65,0xec66,
  0xec67,0xec68,0xec69,0xec6a, 0xec6b,0xec6c,0xec6d,0xec6e,
  0xec6f,0xec70,0xec71,0xec72, 0xec73,0xec74,0xec75,0xec76,
  0xec77,0xec78,0xec79,0xec7a, 0xec7b,0x0000,
/* 0xd341(i:27740) */
  0xec7c,0xec7d,0xec7e,0xec7f, 0xec80,0xec81,0xec82,0xec83,
  0xec84,0xec85,0xec86,0xec87, 0xec88,0xec89,0xec8a,0xec8b,
  0xec8c,0xec8d,0xec8e,0xec8f, 0xec90,0xec91,0xec92,0xec93,
  0xec94,0xec95,0xec96,0xec97, 0xec98,0xec99,0xec9a,0xec9b,
  0xec9c,0xec9d,0xec9e,0xec9f, 0xeca0,0xeca1,0xeca2,0xeca3,
  0xeca4,0xeca5,0xeca6,0xeca7, 0xeca8,0xeca9,0xecaa,0xecab,
  0xecac,0xecad,0xecae,0xecaf, 0xecb0,0xecb1,0xecb2,0xecb3,
  0xecb4,0xecb5,0xecb6,0xecb7, 0xecb8,0xecb9,0xecba,0x0000,
  0xecbb,0xecbc,0xecbd,0xecbe, 0xecbf,0xecc0,0xecc1,0xecc2,
  0xecc3,0xecc4,0xecc5,0xecc6, 0xecc7,0xecc8,0xecc9,0xecca,
  0xeccb,0xeccc,0xeccd,0xecce, 0xeccf,0xecd0,0xecd1,0xecd2,
  0xecd3,0xecd4,0xecd5,0xecd6, 0xecd7,0xecd8,0xecd9,0xecda,
  0xecdb,0xecdc,0xecdd,0xecde, 0xecdf,0xece0,0xece1,0xece2,
  0xece3,0xece4,0xece5,0xece6, 0xece7,0xece8,0xece9,0xecea,
  0xeceb,0xecec,0xeced,0xecee, 0xecef,0xecf0,0xecf1,0xecf2,
  0xecf3,0xecf4,0xecf5,0xecf6, 0xecf7,0xecf8,0xecf9,0xecfa,
  0xecfb,0xecfc,0xecfd,0xecfe, 0xecff,0xed00,0xed01,0xed02,
  0xed03,0xed04,0xed05,0xed06, 0xed07,0xed08,0xed09,0xed0a,
  0xed0b,0xed0c,0xed0d,0xed0e, 0xed0f,0xed10,0xed11,0xed12,
  0xed13,0xed14,0xed15,0xed16, 0xed17,0xed18,0xed19,0xed1a,
  0xed1b,0xed1c,0xed1d,0xed1e, 0xed1f,0xed20,0xed21,0xed22,
  0xed23,0xed24,0xed25,0xed26, 0xed27,0xed28,0xed29,0xed2a,
  0xed2b,0xed2c,0xed2d,0xed2e, 0xed2f,0xed30,0xed31,0xed32,
  0xed33,0xed34,0xed35,0xed36, 0xed37,0x0000,
/* 0xd441(i:27930) */
  0xed38,0xed39,0xed3a,0xed3b, 0xed3c,0xed3d,0xed3e,0xed3f,
  0xed40,0xed41,0xed42,0xed43, 0xed44,0xed45,0xed46,0xed47,
  0xed48,0xed49,0xed4a,0xed4b, 0xed4c,0xed4d,0xed4e,0xed4f,
  0xed50,0xed51,0xed52,0xed53, 0xed54,0xed55,0xed56,0xed57,
  0xed58,0xed59,0xed5a,0xed5b, 0xed5c,0xed5d,0xed5e,0xed5f,
  0xed60,0xed61,0xed62,0xed63, 0xed64,0xed65,0xed66,0xed67,
  0xed68,0xed69,0xed6a,0xed6b, 0xed6c,0xed6d,0xed6e,0xed6f,
  0xed70,0xed71,0xed72,0xed73, 0xed74,0xed75,0xed76,0x0000,
  0xed77,0xed78,0xed79,0xed7a, 0xed7b,0xed7c,0xed7d,0xed7e,
  0xed7f,0xed80,0xed81,0xed82, 0xed83,0xed84,0xed85,0xed86,
  0xed87,0xed88,0xed89,0xed8a, 0xed8b,0xed8c,0xed8d,0xed8e,
  0xed8f,0xed90,0xed91,0xed92, 0xed93,0xed94,0xed95,0xed96,
  0xed97,0xed98,0xed99,0xed9a, 0xed9b,0xed9c,0xed9d,0xed9e,
  0xed9f,0xeda0,0xeda1,0xeda2, 0xeda3,0xeda4,0xeda5,0xeda6,
  0xeda7,0xeda8,0xeda9,0xedaa, 0xedab,0xedac,0xedad,0xedae,
  0xedaf,0xedb0,0xedb1,0xedb2, 0xedb3,0xedb4,0xedb5,0xedb6,
  0xedb7,0xedb8,0xedb9,0xedba, 0xedbb,0xedbc,0xedbd,0xedbe,
  0xedbf,0xedc0,0xedc1,0xedc2, 0xedc3,0xedc4,0xedc5,0xedc6,
  0xedc7,0xedc8,0xedc9,0xedca, 0xedcb,0xedcc,0xedcd,0xedce,
  0xedcf,0xedd0,0xedd1,0xedd2, 0xedd3,0xedd4,0xedd5,0xedd6,
  0xedd7,0xedd8,0xedd9,0xedda, 0xeddb,0xeddc,0xeddd,0xedde,
  0xeddf,0xede0,0xede1,0xede2, 0xede3,0xede4,0xede5,0xede6,
  0xede7,0xede8,0xede9,0xedea, 0xedeb,0xedec,0xeded,0xedee,
  0xedef,0xedf0,0xedf1,0xedf2, 0xedf3,0x0000,
/* 0xd541(i:28120) */
  0xedf4,0xedf5,0xedf6,0xedf7, 0xedf8,0xedf9,0xedfa,0xedfb,
  0xedfc,0xedfd,0xedfe,0xedff, 0xee00,0xee01,0xee02,0xee03,
  0xee04,0xee05,0xee06,0xee07, 0xee08,0xee09,0xee0a,0xee0b,
  0xee0c,0xee0d,0xee0e,0xee0f, 0xee10,0xee11,0xee12,0xee13,
  0xee14,0xee15,0xee16,0xee17, 0xee18,0xee19,0xee1a,0xee1b,
  0xee1c,0xee1d,0xee1e,0xee1f, 0xee20,0xee21,0xee22,0xee23,
  0xee24,0xee25,0xee26,0xee27, 0xee28,0xee29,0xee2a,0xee2b,
  0xee2c,0xee2d,0xee2e,0xee2f, 0xee30,0xee31,0xee32,0x0000,
  0xee33,0xee34,0xee35,0xee36, 0xee37,0xee38,0xee39,0xee3a,
  0xee3b,0xee3c,0xee3d,0xee3e, 0xee3f,0xee40,0xee41,0xee42,
  0xee43,0xee44,0xee45,0xee46, 0xee47,0xee48,0xee49,0xee4a,
  0xee4b,0xee4c,0xee4d,0xee4e, 0xee4f,0xee50,0xee51,0xee52,
  0xee53,0xee54,0xee55,0xee56, 0xee57,0xee58,0xee59,0xee5a,
  0xee5b,0xee5c,0xee5d,0xee5e, 0xee5f,0xee60,0xee61,0xee62,
  0xee63,0xee64,0xee65,0xee66, 0xee67,0xee68,0xee69,0xee6a,
  0xee6b,0xee6c,0xee6d,0xee6e, 0xee6f,0xee70,0xee71,0xee72,
  0xee73,0xee74,0xee75,0xee76, 0xee77,0xee78,0xee79,0xee7a,
  0xee7b,0xee7c,0xee7d,0xee7e, 0xee7f,0xee80,0xee81,0xee82,
  0xee83,0xee84,0xee85,0xee86, 0xee87,0xee88,0xee89,0xee8a,
  0xee8b,0xee8c,0xee8d,0xee8e, 0xee8f,0xee90,0xee91,0xee92,
  0xee93,0xee94,0xee95,0xee96, 0xee97,0xee98,0xee99,0xee9a,
  0xee9b,0xee9c,0xee9d,0xee9e, 0xee9f,0xeea0,0xeea1,0xeea2,
  0xeea3,0xeea4,0xeea5,0xeea6, 0xeea7,0xeea8,0xeea9,0xeeaa,
  0xeeab,0xeeac,0xeead,0xeeae, 0xeeaf,0x0000,
/* 0xd641(i:28310) */
  0xeeb0,0xeeb1,0xeeb2,0xeeb3, 0xeeb4,0xeeb5,0xeeb6,0xeeb7,
  0xeeb8,0xeeb9,0xeeba,0xeebb, 0xeebc,0xeebd,0xeebe,0xeebf,
  0xeec0,0xeec1,0xeec2,0xeec3, 0xeec4,0xeec5,0xeec6,0xeec7,
  0xeec8,0xeec9,0xeeca,0xeecb, 0xeecc,0xeecd,0xeece,0xeecf,
  0xeed0,0xeed1,0xeed2,0xeed3, 0xeed4,0xeed5,0xeed6,0xeed7,
  0xeed8,0xeed9,0xeeda,0xeedb, 0xeedc,0xeedd,0xeede,0xeedf,
  0xeee0,0xeee1,0xeee2,0xeee3, 0xeee4,0xeee5,0xeee6,0xeee7,
  0xeee8,0xeee9,0xeeea,0xeeeb, 0xeeec,0xeeed,0xeeee,0x0000,
  0xeeef,0xeef0,0xeef1,0xeef2, 0xeef3,0xeef4,0xeef5,0xeef6,
  0xeef7,0xeef8,0xeef9,0xeefa, 0xeefb,0xeefc,0xeefd,0xeefe,
  0xeeff,0xef00,0xef01,0xef02, 0xef03,0xef04,0xef05,0xef06,
  0xef07,0xef08,0xef09,0xef0a, 0xef0b,0xef0c,0xef0d,0xef0e,
  0xef0f,0xef10,0xef11,0xef12, 0xef13,0xef14,0xef15,0xef16,
  0xef17,0xef18,0xef19,0xef1a, 0xef1b,0xef1c,0xef1d,0xef1e,
  0xef1f,0xef20,0xef21,0xef22, 0xef23,0xef24,0xef25,0xef26,
  0xef27,0xef28,0xef29,0xef2a, 0xef2b,0xef2c,0xef2d,0xef2e,
  0xef2f,0xef30,0xef31,0xef32, 0xef33,0xef34,0xef35,0xef36,
  0xef37,0xef38,0xef39,0xef3a, 0xef3b,0xef3c,0xef3d,0xef3e,
  0xef3f,0xef40,0xef41,0xef42, 0xef43,0xef44,0xef45,0xef46,
  0xef47,0xef48,0xef49,0xef4a, 0xef4b,0xef4c,0xef4d,0xef4e,
  0xef4f,0xef50,0xef51,0xef52, 0xef53,0xef54,0xef55,0xef56,
  0xef57,0xef58,0xef59,0xef5a, 0xef5b,0xef5c,0xef5d,0xef5e,
  0xef5f,0xef60,0xef61,0xef62, 0xef63,0xef64,0xef65,0xef66,
  0xef67,0xef68,0xef69,0xef6a, 0xef6b,0x0000,
/* 0xd741(i:28500) */
  0xef6c,0xef6d,0xef6e,0xef6f, 0xef70,0xef71,0xef72,0xef73,
  0xef74,0xef75,0xef76,0xef77, 0xef78,0xef79,0xef7a,0xef7b,
  0xef7c,0xef7d,0xef7e,0xef7f, 0xef80,0xef81,0xef82,0xef83,
  0xef84,0xef85,0xef86,0xef87, 0xef88,0xef89,0xef8a,0xef8b,
  0xef8c,0xef8d,0xef8e,0xef8f, 0xef90,0xef91,0xef92,0xef93,
  0xef94,0xef95,0xef96,0xef97, 0xef98,0xef99,0xef9a,0xef9b,
  0xef9c,0xef9d,0xef9e,0xef9f, 0xefa0,0xefa1,0xefa2,0xefa3,
  0xefa4,0xefa5,0xefa6,0xefa7, 0xefa8,0xefa9,0xefaa,0x0000,
  0xefab,0xefac,0xefad,0xefae, 0xefaf,0xefb0,0xefb1,0xefb2,
  0xefb3,0xefb4,0xefb5,0xefb6, 0xefb7,0xefb8,0xefb9,0xefba,
  0xefbb,0xefbc,0xefbd,0xefbe, 0xefbf,0xefc0,0xefc1,0xefc2,
  0xefc3,0xefc4,0xefc5,0xefc6, 0xefc7,0xefc8,0xefc9,0xefca,
  0xefcb,0xefcc,0xefcd,0xefce, 0xefcf,0xefd0,0xefd1,0xefd2,
  0xefd3,0xefd4,0xefd5,0xefd6, 0xefd7,0xefd8,0xefd9,0xefda,
  0xefdb,0xefdc,0xefdd,0xefde, 0xefdf,0xefe0,0xefe1,0xefe2,
  0xefe3,0xefe4,0xefe5,0xefe6, 0xefe7,0xefe8,0xefe9,0xefea,
  0xefeb,0xefec,0xefed,0xefee, 0xefef,0xeff0,0xeff1,0xeff2,
  0xeff3,0xeff4,0xeff5,0xeff6, 0xeff7,0xeff8,0xeff9,0xeffa,
  0xeffb,0xeffc,0xeffd,0xeffe, 0xefff,0xf000,0xf001,0xf002,
  0xf003,0xf004,0xf005,0xf006, 0xf007,0xf008,0xf009,0xf00a,
  0xf00b,0xf00c,0xf00d,0xf00e, 0xf00f,0xf010,0xf011,0xf012,
  0xf013,0xf014,0xf015,0xf016, 0xf017,0xf018,0xf019,0xf01a,
  0xf01b,0xf01c,0xf01d,0xf01e, 0xf01f,0xf020,0xf021,0xf022,
  0xf023,0xf024,0xf025,0xf026, 0xf027,0x0000,
/* 0xd841(i:28690) */
  0xf028,0xf029,0xf02a,0xf02b, 0xf02c,0xf02d,0xf02e,0xf02f,
  0xf030,0xf031,0xf032,0xf033, 0xf034,0xf035,0xf036,0xf037,
  0xf038,0xf039,0xf03a,0xf03b, 0xf03c,0xf03d,0xf03e,0xf03f,
  0xf040,0xf041,0xf042,0xf043, 0xf044,0xf045,0xf046,0xf047,
  0xf048,0xf049,0xf04a,0xf04b, 0xf04c,0xf04d,0xf04e,0xf04f,
  0xf050,0xf051,0xf052,0xf053, 0xf054,0xf055,0xf056,0xf057,
  0xf058,0xf059,0xf05a,0xf05b, 0xf05c,0xf05d,0xf05e,0xf05f,
  0xf060,0xf061,0xf062,0xf063, 0xf064,0xf065,0xf066,0x0000,
  0xf067,0xf068,0xf069,0xf06a, 0xf06b,0xf06c,0xf06d,0xf06e,
  0xf06f,0xf070,0xf071,0xf072, 0xf073,0xf074,0xf075,0xf076,
  0xf077,0xf078,0xf079,0xf07a, 0xf07b,0xf07c,0xf07d,0xf07e,
  0xf07f,0xf080,0xf081,0xf082, 0xf083,0xf084,0xf085,0xf086,
  0xf087,0xf088,0xf089,0xf08a, 0xf08b,0xf08c,0xf08d,0xf08e,
  0xf08f,0xf090,0xf091,0xf092, 0xf093,0xf094,0xf095,0xf096,
  0xf097,0xf098,0xf099,0xf09a, 0xf09b,0xf09c,0xf09d,0xf09e,
  0xf09f,0xf0a0,0xf0a1,0xf0a2, 0xf0a3,0xf0a4,0xf0a5,0xf0a6,
  0xf0a7,0xf0a8,0xf0a9,0xf0aa, 0xf0ab,0xf0ac,0xf0ad,0xf0ae,
  0xf0af,0xf0b0,0xf0b1,0xf0b2, 0xf0b3,0xf0b4,0xf0b5,0xf0b6,
  0xf0b7,0xf0b8,0xf0b9,0xf0ba, 0xf0bb,0xf0bc,0xf0bd,0xf0be,
  0xf0bf,0xf0c0,0xf0c1,0xf0c2, 0xf0c3,0xf0c4,0xf0c5,0xf0c6,
  0xf0c7,0xf0c8,0xf0c9,0xf0ca, 0xf0cb,0xf0cc,0xf0cd,0xf0ce,
  0xf0cf,0xf0d0,0xf0d1,0xf0d2, 0xf0d3,0xf0d4,0xf0d5,0xf0d6,
  0xf0d7,0xf0d8,0xf0d9,0xf0da, 0xf0db,0xf0dc,0xf0dd,0xf0de,
  0xf0df,0xf0e0,0xf0e1,0xf0e2, 0xf0e3,0x0000,
/* 0xd941(i:28880) */
  0xf0e4,0xf0e5,0xf0e6,0xf0e7, 0xf0e8,0xf0e9,0xf0ea,0xf0eb,
  0xf0ec,0xf0ed,0xf0ee,0xf0ef, 0xf0f0,0xf0f1,0xf0f2,0xf0f3,
  0xf0f4,0xf0f5,0xf0f6,0xf0f7, 0xf0f8,0xf0f9,0xf0fa,0xf0fb,
  0xf0fc,0xf0fd,0xf0fe,0xf0ff, 0xf100,0xf101,0xf102,0xf103,
  0xf104,0xf105,0xf106,0xf107, 0xf108,0xf109,0xf10a,0xf10b,
  0xf10c,0xf10d,0xf10e,0xf10f, 0xf110,0xf111,0xf112,0xf113,
  0xf114,0xf115,0xf116,0xf117, 0xf118,0xf119,0xf11a,0xf11b,
  0xf11c,0xf11d,0xf11e,0xf11f, 0xf120,0xf121,0xf122,0x0000,
  0xf123,0xf124,0xf125,0xf126, 0xf127,0xf128,0xf129,0xf12a,
  0xf12b,0xf12c,0xf12d,0xf12e, 0xf12f,0xf130,0xf131,0xf132,
  0xf133,0xf134,0xf135,0xf136, 0xf137,0xf138,0xf139,0xf13a,
  0xf13b,0xf13c,0xf13d,0xf13e, 0xf13f,0xf140,0xf141,0xf142,
  0xf143,0xf144,0xf145,0xf146, 0xf147,0xf148,0xf149,0xf14a,
  0xf14b,0xf14c,0xf14d,0xf14e, 0xf14f,0xf150,0xf151,0xf152,
  0xf153,0xf154,0xf155,0xf156, 0xf157,0xf158,0xf159,0xf15a,
  0xf15b,0xf15c,0xf15d,0xf15e, 0xf15f,0xf160,0xf161,0xf162,
  0xf163,0xf164,0xf165,0xf166, 0xf167,0xf168,0xf169,0xf16a,
  0xf16b,0xf16c,0xf16d,0xf16e, 0xf16f,0xf170,0xf171,0xf172,
  0xf173,0xf174,0xf175,0xf176, 0xf177,0xf178,0xf179,0xf17a,
  0xf17b,0xf17c,0xf17d,0xf17e, 0xf17f,0xf180,0xf181,0xf182,
  0xf183,0xf184,0xf185,0xf186, 0xf187,0xf188,0xf189,0xf18a,
  0xf18b,0xf18c,0xf18d,0xf18e, 0xf18f,0xf190,0xf191,0xf192,
  0xf193,0xf194,0xf195,0xf196, 0xf197,0xf198,0xf199,0xf19a,
  0xf19b,0xf19c,0xf19d,0xf19e, 0xf19f,0x0000,
/* 0xda41(i:29070) */
  0xf1a0,0xf1a1,0xf1a2,0xf1a3, 0xf1a4,0xf1a5,0xf1a6,0xf1a7,
  0xf1a8,0xf1a9,0xf1aa,0xf1ab, 0xf1ac,0xf1ad,0xf1ae,0xf1af,
  0xf1b0,0xf1b1,0xf1b2,0xf1b3, 0xf1b4,0xf1b5,0xf1b6,0xf1b7,
  0xf1b8,0xf1b9,0xf1ba,0xf1bb, 0xf1bc,0xf1bd,0xf1be,0xf1bf,
  0xf1c0,0xf1c1,0xf1c2,0xf1c3, 0xf1c4,0xf1c5,0xf1c6,0xf1c7,
  0xf1c8,0xf1c9,0xf1ca,0xf1cb, 0xf1cc,0xf1cd,0xf1ce,0xf1cf,
  0xf1d0,0xf1d1,0xf1d2,0xf1d3, 0xf1d4,0xf1d5,0xf1d6,0xf1d7,
  0xf1d8,0xf1d9,0xf1da,0xf1db, 0xf1dc,0xf1dd,0xf1de,0x0000,
  0xf1df,0xf1e0,0xf1e1,0xf1e2, 0xf1e3,0xf1e4,0xf1e5,0xf1e6,
  0xf1e7,0xf1e8,0xf1e9,0xf1ea, 0xf1eb,0xf1ec,0xf1ed,0xf1ee,
  0xf1ef,0xf1f0,0xf1f1,0xf1f2, 0xf1f3,0xf1f4,0xf1f5,0xf1f6,
  0xf1f7,0xf1f8,0xf1f9,0xf1fa, 0xf1fb,0xf1fc,0xf1fd,0xf1fe,
  0xf1ff,0xf200,0xf201,0xf202, 0xf203,0xf204,0xf205,0xf206,
  0xf207,0xf208,0xf209,0xf20a, 0xf20b,0xf20c,0xf20d,0xf20e,
  0xf20f,0xf210,0xf211,0xf212, 0xf213,0xf214,0xf215,0xf216,
  0xf217,0xf218,0xf219,0xf21a, 0xf21b,0xf21c,0xf21d,0xf21e,
  0xf21f,0xf220,0xf221,0xf222, 0xf223,0xf224,0xf225,0xf226,
  0xf227,0xf228,0xf229,0xf22a, 0xf22b,0xf22c,0xf22d,0xf22e,
  0xf22f,0xf230,0xf231,0xf232, 0xf233,0xf234,0xf235,0xf236,
  0xf237,0xf238,0xf239,0xf23a, 0xf23b,0xf23c,0xf23d,0xf23e,
  0xf23f,0xf240,0xf241,0xf242, 0xf243,0xf244,0xf245,0xf246,
  0xf247,0xf248,0xf249,0xf24a, 0xf24b,0xf24c,0xf24d,0xf24e,
  0xf24f,0xf250,0xf251,0xf252, 0xf253,0xf254,0xf255,0xf256,
  0xf257,0xf258,0xf259,0xf25a, 0xf25b,0x0000,
/* 0xdb41(i:29260) */
  0xf25c,0xf25d,0xf25e,0xf25f, 0xf260,0xf261,0xf262,0xf263,
  0xf264,0xf265,0xf266,0xf267, 0xf268,0xf269,0xf26a,0xf26b,
  0xf26c,0xf26d,0xf26e,0xf26f, 0xf270,0xf271,0xf272,0xf273,
  0xf274,0xf275,0xf276,0xf277, 0xf278,0xf279,0xf27a,0xf27b,
  0xf27c,0xf27d,0xf27e,0xf27f, 0xf280,0xf281,0xf282,0xf283,
  0xf284,0xf285,0xf286,0xf287, 0xf288,0xf289,0xf28a,0xf28b,
  0xf28c,0xf28d,0xf28e,0xf28f, 0xf290,0xf291,0xf292,0xf293,
  0xf294,0xf295,0xf296,0xf297, 0xf298,0xf299,0xf29a,0x0000,
  0xf29b,0xf29c,0xf29d,0xf29e, 0xf29f,0xf2a0,0xf2a1,0xf2a2,
  0xf2a3,0xf2a4,0xf2a5,0xf2a6, 0xf2a7,0xf2a8,0xf2a9,0xf2aa,
  0xf2ab,0xf2ac,0xf2ad,0xf2ae, 0xf2af,0xf2b0,0xf2b1,0xf2b2,
  0xf2b3,0xf2b4,0xf2b5,0xf2b6, 0xf2b7,0xf2b8,0xf2b9,0xf2ba,
  0xf2bb,0xf2bc,0xf2bd,0xf2be, 0xf2bf,0xf2c0,0xf2c1,0xf2c2,
  0xf2c3,0xf2c4,0xf2c5,0xf2c6, 0xf2c7,0xf2c8,0xf2c9,0xf2ca,
  0xf2cb,0xf2cc,0xf2cd,0xf2ce, 0xf2cf,0xf2d0,0xf2d1,0xf2d2,
  0xf2d3,0xf2d4,0xf2d5,0xf2d6, 0xf2d7,0xf2d8,0xf2d9,0xf2da,
  0xf2db,0xf2dc,0xf2dd,0xf2de, 0xf2df,0xf2e0,0xf2e1,0xf2e2,
  0xf2e3,0xf2e4,0xf2e5,0xf2e6, 0xf2e7,0xf2e8,0xf2e9,0xf2ea,
  0xf2eb,0xf2ec,0xf2ed,0xf2ee, 0xf2ef,0xf2f0,0xf2f1,0xf2f2,
  0xf2f3,0xf2f4,0xf2f5,0xf2f6, 0xf2f7,0xf2f8,0xf2f9,0xf2fa,
  0xf2fb,0xf2fc,0xf2fd,0xf2fe, 0xf2ff,0xf300,0xf301,0xf302,
  0xf303,0xf304,0xf305,0xf306, 0xf307,0xf308,0xf309,0xf30a,
  0xf30b,0xf30c,0xf30d,0xf30e, 0xf30f,0xf310,0xf311,0xf312,
  0xf313,0xf314,0xf315,0xf316, 0xf317,0x0000,
/* 0xdc41(i:29450) */
  0xf318,0xf319,0xf31a,0xf31b, 0xf31c,0xf31d,0xf31e,0xf31f,
  0xf320,0xf321,0xf322,0xf323, 0xf324,0xf325,0xf326,0xf327,
  0xf328,0xf329,0xf32a,0xf32b, 0xf32c,0xf32d,0xf32e,0xf32f,
  0xf330,0xf331,0xf332,0xf333, 0xf334,0xf335,0xf336,0xf337,
  0xf338,0xf339,0xf33a,0xf33b, 0xf33c,0xf33d,0xf33e,0xf33f,
  0xf340,0xf341,0xf342,0xf343, 0xf344,0xf345,0xf346,0xf347,
  0xf348,0xf349,0xf34a,0xf34b, 0xf34c,0xf34d,0xf34e,0xf34f,
  0xf350,0xf351,0xf352,0xf353, 0xf354,0xf355,0xf356,0x0000,
  0xf357,0xf358,0xf359,0xf35a, 0xf35b,0xf35c,0xf35d,0xf35e,
  0xf35f,0xf360,0xf361,0xf362, 0xf363,0xf364,0xf365,0xf366,
  0xf367,0xf368,0xf369,0xf36a, 0xf36b,0xf36c,0xf36d,0xf36e,
  0xf36f,0xf370,0xf371,0xf372, 0xf373,0xf374,0xf375,0xf376,
  0xf377,0xf378,0xf379,0xf37a, 0xf37b,0xf37c,0xf37d,0xf37e,
  0xf37f,0xf380,0xf381,0xf382, 0xf383,0xf384,0xf385,0xf386,
  0xf387,0xf388,0xf389,0xf38a, 0xf38b,0xf38c,0xf38d,0xf38e,
  0xf38f,0xf390,0xf391,0xf392, 0xf393,0xf394,0xf395,0xf396,
  0xf397,0xf398,0xf399,0xf39a, 0xf39b,0xf39c,0xf39d,0xf39e,
  0xf39f,0xf3a0,0xf3a1,0xf3a2, 0xf3a3,0xf3a4,0xf3a5,0xf3a6,
  0xf3a7,0xf3a8,0xf3a9,0xf3aa, 0xf3ab,0xf3ac,0xf3ad,0xf3ae,
  0xf3af,0xf3b0,0xf3b1,0xf3b2, 0xf3b3,0xf3b4,0xf3b5,0xf3b6,
  0xf3b7,0xf3b8,0xf3b9,0xf3ba, 0xf3bb,0xf3bc,0xf3bd,0xf3be,
  0xf3bf,0xf3c0,0xf3c1,0xf3c2, 0xf3c3,0xf3c4,0xf3c5,0xf3c6,
  0xf3c7,0xf3c8,0xf3c9,0xf3ca, 0xf3cb,0xf3cc,0xf3cd,0xf3ce,
  0xf3cf,0xf3d0,0xf3d1,0xf3d2, 0xf3d3,0x0000,
/* 0xdd41(i:29640) */
  0xf3d4,0xf3d5,0xf3d6,0xf3d7, 0xf3d8,0xf3d9,0xf3da,0xf3db,
  0xf3dc,0xf3dd,0xf3de,0xf3df, 0xf3e0,0xf3e1,0xf3e2,0xf3e3,
  0xf3e4,0xf3e5,0xf3e6,0xf3e7, 0xf3e8,0xf3e9,0xf3ea,0xf3eb,
  0xf3ec,0xf3ed,0xf3ee,0xf3ef, 0xf3f0,0xf3f1,0xf3f2,0xf3f3,
  0xf3f4,0xf3f5,0xf3f6,0xf3f7, 0xf3f8,0xf3f9,0xf3fa,0xf3fb,
  0xf3fc,0xf3fd,0xf3fe,0xf3ff, 0xf400,0xf401,0xf402,0xf403,
  0xf404,0xf405,0xf406,0xf407, 0xf408,0xf409,0xf40a,0xf40b,
  0xf40c,0xf40d,0xf40e,0xf40f, 0xf410,0xf411,0xf412,0x0000,
  0xf413,0xf414,0xf415,0xf416, 0xf417,0xf418,0xf419,0xf41a,
  0xf41b,0xf41c,0xf41d,0xf41e, 0xf41f,0xf420,0xf421,0xf422,
  0xf423,0xf424,0xf425,0xf426, 0xf427,0xf428,0xf429,0xf42a,
  0xf42b,0xf42c,0xf42d,0xf42e, 0xf42f,0xf430,0xf431,0xf432,
  0xf433,0xf434,0xf435,0xf436, 0xf437,0xf438,0xf439,0xf43a,
  0xf43b,0xf43c,0xf43d,0xf43e, 0xf43f,0xf440,0xf441,0xf442,
  0xf443,0xf444,0xf445,0xf446, 0xf447,0xf448,0xf449,0xf44a,
  0xf44b,0xf44c,0xf44d,0xf44e, 0xf44f,0xf450,0xf451,0xf452,
  0xf453,0xf454,0xf455,0xf456, 0xf457,0xf458,0xf459,0xf45a,
  0xf45b,0xf45c,0xf45d,0xf45e, 0xf45f,0xf460,0xf461,0xf462,
  0xf463,0xf464,0xf465,0xf466, 0xf467,0xf468,0xf469,0xf46a,
  0xf46b,0xf46c,0xf46d,0xf46e, 0xf46f,0xf470,0xf471,0xf472,
  0xf473,0xf474,0xf475,0xf476, 0xf477,0xf478,0xf479,0xf47a,
  0xf47b,0xf47c,0xf47d,0xf47e, 0xf47f,0xf480,0xf481,0xf482,
  0xf483,0xf484,0xf485,0xf486, 0xf487,0xf488,0xf489,0xf48a,
  0xf48b,0xf48c,0xf48d,0xf48e, 0xf48f,0x0000,
/* 0xde41(i:29830) */
  0xf490,0xf491,0xf492,0xf493, 0xf494,0xf495,0xf496,0xf497,
  0xf498,0xf499,0xf49a,0xf49b, 0xf49c,0xf49d,0xf49e,0xf49f,
  0xf4a0,0xf4a1,0xf4a2,0xf4a3, 0xf4a4,0xf4a5,0xf4a6,0xf4a7,
  0xf4a8,0xf4a9,0xf4aa,0xf4ab, 0xf4ac,0xf4ad,0xf4ae,0xf4af,
  0xf4b0,0xf4b1,0xf4b2,0xf4b3, 0xf4b4,0xf4b5,0xf4b6,0xf4b7,
  0xf4b8,0xf4b9,0xf4ba,0xf4bb, 0xf4bc,0xf4bd,0xf4be,0xf4bf,
  0xf4c0,0xf4c1,0xf4c2,0xf4c3, 0xf4c4,0xf4c5,0xf4c6,0xf4c7,
  0xf4c8,0xf4c9,0xf4ca,0xf4cb, 0xf4cc,0xf4cd,0xf4ce,0x0000,
  0xf4cf,0xf4d0,0xf4d1,0xf4d2, 0xf4d3,0xf4d4,0xf4d5,0xf4d6,
  0xf4d7,0xf4d8,0xf4d9,0xf4da, 0xf4db,0xf4dc,0xf4dd,0xf4de,
  0xf4df,0xf4e0,0xf4e1,0xf4e2, 0xf4e3,0xf4e4,0xf4e5,0xf4e6,
  0xf4e7,0xf4e8,0xf4e9,0xf4ea, 0xf4eb,0xf4ec,0xf4ed,0xf4ee,
  0xf4ef,0xf4f0,0xf4f1,0xf4f2, 0xf4f3,0xf4f4,0xf4f5,0xf4f6,
  0xf4f7,0xf4f8,0xf4f9,0xf4fa, 0xf4fb,0xf4fc,0xf4fd,0xf4fe,
  0xf4ff,0xf500,0xf501,0xf502, 0xf503,0xf504,0xf505,0xf506,
  0xf507,0xf508,0xf509,0xf50a, 0xf50b,0xf50c,0xf50d,0xf50e,
  0xf50f,0xf510,0xf511,0xf512, 0xf513,0xf514,0xf515,0xf516,
  0xf517,0xf518,0xf519,0xf51a, 0xf51b,0xf51c,0xf51d,0xf51e,
  0xf51f,0xf520,0xf521,0xf522, 0xf523,0xf524,0xf525,0xf526,
  0xf527,0xf528,0xf529,0xf52a, 0xf52b,0xf52c,0xf52d,0xf52e,
  0xf52f,0xf530,0xf531,0xf532, 0xf533,0xf534,0xf535,0xf536,
  0xf537,0xf538,0xf539,0xf53a, 0xf53b,0xf53c,0xf53d,0xf53e,
  0xf53f,0xf540,0xf541,0xf542, 0xf543,0xf544,0xf545,0xf546,
  0xf547,0xf548,0xf549,0xf54a, 0xf54b,0x0000,
/* 0xdf41(i:30020) */
  0xf54c,0xf54d,0xf54e,0xf54f, 0xf550,0xf551,0xf552,0xf553,
  0xf554,0xf555,0xf556,0xf557, 0xf558,0xf559,0xf55a,0xf55b,
  0xf55c,0xf55d,0xf55e,0xf55f, 0xf560,0xf561,0xf562,0xf563,
  0xf564,0xf565,0xf566,0xf567, 0xf568,0xf569,0xf56a,0xf56b,
  0xf56c,0xf56d,0xf56e,0xf56f, 0xf570,0xf571,0xf572,0xf573,
  0xf574,0xf575,0xf576,0xf577, 0xf578,0xf579,0xf57a,0xf57b,
  0xf57c,0xf57d,0xf57e,0xf57f, 0xf580,0xf581,0xf582,0xf583,
  0xf584,0xf585,0xf586,0xf587, 0xf588,0xf589,0xf58a,0x0000,
  0xf58b,0xf58c,0xf58d,0xf58e, 0xf58f,0xf590,0xf591,0xf592,
  0xf593,0xf594,0xf595,0xf596, 0xf597,0xf598,0xf599,0xf59a,
  0xf59b,0xf59c,0xf59d,0xf59e, 0xf59f,0xf5a0,0xf5a1,0xf5a2,
  0xf5a3,0xf5a4,0xf5a5,0xf5a6, 0xf5a7,0xf5a8,0xf5a9,0xf5aa,
  0xf5ab,0xf5ac,0xf5ad,0xf5ae, 0xf5af,0xf5b0,0xf5b1,0xf5b2,
  0xf5b3,0xf5b4,0xf5b5,0xf5b6, 0xf5b7,0xf5b8,0xf5b9,0xf5ba,
  0xf5bb,0xf5bc,0xf5bd,0xf5be, 0xf5bf,0xf5c0,0xf5c1,0xf5c2,
  0xf5c3,0xf5c4,0xf5c5,0xf5c6, 0xf5c7,0xf5c8,0xf5c9,0xf5ca,
  0xf5cb,0xf5cc,0xf5cd,0xf5ce, 0xf5cf,0xf5d0,0xf5d1,0xf5d2,
  0xf5d3,0xf5d4,0xf5d5,0xf5d6, 0xf5d7,0xf5d8,0xf5d9,0xf5da,
  0xf5db,0xf5dc,0xf5dd,0xf5de, 0xf5df,0xf5e0,0xf5e1,0xf5e2,
  0xf5e3,0xf5e4,0xf5e5,0xf5e6, 0xf5e7,0xf5e8,0xf5e9,0xf5ea,
  0xf5eb,0xf5ec,0xf5ed,0xf5ee, 0xf5ef,0xf5f0,0xf5f1,0xf5f2,
  0xf5f3,0xf5f4,0xf5f5,0xf5f6, 0xf5f7,0xf5f8,0xf5f9,0xf5fa,
  0xf5fb,0xf5fc,0xf5fd,0xf5fe, 0xf5ff,0xf600,0xf601,0xf602,
  0xf603,0xf604,0xf605,0xf606, 0xf607,0x0000,
/* 0xe041(i:30210) */
  0xf608,0xf609,0xf60a,0xf60b, 0xf60c,0xf60d,0xf60e,0xf60f,
  0xf610,0xf611,0xf612,0xf613, 0xf614,0xf615,0xf616,0xf617,
  0xf618,0xf619,0xf61a,0xf61b, 0xf61c,0xf61d,0xf61e,0xf61f,
  0xf620,0xf621,0xf622,0xf623, 0xf624,0xf625,0xf626,0xf627,
  0xf628,0xf629,0xf62a,0xf62b, 0xf62c,0xf62d,0xf62e,0xf62f,
  0xf630,0xf631,0xf632,0xf633, 0xf634,0xf635,0xf636,0xf637,
  0xf638,0xf639,0xf63a,0xf63b, 0xf63c,0xf63d,0xf63e,0xf63f,
  0xf640,0xf641,0xf642,0xf643, 0xf644,0xf645,0xf646,0x0000,
  0xf647,0xf648,0xf649,0xf64a, 0xf64b,0xf64c,0xf64d,0xf64e,
  0xf64f,0xf650,0xf651,0xf652, 0xf653,0xf654,0xf655,0xf656,
  0xf657,0xf658,0xf659,0xf65a, 0xf65b,0xf65c,0xf65d,0xf65e,
  0xf65f,0xf660,0xf661,0xf662, 0xf663,0xf664,0xf665,0xf666,
  0xf667,0xf668,0xf669,0xf66a, 0xf66b,0xf66c,0xf66d,0xf66e,
  0xf66f,0xf670,0xf671,0xf672, 0xf673,0xf674,0xf675,0xf676,
  0xf677,0xf678,0xf679,0xf67a, 0xf67b,0xf67c,0xf67d,0xf67e,
  0xf67f,0xf680,0xf681,0xf682, 0xf683,0xf684,0xf685,0xf686,
  0xf687,0xf688,0xf689,0xf68a, 0xf68b,0xf68c,0xf68d,0xf68e,
  0xf68f,0xf690,0xf691,0xf692, 0xf693,0xf694,0xf695,0xf696,
  0xf697,0xf698,0xf699,0xf69a, 0xf69b,0xf69c,0xf69d,0xf69e,
  0xf69f,0xf6a0,0xf6a1,0xf6a2, 0xf6a3,0xf6a4,0xf6a5,0xf6a6,
  0xf6a7,0xf6a8,0xf6a9,0xf6aa, 0xf6ab,0xf6ac,0xf6ad,0xf6ae,
  0xf6af,0xf6b0,0xf6b1,0xf6b2, 0xf6b3,0xf6b4,0xf6b5,0xf6b6,
  0xf6b7,0xf6b8,0xf6b9,0xf6ba, 0xf6bb,0xf6bc,0xf6bd,0xf6be,
  0xf6bf,0xf6c0,0xf6c1,0xf6c2, 0xf6c3,0x0000,
/* 0xe141(i:30400) */
  0xf6c4,0xf6c5,0xf6c6,0xf6c7, 0xf6c8,0xf6c9,0xf6ca,0xf6cb,
  0xf6cc,0xf6cd,0xf6ce,0xf6cf, 0xf6d0,0xf6d1,0xf6d2,0xf6d3,
  0xf6d4,0xf6d5,0xf6d6,0xf6d7, 0xf6d8,0xf6d9,0xf6da,0xf6db,
  0xf6dc,0xf6dd,0xf6de,0xf6df, 0xf6e0,0xf6e1,0xf6e2,0xf6e3,
  0xf6e4,0xf6e5,0xf6e6,0xf6e7, 0xf6e8,0xf6e9,0xf6ea,0xf6eb,
  0xf6ec,0xf6ed,0xf6ee,0xf6ef, 0xf6f0,0xf6f1,0xf6f2,0xf6f3,
  0xf6f4,0xf6f5,0xf6f6,0xf6f7, 0xf6f8,0xf6f9,0xf6fa,0xf6fb,
  0xf6fc,0xf6fd,0xf6fe,0xf6ff, 0xf700,0xf701,0xf702,0x0000,
  0xf703,0xf704,0xf705,0xf706, 0xf707,0xf708,0xf709,0xf70a,
  0xf70b,0xf70c,0xf70d,0xf70e, 0xf70f,0xf710,0xf711,0xf712,
  0xf713,0xf714,0xf715,0xf716, 0xf717,0xf718,0xf719,0xf71a,
  0xf71b,0xf71c,0xf71d,0xf71e, 0xf71f,0xf720,0xf721,0xf722,
  0xf723,0xf724,0xf725,0xf726, 0xf727,0xf728,0xf729,0xf72a,
  0xf72b,0xf72c,0xf72d,0xf72e, 0xf72f,0xf730,0xf731,0xf732,
  0xf733,0xf734,0xf735,0xf736, 0xf737,0xf738,0xf739,0xf73a,
  0xf73b,0xf73c,0xf73d,0xf73e, 0xf73f,0xf740,0xf741,0xf742,
  0xf743,0xf744,0xf745,0xf746, 0xf747,0xf748,0xf749,0xf74a,
  0xf74b,0xf74c,0xf74d,0xf74e, 0xf74f,0xf750,0xf751,0xf752,
  0xf753,0xf754,0xf755,0xf756, 0xf757,0xf758,0xf759,0xf75a,
  0xf75b,0xf75c,0xf75d,0xf75e, 0xf75f,0xf760,0xf761,0xf762,
  0xf763,0xf764,0xf765,0xf766, 0xf767,0xf768,0xf769,0xf76a,
  0xf76b,0xf76c,0xf76d,0xf76e, 0xf76f,0xf770,0xf771,0xf772,
  0xf773,0xf774,0xf775,0xf776, 0xf777,0xf778,0xf779,0xf77a,
  0xf77b,0xf77c,0xf77d,0xf77e, 0xf77f,0x0000,
/* 0xe241(i:30590) */
  0xf780,0xf781,0xf782,0xf783, 0xf784,0xf785,0xf786,0xf787,
  0xf788,0xf789,0xf78a,0xf78b, 0xf78c,0xf78d,0xf78e,0xf78f,
  0xf790,0xf791,0xf792,0xf793, 0xf794,0xf795,0xf796,0xf797,
  0xf798,0xf799,0xf79a,0xf79b, 0xf79c,0xf79d,0xf79e,0xf79f,
  0xf7a0,0xf7a1,0xf7a2,0xf7a3, 0xf7a4,0xf7a5,0xf7a6,0xf7a7,
  0xf7a8,0xf7a9,0xf7aa,0xf7ab, 0xf7ac,0xf7ad,0xf7ae,0xf7af,
  0xf7b0,0xf7b1,0xf7b2,0xf7b3, 0xf7b4,0xf7b5,0xf7b6,0xf7b7,
  0xf7b8,0xf7b9,0xf7ba,0xf7bb, 0xf7bc,0xf7bd,0xf7be,0x0000,
  0xf7bf,0xf7c0,0xf7c1,0xf7c2, 0xf7c3,0xf7c4,0xf7c5,0xf7c6,
  0xf7c7,0xf7c8,0xf7c9,0xf7ca, 0xf7cb,0xf7cc,0xf7cd,0xf7ce,
  0xf7cf,0xf7d0,0xf7d1,0xf7d2, 0xf7d3,0xf7d4,0xf7d5,0xf7d6,
  0xf7d7,0xf7d8,0xf7d9,0xf7da, 0xf7db,0xf7dc,0xf7dd,0xf7de,
  0xf7df,0xf7e0,0xf7e1,0xf7e2, 0xf7e3,0xf7e4,0xf7e5,0xf7e6,
  0xf7e7,0xf7e8,0xf7e9,0xf7ea, 0xf7eb,0xf7ec,0xf7ed,0xf7ee,
  0xf7ef,0xf7f0,0xf7f1,0xf7f2, 0xf7f3,0xf7f4,0xf7f5,0xf7f6,
  0xf7f7,0xf7f8,0xf7f9,0xf7fa, 0xf7fb,0xf7fc,0xf7fd,0xf7fe,
  0xf7ff,0xf800,0xf801,0xf802, 0xf803,0xf804,0xf805,0xf806,
  0xf807,0xf808,0xf809,0xf80a, 0xf80b,0xf80c,0xf80d,0xf80e,
  0xf80f,0xf810,0xf811,0xf812, 0xf813,0xf814,0xf815,0xf816,
  0xf817,0xf818,0xf819,0xf81a, 0xf81b,0xf81c,0xf81d,0xf81e,
  0xf81f,0xf820,0xf821,0xf822, 0xf823,0xf824,0xf825,0xf826,
  0xf827,0xf828,0xf829,0xf82a, 0xf82b,0xf82c,0xf82d,0xf82e,
  0xf82f,0xf830,0xf831,0xf832, 0xf833,0xf834,0xf835,0xf836,
  0xf837,0xf838,0xf839,0xf83a, 0xf83b,0x0000,
/* 0xe341(i:30780) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000
};
#endif

#if defined(OUTPUT_DYNAMIC_TABLE) || !defined(DYNAMIC_LOADING) || defined(SWIG_EXT)
/* --- JIS X0208 Table --- */
unsigned short uni_t_x0208_78[9025] = {
0x3000,0x3001,0x3002,0xff0c,0xff0e,0x30fb,0xff1a,0xff1b,
0xff1f,0xff01,0x309b,0x309c,0x00b4,0xff40,0x00a8,0xff3e,
0xffe3,0xff3f,0x30fd,0x30fe,0x309d,0x309e,0x3003,0x4edd,
0x3005,0x3006,0x3007,0x30fc,0x2015,0x2010,0xff0f,0xff3c,
0x301c,0x2016,0xff5c,0x2026,0x2025,0x2018,0x2019,0x201c,
0x201d,0xff08,0xff09,0x3014,0x3015,0xff3b,0xff3d,0xff5b,
0xff5d,0x3008,0x3009,0x300a,0x300b,0x300c,0x300d,0x300e,
0x300f,0x3010,0x3011,0xff0b,0xff0d,0x00b1,0x00d7,0x00f7,
0xff1d,0x2260,0xff1c,0xff1e,0x2266,0x2267,0x221e,0x2234,
0x2642,0x2640,0x00b0,0x2032,0x2033,0x2103,0xffe5,0xff04,
0x00a2,0x00a3,0xff05,0xff03,0xff06,0xff0a,0xff20,0x00a7,
0x2606,0x2605,0x25cb,0x25cf,0x25ce,0x25c7,
0x25c6,0x25a1,0x25a0,0x25b3,0x25b2,0x25bd,0x25bc,0x203b,
0x3012,0x2192,0x2190,0x2191,0x2193,0x3013,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x2208,0x220b,0x2286,0x2287,0x2282,0x2283,0x222a,
0x2229,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x2227,0x2228,0x00ac,0x21d2,0x21d4,0x2200,0x2203,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x2220,0x22a5,0x2312,0x2202,0x2207,
0x2261,0x2252,0x226a,0x226b,0x221a,0x223d,0x221d,0x2235,
0x222b,0x222c,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x212b,0x2030,0x266f,0x266d,0x266a,0x2020,0x2021,
0x00b6,0x0000,0x0000,0x0000,0x0000,0x25ef,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0xff10,
0xff11,0xff12,0xff13,0xff14,0xff15,0xff16,0xff17,0xff18,
0xff19,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0xff21,0xff22,0xff23,0xff24,0xff25,0xff26,0xff27,0xff28,
0xff29,0xff2a,0xff2b,0xff2c,0xff2d,0xff2e,0xff2f,0xff30,
0xff31,0xff32,0xff33,0xff34,0xff35,0xff36,0xff37,0xff38,
0xff39,0xff3a,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0xff41,0xff42,0xff43,0xff44,0xff45,0xff46,0xff47,0xff48,
0xff49,0xff4a,0xff4b,0xff4c,0xff4d,0xff4e,0xff4f,0xff50,
0xff51,0xff52,0xff53,0xff54,0xff55,0xff56,0xff57,0xff58,
0xff59,0xff5a,0x0000,0x0000,0x0000,0x0000,
0x3041,0x3042,0x3043,0x3044,0x3045,0x3046,0x3047,0x3048,
0x3049,0x304a,0x304b,0x304c,0x304d,0x304e,0x304f,0x3050,
0x3051,0x3052,0x3053,0x3054,0x3055,0x3056,0x3057,0x3058,
0x3059,0x305a,0x305b,0x305c,0x305d,0x305e,0x305f,0x3060,
0x3061,0x3062,0x3063,0x3064,0x3065,0x3066,0x3067,0x3068,
0x3069,0x306a,0x306b,0x306c,0x306d,0x306e,0x306f,0x3070,
0x3071,0x3072,0x3073,0x3074,0x3075,0x3076,0x3077,0x3078,
0x3079,0x307a,0x307b,0x307c,0x307d,0x307e,0x307f,0x3080,
0x3081,0x3082,0x3083,0x3084,0x3085,0x3086,0x3087,0x3088,
0x3089,0x308a,0x308b,0x308c,0x308d,0x308e,0x308f,0x3090,
0x3091,0x3092,0x3093,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x30a1,0x30a2,0x30a3,0x30a4,0x30a5,0x30a6,0x30a7,0x30a8,
0x30a9,0x30aa,0x30ab,0x30ac,0x30ad,0x30ae,0x30af,0x30b0,
0x30b1,0x30b2,0x30b3,0x30b4,0x30b5,0x30b6,0x30b7,0x30b8,
0x30b9,0x30ba,0x30bb,0x30bc,0x30bd,0x30be,0x30bf,0x30c0,
0x30c1,0x30c2,0x30c3,0x30c4,0x30c5,0x30c6,0x30c7,0x30c8,
0x30c9,0x30ca,0x30cb,0x30cc,0x30cd,0x30ce,0x30cf,0x30d0,
0x30d1,0x30d2,0x30d3,0x30d4,0x30d5,0x30d6,0x30d7,0x30d8,
0x30d9,0x30da,0x30db,0x30dc,0x30dd,0x30de,0x30df,0x30e0,
0x30e1,0x30e2,0x30e3,0x30e4,0x30e5,0x30e6,0x30e7,0x30e8,
0x30e9,0x30ea,0x30eb,0x30ec,0x30ed,0x30ee,0x30ef,0x30f0,
0x30f1,0x30f2,0x30f3,0x30f4,0x30f5,0x30f6,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0391,0x0392,0x0393,0x0394,0x0395,0x0396,0x0397,0x0398,
0x0399,0x039a,0x039b,0x039c,0x039d,0x039e,0x039f,0x03a0,
0x03a1,0x03a3,0x03a4,0x03a5,0x03a6,0x03a7,0x03a8,0x03a9,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x03b1,0x03b2,0x03b3,0x03b4,0x03b5,0x03b6,0x03b7,0x03b8,
0x03b9,0x03ba,0x03bb,0x03bc,0x03bd,0x03be,0x03bf,0x03c0,
0x03c1,0x03c3,0x03c4,0x03c5,0x03c6,0x03c7,0x03c8,0x03c9,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0410,0x0411,0x0412,0x0413,0x0414,0x0415,0x0401,0x0416,
0x0417,0x0418,0x0419,0x041a,0x041b,0x041c,0x041d,0x041e,
0x041f,0x0420,0x0421,0x0422,0x0423,0x0424,0x0425,0x0426,
0x0427,0x0428,0x0429,0x042a,0x042b,0x042c,0x042d,0x042e,
0x042f,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0430,0x0431,0x0432,0x0433,0x0434,0x0435,0x0451,0x0436,
0x0437,0x0438,0x0439,0x043a,0x043b,0x043c,0x043d,0x043e,
0x043f,0x0440,0x0441,0x0442,0x0443,0x0444,0x0445,0x0446,
0x0447,0x0448,0x0449,0x044a,0x044b,0x044c,0x044d,0x044e,
0x044f,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x2500,0x2502,0x250c,0x2510,0x2518,0x2514,0x251c,0x252c,
0x2524,0x2534,0x253c,0x2501,0x2503,0x250f,0x2513,0x251b,
0x2517,0x2523,0x2533,0x252b,0x253b,0x254b,0x2520,0x252f,
0x2528,0x2537,0x253f,0x251d,0x2530,0x2525,0x2538,0x2542,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
/* -- 2d -- */
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
/* -- 30 -- */
0x4e9c,0x555e,0x5a03,0x963f,0x54c0,0x611b,0x6328,0x59f6,
0x9022,0x8475,0x831c,0x7a50,0x60aa,0x63e1,0x6e25,0x65ed,
0x8466,0x82a6,0x9c3a,0x6893,0x5727,0x65a1,0x6271,0x5b9b,
0x59d0,0x867b,0x98f4,0x7d62,0x7dbe,0x9b8e,0x6216,0x7c9f,
0x88b7,0x5b89,0x5eb5,0x6309,0x6697,0x6848,0x95c7,0x978d,
0x674f,0x4ee5,0x4f0a,0x4f4d,0x4f9d,0x5049,0x56f2,0x5937,
0x59d4,0x5a01,0x5c09,0x60df,0x610f,0x6170,0x6613,0x6905,
0x70ba,0x754f,0x7570,0x79fb,0x7dad,0x7def,0x80c3,0x840e,
0x8863,0x8b02,0x9055,0x907a,0x533b,0x4e95,0x4ea5,0x57df,
0x80b2,0x90c1,0x78ef,0x4e00,0x58f1,0x6ea2,0x9038,0x7a32,
0x8328,0x828b,0x9c2f,0x5141,0x5370,0x54bd,0x54e1,0x56e0,
0x59fb,0x5f15,0x98f2,0x6deb,0x80e4,0x852d,
0x9662,0x9670,0x96a0,0x97fb,0x540b,0x53f3,0x5b87,0x70cf,
0x7fbd,0x8fc2,0x96e8,0x536f,0x9d5c,0x7aba,0x4e11,0x7893,
0x81fc,0x6e26,0x5618,0x5504,0x6b1d,0x851a,0x9c3b,0x59e5,
0x53a9,0x6d66,0x74dc,0x958f,0x5642,0x4e91,0x904b,0x96f2,
0x834f,0x990c,0x53e1,0x55b6,0x5b30,0x5f71,0x6620,0x66f3,
0x6804,0x6c38,0x6cf3,0x6d29,0x745b,0x76c8,0x7a4e,0x9834,
0x82f1,0x885b,0x8a60,0x92ed,0x6db2,0x75ab,0x76ca,0x99c5,
0x60a6,0x8b01,0x8d8a,0x95b2,0x698e,0x53ad,0x5186,0x5712,
0x5830,0x5944,0x5bb4,0x5ef6,0x6028,0x63a9,0x63f4,0x6cbf,
0x6f14,0x708e,0x7130,0x7159,0x71d5,0x733f,0x7e01,0x8276,
0x82d1,0x8597,0x9060,0x925b,0x9d1b,0x5869,0x65bc,0x6c5a,
0x7525,0x51f9,0x592e,0x5965,0x5f80,0x5fdc,
0x62bc,0x65fa,0x6a2a,0x6b27,0x6bb4,0x738b,0x7fc1,0x8956,
0x9daf,0x9dd7,0x9ec4,0x5ca1,0x6c96,0x837b,0x5104,0x5c4b,
0x61b6,0x81c6,0x6876,0x7261,0x4e59,0x4ffa,0x5378,0x6069,
0x6e29,0x7a4f,0x97f3,0x4e0b,0x5316,0x4eee,0x4f55,0x4f3d,
0x4fa1,0x4f73,0x52a0,0x53ef,0x5609,0x590f,0x5ac1,0x5bb6,
0x5be1,0x79d1,0x6687,0x679c,0x67b6,0x6b4c,0x6cb3,0x706b,
0x73c2,0x798d,0x79be,0x7a3c,0x7b87,0x82b1,0x82db,0x8304,
0x8377,0x83ef,0x83d3,0x8766,0x8ab2,0x5629,0x8ca8,0x8fe6,
0x904e,0x971e,0x868a,0x4fc4,0x5ce8,0x6211,0x7259,0x753b,
0x81e5,0x82bd,0x86fe,0x8cc0,0x96c5,0x9913,0x99d5,0x4ecb,
0x4f1a,0x89e3,0x56de,0x584a,0x58ca,0x5efb,0x5feb,0x602a,
0x6094,0x6062,0x61d0,0x6212,0x62d0,0x6539,
0x9b41,0x6666,0x68b0,0x6d77,0x7070,0x754c,0x7686,0x7d75,
0x82a5,0x87f9,0x958b,0x968e,0x8c9d,0x51f1,0x52be,0x5916,
0x54b3,0x5bb3,0x5d16,0x6168,0x6982,0x6daf,0x788d,0x84cb,
0x8857,0x8a72,0x93a7,0x9ab8,0x6d6c,0x99a8,0x86d9,0x57a3,
0x67ff,0x8823,0x920e,0x5283,0x5687,0x5404,0x5ed3,0x62e1,
0x652a,0x683c,0x6838,0x6bbb,0x7372,0x78ba,0x7a6b,0x899a,
0x89d2,0x8d6b,0x8f03,0x90ed,0x95a3,0x9694,0x9769,0x5b66,
0x5cb3,0x697d,0x984d,0x984e,0x639b,0x7b20,0x6a2b,0x6a7f,
0x68b6,0x9c0d,0x6f5f,0x5272,0x559d,0x6070,0x62ec,0x6d3b,
0x6e07,0x6ed1,0x845b,0x8910,0x8f44,0x4e14,0x9c39,0x53f6,
0x691b,0x6a3a,0x9784,0x682a,0x515c,0x7ac8,0x84b2,0x91dc,
0x938c,0x5699,0x9d28,0x6822,0x8305,0x8431,
/* -- 34 -- */
0x7ca5,0x5208,0x82c5,0x74e6,0x4e7e,0x4f83,0x51a0,0x5bd2,
0x520a,0x52d8,0x52e7,0x5dfb,0x559a,0x582a,0x59e6,0x5b8c,
0x5b98,0x5bdb,0x5e72,0x5e79,0x60a3,0x611f,0x6163,0x61be,
0x63db,0x6562,0x67d1,0x6853,0x68fa,0x6b3e,0x6b53,0x6c57,
0x6f22,0x6f97,0x704c,0x74b0,0x7518,0x76e3,0x770b,0x7aff,
0x7ba1,0x7c21,0x7de9,0x7f36,0x7ff0,0x809d,0x8266,0x839e,
0x89b3,0x8aeb,0x8cab,0x9084,0x9451,0x9593,0x9591,0x95a2,
0x9665,0x97d3,0x9928,0x8218,0x4e38,0x542b,0x5cb8,0x5dcc,
0x73a9,0x764c,0x773c,0x5ca9,0x7feb,0x8d0b,0x96c1,0x9811,
0x9854,0x9858,0x4f01,0x4f0e,0x5371,0x559c,0x5668,0x57fa,
0x5947,0x5b09,0x5bc4,0x5c90,0x5e0c,0x5e7e,0x5fcc,0x63ee,
0x673a,0x65d7,0x65e2,0x671f,0x68cb,0x68c4,
0x6a5f,0x5e30,0x6bc5,0x6c17,0x6c7d,0x757f,0x7948,0x5b63,
0x7a00,0x7d00,0x5fbd,0x898f,0x8a18,0x8cb4,0x8d77,0x8ecc,
0x8f1d,0x98e2,0x9a0e,0x9b3c,0x4e80,0x507d,0x5100,0x5993,
0x5b9c,0x622f,0x6280,0x64ec,0x6b3a,0x72a0,0x7591,0x7947,
0x7fa9,0x87fb,0x8abc,0x8b70,0x63ac,0x83ca,0x97a0,0x5409,
0x5403,0x55ab,0x6854,0x6a58,0x8a70,0x7827,0x6775,0x9ecd,
0x5374,0x5ba2,0x811a,0x8650,0x9006,0x4e18,0x4e45,0x4ec7,
0x4f11,0x53ca,0x5438,0x5bae,0x5f13,0x6025,0x6551,0x673d,
0x6c42,0x6c72,0x6ce3,0x7078,0x7403,0x7a76,0x7aae,0x7b08,
0x7d1a,0x7cfe,0x7d66,0x65e7,0x725b,0x53bb,0x5c45,0x5de8,
0x62d2,0x62e0,0x6319,0x6e20,0x865a,0x8a31,0x8ddd,0x92f8,
0x6f01,0x79a6,0x9b5a,0x4ea8,0x4eab,0x4eac,
/* -- 36xx -- */
0x4f9b,0x4fe0,0x50d1,0x5147,0x7af6,0x5171,0x51f6,0x5354,
0x5321,0x537f,0x53eb,0x55ac,0x5883,0x5ce1,0x5f37,0x5f4a,
0x602f,0x6050,0x606d,0x631f,0x6559,0x6a4b,0x6cc1,0x72c2,
0x72ed,0x77ef,0x80f8,0x8105,0x8208,0x854e,0x90f7,0x93e1,
0x97ff,0x9957,0x9a5a,0x4ef0,0x51dd,0x582f,0x6681,0x696d,
0x5c40,0x66f2,0x6975,0x7389,0x6850,0x7c81,0x50c5,0x52e4,
0x5747,0x5dfe,0x9326,0x65a4,0x6b23,0x6b3d,0x7434,0x7981,
0x79bd,0x7b4b,0x7dca,0x82b9,0x83cc,0x887f,0x895f,0x8b39,
0x8fd1,0x91d1,0x541f,0x9280,0x4e5d,0x5036,0x53e5,0x533a,
0x72d7,0x7396,0x77e9,0x82e6,0x8ec0,0x99c6,0x99c8,0x99d2,
0x5177,0x611a,0x865e,0x55b0,0x7a7a,0x5076,0x5bd3,0x9047,
0x9685,0x4e32,0x6adb,0x91e7,0x5c51,0x5c48,
0x6398,0x7a9f,0x6c93,0x9774,0x8f61,0x7aaa,0x718a,0x9688,
0x7c82,0x6817,0x7e70,0x6851,0x936c,0x52f2,0x541b,0x85ab,
0x8a13,0x7fa4,0x8ecd,0x90e1,0x5366,0x8888,0x7941,0x4fc2,
0x50be,0x5211,0x5144,0x5553,0x572d,0x73ea,0x578b,0x5951,
0x5f62,0x5f84,0x6075,0x6176,0x6167,0x61a9,0x63b2,0x643a,
0x656c,0x666f,0x6842,0x6e13,0x7566,0x7a3d,0x7cfb,0x7d4c,
0x7d99,0x7e6b,0x7f6b,0x830e,0x834a,0x86cd,0x8a08,0x8a63,
0x8b66,0x8efd,0x9838,0x9d8f,0x82b8,0x8fce,0x9be8,0x5287,
0x621f,0x6483,0x6fc0,0x9699,0x6841,0x5091,0x6b20,0x6c7a,
0x6f54,0x7a74,0x7d50,0x8840,0x8a23,0x6708,0x4ef6,0x5039,
0x5026,0x5065,0x517c,0x5238,0x5263,0x55a7,0x570f,0x5805,
0x5acc,0x5efa,0x61b2,0x61f8,0x62f3,0x6372,
/* -- 38 -- */
0x691c,0x6a29,0x727d,0x72ac,0x732e,0x7814,0x786f,0x7d79,
0x770c,0x80a9,0x898b,0x8b19,0x8ce2,0x8ed2,0x9063,0x9375,
0x967a,0x9855,0x9a13,0x9e7c,0x5143,0x539f,0x53b3,0x5e7b,
0x5f26,0x6e1b,0x6e90,0x7384,0x73fe,0x7d43,0x8237,0x8a00,
0x8afa,0x9650,0x4e4e,0x500b,0x53e4,0x547c,0x56fa,0x59d1,
0x5b64,0x5df1,0x5eab,0x5f27,0x6238,0x6545,0x67af,0x6e56,
0x72d0,0x7cca,0x88b4,0x80a1,0x80e1,0x83f0,0x864e,0x8a87,
0x8de8,0x9237,0x96c7,0x9867,0x9f13,0x4e94,0x4e92,0x4f0d,
0x5348,0x5449,0x543e,0x5a2f,0x5f8c,0x5fa1,0x609f,0x68a7,
0x6a8e,0x745a,0x7881,0x8a9e,0x8aa4,0x8b77,0x9190,0x4e5e,
0x9bc9,0x4ea4,0x4f7c,0x4faf,0x5019,0x5016,0x5149,0x516c,
0x529f,0x52b9,0x52fe,0x539a,0x53e3,0x5411,
0x540e,0x5589,0x5751,0x57a2,0x597d,0x5b54,0x5b5d,0x5b8f,
0x5de5,0x5de7,0x5df7,0x5e78,0x5e83,0x5e9a,0x5eb7,0x5f18,
0x6052,0x614c,0x6297,0x62d8,0x63a7,0x653b,0x6602,0x6643,
0x66f4,0x676d,0x6821,0x6897,0x69cb,0x6c5f,0x6d2a,0x6d69,
0x6e2f,0x6e9d,0x7532,0x7687,0x786c,0x7a3f,0x7ce0,0x7d05,
0x7d18,0x7d5e,0x7db1,0x8015,0x8003,0x80af,0x80b1,0x8154,
0x818f,0x822a,0x8352,0x884c,0x8861,0x8b1b,0x8ca2,0x8cfc,
0x90ca,0x9175,0x9271,0x7926,0x92fc,0x95a4,0x964d,0x9805,
0x9999,0x9ad8,0x9d3b,0x525b,0x52ab,0x53f7,0x5408,0x58d5,
0x62f7,0x6fe0,0x8c6a,0x8f5f,0x9eb4,0x514b,0x523b,0x544a,
0x56fd,0x7a40,0x9177,0x9d60,0x9ed2,0x7344,0x6f09,0x8170,
0x7511,0x5ffd,0x60da,0x9aa8,0x72db,0x8fbc,
0x6b64,0x9803,0x4eca,0x56f0,0x5764,0x58be,0x5a5a,0x6068,
0x61c7,0x660f,0x6606,0x6839,0x68b1,0x6df7,0x75d5,0x7d3a,
0x826e,0x9b42,0x4e9b,0x4f50,0x53c9,0x5506,0x5d6f,0x5de6,
0x5dee,0x67fb,0x6c99,0x7473,0x7802,0x8a50,0x9396,0x88df,
0x5750,0x5ea7,0x632b,0x50b5,0x50ac,0x518d,0x6700,0x54c9,
0x585e,0x59bb,0x5bb0,0x5f69,0x624d,0x63a1,0x683d,0x6b73,
0x6e08,0x707d,0x91c7,0x7280,0x7815,0x7826,0x796d,0x658e,
0x7d30,0x83dc,0x88c1,0x8f09,0x969b,0x5264,0x5728,0x6750,
0x7f6a,0x8ca1,0x51b4,0x5742,0x962a,0x583a,0x698a,0x80b4,
0x54b2,0x5d0e,0x57fc,0x7895,0x9dfa,0x4f5c,0x524a,0x548b,
0x643e,0x6628,0x6714,0x67f5,0x7a84,0x7b56,0x7d22,0x932f,
0x685c,0x9bad,0x7b39,0x5319,0x518a,0x5237,
0x5bdf,0x62f6,0x64ae,0x64e6,0x672d,0x6bba,0x85a9,0x96d1,
0x7690,0x9bd6,0x634c,0x9306,0x9bab,0x76bf,0x6652,0x4e09,
0x5098,0x53c2,0x5c71,0x60e8,0x6492,0x6563,0x685f,0x71e6,
0x73ca,0x7523,0x7b97,0x7e82,0x8695,0x8b83,0x8cdb,0x9178,
0x9910,0x65ac,0x66ab,0x6b8b,0x4ed5,0x4ed4,0x4f3a,0x4f7f,
0x523a,0x53f8,0x53f2,0x55e3,0x56db,0x58eb,0x59cb,0x59c9,
0x59ff,0x5b50,0x5c4d,0x5e02,0x5e2b,0x5fd7,0x601d,0x6307,
0x652f,0x5b5c,0x65af,0x65bd,0x65e8,0x679d,0x6b62,0x6b7b,
0x6c0f,0x7345,0x7949,0x79c1,0x7cf8,0x7d19,0x7d2b,0x80a2,
0x8102,0x81f3,0x8996,0x8a5e,0x8a69,0x8a66,0x8a8c,0x8aee,
0x8cc7,0x8cdc,0x96cc,0x98fc,0x6b6f,0x4e8b,0x4f3c,0x4f8d,
0x5150,0x5b57,0x5bfa,0x6148,0x6301,0x6642,
/* -- 3c -- */
0x6b21,0x6ecb,0x6cbb,0x723e,0x74bd,0x75d4,0x78c1,0x793a,
0x800c,0x8033,0x81ea,0x8494,0x8f9e,0x6c50,0x9e7f,0x5f0f,
0x8b58,0x9d2b,0x7afa,0x8ef8,0x5b8d,0x96eb,0x4e03,0x53f1,
0x57f7,0x5931,0x5ac9,0x5ba4,0x6089,0x6e7f,0x6f06,0x75be,
0x8cea,0x5b9f,0x8500,0x7be0,0x5072,0x67f4,0x829d,0x5c62,
0x8602,0x7e1e,0x820e,0x5199,0x5c04,0x6368,0x8d66,0x659c,
0x716e,0x793e,0x7d17,0x8005,0x8b1d,0x8eca,0x906e,0x86c7,
0x90aa,0x501f,0x52fa,0x5c3a,0x6753,0x707c,0x7235,0x914c,
0x91c8,0x932b,0x82e5,0x5bc2,0x5f31,0x60f9,0x4e3b,0x53d6,
0x5b88,0x624b,0x6731,0x6b8a,0x72e9,0x73e0,0x7a2e,0x816b,
0x8da3,0x9152,0x9996,0x5112,0x53d7,0x546a,0x5bff,0x6388,
0x6a39,0x7dac,0x9700,0x56da,0x53ce,0x5468,
0x5b97,0x5c31,0x5dde,0x4fee,0x6101,0x62fe,0x6d32,0x79c0,
0x79cb,0x7d42,0x7e61,0x7fd2,0x81ed,0x821f,0x8490,0x8846,
0x8972,0x8b90,0x8e74,0x8f2f,0x9031,0x914b,0x916c,0x96c6,
0x919c,0x4ec0,0x4f4f,0x5145,0x5341,0x5f93,0x620e,0x67d4,
0x6c41,0x6e0b,0x7363,0x7e26,0x91cd,0x9283,0x53d4,0x5919,
0x5bbf,0x6dd1,0x795d,0x7e2e,0x7c9b,0x587e,0x719f,0x51fa,
0x8853,0x8ff0,0x4fca,0x5cfb,0x6625,0x77ac,0x7ae3,0x821c,
0x99ff,0x51c6,0x5faa,0x65ec,0x696f,0x6b89,0x6df3,0x6e96,
0x6f64,0x76fe,0x7d14,0x5de1,0x9075,0x9187,0x9806,0x51e6,
0x521d,0x6240,0x6691,0x66d9,0x6e1a,0x5eb6,0x7dd2,0x7f72,
0x66f8,0x85af,0x85f7,0x8af8,0x52a9,0x53d9,0x5973,0x5e8f,
0x5f90,0x6055,0x92e4,0x9664,0x50b7,0x511f,
0x52dd,0x5320,0x5347,0x53ec,0x54e8,0x5546,0x5531,0x5617,
0x5968,0x59be,0x5a3c,0x5bb5,0x5c06,0x5c0f,0x5c11,0x5c1a,
0x5e84,0x5e8a,0x5ee0,0x5f70,0x627f,0x6284,0x62db,0x638c,
0x6377,0x6607,0x660c,0x662d,0x6676,0x677e,0x68a2,0x6a1f,
0x6a35,0x6cbc,0x6d88,0x6e09,0x6e58,0x713c,0x7126,0x7167,
0x75c7,0x7701,0x785d,0x7901,0x7965,0x79f0,0x7ae0,0x7b11,
0x7ca7,0x7d39,0x8096,0x83d6,0x8523,0x8549,0x885d,0x88f3,
0x8a1f,0x8a3c,0x8a54,0x8a73,0x8c61,0x8cde,0x91ac,0x9266,
0x937e,0x9418,0x969c,0x9798,0x4e0a,0x4e08,0x4e1e,0x4e57,
0x5197,0x5270,0x57ce,0x5834,0x58cc,0x5b22,0x5e38,0x60c5,
0x64fe,0x6761,0x6756,0x6d44,0x72b6,0x7573,0x7a63,0x84b8,
0x8b72,0x91b8,0x9320,0x5631,0x57f4,0x98fe,
0x62ed,0x690d,0x6b96,0x71ed,0x7e54,0x8077,0x8272,0x89e6,
0x98df,0x8755,0x8fb1,0x5c3b,0x4f38,0x4fe1,0x4fb5,0x5507,
0x5a20,0x5bdd,0x5be9,0x5fc3,0x614e,0x632f,0x65b0,0x664b,
0x68ee,0x699b,0x6d78,0x6df1,0x7533,0x75b9,0x771f,0x795e,
0x79e6,0x7d33,0x81e3,0x82af,0x85aa,0x89aa,0x8a3a,0x8eab,
0x8f9b,0x9032,0x91dd,0x9707,0x4eba,0x4ec1,0x5203,0x5875,
0x58ec,0x5c0b,0x751a,0x5c3d,0x814e,0x8a0a,0x8fc5,0x9663,
0x9771,0x7b25,0x8acf,0x9808,0x9162,0x56f3,0x53a8,0x9017,
0x5439,0x5782,0x5e25,0x63a8,0x6c34,0x708a,0x7761,0x7c8b,
0x7fe0,0x8870,0x9042,0x9154,0x9310,0x9318,0x968f,0x745e,
0x9ac4,0x5d07,0x5d69,0x6570,0x67a2,0x8da8,0x96db,0x636e,
0x6749,0x6919,0x83c5,0x9817,0x96c0,0x88fe,
/* -- 40 -- */
0x6f84,0x647a,0x5bf8,0x4e16,0x702c,0x755d,0x662f,0x51c4,
0x5236,0x52e2,0x59d3,0x5f81,0x6027,0x6210,0x653f,0x6574,
0x661f,0x6674,0x68f2,0x6816,0x6b63,0x6e05,0x7272,0x751f,
0x76db,0x7cbe,0x8056,0x58f0,0x88fd,0x897f,0x8aa0,0x8a93,
0x8acb,0x901d,0x9192,0x9752,0x9759,0x6589,0x7a0e,0x8106,
0x96bb,0x5e2d,0x60dc,0x621a,0x65a5,0x6614,0x6790,0x77f3,
0x7a4d,0x7c4d,0x7e3e,0x810a,0x8cac,0x8d64,0x8de1,0x8e5f,
0x78a9,0x5207,0x62d9,0x63a5,0x6442,0x6298,0x8a2d,0x7a83,
0x7bc0,0x8aac,0x96ea,0x7d76,0x820c,0x8749,0x4ed9,0x5148,
0x5343,0x5360,0x5ba3,0x5c02,0x5c16,0x5ddd,0x6226,0x6247,
0x64b0,0x6813,0x6834,0x6cc9,0x6d45,0x6d17,0x67d3,0x6f5c,
0x714e,0x717d,0x65cb,0x7a7f,0x7bad,0x7dda,
0x7e4a,0x7fa8,0x817a,0x821b,0x8239,0x85a6,0x8a6e,0x8ce4,
0x8df5,0x9078,0x9077,0x92ad,0x9291,0x9583,0x9bae,0x524d,
0x5584,0x6f38,0x7136,0x5168,0x7985,0x7e55,0x81b3,0x7cce,
0x564c,0x5851,0x5ca8,0x63aa,0x66fe,0x66fd,0x695a,0x72d9,
0x758f,0x758e,0x790e,0x7956,0x79df,0x7c97,0x7d20,0x7d44,
0x8607,0x8a34,0x963b,0x9061,0x9f20,0x50e7,0x5275,0x53cc,
0x53e2,0x5009,0x55aa,0x58ee,0x594f,0x723d,0x5b8b,0x5c64,
0x531d,0x60e3,0x60f3,0x635c,0x6383,0x633f,0x6414,0x64cd,
0x65e9,0x66f9,0x5de3,0x69cd,0x69fd,0x6f15,0x71e5,0x4e89,
0x7626,0x76f8,0x7a93,0x7cdf,0x7dcf,0x7d9c,0x8061,0x8349,
0x8358,0x846c,0x84bc,0x85fb,0x88c5,0x8d70,0x9001,0x906d,
0x9397,0x971c,0x9a12,0x50cf,0x5897,0x618e,
0x81d3,0x8535,0x8d08,0x9020,0x4fc3,0x5074,0x5247,0x5373,
0x606f,0x6349,0x675f,0x6e2c,0x8db3,0x901f,0x4fd7,0x5c5e,
0x8cca,0x65cf,0x7d9a,0x5352,0x8896,0x5176,0x63c3,0x5b58,
0x5b6b,0x5c0a,0x640d,0x6751,0x905c,0x4ed6,0x591a,0x592a,
0x6c70,0x8a51,0x553e,0x5815,0x59a5,0x60f0,0x6253,0x67c1,
0x8235,0x6955,0x9640,0x99c4,0x9a28,0x4f53,0x5806,0x5bfe,
0x8010,0x5cb1,0x5e2f,0x5f85,0x6020,0x614b,0x6234,0x66ff,
0x6cf0,0x6ede,0x80ce,0x817f,0x82d4,0x888b,0x8cb8,0x9000,
0x902e,0x968a,0x9edb,0x9bdb,0x4ee3,0x53f0,0x5927,0x7b2c,
0x918d,0x984c,0x9df9,0x6edd,0x7027,0x5353,0x5544,0x5b85,
0x6258,0x629e,0x62d3,0x6ca2,0x6fef,0x7422,0x8a17,0x9438,
0x6fc1,0x8afe,0x8338,0x51e7,0x86f8,0x53ea,
0x53e9,0x4f46,0x9054,0x8fb0,0x596a,0x8131,0x5dfd,0x7aea,
0x8fbf,0x68da,0x8c37,0x72f8,0x9c48,0x6a3d,0x8ab0,0x4e39,
0x5358,0x5606,0x5766,0x62c5,0x63a2,0x65e6,0x6b4e,0x6de1,
0x6e5b,0x70ad,0x77ed,0x7aef,0x7baa,0x7dbb,0x803d,0x80c6,
0x86cb,0x8a95,0x935b,0x56e3,0x58c7,0x5f3e,0x65ad,0x6696,
0x6a80,0x6bb5,0x7537,0x8ac7,0x5024,0x77e5,0x5730,0x5f1b,
0x6065,0x667a,0x6c60,0x75f4,0x7a1a,0x7f6e,0x81f4,0x8718,
0x9045,0x99b3,0x7bc9,0x755c,0x7af9,0x7b51,0x84c4,0x9010,
0x79e9,0x7a92,0x8336,0x5ae1,0x7740,0x4e2d,0x4ef2,0x5b99,
0x5fe0,0x62bd,0x663c,0x67f1,0x6ce8,0x866b,0x8877,0x8a3b,
0x914e,0x92f3,0x99d0,0x6a17,0x7026,0x732a,0x82e7,0x8457,
0x8caf,0x4e01,0x5146,0x51cb,0x558b,0x5bf5,
/* -- 44 -- */
0x5e16,0x5e33,0x5e81,0x5f14,0x5f35,0x5f6b,0x5fb4,0x61f2,
0x6311,0x66a2,0x671d,0x6f6e,0x7252,0x753a,0x773a,0x8074,
0x8139,0x8178,0x8776,0x8abf,0x8adc,0x8d85,0x8df3,0x929a,
0x9577,0x9802,0x9ce5,0x52c5,0x6357,0x76f4,0x6715,0x6c88,
0x73cd,0x8cc3,0x93ae,0x9673,0x6d25,0x589c,0x690e,0x69cc,
0x8ffd,0x939a,0x75db,0x901a,0x585a,0x6802,0x6451,0x69fb,
0x4f43,0x6f2c,0x67d8,0x8fbb,0x8526,0x7db4,0x9354,0x693f,
0x6f70,0x576a,0x58fa,0x5b2c,0x7d2c,0x722a,0x540a,0x91e3,
0x9db4,0x4ead,0x4f4e,0x505c,0x5075,0x5243,0x8c9e,0x5448,
0x5824,0x5b9a,0x5e1d,0x5e95,0x5ead,0x5ef7,0x5f1f,0x608c,
0x62b5,0x633a,0x63d0,0x68af,0x6c40,0x7887,0x798e,0x7a0b,
0x7de0,0x8247,0x8a02,0x8ae6,0x8e44,0x9013,
0x90b8,0x912d,0x91d8,0x9f0e,0x6ce5,0x6458,0x64e2,0x6575,
0x6ef4,0x7684,0x7b1b,0x9069,0x93d1,0x6eba,0x54f2,0x5fb9,
0x64a4,0x8f4d,0x8fed,0x9244,0x5178,0x5861,0x5929,0x5c55,
0x5e97,0x6dfb,0x7e8f,0x751c,0x8cbc,0x8ee2,0x985a,0x70b9,
0x4f1d,0x6bbf,0x6fb1,0x7530,0x96fb,0x514e,0x5410,0x5835,
0x5857,0x59ac,0x5c60,0x5f92,0x6597,0x675c,0x6e21,0x767b,
0x83df,0x8ced,0x9014,0x90fd,0x934d,0x7825,0x792a,0x52aa,
0x5ea6,0x571f,0x5974,0x6012,0x5012,0x515a,0x51ac,0x51cd,
0x5200,0x5510,0x5854,0x5858,0x5957,0x5b95,0x5cf6,0x5d8b,
0x60bc,0x6295,0x642d,0x6771,0x6843,0x6aae,0x68df,0x76d7,
0x6dd8,0x6e6f,0x6fe4,0x706f,0x71c8,0x5f53,0x75d8,0x79b1,
0x7b49,0x7b54,0x7b52,0x7cd6,0x7d71,0x5230,
0x8463,0x8569,0x85e4,0x8a0e,0x8b04,0x8c46,0x8e0f,0x9003,
0x900f,0x9419,0x9676,0x982d,0x9a30,0x95d8,0x50cd,0x52d5,
0x540c,0x5802,0x5c0e,0x61a7,0x649e,0x6d1e,0x77b3,0x7ae5,
0x80f4,0x8404,0x9053,0x9285,0x5ce0,0x9d07,0x533f,0x5f97,
0x5fb3,0x7006,0x7279,0x7763,0x79bf,0x7be4,0x6bd2,0x72ec,
0x8aad,0x6803,0x6a61,0x51f8,0x7a81,0x6934,0x5c4a,0x9cf6,
0x82eb,0x5bc5,0x9149,0x701e,0x5678,0x5c6f,0x60c7,0x6566,
0x6c8c,0x8c5a,0x9041,0x9813,0x5451,0x66c7,0x920d,0x5948,
0x90a3,0x5185,0x4e4d,0x51ea,0x8599,0x8b0e,0x7058,0x637a,
0x934b,0x6962,0x99b4,0x7e04,0x7577,0x5357,0x6960,0x8edf,
0x96e3,0x6c5d,0x4e8c,0x5c3c,0x5f10,0x9087,0x5302,0x8cd1,
0x8089,0x8679,0x5eff,0x65e5,0x4e73,0x5165,
0x5982,0x5c3f,0x97ee,0x4efb,0x598a,0x5fcd,0x8a8d,0x6fe1,
0x79b0,0x7962,0x5be7,0x8471,0x732b,0x71b1,0x5e74,0x5ff5,
0x637b,0x649a,0x71c3,0x7c98,0x4e43,0x5efc,0x4e4b,0x57dc,
0x56ca,0x60a9,0x6fc3,0x7d0d,0x80fd,0x8133,0x81bf,0x8fb2,
0x8997,0x86a4,0x5df4,0x628a,0x64ad,0x8987,0x6777,0x6ce2,
0x6d3e,0x7436,0x7834,0x5a46,0x7f75,0x82ad,0x99ac,0x4ff3,
0x5ec3,0x62dd,0x6392,0x6557,0x676f,0x76c3,0x724c,0x80cc,
0x80ba,0x8f29,0x914d,0x500d,0x57f9,0x5a92,0x6885,0x6973,
0x7164,0x72fd,0x8cb7,0x58f2,0x8ce0,0x966a,0x9019,0x8805,
0x79e4,0x77e7,0x8429,0x4f2f,0x5265,0x535a,0x62cd,0x67cf,
0x6cca,0x767d,0x7b94,0x7c95,0x8236,0x8584,0x8feb,0x66dd,
0x6f20,0x7206,0x7e1b,0x83ab,0x99c1,0x9ea6,
/* -- 48 -- */
0x51fd,0x7bb1,0x7872,0x7bb8,0x8087,0x7b48,0x6ae8,0x5e61,
0x808c,0x7551,0x7560,0x516b,0x9262,0x6f51,0x767a,0x91b1,
0x9aea,0x4f10,0x7f70,0x629c,0x7b4f,0x95a5,0x9ce9,0x567a,
0x5859,0x86e4,0x96bc,0x4f34,0x5224,0x534a,0x53cd,0x53db,
0x5e06,0x642c,0x6591,0x677f,0x6c3e,0x6c4e,0x7248,0x72af,
0x73ed,0x7554,0x7e41,0x822c,0x85e9,0x8ca9,0x7bc4,0x91c6,
0x7169,0x9812,0x98ef,0x633d,0x6669,0x756a,0x76e4,0x78d0,
0x8543,0x86ee,0x532a,0x5351,0x5426,0x5983,0x5e87,0x5f7c,
0x60b2,0x6249,0x6279,0x62ab,0x6590,0x6bd4,0x6ccc,0x75b2,
0x76ae,0x7891,0x79d8,0x7dcb,0x7f77,0x80a5,0x88ab,0x8ab9,
0x8cbb,0x907f,0x975e,0x98db,0x6a0b,0x7c38,0x5099,0x5c3e,
0x5fae,0x6787,0x6bd8,0x7435,0x7709,0x7f8e,
0x9f3b,0x67ca,0x7a17,0x5339,0x758b,0x9aed,0x5f66,0x819d,
0x83f1,0x8098,0x5f3c,0x5fc5,0x7562,0x7b46,0x903c,0x6a9c,
0x59eb,0x5a9b,0x7d10,0x767e,0x8b2c,0x4ff5,0x5f6a,0x6a19,
0x6c37,0x6f02,0x74e2,0x7968,0x8868,0x8a55,0x8c79,0x5edf,
0x63cf,0x75c5,0x79d2,0x82d7,0x9328,0x92f2,0x849c,0x86ed,
0x9c2d,0x54c1,0x5f6c,0x658c,0x6d5c,0x7015,0x8ca7,0x8cd3,
0x983b,0x654f,0x74f6,0x4e0d,0x4ed8,0x57e0,0x592b,0x5a66,
0x5bcc,0x51a8,0x5e03,0x5e9c,0x6016,0x6276,0x6577,0x65a7,
0x666e,0x6d6e,0x7236,0x7b26,0x8150,0x819a,0x8299,0x8b5c,
0x8ca0,0x8ce6,0x8d74,0x961c,0x9644,0x4fae,0x64ab,0x6b66,
0x821e,0x8461,0x856a,0x90e8,0x5c01,0x6953,0x98a8,0x847a,
0x8557,0x4f0f,0x526f,0x5fa9,0x5e45,0x670d,
0x798f,0x8179,0x8907,0x8986,0x6df5,0x5f17,0x6255,0x6cb8,
0x4ecf,0x7269,0x9b92,0x5206,0x543b,0x5674,0x58b3,0x61a4,
0x626e,0x711a,0x596e,0x7c89,0x7cde,0x7d1b,0x96f0,0x6587,
0x805e,0x4e19,0x4f75,0x5175,0x5840,0x5e63,0x5e73,0x5f0a,
0x67c4,0x4e26,0x853d,0x9589,0x965b,0x7c73,0x9801,0x50fb,
0x58c1,0x7656,0x78a7,0x5225,0x77a5,0x8511,0x7b86,0x504f,
0x5909,0x7247,0x7bc7,0x7de8,0x8fba,0x8fd4,0x904d,0x4fbf,
0x52c9,0x5a29,0x5f01,0x97ad,0x4fdd,0x8217,0x92ea,0x5703,
0x6355,0x6b69,0x752b,0x88dc,0x8f14,0x7a42,0x52df,0x5893,
0x6155,0x620a,0x66ae,0x6bcd,0x7c3f,0x83e9,0x5023,0x4ff8,
0x5305,0x5446,0x5831,0x5949,0x5b9d,0x5cf0,0x5cef,0x5d29,
0x5e96,0x62b1,0x6367,0x653e,0x65b9,0x670b,
0x6cd5,0x6ce1,0x70f9,0x7832,0x7e2b,0x80de,0x82b3,0x840c,
0x84ec,0x8702,0x8912,0x8a2a,0x8c4a,0x90a6,0x92d2,0x98fd,
0x9cf3,0x9d6c,0x4e4f,0x4ea1,0x508d,0x5256,0x574a,0x59a8,
0x5e3d,0x5fd8,0x5fd9,0x623f,0x66b4,0x671b,0x67d0,0x68d2,
0x5192,0x7d21,0x80aa,0x81a8,0x8b00,0x8c8c,0x8cbf,0x927e,
0x9632,0x5420,0x9830,0x5317,0x50d5,0x535c,0x58a8,0x64b2,
0x6734,0x7267,0x7766,0x7a46,0x91e6,0x52c3,0x6ca1,0x6b86,
0x5800,0x5e4c,0x5954,0x672c,0x7ffb,0x51e1,0x76c6,0x6469,
0x78e8,0x9b54,0x9ebb,0x57cb,0x59b9,0x6627,0x679a,0x6bce,
0x54e9,0x69c7,0x5e55,0x819c,0x6795,0x9baa,0x67fe,0x9c52,
0x685d,0x4ea6,0x4fe3,0x53c8,0x62b9,0x672b,0x6cab,0x8fc4,
0x5118,0x7e6d,0x9ebf,0x4e07,0x6162,0x6e80,
/* -- 4c -- */
0x6f2b,0x8513,0x5473,0x672a,0x9b45,0x5df3,0x7b95,0x5cac,
0x5bc6,0x871c,0x6e4a,0x84d1,0x7a14,0x8108,0x5999,0x7c8d,
0x6c11,0x7720,0x52d9,0x5922,0x7121,0x725f,0x77db,0x9727,
0x9d61,0x690b,0x5a7f,0x5a18,0x51a5,0x540d,0x547d,0x660e,
0x76df,0x8ff7,0x9298,0x9cf4,0x59ea,0x725d,0x6ec5,0x514d,
0x68c9,0x7dbf,0x7dec,0x9762,0x9eb5,0x6478,0x6a21,0x8302,
0x5984,0x5b5f,0x6bdb,0x731b,0x76f2,0x7db2,0x8017,0x8499,
0x5132,0x6728,0x9ed9,0x76ee,0x6762,0x52ff,0x9905,0x5c24,
0x623b,0x7c7e,0x8cb0,0x554f,0x60b6,0x7d0b,0x9580,0x5301,
0x4e5f,0x51b6,0x591c,0x723a,0x8036,0x91ce,0x5f25,0x77e2,
0x5384,0x5f79,0x7d04,0x85ac,0x8a33,0x8e8d,0x9756,0x67f3,
0x85ea,0x9453,0x6109,0x6108,0x6cb9,0x7652,
0x8aed,0x8f38,0x552f,0x4f51,0x512a,0x52c7,0x53cb,0x5ba5,
0x5e7d,0x60a0,0x6182,0x63d6,0x6709,0x67da,0x6e67,0x6d8c,
0x7336,0x7337,0x7531,0x7950,0x88d5,0x8a98,0x904a,0x9091,
0x90f5,0x96c4,0x878d,0x5915,0x4e88,0x4f59,0x4e0e,0x8a89,
0x8f3f,0x9810,0x50ad,0x5e7c,0x5996,0x5bb9,0x5eb8,0x63da,
0x63fa,0x64c1,0x66dc,0x694a,0x69d8,0x6d0b,0x6eb6,0x7194,
0x7528,0x7aaf,0x7f8a,0x8000,0x8449,0x84c9,0x8981,0x8b21,
0x8e0a,0x9059,0x967d,0x990a,0x617e,0x6291,0x6b32,0x6c83,
0x6d74,0x7fcc,0x7ffc,0x6dc0,0x7f85,0x87ba,0x88f8,0x6765,
0x840a,0x983c,0x96f7,0x6d1b,0x7d61,0x843d,0x916a,0x4e71,
0x5375,0x5d50,0x6b04,0x6feb,0x85cd,0x862d,0x89a7,0x5229,
0x540f,0x5c65,0x674e,0x68a8,0x7406,0x7483,
0x75e2,0x88cf,0x88e1,0x91cc,0x96e2,0x9678,0x5f8b,0x7387,
0x7acb,0x844e,0x63a0,0x7565,0x5289,0x6d41,0x6e9c,0x7409,
0x7559,0x786b,0x7c92,0x9686,0x7adc,0x9f8d,0x4fb6,0x616e,
0x65c5,0x865c,0x4e86,0x4eae,0x50da,0x4e21,0x51cc,0x5bee,
0x6599,0x6881,0x6dbc,0x731f,0x7642,0x77ad,0x7a1c,0x7ce7,
0x826f,0x8ad2,0x907c,0x91cf,0x9675,0x9818,0x529b,0x7dd1,
0x502b,0x5398,0x6797,0x6dcb,0x71d0,0x7433,0x81e8,0x8f2a,
0x96a3,0x9c57,0x9e9f,0x7460,0x5841,0x6d99,0x7d2f,0x985e,
0x4ee4,0x4f36,0x4f8b,0x51b7,0x52b1,0x5dba,0x601c,0x73b2,
0x793c,0x82d3,0x9234,0x96b7,0x96f6,0x970a,0x9e97,0x9f62,
0x66a6,0x6b74,0x5217,0x52a3,0x70c8,0x88c2,0x5ec9,0x604b,
0x6190,0x6f23,0x7149,0x7c3e,0x7df4,0x806f,
0x84ee,0x9023,0x932c,0x5442,0x9b6f,0x6ad3,0x7089,0x8cc2,
0x8def,0x9732,0x52b4,0x5a41,0x5eca,0x5f04,0x6717,0x697c,
0x6994,0x6d6a,0x6f0f,0x7262,0x72fc,0x7c60,0x8001,0x807e,
0x881f,0x90ce,0x516d,0x9e93,0x7984,0x808b,0x9332,0x8ad6,
0x502d,0x548c,0x8a71,0x6b6a,0x8cc4,0x8107,0x60d1,0x67a0,
0x9df2,0x4e99,0x4e98,0x9c10,0x8a6b,0x85c1,0x8568,0x6900,
0x6e7e,0x7897,0x8155,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
/* -- 50 -- */
0x5f0c,0x4e10,0x4e15,0x4e2a,0x4e31,0x4e36,0x4e3c,0x4e3f,
0x4e42,0x4e56,0x4e58,0x4e82,0x4e85,0x8c6b,0x4e8a,0x8212,
0x5f0d,0x4e8e,0x4e9e,0x4e9f,0x4ea0,0x4ea2,0x4eb0,0x4eb3,
0x4eb6,0x4ece,0x4ecd,0x4ec4,0x4ec6,0x4ec2,0x4ed7,0x4ede,
0x4eed,0x4edf,0x4ef7,0x4f09,0x4f5a,0x4f30,0x4f5b,0x4f5d,
0x4f57,0x4f47,0x4f76,0x4f88,0x4f8f,0x4f98,0x4f7b,0x4f69,
0x4f70,0x4f91,0x4f6f,0x4f86,0x4f96,0x4fad,0x4fd4,0x4fdf,
0x4fce,0x4fd8,0x4fdb,0x4fd1,0x4fda,0x4fd0,0x4fe4,0x4fe5,
0x501a,0x5028,0x5014,0x502a,0x5025,0x5005,0x4f1c,0x4ff6,
0x5021,0x5029,0x502c,0x4ffe,0x4fef,0x5011,0x5006,0x5043,
0x5047,0x6703,0x5055,0x5050,0x5048,0x505a,0x5056,0x506c,
0x5078,0x5080,0x509a,0x5085,0x50b4,0x50b2,
0x50c9,0x50ca,0x50b3,0x50c2,0x50d6,0x50de,0x50e5,0x50ed,
0x50e3,0x50ee,0x50f9,0x50f5,0x5109,0x5101,0x5102,0x5116,
0x5115,0x5114,0x511a,0x5121,0x513a,0x5137,0x513c,0x513b,
0x513f,0x5140,0x5152,0x514c,0x5154,0x5162,0x7af8,0x5169,
0x516a,0x516e,0x5180,0x5182,0x56d8,0x518c,0x5189,0x518f,
0x5191,0x5193,0x5195,0x5196,0x51a4,0x51a6,0x51a2,0x51a9,
0x51aa,0x51ab,0x51b3,0x51b1,0x51b2,0x51b0,0x51b5,0x51bd,
0x51c5,0x51c9,0x51dc,0x51e0,0x8655,0x51e9,0x51ed,0x51f0,
0x51f5,0x51fe,0x5204,0x520b,0x5214,0x520e,0x5227,0x522a,
0x522e,0x5233,0x5239,0x524f,0x5244,0x524b,0x524c,0x525e,
0x5254,0x526a,0x5274,0x5269,0x5273,0x527f,0x527d,0x528d,
0x5294,0x5292,0x5271,0x5288,0x5291,0x8fa8,
0x8fa7,0x52ac,0x52ad,0x52bc,0x52b5,0x52c1,0x52cd,0x52d7,
0x52de,0x52e3,0x52e6,0x98ed,0x52e0,0x52f3,0x52f5,0x52f8,
0x52f9,0x5306,0x5308,0x7538,0x530d,0x5310,0x530f,0x5315,
0x531a,0x5323,0x532f,0x5331,0x5333,0x5338,0x5340,0x5346,
0x5345,0x4e17,0x5349,0x534d,0x51d6,0x535e,0x5369,0x536e,
0x5918,0x537b,0x5377,0x5382,0x5396,0x53a0,0x53a6,0x53a5,
0x53ae,0x53b0,0x53b6,0x53c3,0x7c12,0x96d9,0x53df,0x66fc,
0x71ee,0x53ee,0x53e8,0x53ed,0x53fa,0x5401,0x543d,0x5440,
0x542c,0x542d,0x543c,0x542e,0x5436,0x5429,0x541d,0x544e,
0x548f,0x5475,0x548e,0x545f,0x5471,0x5477,0x5470,0x5492,
0x547b,0x5480,0x5476,0x5484,0x5490,0x5486,0x54c7,0x54a2,
0x54b8,0x54a5,0x54ac,0x54c4,0x54c8,0x54a8,
0x54ab,0x54c2,0x54a4,0x54be,0x54bc,0x54d8,0x54e5,0x54e6,
0x550f,0x5514,0x54fd,0x54ee,0x54ed,0x54fa,0x54e2,0x5539,
0x5540,0x5563,0x554c,0x552e,0x555c,0x5545,0x5556,0x5557,
0x5538,0x5533,0x555d,0x5599,0x5580,0x54af,0x558a,0x559f,
0x557b,0x557e,0x5598,0x559e,0x55ae,0x557c,0x5583,0x55a9,
0x5587,0x55a8,0x55da,0x55c5,0x55df,0x55c4,0x55dc,0x55e4,
0x55d4,0x5614,0x55f7,0x5616,0x55fe,0x55fd,0x561b,0x55f9,
0x564e,0x5650,0x71df,0x5634,0x5636,0x5632,0x5638,0x566b,
0x5664,0x562f,0x566c,0x566a,0x5686,0x5680,0x568a,0x56a0,
0x5694,0x568f,0x56a5,0x56ae,0x56b6,0x56b4,0x56c2,0x56bc,
0x56c1,0x56c3,0x56c0,0x56c8,0x56ce,0x56d1,0x56d3,0x56d7,
0x56ee,0x56f9,0x5700,0x56ff,0x5704,0x5709,
/* -- 54 -- */
0x5708,0x570b,0x570d,0x5713,0x5718,0x5716,0x55c7,0x571c,
0x5726,0x5737,0x5738,0x574e,0x573b,0x5740,0x574f,0x5769,
0x57c0,0x5788,0x5761,0x577f,0x5789,0x5793,0x57a0,0x57b3,
0x57a4,0x57aa,0x57b0,0x57c3,0x57c6,0x57d4,0x57d2,0x57d3,
0x580a,0x57d6,0x57e3,0x580b,0x5819,0x581d,0x5872,0x5821,
0x5862,0x584b,0x5870,0x6bc0,0x5852,0x583d,0x5879,0x5885,
0x58b9,0x589f,0x58ab,0x58ba,0x58de,0x58bb,0x58b8,0x58ae,
0x58c5,0x58d3,0x58d1,0x58d7,0x58d9,0x58d8,0x58e5,0x58dc,
0x58e4,0x58df,0x58ef,0x58f7,0x58f9,0x58fb,0x58fc,0x58fd,
0x5902,0x590a,0x5910,0x591b,0x68a6,0x5925,0x592c,0x592d,
0x5932,0x5938,0x593e,0x7ad2,0x5955,0x5950,0x594e,0x595a,
0x5958,0x5962,0x5960,0x5967,0x596c,0x5969,
0x5978,0x5981,0x599d,0x4f5e,0x4fab,0x59a3,0x59b2,0x59c6,
0x59e8,0x59dc,0x598d,0x59d9,0x59da,0x5a25,0x5a1f,0x5a11,
0x5a1c,0x5a09,0x5a1a,0x5a40,0x5a6c,0x5a49,0x5a35,0x5a36,
0x5a62,0x5a6a,0x5a9a,0x5abc,0x5abe,0x5acb,0x5ac2,0x5abd,
0x5ae3,0x5ad7,0x5ae6,0x5ae9,0x5ad6,0x5afa,0x5afb,0x5b0c,
0x5b0b,0x5b16,0x5b32,0x5ad0,0x5b2a,0x5b36,0x5b3e,0x5b43,
0x5b45,0x5b40,0x5b51,0x5b55,0x5b5a,0x5b5b,0x5b65,0x5b69,
0x5b70,0x5b73,0x5b75,0x5b78,0x6588,0x5b7a,0x5b80,0x5b83,
0x5ba6,0x5bb8,0x5bc3,0x5bc7,0x5bc9,0x5bd4,0x5bd0,0x5be4,
0x5be6,0x5be2,0x5bde,0x5be5,0x5beb,0x5bf0,0x5bf6,0x5bf3,
0x5c05,0x5c07,0x5c08,0x5c0d,0x5c13,0x5c20,0x5c22,0x5c28,
0x5c38,0x5c39,0x5c41,0x5c46,0x5c4e,0x5c53,
0x5c50,0x5c4f,0x5b71,0x5c6c,0x5c6e,0x4e62,0x5c76,0x5c79,
0x5c8c,0x5c91,0x5c94,0x599b,0x5cab,0x5cbb,0x5cb6,0x5cbc,
0x5cb7,0x5cc5,0x5cbe,0x5cc7,0x5cd9,0x5ce9,0x5cfd,0x5cfa,
0x5ced,0x5d8c,0x5cea,0x5d0b,0x5d15,0x5d17,0x5d5c,0x5d1f,
0x5d1b,0x5d11,0x5d14,0x5d22,0x5d1a,0x5d19,0x5d18,0x5d4c,
0x5d52,0x5d4e,0x5d4b,0x5d6c,0x5d73,0x5d76,0x5d87,0x5d84,
0x5d82,0x5da2,0x5d9d,0x5dac,0x5dae,0x5dbd,0x5d90,0x5db7,
0x5dbc,0x5dc9,0x5dcd,0x5dd3,0x5dd2,0x5dd6,0x5ddb,0x5deb,
0x5df2,0x5df5,0x5e0b,0x5e1a,0x5e19,0x5e11,0x5e1b,0x5e36,
0x5e37,0x5e44,0x5e43,0x5e40,0x5e4e,0x5e57,0x5e54,0x5e5f,
0x5e62,0x5e64,0x5e47,0x5e75,0x5e76,0x5e7a,0x9ebc,0x5e7f,
0x5ea0,0x5ec1,0x5ec2,0x5ec8,0x5ed0,0x5ecf,
0x5ed6,0x5ee3,0x5edd,0x5eda,0x5edb,0x5ee2,0x5ee1,0x5ee8,
0x5ee9,0x5eec,0x5ef1,0x5ef3,0x5ef0,0x5ef4,0x5ef8,0x5efe,
0x5f03,0x5f09,0x5f5d,0x5f5c,0x5f0b,0x5f11,0x5f16,0x5f29,
0x5f2d,0x5f38,0x5f41,0x5f48,0x5f4c,0x5f4e,0x5f2f,0x5f51,
0x5f56,0x5f57,0x5f59,0x5f61,0x5f6d,0x5f73,0x5f77,0x5f83,
0x5f82,0x5f7f,0x5f8a,0x5f88,0x5f91,0x5f87,0x5f9e,0x5f99,
0x5f98,0x5fa0,0x5fa8,0x5fad,0x5fbc,0x5fd6,0x5ffb,0x5fe4,
0x5ff8,0x5ff1,0x5fdd,0x60b3,0x5fff,0x6021,0x6060,0x6019,
0x6010,0x6029,0x600e,0x6031,0x601b,0x6015,0x602b,0x6026,
0x600f,0x603a,0x605a,0x6041,0x606a,0x6077,0x605f,0x604a,
0x6046,0x604d,0x6063,0x6043,0x6064,0x6042,0x606c,0x606b,
0x6059,0x6081,0x608d,0x60e7,0x6083,0x609a,
/* -- 58 -- */
0x6084,0x609b,0x6096,0x6097,0x6092,0x60a7,0x608b,0x60e1,
0x60b8,0x60e0,0x60d3,0x60b4,0x5ff0,0x60bd,0x60c6,0x60b5,
0x60d8,0x614d,0x6115,0x6106,0x60f6,0x60f7,0x6100,0x60f4,
0x60fa,0x6103,0x6121,0x60fb,0x60f1,0x610d,0x610e,0x6147,
0x613e,0x6128,0x6127,0x614a,0x613f,0x613c,0x612c,0x6134,
0x613d,0x6142,0x6144,0x6173,0x6177,0x6158,0x6159,0x615a,
0x616b,0x6174,0x616f,0x6165,0x6171,0x615f,0x615d,0x6153,
0x6175,0x6199,0x6196,0x6187,0x61ac,0x6194,0x619a,0x618a,
0x6191,0x61ab,0x61ae,0x61cc,0x61ca,0x61c9,0x61f7,0x61c8,
0x61c3,0x61c6,0x61ba,0x61cb,0x7f79,0x61cd,0x61e6,0x61e3,
0x61f6,0x61fa,0x61f4,0x61ff,0x61fd,0x61fc,0x61fe,0x6200,
0x6208,0x6209,0x620d,0x620c,0x6214,0x621b,
0x621e,0x6221,0x622a,0x622e,0x6230,0x6232,0x6233,0x6241,
0x624e,0x625e,0x6263,0x625b,0x6260,0x6268,0x627c,0x6282,
0x6289,0x627e,0x6292,0x6293,0x6296,0x62d4,0x6283,0x6294,
0x62d7,0x62d1,0x62bb,0x62cf,0x62ff,0x62c6,0x64d4,0x62c8,
0x62dc,0x62cc,0x62ca,0x62c2,0x62c7,0x629b,0x62c9,0x630c,
0x62ee,0x62f1,0x6327,0x6302,0x6308,0x62ef,0x62f5,0x6350,
0x633e,0x634d,0x641c,0x634f,0x6396,0x638e,0x6380,0x63ab,
0x6376,0x63a3,0x638f,0x6389,0x639f,0x63b5,0x636b,0x6369,
0x63be,0x63e9,0x63c0,0x63c6,0x63e3,0x63c9,0x63d2,0x63f6,
0x63c4,0x6416,0x6434,0x6406,0x6413,0x6426,0x6436,0x651d,
0x6417,0x6428,0x640f,0x6467,0x646f,0x6476,0x644e,0x64b9,
0x6495,0x6493,0x64a5,0x64a9,0x6488,0x64bc,
0x64da,0x64d2,0x64c5,0x64c7,0x64bb,0x64d8,0x64c2,0x64f1,
0x64e7,0x8209,0x64e0,0x64e1,0x62ac,0x64e3,0x64ef,0x652c,
0x64f6,0x64f4,0x64f2,0x64fa,0x6500,0x64fd,0x6518,0x651c,
0x6522,0x6524,0x6523,0x652b,0x6534,0x6535,0x6537,0x6536,
0x6538,0x754b,0x6548,0x6556,0x6555,0x654d,0x6558,0x655e,
0x655d,0x6572,0x6578,0x6582,0x6583,0x8b8a,0x659b,0x659f,
0x65ab,0x65b7,0x65c3,0x65c6,0x65c1,0x65c4,0x65cc,0x65d2,
0x65db,0x65d9,0x65e0,0x65e1,0x65f1,0x6772,0x660a,0x6603,
0x65fb,0x6773,0x6635,0x6636,0x6634,0x661c,0x664f,0x6644,
0x6649,0x6641,0x665e,0x665d,0x6664,0x6667,0x6668,0x665f,
0x6662,0x6670,0x6683,0x6688,0x668e,0x6689,0x6684,0x6698,
0x669d,0x66c1,0x66b9,0x66c9,0x66be,0x66bc,
0x66c4,0x66b8,0x66d6,0x66da,0x66e0,0x663f,0x66e6,0x66e9,
0x66f0,0x66f5,0x66f7,0x670f,0x6716,0x671e,0x6726,0x6727,
0x9738,0x672e,0x673f,0x6736,0x6741,0x6738,0x6737,0x6746,
0x675e,0x6760,0x6759,0x6763,0x6764,0x6789,0x6770,0x67a9,
0x677c,0x676a,0x678c,0x678b,0x67a6,0x67a1,0x6785,0x67b7,
0x67ef,0x67b4,0x67ec,0x67b3,0x67e9,0x67b8,0x67e4,0x67de,
0x67dd,0x67e2,0x67ee,0x67b9,0x67ce,0x67c6,0x67e7,0x6867,
0x681e,0x6846,0x6829,0x6840,0x684d,0x6832,0x684e,0x68b3,
0x682b,0x6859,0x6863,0x6877,0x687f,0x689f,0x688f,0x68ad,
0x6894,0x689d,0x689b,0x6883,0x68bc,0x68b9,0x6874,0x68b5,
0x68a0,0x68ba,0x690f,0x688d,0x687e,0x6901,0x68ca,0x6908,
0x68d8,0x6922,0x6926,0x68e1,0x690c,0x68cd,
/* -- 5c -- */
0x68d4,0x68e7,0x68d5,0x6936,0x6912,0x6904,0x68d7,0x68e3,
0x6925,0x68f9,0x68e0,0x68ef,0x6928,0x692a,0x691a,0x6923,
0x6921,0x68c6,0x6979,0x6977,0x695c,0x6978,0x696b,0x6954,
0x697e,0x696e,0x6939,0x6974,0x693d,0x6959,0x6930,0x6961,
0x695e,0x695d,0x6981,0x696a,0x69b2,0x69ae,0x69d0,0x69bf,
0x69c1,0x69d3,0x69be,0x69ce,0x5be8,0x69ca,0x69dd,0x69bb,
0x69c3,0x69a7,0x6a2e,0x6991,0x69a0,0x699c,0x6995,0x69b4,
0x69de,0x69e8,0x6a02,0x6a1b,0x69ff,0x6b0a,0x69f9,0x69f2,
0x69e7,0x6a05,0x69b1,0x6a1e,0x69ed,0x6a14,0x69eb,0x6a0a,
0x6a12,0x6ac1,0x6a23,0x6a13,0x6a44,0x6a0c,0x6a72,0x6a36,
0x6a78,0x6a47,0x6a62,0x6a59,0x6a66,0x6a48,0x6a38,0x6a22,
0x6a90,0x6a8d,0x6aa0,0x6a84,0x6aa2,0x6aa3,
0x6a97,0x8617,0x6abb,0x6ac3,0x6ac2,0x6ab8,0x6ab3,0x6aac,
0x6ade,0x6ad1,0x6adf,0x6aaa,0x6ada,0x6aea,0x6afb,0x6b05,
0x8616,0x6afa,0x6b12,0x6b16,0x9b31,0x6b1f,0x6b38,0x6b37,
0x76dc,0x6b39,0x98ee,0x6b47,0x6b43,0x6b49,0x6b50,0x6b59,
0x6b54,0x6b5b,0x6b5f,0x6b61,0x6b78,0x6b79,0x6b7f,0x6b80,
0x6b84,0x6b83,0x6b8d,0x6b98,0x6b95,0x6b9e,0x6ba4,0x6baa,
0x6bab,0x6baf,0x6bb2,0x6bb1,0x6bb3,0x6bb7,0x6bbc,0x6bc6,
0x6bcb,0x6bd3,0x6bdf,0x6bec,0x6beb,0x6bf3,0x6bef,0x9ebe,
0x6c08,0x6c13,0x6c14,0x6c1b,0x6c24,0x6c23,0x6c5e,0x6c55,
0x6c62,0x6c6a,0x6c82,0x6c8d,0x6c9a,0x6c81,0x6c9b,0x6c7e,
0x6c68,0x6c73,0x6c92,0x6c90,0x6cc4,0x6cf1,0x6cd3,0x6cbd,
0x6cd7,0x6cc5,0x6cdd,0x6cae,0x6cb1,0x6cbe,
0x6cba,0x6cdb,0x6cef,0x6cd9,0x6cea,0x6d1f,0x884d,0x6d36,
0x6d2b,0x6d3d,0x6d38,0x6d19,0x6d35,0x6d33,0x6d12,0x6d0c,
0x6d63,0x6d93,0x6d64,0x6d5a,0x6d79,0x6d59,0x6d8e,0x6d95,
0x6d9b,0x6d85,0x6df9,0x6e15,0x6e0a,0x6db5,0x6dc7,0x6de6,
0x6db8,0x6dc6,0x6dec,0x6dde,0x6dcc,0x6de8,0x6dd2,0x6dc5,
0x6dfa,0x6dd9,0x6de4,0x6dd5,0x6dea,0x6dee,0x6e2d,0x6e6e,
0x6e2e,0x6e19,0x6e72,0x6e5f,0x6e3e,0x6e23,0x6e6b,0x6e2b,
0x6e76,0x6e4d,0x6e1f,0x6e43,0x6e3a,0x6e4e,0x6e24,0x6eff,
0x6e1d,0x6e38,0x6e82,0x6eaa,0x6e98,0x6ec9,0x6eb7,0x6ed3,
0x6ebd,0x6eaf,0x6ec4,0x6eb2,0x6ed4,0x6ed5,0x6e8f,0x6ea5,
0x6ec2,0x6e9f,0x6f41,0x6f11,0x6f45,0x6eec,0x6ef8,0x6efe,
0x6f3f,0x6ef2,0x6f31,0x6eef,0x6f32,0x6ecc,
0x6f3e,0x6f13,0x6ef7,0x6f86,0x6f7a,0x6f78,0x6f81,0x6f80,
0x6f6f,0x6f5b,0x6ff3,0x6f6d,0x6f82,0x6f7c,0x6f58,0x6f8e,
0x6f91,0x6fc2,0x6f66,0x6fb3,0x6fa3,0x6fa1,0x6fa4,0x6fb9,
0x6fc6,0x6faa,0x6fdf,0x6fd5,0x6fec,0x6fd4,0x6fd8,0x6ff1,
0x6fee,0x6fdb,0x7009,0x700b,0x6ffa,0x7011,0x7001,0x700f,
0x6ffe,0x701b,0x701a,0x6f74,0x701d,0x7018,0x701f,0x7030,
0x703e,0x7032,0x7051,0x7063,0x7099,0x7092,0x70af,0x70f1,
0x70ac,0x70b8,0x70b3,0x70ae,0x70df,0x70cb,0x70dd,0x70d9,
0x7109,0x70fd,0x711c,0x7119,0x7165,0x7199,0x7188,0x7166,
0x7162,0x714c,0x7156,0x716c,0x718f,0x71fb,0x7184,0x7195,
0x71a8,0x71ac,0x71d7,0x71b9,0x71be,0x71d2,0x71c9,0x71d4,
0x71ce,0x71e0,0x71ec,0x71e7,0x71f5,0x71fc,
/* -- 60 -- */
0x71f9,0x71ff,0x720d,0x7210,0x721b,0x7228,0x722d,0x722c,
0x7230,0x7232,0x723b,0x723c,0x723f,0x7240,0x7246,0x724b,
0x7258,0x7274,0x727e,0x7282,0x7281,0x7287,0x7292,0x7296,
0x72a2,0x72a7,0x72b9,0x72b2,0x72c3,0x72c6,0x72c4,0x72ce,
0x72d2,0x72e2,0x72e0,0x72e1,0x72f9,0x72f7,0x500f,0x7317,
0x730a,0x731c,0x7316,0x731d,0x7334,0x732f,0x7329,0x7325,
0x733e,0x734e,0x734f,0x9ed8,0x7357,0x736a,0x7368,0x7370,
0x7378,0x7375,0x737b,0x737a,0x73c8,0x73b3,0x73ce,0x73bb,
0x73c0,0x73e5,0x73ee,0x73de,0x74a2,0x7405,0x746f,0x7425,
0x73f8,0x7432,0x743a,0x7455,0x743f,0x745f,0x7459,0x7441,
0x745c,0x7469,0x7470,0x7463,0x746a,0x7464,0x747e,0x748b,
0x749e,0x74a7,0x74ca,0x74cf,0x74d4,0x73f1,
0x74e0,0x74e3,0x74e7,0x74e9,0x74ee,0x74f2,0x74f0,0x74f1,
0x74f8,0x74f7,0x7504,0x7503,0x7505,0x750c,0x750e,0x750d,
0x7515,0x7513,0x751e,0x7526,0x752c,0x753c,0x7544,0x754d,
0x754a,0x7549,0x755b,0x7546,0x755a,0x7569,0x7564,0x7567,
0x756b,0x756d,0x7578,0x7576,0x7586,0x7587,0x7574,0x758a,
0x7589,0x7582,0x7594,0x759a,0x759d,0x75a5,0x75a3,0x75c2,
0x75b3,0x75c3,0x75b5,0x75bd,0x75b8,0x75bc,0x75b1,0x75cd,
0x75ca,0x75d2,0x75d9,0x75e3,0x75de,0x75fe,0x75ff,0x75fc,
0x7601,0x75f0,0x75fa,0x75f2,0x75f3,0x760b,0x760d,0x7609,
0x761f,0x7627,0x7620,0x7621,0x7622,0x7624,0x7634,0x7630,
0x763b,0x7647,0x7648,0x7646,0x765c,0x7658,0x7661,0x7662,
0x7668,0x7669,0x766a,0x7667,0x766c,0x7670,
0x7672,0x7676,0x7678,0x767c,0x7680,0x7683,0x7688,0x768b,
0x768e,0x7696,0x7693,0x7699,0x769a,0x76b0,0x76b4,0x76b8,
0x76b9,0x76ba,0x76c2,0x76cd,0x76d6,0x76d2,0x76de,0x76e1,
0x76e5,0x76e7,0x76ea,0x862f,0x76fb,0x7708,0x7707,0x7704,
0x7729,0x7724,0x771e,0x7725,0x7726,0x771b,0x7737,0x7738,
0x7747,0x775a,0x7768,0x776b,0x775b,0x7765,0x777f,0x777e,
0x7779,0x778e,0x778b,0x7791,0x77a0,0x779e,0x77b0,0x77b6,
0x77b9,0x77bf,0x77bc,0x77bd,0x77bb,0x77c7,0x77cd,0x77d7,
0x77da,0x77dc,0x77e3,0x77ee,0x77fc,0x780c,0x7812,0x783f,
0x7820,0x783a,0x7845,0x788e,0x7874,0x7886,0x787c,0x789a,
0x788c,0x78a3,0x78b5,0x78aa,0x78af,0x78d1,0x78c6,0x78cb,
0x78d4,0x78be,0x78bc,0x78c5,0x78ca,0x78ec,
0x78e7,0x78da,0x78fd,0x78f4,0x7907,0x7912,0x7911,0x7919,
0x792c,0x792b,0x7940,0x7960,0x7957,0x795f,0x795a,0x7955,
0x7953,0x797a,0x797f,0x798a,0x799d,0x79a7,0x9f4b,0x79aa,
0x79ae,0x79b3,0x79b9,0x79ba,0x79c9,0x79d5,0x79e7,0x79ec,
0x79e1,0x79e3,0x7a08,0x7a0d,0x7a18,0x7a19,0x7a20,0x7a1f,
0x7980,0x7a31,0x7a3b,0x7a3e,0x7a37,0x7a43,0x7a57,0x7a49,
0x7a61,0x7a62,0x7a69,0x9f9d,0x7a70,0x7a79,0x7a7d,0x7a88,
0x7a97,0x7a95,0x7a98,0x7a96,0x7aa9,0x7ac3,0x7ab0,0x7ab6,
0x7ac5,0x7ac4,0x7abf,0x9083,0x7ac7,0x7aca,0x7acd,0x7acf,
0x7ad5,0x7ad3,0x7ad9,0x7ada,0x7add,0x7ae1,0x7ae2,0x7ae6,
0x7aed,0x7af0,0x7b02,0x7b0f,0x7b0a,0x7b06,0x7b33,0x7b18,
0x7b19,0x7b1e,0x7b35,0x7b28,0x7b36,0x7b50,
/* -- 64 -- */
0x7b7a,0x7b04,0x7b4d,0x7b0b,0x7b4c,0x7b45,0x7b75,0x7b65,
0x7b74,0x7b67,0x7b70,0x7b71,0x7b6c,0x7b6e,0x7b9d,0x7b98,
0x7b9f,0x7b8d,0x7b9c,0x7b9a,0x7b8b,0x7b92,0x7b8f,0x7b5d,
0x7b99,0x7bcb,0x7bc1,0x7bcc,0x7bcf,0x7bb4,0x7bc6,0x7bdd,
0x7be9,0x7c11,0x7c14,0x7be6,0x7be5,0x7bed,0x7c00,0x7c07,
0x7c13,0x7bf3,0x7bf7,0x7c17,0x7c0d,0x7bf6,0x7c23,0x7c27,
0x7c2a,0x7c1f,0x7c37,0x7c2b,0x7c3d,0x7c4c,0x7c43,0x7c54,
0x7c4f,0x7c40,0x7c50,0x7c58,0x7c5f,0x7c64,0x7c56,0x7c65,
0x7c6c,0x7c75,0x7c83,0x7c90,0x7ca4,0x7cad,0x7ca2,0x7cab,
0x7ca1,0x7ca8,0x7cb3,0x7cb2,0x7cb1,0x7cae,0x7cb9,0x7cbd,
0x7cc0,0x7cc5,0x7cc2,0x7cd8,0x7cd2,0x7cdc,0x7ce2,0x9b3b,
0x7cef,0x7cf2,0x7cf4,0x7cf6,0x7cfa,0x7d06,
0x7d02,0x7d1c,0x7d15,0x7d0a,0x7d45,0x7d4b,0x7d2e,0x7d32,
0x7d3f,0x7d35,0x7d46,0x7d73,0x7d56,0x7d4e,0x7d72,0x7d68,
0x7d6e,0x7d4f,0x7d63,0x7d93,0x7d89,0x7d5b,0x7d8f,0x7d7d,
0x7d9b,0x7dba,0x7dae,0x7da3,0x7db5,0x7dc7,0x7dbd,0x7dab,
0x7e3d,0x7da2,0x7daf,0x7ddc,0x7db8,0x7d9f,0x7db0,0x7dd8,
0x7ddd,0x7de4,0x7dde,0x7dfb,0x7df2,0x7de1,0x7e05,0x7e0a,
0x7e23,0x7e21,0x7e12,0x7e31,0x7e1f,0x7e09,0x7e0b,0x7e22,
0x7e46,0x7e66,0x7e3b,0x7e35,0x7e39,0x7e43,0x7e37,0x7e32,
0x7e3a,0x7e67,0x7e5d,0x7e56,0x7e5e,0x7e59,0x7e5a,0x7e79,
0x7e6a,0x7e69,0x7e7c,0x7e7b,0x7e83,0x7dd5,0x7e7d,0x8fae,
0x7e7f,0x7e88,0x7e89,0x7e8c,0x7e92,0x7e90,0x7e93,0x7e94,
0x7e96,0x7e8e,0x7e9b,0x7e9c,0x7f38,0x7f3a,
0x7f45,0x7f4c,0x7f4d,0x7f4e,0x7f50,0x7f51,0x7f55,0x7f54,
0x7f58,0x7f5f,0x7f60,0x7f68,0x7f69,0x7f67,0x7f78,0x7f82,
0x7f86,0x7f83,0x7f88,0x7f87,0x7f8c,0x7f94,0x7f9e,0x7f9d,
0x7f9a,0x7fa3,0x7faf,0x7fb2,0x7fb9,0x7fae,0x7fb6,0x7fb8,
0x8b71,0x7fc5,0x7fc6,0x7fca,0x7fd5,0x7fd4,0x7fe1,0x7fe6,
0x7fe9,0x7ff3,0x7ff9,0x98dc,0x8006,0x8004,0x800b,0x8012,
0x8018,0x8019,0x801c,0x8021,0x8028,0x803f,0x803b,0x804a,
0x8046,0x8052,0x8058,0x805a,0x805f,0x8062,0x8068,0x8073,
0x8072,0x8070,0x8076,0x8079,0x807d,0x807f,0x8084,0x8086,
0x8085,0x809b,0x8093,0x809a,0x80ad,0x5190,0x80ac,0x80db,
0x80e5,0x80d9,0x80dd,0x80c4,0x80da,0x80d6,0x8109,0x80ef,
0x80f1,0x811b,0x8129,0x8123,0x812f,0x814b,
0x968b,0x8146,0x813e,0x8153,0x8151,0x80fc,0x8171,0x816e,
0x8165,0x8166,0x8174,0x8183,0x8188,0x818a,0x8180,0x8182,
0x81a0,0x8195,0x81a4,0x81a3,0x815f,0x8193,0x81a9,0x81b0,
0x81b5,0x81be,0x81b8,0x81bd,0x81c0,0x81c2,0x81ba,0x81c9,
0x81cd,0x81d1,0x81d9,0x81d8,0x81c8,0x81da,0x81df,0x81e0,
0x81e7,0x81fa,0x81fb,0x81fe,0x8201,0x8202,0x8205,0x8207,
0x820a,0x820d,0x8210,0x8216,0x8229,0x822b,0x8238,0x8233,
0x8240,0x8259,0x8258,0x825d,0x825a,0x825f,0x8264,0x8262,
0x8268,0x826a,0x826b,0x822e,0x8271,0x8277,0x8278,0x827e,
0x828d,0x8292,0x82ab,0x829f,0x82bb,0x82ac,0x82e1,0x82e3,
0x82df,0x82d2,0x82f4,0x82f3,0x82fa,0x8393,0x8303,0x82fb,
0x82f9,0x82de,0x8306,0x82dc,0x8309,0x82d9,
/* -- 68 -- */
0x8335,0x8334,0x8316,0x8332,0x8331,0x8340,0x8339,0x8350,
0x8345,0x832f,0x832b,0x8317,0x8318,0x8385,0x839a,0x83aa,
0x839f,0x83a2,0x8396,0x8323,0x838e,0x8387,0x838a,0x837c,
0x83b5,0x8373,0x8375,0x83a0,0x8389,0x83a8,0x83f4,0x8413,
0x83eb,0x83ce,0x83fd,0x8403,0x83d8,0x840b,0x83c1,0x83f7,
0x8407,0x83e0,0x83f2,0x840d,0x8422,0x8420,0x83bd,0x8438,
0x8506,0x83fb,0x846d,0x842a,0x843c,0x855a,0x8484,0x8477,
0x846b,0x84ad,0x846e,0x8482,0x8469,0x8446,0x842c,0x846f,
0x8479,0x8435,0x84ca,0x8462,0x84b9,0x84bf,0x849f,0x84d9,
0x84cd,0x84bb,0x84da,0x84d0,0x84c1,0x84c6,0x84d6,0x84a1,
0x8521,0x84ff,0x84f4,0x8517,0x8518,0x852c,0x851f,0x8515,
0x8514,0x84fc,0x8540,0x8563,0x8558,0x8548,
0x8541,0x854a,0x854b,0x8555,0x8580,0x85a4,0x8588,0x8591,
0x858a,0x85a8,0x856d,0x8594,0x859b,0x85ae,0x8587,0x859c,
0x8577,0x857e,0x8590,0x85c9,0x85ba,0x85cf,0x85b9,0x85d0,
0x85d5,0x85dd,0x85e5,0x85dc,0x85f9,0x860a,0x8613,0x860b,
0x85fe,0x85fa,0x8606,0x8622,0x861a,0x8630,0x863f,0x864d,
0x4e55,0x8654,0x865f,0x8667,0x8671,0x8693,0x86a3,0x86a9,
0x86aa,0x868b,0x868c,0x86b6,0x86af,0x86c4,0x86c6,0x86b0,
0x86c9,0x86ce,0x86ab,0x86d4,0x86de,0x86e9,0x86ec,0x86df,
0x86db,0x86ef,0x8712,0x8706,0x8708,0x8700,0x8703,0x86fb,
0x8711,0x8709,0x870d,0x86f9,0x870a,0x8734,0x873f,0x8737,
0x873b,0x8725,0x8729,0x871a,0x8760,0x875f,0x8778,0x874c,
0x874e,0x8774,0x8757,0x8768,0x876e,0x8759,
0x8753,0x8763,0x876a,0x877f,0x87a2,0x879f,0x8782,0x87af,
0x87cb,0x87bd,0x87c0,0x87d0,0x96d6,0x87ab,0x87c4,0x87b3,
0x87c7,0x87c6,0x87bb,0x87ef,0x87f2,0x87e0,0x880f,0x880d,
0x87fe,0x87f6,0x87f7,0x880e,0x87d2,0x8811,0x8816,0x8815,
0x8822,0x8821,0x8831,0x8836,0x8839,0x8827,0x883b,0x8844,
0x8842,0x8852,0x8859,0x885e,0x8862,0x886b,0x8881,0x887e,
0x889e,0x8875,0x887d,0x88b5,0x8872,0x8882,0x8897,0x8892,
0x88ae,0x8899,0x88a2,0x888d,0x88a4,0x88b0,0x88bf,0x88b1,
0x88c3,0x88c4,0x88d4,0x88d8,0x88d9,0x88dd,0x88f9,0x8902,
0x88fc,0x88f4,0x88e8,0x88f2,0x8904,0x890c,0x890a,0x8913,
0x8943,0x891e,0x8925,0x892a,0x892b,0x8941,0x8944,0x893b,
0x8936,0x8938,0x894c,0x891d,0x8960,0x895e,
0x8966,0x8964,0x896d,0x896a,0x896f,0x8974,0x8977,0x897e,
0x8983,0x8988,0x898a,0x8993,0x8998,0x89a1,0x89a9,0x89a6,
0x89ac,0x89af,0x89b2,0x89ba,0x89bd,0x89bf,0x89c0,0x89da,
0x89dc,0x89dd,0x89e7,0x89f4,0x89f8,0x8a03,0x8a16,0x8a10,
0x8a0c,0x8a1b,0x8a1d,0x8a25,0x8a36,0x8a41,0x8a5b,0x8a52,
0x8a46,0x8a48,0x8a7c,0x8a6d,0x8a6c,0x8a62,0x8a85,0x8a82,
0x8a84,0x8aa8,0x8aa1,0x8a91,0x8aa5,0x8aa6,0x8a9a,0x8aa3,
0x8ac4,0x8acd,0x8ac2,0x8ada,0x8acc,0x8af3,0x8ae7,0x8ae4,
0x8af1,0x8b14,0x8ae0,0x8ae2,0x8af7,0x8ade,0x8adb,0x8b0c,
0x8b07,0x8b1a,0x8ae1,0x8b16,0x8b10,0x8b17,0x8b20,0x8b33,
0x97ab,0x8b26,0x8b2b,0x8b3e,0x8b28,0x8b41,0x8b4c,0x8b4f,
0x8b4e,0x8b49,0x8b56,0x8b5b,0x8b5a,0x8b6b,
/* -- 6c -- */
0x8b5f,0x8b6c,0x8b6f,0x8b74,0x8b7d,0x8b80,0x8b8c,0x8b8e,
0x8b92,0x8b93,0x8b96,0x8b99,0x8b9a,0x8c3a,0x8c41,0x8c3f,
0x8c48,0x8c4c,0x8c4e,0x8c50,0x8c55,0x8c62,0x8c6c,0x8c78,
0x8c7a,0x8c82,0x8c89,0x8c85,0x8c8a,0x8c8d,0x8c8e,0x8c94,
0x8c7c,0x8c98,0x621d,0x8cad,0x8caa,0x8cbd,0x8cb2,0x8cb3,
0x8cae,0x8cb6,0x8cc8,0x8cc1,0x8cce,0x8ce3,0x8cda,0x8cfd,
0x8cfa,0x8cfb,0x8d04,0x8d05,0x8d0a,0x8d07,0x8d0f,0x8d0d,
0x8d10,0x9f4e,0x8d13,0x8ccd,0x8d14,0x8d16,0x8d67,0x8d6d,
0x8d71,0x8d73,0x8d81,0x8d99,0x8dc2,0x8dbe,0x8dba,0x8dcf,
0x8dda,0x8dd6,0x8dcc,0x8ddb,0x8dcb,0x8dea,0x8deb,0x8ddf,
0x8de3,0x8dfc,0x8e08,0x8e09,0x8dff,0x8e1d,0x8e1e,0x8e10,
0x8e1f,0x8e42,0x8e35,0x8e30,0x8e34,0x8e4a,
0x8e47,0x8e49,0x8e4c,0x8e50,0x8e48,0x8e59,0x8e64,0x8e60,
0x8e2a,0x8e63,0x8e55,0x8e76,0x8e72,0x8e7c,0x8e81,0x8e87,
0x8e85,0x8e84,0x8e8b,0x8e8a,0x8e93,0x8e91,0x8e94,0x8e99,
0x8eaa,0x8ea1,0x8eac,0x8eb0,0x8ec6,0x8eb1,0x8ebe,0x8ec5,
0x8ec8,0x8ecb,0x8edb,0x8ee3,0x8efc,0x8efb,0x8eeb,0x8efe,
0x8f0a,0x8f05,0x8f15,0x8f12,0x8f19,0x8f13,0x8f1c,0x8f1f,
0x8f1b,0x8f0c,0x8f26,0x8f33,0x8f3b,0x8f39,0x8f45,0x8f42,
0x8f3e,0x8f4c,0x8f49,0x8f46,0x8f4e,0x8f57,0x8f5c,0x8f62,
0x8f63,0x8f64,0x8f9c,0x8f9f,0x8fa3,0x8fad,0x8faf,0x8fb7,
0x8fda,0x8fe5,0x8fe2,0x8fea,0x8fef,0x8fe9,0x8ff4,0x9005,
0x8ff9,0x8ffa,0x9011,0x9015,0x9021,0x900d,0x901e,0x9016,
0x900b,0x9027,0x9036,0x9035,0x9039,0x8ff8,
0x904f,0x9050,0x9051,0x9052,0x900e,0x9049,0x903e,0x9056,
0x9058,0x905e,0x9068,0x906f,0x9076,0x96a8,0x9072,0x9082,
0x907d,0x9081,0x9080,0x908a,0x9089,0x908f,0x90a8,0x90af,
0x90b1,0x90b5,0x90e2,0x90e4,0x6248,0x90db,0x9102,0x9112,
0x9119,0x9132,0x9130,0x914a,0x9156,0x9158,0x9163,0x9165,
0x9169,0x9173,0x9172,0x918b,0x9189,0x9182,0x91a2,0x91ab,
0x91af,0x91aa,0x91b5,0x91b4,0x91ba,0x91c0,0x91c1,0x91c9,
0x91cb,0x91d0,0x91d6,0x91df,0x91e1,0x91db,0x91fc,0x91f5,
0x91f6,0x921e,0x91ff,0x9214,0x922c,0x9215,0x9211,0x925e,
0x9257,0x9245,0x9249,0x9264,0x9248,0x9295,0x923f,0x924b,
0x9250,0x929c,0x9296,0x9293,0x929b,0x925a,0x92cf,0x92b9,
0x92b7,0x92e9,0x930f,0x92fa,0x9344,0x932e,
0x9319,0x9322,0x931a,0x9323,0x933a,0x9335,0x933b,0x935c,
0x9360,0x937c,0x936e,0x9356,0x93b0,0x93ac,0x93ad,0x9394,
0x93b9,0x93d6,0x93d7,0x93e8,0x93e5,0x93d8,0x93c3,0x93dd,
0x93d0,0x93c8,0x93e4,0x941a,0x9414,0x9413,0x9403,0x9407,
0x9410,0x9436,0x942b,0x9435,0x9421,0x943a,0x9441,0x9452,
0x9444,0x945b,0x9460,0x9462,0x945e,0x946a,0x9229,0x9470,
0x9475,0x9477,0x947d,0x945a,0x947c,0x947e,0x9481,0x947f,
0x9582,0x9587,0x958a,0x9594,0x9596,0x9598,0x9599,0x95a0,
0x95a8,0x95a7,0x95ad,0x95bc,0x95bb,0x95b9,0x95be,0x95ca,
0x6ff6,0x95c3,0x95cd,0x95cc,0x95d5,0x95d4,0x95d6,0x95dc,
0x95e1,0x95e5,0x95e2,0x9621,0x9628,0x962e,0x962f,0x9642,
0x964c,0x964f,0x964b,0x9677,0x965c,0x965e,
/* -- 70 -- */
0x965d,0x965f,0x9666,0x9672,0x966c,0x968d,0x9698,0x9695,
0x9697,0x96aa,0x96a7,0x96b1,0x96b2,0x96b0,0x96b4,0x96b6,
0x96b8,0x96b9,0x96ce,0x96cb,0x96c9,0x96cd,0x894d,0x96dc,
0x970d,0x96d5,0x96f9,0x9704,0x9706,0x9708,0x9713,0x970e,
0x9711,0x970f,0x9716,0x9719,0x9724,0x972a,0x9730,0x9739,
0x973d,0x973e,0x9744,0x9746,0x9748,0x9742,0x9749,0x975c,
0x9760,0x9764,0x9766,0x9768,0x52d2,0x976b,0x976d,0x9779,
0x9785,0x977c,0x9781,0x977a,0x9786,0x978b,0x978f,0x9790,
0x979c,0x97a8,0x97a6,0x97a3,0x97b3,0x97b4,0x97c3,0x97c6,
0x97c8,0x97cb,0x97dc,0x97ed,0x9f4f,0x97f2,0x7adf,0x97f6,
0x97f5,0x980f,0x980c,0x981a,0x9824,0x9821,0x9837,0x983d,
0x9846,0x984f,0x984b,0x986b,0x986f,0x9870,
0x9871,0x9874,0x9873,0x98aa,0x98af,0x98b1,0x98b6,0x98c4,
0x98c3,0x98c6,0x98e9,0x98eb,0x9903,0x9909,0x9912,0x9914,
0x9918,0x9921,0x991d,0x991e,0x9924,0x9920,0x992c,0x992e,
0x993d,0x993e,0x9942,0x9949,0x9945,0x9950,0x994b,0x9951,
0x9952,0x994c,0x9955,0x9997,0x9998,0x99a5,0x99ad,0x99ae,
0x99bc,0x99df,0x99db,0x99dd,0x99d8,0x99d1,0x99ed,0x99ee,
0x99f1,0x99f2,0x99fb,0x99f8,0x9a01,0x9a0f,0x9a05,0x99e2,
0x9a19,0x9a2b,0x9a37,0x9a45,0x9a42,0x9a40,0x9a43,0x9a3e,
0x9a55,0x9a4d,0x9a5b,0x9a57,0x9a5f,0x9a62,0x9a65,0x9a64,
0x9a69,0x9a6b,0x9a6a,0x9aad,0x9ab0,0x9abc,0x9ac0,0x9acf,
0x9ad1,0x9ad3,0x9ad4,0x9ade,0x9adf,0x9ae2,0x9ae3,0x9ae6,
0x9aef,0x9aeb,0x9aee,0x9af4,0x9af1,0x9af7,
0x9afb,0x9b06,0x9b18,0x9b1a,0x9b1f,0x9b22,0x9b23,0x9b25,
0x9b27,0x9b28,0x9b29,0x9b2a,0x9b2e,0x9b2f,0x9b32,0x9b44,
0x9b43,0x9b4f,0x9b4d,0x9b4e,0x9b51,0x9b58,0x9b74,0x9b93,
0x9b83,0x9b91,0x9b96,0x9b97,0x9b9f,0x9ba0,0x9ba8,0x9bb4,
0x9bc0,0x9bca,0x9bb9,0x9bc6,0x9bcf,0x9bd1,0x9bd2,0x9be3,
0x9be2,0x9be4,0x9bd4,0x9be1,0x9bf5,0x9bf2,0x9bf1,0x9bf0,
0x9c15,0x9c14,0x9c09,0x9c13,0x9c0c,0x9c06,0x9c08,0x9c12,
0x9c0a,0x9c04,0x9c2e,0x9c1b,0x9c25,0x9c24,0x9c21,0x9c30,
0x9c47,0x9c32,0x9c46,0x9c3e,0x9c5a,0x9c60,0x9c67,0x9c76,
0x9c78,0x9ce7,0x9cec,0x9cf0,0x9d09,0x9d08,0x9ceb,0x9d03,
0x9d06,0x9d2a,0x9d26,0x9d2c,0x9d23,0x9d1f,0x9d44,0x9d15,
0x9d12,0x9d41,0x9d3f,0x9d3e,0x9d46,0x9d48,
0x9d5d,0x9d5e,0x9d64,0x9d51,0x9d50,0x9d59,0x9d72,0x9d89,
0x9d87,0x9dab,0x9d6f,0x9d7a,0x9d9a,0x9da4,0x9da9,0x9db2,
0x9dc4,0x9dc1,0x9dbb,0x9db8,0x9dba,0x9dc6,0x9dcf,0x9dc2,
0x9dd9,0x9dd3,0x9df8,0x9de6,0x9ded,0x9def,0x9dfd,0x9e1a,
0x9e1b,0x9e1e,0x9e75,0x9e79,0x9e7d,0x9e81,0x9e88,0x9e8b,
0x9e8c,0x9e92,0x9e95,0x9e91,0x9e9d,0x9ea5,0x9ea9,0x9eb8,
0x9eaa,0x9ead,0x9761,0x9ecc,0x9ece,0x9ecf,0x9ed0,0x9ed4,
0x9edc,0x9ede,0x9edd,0x9ee0,0x9ee5,0x9ee8,0x9eef,0x9ef4,
0x9ef6,0x9ef7,0x9ef9,0x9efb,0x9efc,0x9efd,0x9f07,0x9f08,
0x76b7,0x9f15,0x9f21,0x9f2c,0x9f3e,0x9f4a,0x9f52,0x9f54,
0x9f63,0x9f5f,0x9f60,0x9f61,0x9f66,0x9f67,0x9f6c,0x9f6a,
0x9f77,0x9f72,0x9f76,0x9f95,0x9f9c,0x9fa0,
/* -- 74 -- */
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x7e8a,0x891c,0x9348,0x9288,0x84dc,0x4fc9,0x70bb,0x6631,
0x68c8,0x92f9,0x66fb,0x5f45,0x4e28,0x4ee1,0x4efc,0x4f00,
0x4f03,0x4f39,0x4f56,0x4f92,0x4f8a,0x4f9a,0x4f94,0x4fcd,
0x5040,0x5022,0x4fff,0x501e,0x5046,0x5070,0x5042,0x5094,
0x50f4,0x50d8,0x514a,0x5164,0x519d,0x51be,0x51ec,0x5215,
0x529c,0x52a6,0x52c0,0x52db,0x5300,0x5307,0x5324,0x5372,
0x5393,0x53b2,0x53dd,0xfa0e,0x549c,0x548a,0x54a9,0x54ff,
0x5586,0x5759,0x5765,0x57ac,0x57c8,0x57c7,0xfa0f,0xfa10,
0x589e,0x58b2,0x590b,0x5953,0x595b,0x595d,0x5963,0x59a4,
0x59ba,0x5b56,0x5bc0,0x752f,0x5bd8,0x5bec,0x5c1e,0x5ca6,
0x5cba,0x5cf5,0x5d27,0x5d53,0xfa11,0x5d42,0x5d6d,0x5db8,
0x5db9,0x5dd0,0x5f21,0x5f34,0x5f67,0x5fb7,
0x5fde,0x605d,0x6085,0x608a,0x60de,0x60d5,0x6120,0x60f2,
0x6111,0x6137,0x6130,0x6198,0x6213,0x62a6,0x63f5,0x6460,
0x649d,0x64ce,0x654e,0x6600,0x6615,0x663b,0x6609,0x662e,
0x661e,0x6624,0x6665,0x6657,0x6659,0xfa12,0x6673,0x6699,
0x66a0,0x66b2,0x66bf,0x66fa,0x670e,0xf929,0x6766,0x67bb,
0x6852,0x67c0,0x6801,0x6844,0x68cf,0xfa13,0x6968,0xfa14,
0x6998,0x69e2,0x6a30,0x6a6b,0x6a46,0x6a73,0x6a7e,0x6ae2,
0x6ae4,0x6bd6,0x6c3f,0x6c5c,0x6c86,0x6c6f,0x6cda,0x6d04,
0x6d87,0x6d6f,0x6d96,0x6dac,0x6dcf,0x6df8,0x6df2,0x6dfc,
0x6e39,0x6e5c,0x6e27,0x6e3c,0x6ebf,0x6f88,0x6fb5,0x6ff5,
0x7005,0x7007,0x7028,0x7085,0x70ab,0x710f,0x7104,0x715c,
0x7146,0x7147,0xfa15,0x71c1,0x71fe,0x72b1,
0x72be,0x7324,0xfa16,0x7377,0x73bd,0x73c9,0x73d6,0x73e3,
0x73d2,0x7407,0x73f5,0x7426,0x742a,0x7429,0x742e,0x7462,
0x7489,0x749f,0x7501,0x756f,0x7682,0x769c,0x769e,0x769b,
0x76a6,0xfa17,0x7746,0x52af,0x7821,0x784e,0x7864,0x787a,
0x7930,0xfa18,0xfa19,0xfa1a,0x7994,0xfa1b,0x799b,0x7ad1,
0x7ae7,0xfa1c,0x7aeb,0x7b9e,0xfa1d,0x7d48,0x7d5c,0x7db7,
0x7da0,0x7dd6,0x7e52,0x7f47,0x7fa1,0xfa1e,0x8301,0x8362,
0x837f,0x83c7,0x83f6,0x8448,0x84b4,0x8553,0x8559,0x856b,
0xfa1f,0x85b0,0xfa20,0xfa21,0x8807,0x88f5,0x8a12,0x8a37,
0x8a79,0x8aa7,0x8abe,0x8adf,0xfa22,0x8af6,0x8b53,0x8b7f,
0x8cf0,0x8cf4,0x8d12,0x8d76,0xfa23,0x8ecf,0xfa24,0xfa25,
0x9067,0x90de,0xfa26,0x9115,0x9127,0x91da,
0x91d7,0x91de,0x91ed,0x91ee,0x91e4,0x91e5,0x9206,0x9210,
0x920a,0x923a,0x9240,0x923c,0x924e,0x9259,0x9251,0x9239,
0x9267,0x92a7,0x9277,0x9278,0x92e7,0x92d7,0x92d9,0x92d0,
0xfa27,0x92d5,0x92e0,0x92d3,0x9325,0x9321,0x92fb,0xfa28,
0x931e,0x92ff,0x931d,0x9302,0x9370,0x9357,0x93a4,0x93c6,
0x93de,0x93f8,0x9431,0x9445,0x9448,0x9592,0xf9dc,0xfa29,
0x969d,0x96af,0x9733,0x973b,0x9743,0x974d,0x974f,0x9751,
0x9755,0x9857,0x9865,0xfa2a,0xfa2b,0x9927,0xfa2c,0x999e,
0x9a4e,0x9ad9,0x9adc,0x9b75,0x9b72,0x9b8f,0x9bb1,0x9bbb,
0x9c00,0x9d70,0x9d6b,0xfa2d,0x9e19,0x9ed1,0x0000,0x0000,
0x2170,0x2171,0x2172,0x2173,0x2174,0x2175,0x2176,0x2177,
0x2178,0x2179,0xffe2,0xffe4,0xff07,0xff02,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0
};
#endif

#if defined(OUTPUT_DYNAMIC_TABLE) || !defined(DYNAMIC_LOADING) || defined(SWIG_EXT)
skf_ucode uni_t_x213_1[ISOMB_CODE_END] = {
0x3000,0x3001,0x3002,0xff0c,0xff0e,0x30fb,0xff1a,0xff1b,
0xff1f,0xff01,0x309b,0x309c,0x00b4,0xff40,0x00a8,0xff3e,
0xffe3,0xff3f,0x30fd,0x30fe,0x309d,0x309e,0x3003,0x4edd,
0x3005,0x3006,0x3007,0x30fc,0x2015,0x2010,0xff0f,0xff3c,
0x301c,0x2016,0xff5c,0x2026,0x2025,0x2018,0x2019,0x201c,
0x201d,0xff08,0xff09,0x3014,0x3015,0xff3b,0xff3d,0xff5b,
0xff5d,0x3008,0x3009,0x300a,0x300b,0x300c,0x300d,0x300e,
0x300f,0x3010,0x3011,0xff0b,0x2212,0x00b1,0x00d7,0x00f7,
0xff1d,0x2260,0xff1c,0xff1e,0x2266,0x2267,0x221e,0x2234,
0x2642,0x2640,0x00b0,0x2032,0x2033,0x2103,0xffe5,0xff04,
0x00a2,0x00a3,0xff05,0xff03,0xff06,0xff0a,0xff20,0x00a7,
0x2606,0x2605,0x25cb,0x25cf,0x25ce,0x25c7,
       0x25c6,0x25a1,0x25a0,0x25b3,0x25b2,0x25bd,0x25bc,
0x203b,0x3012,0x2192,0x2190,0x2191,0x2193,0x3013,0xff07,
0xff02,0xff0d,0xff5e,0x3033,0x3034,0x3035,0x303b,0x303c,
0x30ff,0x309f,0x2208,0x220b,0x2286,0x2287,0x2282,0x2283,
0x222a,0x2229,0x2284,0x2285,0x228a,0x228b,0x2209,0x2205,
0x2305,0x2306,0x2227,0x2228,0x00ac,0x21d2,0x21d4,0x2200,
0x2203,0x2295,0x2296,0x2297,0x2225,0x2226,0x2985,0x2986,
0x3018,0x3019,0x3016,0x3017,0x2220,0x22a5,0x2312,0x2202,
0x2207,0x2261,0x2252,0x226a,0x226b,0x221a,0x223d,0x221d,
0x2235,0x222b,0x222c,0x2262,0x2243,0x2245,0x2248,0x2276,
0x2277,0x2194,0x212b,0x2030,0x266f,0x266d,0x266a,0x2020,
0x2021,0x00b6,0x266e,0x266b,0x266c,0x2669,0x25ef,
       0x25b7,0x25b6,0x25c1,0x25c0,0x2197,0x2198,0x2196,
0x2199,0x21c4,0x21e8,0x21e6,0x21e7,0x21e9,0x2934,0x2935,
0xff10,0xff11,0xff12,0xff13,0xff14,0xff15,0xff16,0xff17,
0xff18,0xff19,0x2a00,0x25c9,0x303d,0xfe46,0xfe45,0x25e6,
0x2022,0xff21,0xff22,0xff23,0xff24,0xff25,0xff26,0xff27,
0xff28,0xff29,0xff2a,0xff2b,0xff2c,0xff2d,0xff2e,0xff2f,
0xff30,0xff31,0xff32,0xff33,0xff34,0xff35,0xff36,0xff37,
0xff38,0xff39,0xff3a,0x2213,0x2135,0x210f,0x33cb,0x2113,
0x2127,0xff41,0xff42,0xff43,0xff44,0xff45,0xff46,0xff47,
0xff48,0xff49,0xff4a,0xff4b,0xff4c,0xff4d,0xff4e,0xff4f,
0xff50,0xff51,0xff52,0xff53,0xff54,0xff55,0xff56,0xff57,
0xff58,0xff59,0xff5a,0x30a0,0x2013,0x3039,0x303a,
/* 2400 */
0x3041,0x3042,0x3043,0x3044,0x3045,0x3046,0x3047,0x3048,
0x3049,0x304a,0x304b,0x304c,0x304d,0x304e,0x304f,0x3050,
0x3051,0x3052,0x3053,0x3054,0x3055,0x3056,0x3057,0x3058,
0x3059,0x305a,0x305b,0x305c,0x305d,0x305e,0x305f,0x3060,
0x3061,0x3062,0x3063,0x3064,0x3065,0x3066,0x3067,0x3068,
0x3069,0x306a,0x306b,0x306c,0x306d,0x306e,0x306f,0x3070,
0x3071,0x3072,0x3073,0x3074,0x3075,0x3076,0x3077,0x3078,
0x3079,0x307a,0x307b,0x307c,0x307d,0x307e,0x307f,0x3080,
0x3081,0x3082,0x3083,0x3084,0x3085,0x3086,0x3087,0x3088,
0x3089,0x308a,0x308b,0x308c,0x308d,0x308e,0x308f,0x3090,
0x3091,0x3092,0x3093,0x3094,0x3095,0x3096,0xd801,0xd802,
0xd803,0xd804,0xd805,0xd806,0xd810,0xd811,
/* 2500 */
0x30a1,0x30a2,0x30a3,0x30a4,0x30a5,0x30a6,0x30a7,0x30a8,
0x30a9,0x30aa,0x30ab,0x30ac,0x30ad,0x30ae,0x30af,0x30b0,
0x30b1,0x30b2,0x30b3,0x30b4,0x30b5,0x30b6,0x30b7,0x30b8,
0x30b9,0x30ba,0x30bb,0x30bc,0x30bd,0x30be,0x30bf,0x30c0,
0x30c1,0x30c2,0x30c3,0x30c4,0x30c5,0x30c6,0x30c7,0x30c8,
0x30c9,0x30ca,0x30cb,0x30cc,0x30cd,0x30ce,0x30cf,0x30d0,
0x30d1,0x30d2,0x30d3,0x30d4,0x30d5,0x30d6,0x30d7,0x30d8,
0x30d9,0x30da,0x30db,0x30dc,0x30dd,0x30de,0x30df,0x30e0,
0x30e1,0x30e2,0x30e3,0x30e4,0x30e5,0x30e6,0x30e7,0x30e8,
0x30e9,0x30ea,0x30eb,0x30ec,0x30ed,0x30ee,0x30ef,0x30f0,
0x30f1,0x30f2,0x30f3,0x30f4,0x30f5,0x30f6,0xd808,0xd809,
0xd80a,0xd80b,0xd80c,0xd80d,0xd80e,0xd80f,
/* 2600 */
0x0391,0x0392,0x0393,0x0394,0x0395,0x0396,0x0397,0x0398,
0x0399,0x039a,0x039b,0x039c,0x039d,0x039e,0x039f,0x03a0,
0x03a1,0x03a3,0x03a4,0x03a5,0x03a6,0x03a7,0x03a8,0x03a9,
0x2664,0x2660,0x2662,0x2666,0x2661,0x2665,0x2667,0x2663,
0x03b1,0x03b2,0x03b3,0x03b4,0x03b5,0x03b6,0x03b7,0x03b8,
0x03b9,0x03ba,0x03bb,0x03bc,0x03bd,0x03be,0x03bf,0x03c0,
0x03c1,0x03c3,0x03c4,0x03c5,0x03c6,0x03c7,0x03c8,0x03c9,
0x03c2,0x24f5,0x24f6,0x24f7,0x24f8,0x24f9,0x24fa,0x24fb,
0x24fc,0x24fd,0x24fe,0x2616,0x2617,0x3020,0x260e,0x2600,
0x2601,0x2602,0x2603,0x2668,0x25b1,0x31f0,0x31f1,0x31f2,
0x31f3,0x31f4,0x31f5,0x31f6,0x31f7,0x31f8,0x31f9,0xd807,
0x31fa,0x31fb,0x31fc,0x31fd,0x31fe,0x31ff,
0x0410,0x0411,0x0412,0x0413,0x0414,0x0415,0x0401,0x0416,
0x0417,0x0418,0x0419,0x041a,0x041b,0x041c,0x041d,0x041e,
0x041f,0x0420,0x0421,0x0422,0x0423,0x0424,0x0425,0x0426,
0x0427,0x0428,0x0429,0x042a,0x042b,0x042c,0x042d,0x042e,
0x042f,0x23be,0x23bf,0x23c0,0x23c1,0x23c2,0x23c3,0x23c4,
0x23c5,0x23c6,0x23c7,0x23c8,0x23c9,0x23ca,0x23cb,0x23cc,
0x0430,0x0431,0x0432,0x0433,0x0434,0x0435,0x0451,0x0436,
0x0437,0x0438,0x0439,0x043a,0x043b,0x043c,0x043d,0x043e,
0x043f,0x0440,0x0441,0x0442,0x0443,0x0444,0x0445,0x0446,
0x0447,0x0448,0x0449,0x044a,0x044b,0x044c,0x044d,0x044e,
0x044f,0x30f7,0x30f8,0x30f9,0x30fa,0x22da,0x22db,0x2153,
0x2154,0x2155,0x2713,0x2318,0x2423,0x23ce,
/* 2800 */
       0x2500,0x2502,0x250c,0x2510,0x2518,0x2514,0x251c,
0x252c,0x2524,0x2534,0x253c,0x2501,0x2503,0x250f,0x2513,
0x251b,0x2517,0x2523,0x2533,0x252b,0x253b,0x254b,0x2520,
0x252f,0x2528,0x2537,0x253f,0x251d,0x2530,0x2525,0x2538,
0x2542,0x3251,0x3252,0x3253,0x3254,0x3255,0x3256,0x3257,
0x3258,0x3259,0x325a,0x325b,0x325c,0x325d,0x325e,0x325f,
0x32b1,0x32b2,0x32b3,0x32b4,0x32b5,0x32b6,0x32b7,0x32b8,
0x32b9,0x32ba,0x32bb,0x32bc,0x32bd,0x32be,0x32bf,0xd815,
0xd816,0xd817,0xd822,0xd823,0xd824,0xd825,0xd826,0x25d0,
0x25d1,0x25d2,0x25d3,0x203c,0x2047,0x2048,0x2049,0x01cd,
0x01ce,0x01d0,0x1e3e,0x1e3f,0x01f8,0x01f9,0x01d1,0x01d2,
0x01d4,0x01d6,0x01d8,0x01da,0x01dc,0xd812,0xd813,
/* 2900 */
       0x20ac,0x00a0,0x00a1,0x00a4,0x00a6,0x00a9,0x00aa,
0x00ab,0x00ad,0x00ae,0x00af,0x00b2,0x00b3,0x00b7,0x00b8,
0x00b9,0x00ba,0x00bb,0x00bc,0x00bd,0x00be,0x00bf,0x00c0,
0x00c1,0x00c2,0x00c3,0x00c4,0x00c5,0x00c6,0x00c7,0x00c8,
0x00c9,0x00ca,0x00cb,0x00cc,0x00cd,0x00ce,0x00cf,0x00d0,
0x00d1,0x00d2,0x00d3,0x00d4,0x00d5,0x00d6,0x00d8,0x00d9,
0x00da,0x00db,0x00dc,0x00dd,0x00de,0x00df,0x00e0,0x00e1,
0x00e2,0x00e3,0x00e4,0x00e5,0x00e6,0x00e7,0x00e8,0x00e9,
0x00ea,0x00eb,0x00ec,0x00ed,0x00ee,0x00ef,0x00f0,0x00f1,
0x00f2,0x00f3,0x00f4,0x00f5,0x00f6,0x00f8,0x00f9,0x00fa,
0x00fb,0x00fc,0x00fd,0x00fe,0x00ff,0x0100,0x012a,0x016a,
0x0112,0x014c,0x0101,0x012b,0x016b,0x0113,0x014d,
       0x0104,0x02d8,0x0141,0x013d,0x015a,0x0160,0x015e,
0x0164,0x0179,0x017d,0x017b,0x0105,0x02db,0x0142,0x013e,
0x015b,0x02c7,0x0161,0x015f,0x0165,0x017a,0x02dd,0x017e,
0x017c,0x0154,0x0102,0x0139,0x0106,0x010c,0x0118,0x011a,
0x010e,0x0143,0x0147,0x0150,0x0158,0x016e,0x0170,0x0162,
0x0155,0x0103,0x013a,0x0107,0x010d,0x0119,0x011b,0x010f,
0x0111,0x0144,0x0148,0x0151,0x0159,0x016f,0x0171,0x0163,
0x02d9,0x0108,0x011c,0x0124,0x0134,0x015c,0x016c,0x0109,
0x011d,0x0125,0x0135,0x015d,0x016d,0x0271,0x028b,0x027e,
0x0283,0x0292,0x026c,0x026e,0x0279,0x0288,0x0256,0x0273,
0x027d,0x0282,0x0290,0x027b,0x026d,0x025f,0x0272,0x029d,
0x028e,0x0261,0x014b,0x0270,0x0281,0x0127,0x0295,
       0x0294,0x0266,0x0298,0x01c2,0x0253,0x0257,0x0284,
0x0260,0x0193,0x0153,0x0152,0x0268,0x0289,0x0258,0x0275,
0x0259,0x025c,0x025e,0x0250,0x026f,0x028a,0x0264,0x028c,
0x0254,0x0251,0x0252,0x028d,0x0265,0x02a2,0x02a1,0x0255,
0x0291,0x027a,0x0267,0x025a,0xd814,0x01fd,0x1f70,0x1f71,
0xd818,0xd819,0xd81a,0xd81b,0xd81c,0xd81d,0xd81e,0xd81f,
0x1f72,0x1f73,0x0361,0x02c8,0x02cc,0x02d0,0x02d1,0x0306,
0x203F,0x030b,0x0301,0x0304,0x0300,0x030f,0x030c,0x0302,
0x02e5,0x02e6,0x02e7,0x02e8,0x02e9,0xd820,0xd821,0x0325,
0x032c,0x0339,0x031c,0x031f,0x0320,0x0308,0x033d,0x0329,
0x032f,0x02de,0x0324,0x0330,0x033c,0x0334,0x031d,0x031e,
0x0318,0x0319,0x032a,0x033a,0x033b,0x0303,0x031a,
/* 2c00 */
       0x2776,0x2777,0x2778,0x2779,0x277a,0x277b,0x277c,
0x277d,0x277e,0x277f,0x24eb,0x24ec,0x24ed,0x24ee,0x24ef,
0x24f0,0x24f1,0x24f2,0x24f3,0x24f4,0x2170,0x2171,0x2172,
0x2173,0x2174,0x2175,0x2176,0x2177,0x2178,0x2179,0x217a,
0x217b,0x24d0,0x24d1,0x24d2,0x24d3,0x24d4,0x24d5,0x24d6,
0x24d7,0x24d8,0x24d9,0x24da,0x24db,0x24dc,0x24dd,0x24de,
0x24df,0x24e0,0x24e1,0x24e2,0x24e3,0x24e4,0x24e5,0x24e6,
0x24e7,0x24e8,0x24e9,0x32d0,0x32d1,0x32d2,0x32d3,0x32d4,
0x32d5,0x32d6,0x32d7,0x32d8,0x32d9,0x32da,0x32db,0x32dc,
0x32dd,0x32de,0x32df,0x32e0,0x32e1,0x32e2,0x32e3,0x32fa,
0x32e9,0x32e5,0x32ed,0x32ec,0xd82c,0xd82d,0xd82e,0xd82f,
0xd830,0xd831,0xd832,0xd833,0xd834,0x2051,0x2042,
       0x2460,0x2461,0x2462,0x2463,0x2464,0x2465,0x2466,
0x2467,0x2468,0x2469,0x246a,0x246b,0x246c,0x246d,0x246e,
0x246f,0x2470,0x2471,0x2472,0x2473,0x2160,0x2161,0x2162,
0x2163,0x2164,0x2165,0x2166,0x2167,0x2168,0x2169,0x216a,
0x3349,0x3314,0x3322,0x334d,0x3318,0x3327,0x3303,0x3336,
0x3351,0x3357,0x330d,0x3326,0x3323,0x332b,0x334a,0x333b,
0x339c,0x339d,0x339e,0x338e,0x338f,0x33c4,0x33a1,0x216b,
0xd835,0xd836,0xd837,0xd838,0xd839,0xd83a,0xd83b,0x337b,
0x301d,0x301f,0x2116,0x33cd,0x2121,0x32a4,0x32a5,0x32a6,
0x32a7,0x32a8,0x3231,0x3232,0x3239,0x337e,0x337d,0x337c,
0xd83c,0xd83d,0xd83e,0x222e,0xd83f,0xd840,0xd841,0xd842,
0x221f,0x22bf,0xd843,0xd844,0xd845,0x2756,0x261e,
/* 2e00 */
       0xd846,0x2000b,0x3402,0x4e28,0x4e2f,0x4e30,0x4e8d,
0x4ee1,0x4efd,0x4eff,0x4f03,0x4f0b,0x4f60,0x4f48,0x4f49,
0x4f56,0x4f5f,0x4f6a,0x4f6c,0x4f7e,0x4f8a,0x4f94,0x4f97,
0xfa30,0x4fc9,0x4fe0,0x5001,0x5002,0x500e,0x5018,0x5027,
0x502e,0x5040,0x503b,0x5041,0x5094,0x50cc,0x50f2,0x50d0,
0x50e6,0xfa31,0x5106,0x5103,0x510b,0x511e,0x5135,0x514a,
0xfa32,0x5155,0x5157,0x34b5,0x519d,0x51c3,0x51ca,0x51de,
0x51e2,0x51ee,0x5201,0x34db,0x5213,0x5215,0x5249,0x5257,
0x5261,0x5293,0x52c8,0xfa33,0x52cc,0x52d0,0x52d6,0x52db,
0xfa34,0x52f0,0x52fb,0x5300,0x5307,0x531c,0xfa35,0x5361,
0x5363,0x537d,0x5393,0x539d,0x53b2,0x5412,0x5427,0x544d,
0x549c,0x546b,0x5474,0x547f,0x5488,0x5496,0x54a1,
       0x54a9,0x54c6,0x54ff,0x550e,0x552b,0x5535,0x5550,
0x555e,0x5581,0x5586,0x558e,0xfa36,0x55ad,0x55ce,0xfa37,
0x5608,0x560e,0x563b,0x5649,0x5676,0x5666,0xfa38,0x566f,
0x5671,0x5672,0x5699,0x569e,0x56a9,0x56ac,0x56b3,0x56c9,
0x56ca,0x570a,0x2123d,0x5721,0x572f,0x5733,0x5734,0x5770,
0x5777,0x577c,0x579c,0xfa0f,0x2131b,0x57b8,0x57c7,0x57c8,
0x57cf,0x57e4,0x57ed,0x57f5,0x57f6,0x57ff,0x5809,0xfa10,
0x5861,0x5864,0xfa39,0x587c,0x5889,0x589e,0xfa3a,0x58a9,
0x2146e,0x58d2,0x58ce,0x58d4,0x58da,0x58e0,0x58e9,0x590c,
0x8641,0x595d,0x596d,0x598b,0x5992,0x59a4,0x59c3,0x59d2,
0x59dd,0x5a13,0x5a23,0x5a67,0x5a6d,0x5a77,0x5a7e,0x5a84,
0x5a9e,0x5aa7,0x5ac4,0x218bd,0x5b19,0x5b25,0xd847,
/* 3000 */
0x4e9c,0x5516,0x5a03,0x963f,0x54c0,0x611b,0x6328,0x59f6,
0x9022,0x8475,0x831c,0x7a50,0x60aa,0x63e1,0x6e25,0x65ed,
0x8466,0x82a6,0x9bf5,0x6893,0x5727,0x65a1,0x6271,0x5b9b,
0x59d0,0x867b,0x98f4,0x7d62,0x7dbe,0x9b8e,0x6216,0x7c9f,
0x88b7,0x5b89,0x5eb5,0x6309,0x6697,0x6848,0x95c7,0x978d,
0x674f,0x4ee5,0x4f0a,0x4f4d,0x4f9d,0x5049,0x56f2,0x5937,
0x59d4,0x5a01,0x5c09,0x60df,0x610f,0x6170,0x6613,0x6905,
0x70ba,0x754f,0x7570,0x79fb,0x7dad,0x7def,0x80c3,0x840e,
0x8863,0x8b02,0x9055,0x907a,0x533b,0x4e95,0x4ea5,0x57df,
0x80b2,0x90c1,0x78ef,0x4e00,0x58f1,0x6ea2,0x9038,0x7a32,
0x8328,0x828b,0x9c2f,0x5141,0x5370,0x54bd,0x54e1,0x56e0,
0x59fb,0x5f15,0x98f2,0x6deb,0x80e4,0x852d,
0x9662,0x9670,0x96a0,0x97fb,0x540b,0x53f3,0x5b87,0x70cf,
0x7fbd,0x8fc2,0x96e8,0x536f,0x9d5c,0x7aba,0x4e11,0x7893,
0x81fc,0x6e26,0x5618,0x5504,0x6b1d,0x851a,0x9c3b,0x59e5,
0x53a9,0x6d66,0x74dc,0x958f,0x5642,0x4e91,0x904b,0x96f2,
0x834f,0x990c,0x53e1,0x55b6,0x5b30,0x5f71,0x6620,0x66f3,
0x6804,0x6c38,0x6cf3,0x6d29,0x745b,0x76c8,0x7a4e,0x9834,
0x82f1,0x885b,0x8a60,0x92ed,0x6db2,0x75ab,0x76ca,0x99c5,
0x60a6,0x8b01,0x8d8a,0x95b2,0x698e,0x53ad,0x5186,0x5712,
0x5830,0x5944,0x5bb4,0x5ef6,0x6028,0x63a9,0x63f4,0x6cbf,
0x6f14,0x708e,0x7114,0x7159,0x71d5,0x733f,0x7e01,0x8276,
0x82d1,0x8597,0x9060,0x925b,0x9d1b,0x5869,0x65bc,0x6c5a,
0x7525,0x51f9,0x592e,0x5965,0x5f80,0x5fdc,
0x62bc,0x65fa,0x6a2a,0x6b27,0x6bb4,0x738b,0x7fc1,0x8956,
0x9d2c,0x9d0e,0x9ec4,0x5ca1,0x6c96,0x837b,0x5104,0x5c4b,
0x61b6,0x81c6,0x6876,0x7261,0x4e59,0x4ffa,0x5378,0x6069,
0x6e29,0x7a4f,0x97f3,0x4e0b,0x5316,0x4eee,0x4f55,0x4f3d,
0x4fa1,0x4f73,0x52a0,0x53ef,0x5609,0x590f,0x5ac1,0x5bb6,
0x5be1,0x79d1,0x6687,0x679c,0x67b6,0x6b4c,0x6cb3,0x706b,
0x73c2,0x798d,0x79be,0x7a3c,0x7b87,0x82b1,0x82db,0x8304,
0x8377,0x83ef,0x83d3,0x8766,0x8ab2,0x5629,0x8ca8,0x8fe6,
0x904e,0x971e,0x868a,0x4fc4,0x5ce8,0x6211,0x7259,0x753b,
0x81e5,0x82bd,0x86fe,0x8cc0,0x96c5,0x9913,0x99d5,0x4ecb,
0x4f1a,0x89e3,0x56de,0x584a,0x58ca,0x5efb,0x5feb,0x602a,
0x6094,0x6062,0x61d0,0x6212,0x62d0,0x6539,
0x9b41,0x6666,0x68b0,0x6d77,0x7070,0x754c,0x7686,0x7d75,
0x82a5,0x87f9,0x958b,0x968e,0x8c9d,0x51f1,0x52be,0x5916,
0x54b3,0x5bb3,0x5d16,0x6168,0x6982,0x6daf,0x788d,0x84cb,
0x8857,0x8a72,0x93a7,0x9ab8,0x6d6c,0x99a8,0x86d9,0x57a3,
0x67ff,0x86ce,0x920e,0x5283,0x5687,0x5404,0x5ed3,0x62e1,
0x64b9,0x683c,0x6838,0x6bbb,0x7372,0x78ba,0x7a6b,0x899a,
0x89d2,0x8d6b,0x8f03,0x90ed,0x95a3,0x9694,0x9769,0x5b66,
0x5cb3,0x697d,0x984d,0x984e,0x639b,0x7b20,0x6a2b,0x6a7f,
0x68b6,0x9c0d,0x6f5f,0x5272,0x559d,0x6070,0x62ec,0x6d3b,
0x6e07,0x6ed1,0x845b,0x8910,0x8f44,0x4e14,0x9c39,0x53f6,
0x691b,0x6a3a,0x9784,0x682a,0x515c,0x7ac3,0x84b2,0x91dc,
0x938c,0x565b,0x9d28,0x6822,0x8305,0x8431,
0x7ca5,0x5208,0x82c5,0x74e6,0x4e7e,0x4f83,0x51a0,0x5bd2,
0x520a,0x52d8,0x52e7,0x5dfb,0x559a,0x582a,0x59e6,0x5b8c,
0x5b98,0x5bdb,0x5e72,0x5e79,0x60a3,0x611f,0x6163,0x61be,
0x63db,0x6562,0x67d1,0x6853,0x68fa,0x6b3e,0x6b53,0x6c57,
0x6f22,0x6f97,0x6f45,0x74b0,0x7518,0x76e3,0x770b,0x7aff,
0x7ba1,0x7c21,0x7de9,0x7f36,0x7ff0,0x809d,0x8266,0x839e,
0x89b3,0x8acc,0x8cab,0x9084,0x9451,0x9593,0x9591,0x95a2,
0x9665,0x97d3,0x9928,0x8218,0x4e38,0x542b,0x5cb8,0x5dcc,
0x73a9,0x764c,0x773c,0x5ca9,0x7feb,0x8d0b,0x96c1,0x9811,
0x9854,0x9858,0x4f01,0x4f0e,0x5371,0x559c,0x5668,0x57fa,
0x5947,0x5b09,0x5bc4,0x5c90,0x5e0c,0x5e7e,0x5fcc,0x63ee,
0x673a,0x65d7,0x65e2,0x671f,0x68cb,0x68c4,
0x6a5f,0x5e30,0x6bc5,0x6c17,0x6c7d,0x757f,0x7948,0x5b63,
0x7a00,0x7d00,0x5fbd,0x898f,0x8a18,0x8cb4,0x8d77,0x8ecc,
0x8f1d,0x98e2,0x9a0e,0x9b3c,0x4e80,0x507d,0x5100,0x5993,
0x5b9c,0x622f,0x6280,0x64ec,0x6b3a,0x72a0,0x7591,0x7947,
0x7fa9,0x87fb,0x8abc,0x8b70,0x63ac,0x83ca,0x97a0,0x5409,
0x5403,0x55ab,0x6854,0x6a58,0x8a70,0x7827,0x6775,0x9ecd,
0x5374,0x5ba2,0x811a,0x8650,0x9006,0x4e18,0x4e45,0x4ec7,
0x4f11,0x53ca,0x5438,0x5bae,0x5f13,0x6025,0x6551,0x673d,
0x6c42,0x6c72,0x6ce3,0x7078,0x7403,0x7a76,0x7aae,0x7b08,
0x7d1a,0x7cfe,0x7d66,0x65e7,0x725b,0x53bb,0x5c45,0x5de8,
0x62d2,0x62e0,0x6319,0x6e20,0x865a,0x8a31,0x8ddd,0x92f8,
0x6f01,0x79a6,0x9b5a,0x4ea8,0x4eab,0x4eac,
0x4f9b,0x4fa0,0x50d1,0x5147,0x7af6,0x5171,0x51f6,0x5354,
0x5321,0x537f,0x53eb,0x55ac,0x5883,0x5ce1,0x5f37,0x5f4a,
0x602f,0x6050,0x606d,0x631f,0x6559,0x6a4b,0x6cc1,0x72c2,
0x72ed,0x77ef,0x80f8,0x8105,0x8208,0x854e,0x90f7,0x93e1,
0x97ff,0x9957,0x9a5a,0x4ef0,0x51dd,0x5c2d,0x6681,0x696d,
0x5c40,0x66f2,0x6975,0x7389,0x6850,0x7c81,0x50c5,0x52e4,
0x5747,0x5dfe,0x9326,0x65a4,0x6b23,0x6b3d,0x7434,0x7981,
0x79bd,0x7b4b,0x7dca,0x82b9,0x83cc,0x887f,0x895f,0x8b39,
0x8fd1,0x91d1,0x541f,0x9280,0x4e5d,0x5036,0x53e5,0x533a,
0x72d7,0x7396,0x77e9,0x82e6,0x8eaf,0x99c6,0x99c8,0x99d2,
0x5177,0x611a,0x865e,0x55b0,0x7a7a,0x5076,0x5bd3,0x9047,
0x9685,0x4e32,0x6adb,0x91e7,0x5c51,0x5c48,
0x6398,0x7a9f,0x6c93,0x9774,0x8f61,0x7aaa,0x718a,0x9688,
0x7c82,0x6817,0x7e70,0x6851,0x936c,0x52f2,0x541b,0x85ab,
0x8a13,0x7fa4,0x8ecd,0x90e1,0x5366,0x8888,0x7941,0x4fc2,
0x50be,0x5211,0x5144,0x5553,0x572d,0x73ea,0x578b,0x5951,
0x5f62,0x5f84,0x6075,0x6176,0x6167,0x61a9,0x63b2,0x643a,
0x656c,0x666f,0x6842,0x6e13,0x7566,0x7a3d,0x7cfb,0x7d4c,
0x7d99,0x7e4b,0x7f6b,0x830e,0x834a,0x86cd,0x8a08,0x8a63,
0x8b66,0x8efd,0x981a,0x9d8f,0x82b8,0x8fce,0x9be8,0x5287,
0x621f,0x6483,0x6fc0,0x9699,0x6841,0x5091,0x6b20,0x6c7a,
0x6f54,0x7a74,0x7d50,0x8840,0x8a23,0x6708,0x4ef6,0x5039,
0x5026,0x5065,0x517c,0x5238,0x5263,0x55a7,0x570f,0x5805,
0x5acc,0x5efa,0x61b2,0x61f8,0x62f3,0x6372,
0x691c,0x6a29,0x727d,0x72ac,0x732e,0x7814,0x786f,0x7d79,
0x770c,0x80a9,0x898b,0x8b19,0x8ce2,0x8ed2,0x9063,0x9375,
0x967a,0x9855,0x9a13,0x9e78,0x5143,0x539f,0x53b3,0x5e7b,
0x5f26,0x6e1b,0x6e90,0x7384,0x73fe,0x7d43,0x8237,0x8a00,
0x8afa,0x9650,0x4e4e,0x500b,0x53e4,0x547c,0x56fa,0x59d1,
0x5b64,0x5df1,0x5eab,0x5f27,0x6238,0x6545,0x67af,0x6e56,
0x72d0,0x7cca,0x88b4,0x80a1,0x80e1,0x83f0,0x864e,0x8a87,
0x8de8,0x9237,0x96c7,0x9867,0x9f13,0x4e94,0x4e92,0x4f0d,
0x5348,0x5449,0x543e,0x5a2f,0x5f8c,0x5fa1,0x609f,0x68a7,
0x6a8e,0x745a,0x7881,0x8a9e,0x8aa4,0x8b77,0x9190,0x4e5e,
0x9bc9,0x4ea4,0x4f7c,0x4faf,0x5019,0x5016,0x5149,0x516c,
0x529f,0x52b9,0x52fe,0x539a,0x53e3,0x5411,
0x540e,0x5589,0x5751,0x57a2,0x597d,0x5b54,0x5b5d,0x5b8f,
0x5de5,0x5de7,0x5df7,0x5e78,0x5e83,0x5e9a,0x5eb7,0x5f18,
0x6052,0x614c,0x6297,0x62d8,0x63a7,0x653b,0x6602,0x6643,
0x66f4,0x676d,0x6821,0x6897,0x69cb,0x6c5f,0x6d2a,0x6d69,
0x6e2f,0x6e9d,0x7532,0x7687,0x786c,0x7a3f,0x7ce0,0x7d05,
0x7d18,0x7d5e,0x7db1,0x8015,0x8003,0x80af,0x80b1,0x8154,
0x818f,0x822a,0x8352,0x884c,0x8861,0x8b1b,0x8ca2,0x8cfc,
0x90ca,0x9175,0x9271,0x783f,0x92fc,0x95a4,0x964d,0x9805,
0x9999,0x9ad8,0x9d3b,0x525b,0x52ab,0x53f7,0x5408,0x58d5,
0x62f7,0x6fe0,0x8c6a,0x8f5f,0x9eb9,0x514b,0x523b,0x544a,
0x56fd,0x7a40,0x9177,0x9d60,0x9ed2,0x7344,0x6f09,0x8170,
0x7511,0x5ffd,0x60da,0x9aa8,0x72db,0x8fbc,
0x6b64,0x9803,0x4eca,0x56f0,0x5764,0x58be,0x5a5a,0x6068,
0x61c7,0x660f,0x6606,0x6839,0x68b1,0x6df7,0x75d5,0x7d3a,
0x826e,0x9b42,0x4e9b,0x4f50,0x53c9,0x5506,0x5d6f,0x5de6,
0x5dee,0x67fb,0x6c99,0x7473,0x7802,0x8a50,0x9396,0x88df,
0x5750,0x5ea7,0x632b,0x50b5,0x50ac,0x518d,0x6700,0x54c9,
0x585e,0x59bb,0x5bb0,0x5f69,0x624d,0x63a1,0x683d,0x6b73,
0x6e08,0x707d,0x91c7,0x7280,0x7815,0x7826,0x796d,0x658e,
0x7d30,0x83dc,0x88c1,0x8f09,0x969b,0x5264,0x5728,0x6750,
0x7f6a,0x8ca1,0x51b4,0x5742,0x962a,0x583a,0x698a,0x80b4,
0x54b2,0x5d0e,0x57fc,0x7895,0x9dfa,0x4f5c,0x524a,0x548b,
0x643e,0x6628,0x6714,0x67f5,0x7a84,0x7b56,0x7d22,0x932f,
0x685c,0x9bad,0x7b39,0x5319,0x518a,0x5237,
0x5bdf,0x62f6,0x64ae,0x64e6,0x672d,0x6bba,0x85a9,0x96d1,
0x7690,0x9bd6,0x634c,0x9306,0x9bab,0x76bf,0x6652,0x4e09,
0x5098,0x53c2,0x5c71,0x60e8,0x6492,0x6563,0x685f,0x71e6,
0x73ca,0x7523,0x7b97,0x7e82,0x8695,0x8b83,0x8cdb,0x9178,
0x9910,0x65ac,0x66ab,0x6b8b,0x4ed5,0x4ed4,0x4f3a,0x4f7f,
0x523a,0x53f8,0x53f2,0x55e3,0x56db,0x58eb,0x59cb,0x59c9,
0x59ff,0x5b50,0x5c4d,0x5e02,0x5e2b,0x5fd7,0x601d,0x6307,
0x652f,0x5b5c,0x65af,0x65bd,0x65e8,0x679d,0x6b62,0x6b7b,
0x6c0f,0x7345,0x7949,0x79c1,0x7cf8,0x7d19,0x7d2b,0x80a2,
0x8102,0x81f3,0x8996,0x8a5e,0x8a69,0x8a66,0x8a8c,0x8aee,
0x8cc7,0x8cdc,0x96cc,0x98fc,0x6b6f,0x4e8b,0x4f3c,0x4f8d,
0x5150,0x5b57,0x5bfa,0x6148,0x6301,0x6642,
0x6b21,0x6ecb,0x6cbb,0x723e,0x74bd,0x75d4,0x78c1,0x793a,
0x800c,0x8033,0x81ea,0x8494,0x8f9e,0x6c50,0x9e7f,0x5f0f,
0x8b58,0x9d2b,0x7afa,0x8ef8,0x5b8d,0x96eb,0x4e03,0x53f1,
0x57f7,0x5931,0x5ac9,0x5ba4,0x6089,0x6e7f,0x6f06,0x75be,
0x8cea,0x5b9f,0x8500,0x7be0,0x5072,0x67f4,0x829d,0x5c61,
0x854a,0x7e1e,0x820e,0x5199,0x5c04,0x6368,0x8d66,0x659c,
0x716e,0x793e,0x7d17,0x8005,0x8b1d,0x8eca,0x906e,0x86c7,
0x90aa,0x501f,0x52fa,0x5c3a,0x6753,0x707c,0x7235,0x914c,
0x91c8,0x932b,0x82e5,0x5bc2,0x5f31,0x60f9,0x4e3b,0x53d6,
0x5b88,0x624b,0x6731,0x6b8a,0x72e9,0x73e0,0x7a2e,0x816b,
0x8da3,0x9152,0x9996,0x5112,0x53d7,0x546a,0x5bff,0x6388,
0x6a39,0x7dac,0x9700,0x56da,0x53ce,0x5468,
0x5b97,0x5c31,0x5dde,0x4fee,0x6101,0x62fe,0x6d32,0x79c0,
0x79cb,0x7d42,0x7e4d,0x7fd2,0x81ed,0x821f,0x8490,0x8846,
0x8972,0x8b90,0x8e74,0x8f2f,0x9031,0x914b,0x916c,0x96c6,
0x919c,0x4ec0,0x4f4f,0x5145,0x5341,0x5f93,0x620e,0x67d4,
0x6c41,0x6e0b,0x7363,0x7e26,0x91cd,0x9283,0x53d4,0x5919,
0x5bbf,0x6dd1,0x795d,0x7e2e,0x7c9b,0x587e,0x719f,0x51fa,
0x8853,0x8ff0,0x4fca,0x5cfb,0x6625,0x77ac,0x7ae3,0x821c,
0x99ff,0x51c6,0x5faa,0x65ec,0x696f,0x6b89,0x6df3,0x6e96,
0x6f64,0x76fe,0x7d14,0x5de1,0x9075,0x9187,0x9806,0x51e6,
0x521d,0x6240,0x6691,0x66d9,0x6e1a,0x5eb6,0x7dd2,0x7f72,
0x66f8,0x85af,0x85f7,0x8af8,0x52a9,0x53d9,0x5973,0x5e8f,
0x5f90,0x6055,0x92e4,0x9664,0x50b7,0x511f,
0x52dd,0x5320,0x5347,0x53ec,0x54e8,0x5546,0x5531,0x5617,
0x5968,0x59be,0x5a3c,0x5bb5,0x5c06,0x5c0f,0x5c11,0x5c1a,
0x5e84,0x5e8a,0x5ee0,0x5f70,0x627f,0x6284,0x62db,0x638c,
0x6377,0x6607,0x660c,0x662d,0x6676,0x677e,0x68a2,0x6a1f,
0x6a35,0x6cbc,0x6d88,0x6e09,0x6e58,0x713c,0x7126,0x7167,
0x75c7,0x7701,0x785d,0x7901,0x7965,0x79f0,0x7ae0,0x7b11,
0x7ca7,0x7d39,0x8096,0x83d6,0x848b,0x8549,0x885d,0x88f3,
0x8a1f,0x8a3c,0x8a54,0x8a73,0x8c61,0x8cde,0x91a4,0x9266,
0x937e,0x9418,0x969c,0x9798,0x4e0a,0x4e08,0x4e1e,0x4e57,
0x5197,0x5270,0x57ce,0x5834,0x58cc,0x5b22,0x5e38,0x60c5,
0x64fe,0x6761,0x6756,0x6d44,0x72b6,0x7573,0x7a63,0x84b8,
0x8b72,0x91b8,0x9320,0x5631,0x57f4,0x98fe,
0x62ed,0x690d,0x6b96,0x71ed,0x7e54,0x8077,0x8272,0x89e6,
0x98df,0x8755,0x8fb1,0x5c3b,0x4f38,0x4fe1,0x4fb5,0x5507,
0x5a20,0x5bdd,0x5be9,0x5fc3,0x614e,0x632f,0x65b0,0x664b,
0x68ee,0x699b,0x6d78,0x6df1,0x7533,0x75b9,0x771f,0x795e,
0x79e6,0x7d33,0x81e3,0x82af,0x85aa,0x89aa,0x8a3a,0x8eab,
0x8f9b,0x9032,0x91dd,0x9707,0x4eba,0x4ec1,0x5203,0x5875,
0x58ec,0x5c0b,0x751a,0x5c3d,0x814e,0x8a0a,0x8fc5,0x9663,
0x976d,0x7b25,0x8acf,0x9808,0x9162,0x56f3,0x53a8,0x9017,
0x5439,0x5782,0x5e25,0x63a8,0x6c34,0x708a,0x7761,0x7c8b,
0x7fe0,0x8870,0x9042,0x9154,0x9310,0x9318,0x968f,0x745e,
0x9ac4,0x5d07,0x5d69,0x6570,0x67a2,0x8da8,0x96db,0x636e,
0x6749,0x6919,0x83c5,0x9817,0x96c0,0x88fe,
0x6f84,0x647a,0x5bf8,0x4e16,0x702c,0x755d,0x662f,0x51c4,
0x5236,0x52e2,0x59d3,0x5f81,0x6027,0x6210,0x653f,0x6574,
0x661f,0x6674,0x68f2,0x6816,0x6b63,0x6e05,0x7272,0x751f,
0x76db,0x7cbe,0x8056,0x58f0,0x88fd,0x897f,0x8aa0,0x8a93,
0x8acb,0x901d,0x9192,0x9752,0x9759,0x6589,0x7a0e,0x8106,
0x96bb,0x5e2d,0x60dc,0x621a,0x65a5,0x6614,0x6790,0x77f3,
0x7a4d,0x7c4d,0x7e3e,0x810a,0x8cac,0x8d64,0x8de1,0x8e5f,
0x78a9,0x5207,0x62d9,0x63a5,0x6442,0x6298,0x8a2d,0x7a83,
0x7bc0,0x8aac,0x96ea,0x7d76,0x820c,0x8749,0x4ed9,0x5148,
0x5343,0x5360,0x5ba3,0x5c02,0x5c16,0x5ddd,0x6226,0x6247,
0x64b0,0x6813,0x6834,0x6cc9,0x6d45,0x6d17,0x67d3,0x6f5c,
0x714e,0x717d,0x65cb,0x7a7f,0x7bad,0x7dda,
0x7e4a,0x7fa8,0x817a,0x821b,0x8239,0x85a6,0x8a6e,0x8cce,
0x8df5,0x9078,0x9077,0x92ad,0x9291,0x9583,0x9bae,0x524d,
0x5584,0x6f38,0x7136,0x5168,0x7985,0x7e55,0x81b3,0x7cce,
0x564c,0x5851,0x5ca8,0x63aa,0x66fe,0x66fd,0x695a,0x72d9,
0x758f,0x758e,0x790e,0x7956,0x79df,0x7c97,0x7d20,0x7d44,
0x8607,0x8a34,0x963b,0x9061,0x9f20,0x50e7,0x5275,0x53cc,
0x53e2,0x5009,0x55aa,0x58ee,0x594f,0x723d,0x5b8b,0x5c64,
0x531d,0x60e3,0x60f3,0x635c,0x6383,0x633f,0x63bb,0x64cd,
0x65e9,0x66f9,0x5de3,0x69cd,0x69fd,0x6f15,0x71e5,0x4e89,
0x75e9,0x76f8,0x7a93,0x7cdf,0x7dcf,0x7d9c,0x8061,0x8349,
0x8358,0x846c,0x84bc,0x85fb,0x88c5,0x8d70,0x9001,0x906d,
0x9397,0x971c,0x9a12,0x50cf,0x5897,0x618e,
0x81d3,0x8535,0x8d08,0x9020,0x4fc3,0x5074,0x5247,0x5373,
0x606f,0x6349,0x675f,0x6e2c,0x8db3,0x901f,0x4fd7,0x5c5e,
0x8cca,0x65cf,0x7d9a,0x5352,0x8896,0x5176,0x63c3,0x5b58,
0x5b6b,0x5c0a,0x640d,0x6751,0x905c,0x4ed6,0x591a,0x592a,
0x6c70,0x8a51,0x553e,0x5815,0x59a5,0x60f0,0x6253,0x67c1,
0x8235,0x6955,0x9640,0x99c4,0x9a28,0x4f53,0x5806,0x5bfe,
0x8010,0x5cb1,0x5e2f,0x5f85,0x6020,0x614b,0x6234,0x66ff,
0x6cf0,0x6ede,0x80ce,0x817f,0x82d4,0x888b,0x8cb8,0x9000,
0x902e,0x968a,0x9edb,0x9bdb,0x4ee3,0x53f0,0x5927,0x7b2c,
0x918d,0x984c,0x9df9,0x6edd,0x7027,0x5353,0x5544,0x5b85,
0x6258,0x629e,0x62d3,0x6ca2,0x6fef,0x7422,0x8a17,0x9438,
0x6fc1,0x8afe,0x8338,0x51e7,0x86f8,0x53ea,
0x53e9,0x4f46,0x9054,0x8fb0,0x596a,0x8131,0x5dfd,0x7aea,
0x8fbf,0x68da,0x8c37,0x72f8,0x9c48,0x6a3d,0x8ab0,0x4e39,
0x5358,0x5606,0x5766,0x62c5,0x63a2,0x65e6,0x6b4e,0x6de1,
0x6e5b,0x70ad,0x77ed,0x7aef,0x7baa,0x7dbb,0x803d,0x80c6,
0x86cb,0x8a95,0x935b,0x56e3,0x58c7,0x5f3e,0x65ad,0x6696,
0x6a80,0x6bb5,0x7537,0x8ac7,0x5024,0x77e5,0x5730,0x5f1b,
0x6065,0x667a,0x6c60,0x75f4,0x7a1a,0x7f6e,0x81f4,0x8718,
0x9045,0x99b3,0x7bc9,0x755c,0x7af9,0x7b51,0x84c4,0x9010,
0x79e9,0x7a92,0x8336,0x5ae1,0x7740,0x4e2d,0x4ef2,0x5b99,
0x5fe0,0x62bd,0x663c,0x67f1,0x6ce8,0x866b,0x8877,0x8a3b,
0x914e,0x92f3,0x99d0,0x6a17,0x7026,0x732a,0x82e7,0x8457,
0x8caf,0x4e01,0x5146,0x51cb,0x558b,0x5bf5,
0x5e16,0x5e33,0x5e81,0x5f14,0x5f35,0x5f6b,0x5fb4,0x61f2,
0x6311,0x66a2,0x671d,0x6f6e,0x7252,0x753a,0x773a,0x8074,
0x8139,0x8178,0x8776,0x8abf,0x8adc,0x8d85,0x8df3,0x929a,
0x9577,0x9802,0x9ce5,0x52c5,0x6357,0x76f4,0x6715,0x6c88,
0x73cd,0x8cc3,0x93ae,0x9673,0x6d25,0x589c,0x690e,0x69cc,
0x8ffd,0x939a,0x75db,0x901a,0x585a,0x6802,0x63b4,0x69fb,
0x4f43,0x6f2c,0x67d8,0x8fbb,0x8526,0x7db4,0x9354,0x693f,
0x6f70,0x576a,0x58f7,0x5b2c,0x7d2c,0x722a,0x540a,0x91e3,
0x9db4,0x4ead,0x4f4e,0x505c,0x5075,0x5243,0x8c9e,0x5448,
0x5824,0x5b9a,0x5e1d,0x5e95,0x5ead,0x5ef7,0x5f1f,0x608c,
0x62b5,0x633a,0x63d0,0x68af,0x6c40,0x7887,0x798e,0x7a0b,
0x7de0,0x8247,0x8a02,0x8ae6,0x8e44,0x9013,
0x90b8,0x912d,0x91d8,0x9f0e,0x6ce5,0x6458,0x64e2,0x6575,
0x6ef4,0x7684,0x7b1b,0x9069,0x93d1,0x6eba,0x54f2,0x5fb9,
0x64a4,0x8f4d,0x8fed,0x9244,0x5178,0x586b,0x5929,0x5c55,
0x5e97,0x6dfb,0x7e8f,0x751c,0x8cbc,0x8ee2,0x985b,0x70b9,
0x4f1d,0x6bbf,0x6fb1,0x7530,0x96fb,0x514e,0x5410,0x5835,
0x5857,0x59ac,0x5c60,0x5f92,0x6597,0x675c,0x6e21,0x767b,
0x83df,0x8ced,0x9014,0x90fd,0x934d,0x7825,0x783a,0x52aa,
0x5ea6,0x571f,0x5974,0x6012,0x5012,0x515a,0x51ac,0x51cd,
0x5200,0x5510,0x5854,0x5858,0x5957,0x5b95,0x5cf6,0x5d8b,
0x60bc,0x6295,0x642d,0x6771,0x6843,0x68bc,0x68df,0x76d7,
0x6dd8,0x6e6f,0x6d9b,0x706f,0x71c8,0x5f53,0x75d8,0x7977,
0x7b49,0x7b54,0x7b52,0x7cd6,0x7d71,0x5230,
0x8463,0x8569,0x85e4,0x8a0e,0x8b04,0x8c46,0x8e0f,0x9003,
0x900f,0x9419,0x9676,0x982d,0x9a30,0x95d8,0x50cd,0x52d5,
0x540c,0x5802,0x5c0e,0x61a7,0x649e,0x6d1e,0x77b3,0x7ae5,
0x80f4,0x8404,0x9053,0x9285,0x5ce0,0x9d07,0x533f,0x5f97,
0x5fb3,0x6d9c,0x7279,0x7763,0x79bf,0x7be4,0x6bd2,0x72ec,
0x8aad,0x6803,0x6a61,0x51f8,0x7a81,0x6934,0x5c4a,0x9cf6,
0x82eb,0x5bc5,0x9149,0x701e,0x5678,0x5c6f,0x60c7,0x6566,
0x6c8c,0x8c5a,0x9041,0x9813,0x5451,0x66c7,0x920d,0x5948,
0x90a3,0x5185,0x4e4d,0x51ea,0x8599,0x8b0e,0x7058,0x637a,
0x934b,0x6962,0x99b4,0x7e04,0x7577,0x5357,0x6960,0x8edf,
0x96e3,0x6c5d,0x4e8c,0x5c3c,0x5f10,0x8fe9,0x5302,0x8cd1,
0x8089,0x8679,0x5eff,0x65e5,0x4e73,0x5165,
0x5982,0x5c3f,0x97ee,0x4efb,0x598a,0x5fcd,0x8a8d,0x6fe1,
0x79b0,0x7962,0x5be7,0x8471,0x732b,0x71b1,0x5e74,0x5ff5,
0x637b,0x649a,0x71c3,0x7c98,0x4e43,0x5efc,0x4e4b,0x57dc,
0x56a2,0x60a9,0x6fc3,0x7d0d,0x80fd,0x8133,0x81bf,0x8fb2,
0x8997,0x86a4,0x5df4,0x628a,0x64ad,0x8987,0x6777,0x6ce2,
0x6d3e,0x7436,0x7834,0x5a46,0x7f75,0x82ad,0x99ac,0x4ff3,
0x5ec3,0x62dd,0x6392,0x6557,0x676f,0x76c3,0x724c,0x80cc,
0x80ba,0x8f29,0x914d,0x500d,0x57f9,0x5a92,0x6885,0x6973,
0x7164,0x72fd,0x8cb7,0x58f2,0x8ce0,0x966a,0x9019,0x877f,
0x79e4,0x77e7,0x8429,0x4f2f,0x5265,0x535a,0x62cd,0x67cf,
0x6cca,0x767d,0x7b94,0x7c95,0x8236,0x8584,0x8feb,0x66dd,
0x6f20,0x7206,0x7e1b,0x83ab,0x99c1,0x9ea6,
0x51fd,0x7bb1,0x7872,0x7bb8,0x8087,0x7b48,0x6ae8,0x5e61,
0x808c,0x7551,0x7560,0x516b,0x9262,0x6e8c,0x767a,0x9197,
0x9aea,0x4f10,0x7f70,0x629c,0x7b4f,0x95a5,0x9ce9,0x567a,
0x5859,0x86e4,0x96bc,0x4f34,0x5224,0x534a,0x53cd,0x53db,
0x5e06,0x642c,0x6591,0x677f,0x6c3e,0x6c4e,0x7248,0x72af,
0x73ed,0x7554,0x7e41,0x822c,0x85e9,0x8ca9,0x7bc4,0x91c6,
0x7169,0x9812,0x98ef,0x633d,0x6669,0x756a,0x76e4,0x78d0,
0x8543,0x86ee,0x532a,0x5351,0x5426,0x5983,0x5e87,0x5f7c,
0x60b2,0x6249,0x6279,0x62ab,0x6590,0x6bd4,0x6ccc,0x75b2,
0x76ae,0x7891,0x79d8,0x7dcb,0x7f77,0x80a5,0x88ab,0x8ab9,
0x8cbb,0x907f,0x975e,0x98db,0x6a0b,0x7c38,0x5099,0x5c3e,
0x5fae,0x6787,0x6bd8,0x7435,0x7709,0x7f8e,
0x9f3b,0x67ca,0x7a17,0x5339,0x758b,0x9aed,0x5f66,0x819d,
0x83f1,0x8098,0x5f3c,0x5fc5,0x7562,0x7b46,0x903c,0x6867,
0x59eb,0x5a9b,0x7d10,0x767e,0x8b2c,0x4ff5,0x5f6a,0x6a19,
0x6c37,0x6f02,0x74e2,0x7968,0x8868,0x8a55,0x8c79,0x5edf,
0x63cf,0x75c5,0x79d2,0x82d7,0x9328,0x92f2,0x849c,0x86ed,
0x9c2d,0x54c1,0x5f6c,0x658c,0x6d5c,0x7015,0x8ca7,0x8cd3,
0x983b,0x654f,0x74f6,0x4e0d,0x4ed8,0x57e0,0x592b,0x5a66,
0x5bcc,0x51a8,0x5e03,0x5e9c,0x6016,0x6276,0x6577,0x65a7,
0x666e,0x6d6e,0x7236,0x7b26,0x8150,0x819a,0x8299,0x8b5c,
0x8ca0,0x8ce6,0x8d74,0x961c,0x9644,0x4fae,0x64ab,0x6b66,
0x821e,0x8461,0x856a,0x90e8,0x5c01,0x6953,0x98a8,0x847a,
0x8557,0x4f0f,0x526f,0x5fa9,0x5e45,0x670d,
0x798f,0x8179,0x8907,0x8986,0x6df5,0x5f17,0x6255,0x6cb8,
0x4ecf,0x7269,0x9b92,0x5206,0x543b,0x5674,0x58b3,0x61a4,
0x626e,0x711a,0x596e,0x7c89,0x7cde,0x7d1b,0x96f0,0x6587,
0x805e,0x4e19,0x4f75,0x5175,0x5840,0x5e63,0x5e73,0x5f0a,
0x67c4,0x4e26,0x853d,0x9589,0x965b,0x7c73,0x9801,0x50fb,
0x58c1,0x7656,0x78a7,0x5225,0x77a5,0x8511,0x7b86,0x504f,
0x5909,0x7247,0x7bc7,0x7de8,0x8fba,0x8fd4,0x904d,0x4fbf,
0x52c9,0x5a29,0x5f01,0x97ad,0x4fdd,0x8217,0x92ea,0x5703,
0x6355,0x6b69,0x752b,0x88dc,0x8f14,0x7a42,0x52df,0x5893,
0x6155,0x620a,0x66ae,0x6bcd,0x7c3f,0x83e9,0x5023,0x4ff8,
0x5305,0x5446,0x5831,0x5949,0x5b9d,0x5cf0,0x5cef,0x5d29,
0x5e96,0x62b1,0x6367,0x653e,0x65b9,0x670b,
0x6cd5,0x6ce1,0x70f9,0x7832,0x7e2b,0x80de,0x82b3,0x840c,
0x84ec,0x8702,0x8912,0x8a2a,0x8c4a,0x90a6,0x92d2,0x98fd,
0x9cf3,0x9d6c,0x4e4f,0x4ea1,0x508d,0x5256,0x574a,0x59a8,
0x5e3d,0x5fd8,0x5fd9,0x623f,0x66b4,0x671b,0x67d0,0x68d2,
0x5192,0x7d21,0x80aa,0x81a8,0x8b00,0x8c8c,0x8cbf,0x927e,
0x9632,0x5420,0x982c,0x5317,0x50d5,0x535c,0x58a8,0x64b2,
0x6734,0x7267,0x7766,0x7a46,0x91e6,0x52c3,0x6ca1,0x6b86,
0x5800,0x5e4c,0x5954,0x672c,0x7ffb,0x51e1,0x76c6,0x6469,
0x78e8,0x9b54,0x9ebb,0x57cb,0x59b9,0x6627,0x679a,0x6bce,
0x54e9,0x69d9,0x5e55,0x819c,0x6795,0x9baa,0x67fe,0x9c52,
0x685d,0x4ea6,0x4fe3,0x53c8,0x62b9,0x672b,0x6cab,0x8fc4,
0x4fad,0x7e6d,0x9ebf,0x4e07,0x6162,0x6e80,
0x6f2b,0x8513,0x5473,0x672a,0x9b45,0x5df3,0x7b95,0x5cac,
0x5bc6,0x871c,0x6e4a,0x84d1,0x7a14,0x8108,0x5999,0x7c8d,
0x6c11,0x7720,0x52d9,0x5922,0x7121,0x725f,0x77db,0x9727,
0x9d61,0x690b,0x5a7f,0x5a18,0x51a5,0x540d,0x547d,0x660e,
0x76df,0x8ff7,0x9298,0x9cf4,0x59ea,0x725d,0x6ec5,0x514d,
0x68c9,0x7dbf,0x7dec,0x9762,0x9eba,0x6478,0x6a21,0x8302,
0x5984,0x5b5f,0x6bdb,0x731b,0x76f2,0x7db2,0x8017,0x8499,
0x5132,0x6728,0x9ed9,0x76ee,0x6762,0x52ff,0x9905,0x5c24,
0x623b,0x7c7e,0x8cb0,0x554f,0x60b6,0x7d0b,0x9580,0x5301,
0x4e5f,0x51b6,0x591c,0x723a,0x8036,0x91ce,0x5f25,0x77e2,
0x5384,0x5f79,0x7d04,0x85ac,0x8a33,0x8e8d,0x9756,0x67f3,
0x85ae,0x9453,0x6109,0x6108,0x6cb9,0x7652,
0x8aed,0x8f38,0x552f,0x4f51,0x512a,0x52c7,0x53cb,0x5ba5,
0x5e7d,0x60a0,0x6182,0x63d6,0x6709,0x67da,0x6e67,0x6d8c,
0x7336,0x7337,0x7531,0x7950,0x88d5,0x8a98,0x904a,0x9091,
0x90f5,0x96c4,0x878d,0x5915,0x4e88,0x4f59,0x4e0e,0x8a89,
0x8f3f,0x9810,0x50ad,0x5e7c,0x5996,0x5bb9,0x5eb8,0x63da,
0x63fa,0x64c1,0x66dc,0x694a,0x69d8,0x6d0b,0x6eb6,0x7194,
0x7528,0x7aaf,0x7f8a,0x8000,0x8449,0x84c9,0x8981,0x8b21,
0x8e0a,0x9065,0x967d,0x990a,0x617e,0x6291,0x6b32,0x6c83,
0x6d74,0x7fcc,0x7ffc,0x6dc0,0x7f85,0x87ba,0x88f8,0x6765,
0x83b1,0x983c,0x96f7,0x6d1b,0x7d61,0x843d,0x916a,0x4e71,
0x5375,0x5d50,0x6b04,0x6feb,0x85cd,0x862d,0x89a7,0x5229,
0x540f,0x5c65,0x674e,0x68a8,0x7406,0x7483,
0x75e2,0x88cf,0x88e1,0x91cc,0x96e2,0x9678,0x5f8b,0x7387,
0x7acb,0x844e,0x63a0,0x7565,0x5289,0x6d41,0x6e9c,0x7409,
0x7559,0x786b,0x7c92,0x9686,0x7adc,0x9f8d,0x4fb6,0x616e,
0x65c5,0x865c,0x4e86,0x4eae,0x50da,0x4e21,0x51cc,0x5bee,
0x6599,0x6881,0x6dbc,0x731f,0x7642,0x77ad,0x7a1c,0x7ce7,
0x826f,0x8ad2,0x907c,0x91cf,0x9675,0x9818,0x529b,0x7dd1,
0x502b,0x5398,0x6797,0x6dcb,0x71d0,0x7433,0x81e8,0x8f2a,
0x96a3,0x9c57,0x9e9f,0x7460,0x5841,0x6d99,0x7d2f,0x985e,
0x4ee4,0x4f36,0x4f8b,0x51b7,0x52b1,0x5dba,0x601c,0x73b2,
0x793c,0x82d3,0x9234,0x96b7,0x96f6,0x970a,0x9e97,0x9f62,
0x66a6,0x6b74,0x5217,0x52a3,0x70c8,0x88c2,0x5ec9,0x604b,
0x6190,0x6f23,0x7149,0x7c3e,0x7df4,0x806f,
/* 4f00 */
       0x84ee,0x9023,0x932c,0x5442,0x9b6f,0x6ad3,0x7089,
0x8cc2,0x8def,0x9732,0x52b4,0x5a41,0x5eca,0x5f04,0x6717,
0x697c,0x6994,0x6d6a,0x6f0f,0x7262,0x72fc,0x7bed,0x8001,
0x807e,0x874b,0x90ce,0x516d,0x9e93,0x7984,0x808b,0x9332,
0x8ad6,0x502d,0x548c,0x8a71,0x6b6a,0x8cc4,0x8107,0x60d1,
0x67a0,0x9df2,0x4e99,0x4e98,0x9c10,0x8a6b,0x85c1,0x8568,
0x6900,0x6e7e,0x7897,0x8155,0xd848,0x5b41,0x5b56,0x5b7d,
0x5b93,0x5bd8,0x5bec,0x5c12,0x5c1e,0x5c23,0x5c2b,0x378d,
0x5c62,0xfa3b,0xfa3c,0x216b4,0x5c7a,0x5c8f,0x5c9f,0x5ca3,
0x5caa,0x5cba,0x5ccb,0x5cd0,0x5cd2,0x5cf4,0x21e34,0x37e2,
0x5d0d,0x5d27,0xfa11,0x5d46,0x5d47,0x5d53,0x5d4a,0x5d6d,
0x5d81,0x5da0,0x5da4,0x5da7,0x5db8,0x5dcb,0xd849,
/* 5000 */
0x5f0c,0x4e10,0x4e15,0x4e2a,0x4e31,0x4e36,0x4e3c,0x4e3f,
0x4e42,0x4e56,0x4e58,0x4e82,0x4e85,0x8c6b,0x4e8a,0x8212,
0x5f0d,0x4e8e,0x4e9e,0x4e9f,0x4ea0,0x4ea2,0x4eb0,0x4eb3,
0x4eb6,0x4ece,0x4ecd,0x4ec4,0x4ec6,0x4ec2,0x4ed7,0x4ede,
0x4eed,0x4edf,0x4ef7,0x4f09,0x4f5a,0x4f30,0x4f5b,0x4f5d,
0x4f57,0x4f47,0x4f76,0x4f88,0x4f8f,0x4f98,0x4f7b,0x4f69,
0x4f70,0x4f91,0x4f6f,0x4f86,0x4f96,0x5118,0x4fd4,0x4fdf,
0x4fce,0x4fd8,0x4fdb,0x4fd1,0x4fda,0x4fd0,0x4fe4,0x4fe5,
0x501a,0x5028,0x5014,0x502a,0x5025,0x5005,0x4f1c,0x4ff6,
0x5021,0x5029,0x502c,0x4ffe,0x4fef,0x5011,0x5006,0x5043,
0x5047,0x6703,0x5055,0x5050,0x5048,0x505a,0x5056,0x506c,
0x5078,0x5080,0x509a,0x5085,0x50b4,0x50b2,
0x50c9,0x50ca,0x50b3,0x50c2,0x50d6,0x50de,0x50e5,0x50ed,
0x50e3,0x50ee,0x50f9,0x50f5,0x5109,0x5101,0x5102,0x5116,
0x5115,0x5114,0x511a,0x5121,0x513a,0x5137,0x513c,0x513b,
0x513f,0x5140,0x5152,0x514c,0x5154,0x5162,0x7af8,0x5169,
0x516a,0x516e,0x5180,0x5182,0x56d8,0x518c,0x5189,0x518f,
0x5191,0x5193,0x5195,0x5196,0x51a4,0x51a6,0x51a2,0x51a9,
0x51aa,0x51ab,0x51b3,0x51b1,0x51b2,0x51b0,0x51b5,0x51bd,
0x51c5,0x51c9,0x51db,0x51e0,0x8655,0x51e9,0x51ed,0x51f0,
0x51f5,0x51fe,0x5204,0x520b,0x5214,0x520e,0x5227,0x522a,
0x522e,0x5233,0x5239,0x524f,0x5244,0x524b,0x524c,0x525e,
0x5254,0x526a,0x5274,0x5269,0x5273,0x527f,0x527d,0x528d,
0x5294,0x5292,0x5271,0x5288,0x5291,0x8fa8,
0x8fa7,0x52ac,0x52ad,0x52bc,0x52b5,0x52c1,0x52cd,0x52d7,
0x52de,0x52e3,0x52e6,0x98ed,0x52e0,0x52f3,0x52f5,0x52f8,
0x52f9,0x5306,0x5308,0x7538,0x530d,0x5310,0x530f,0x5315,
0x531a,0x5323,0x532f,0x5331,0x5333,0x5338,0x5340,0x5346,
0x5345,0x4e17,0x5349,0x534d,0x51d6,0x535e,0x5369,0x536e,
0x5918,0x537b,0x5377,0x5382,0x5396,0x53a0,0x53a6,0x53a5,
0x53ae,0x53b0,0x53b6,0x53c3,0x7c12,0x96d9,0x53df,0x66fc,
0x71ee,0x53ee,0x53e8,0x53ed,0x53fa,0x5401,0x543d,0x5440,
0x542c,0x542d,0x543c,0x542e,0x5436,0x5429,0x541d,0x544e,
0x548f,0x5475,0x548e,0x545f,0x5471,0x5477,0x5470,0x5492,
0x547b,0x5480,0x5476,0x5484,0x5490,0x5486,0x54c7,0x54a2,
0x54b8,0x54a5,0x54ac,0x54c4,0x54c8,0x54a8,
0x54ab,0x54c2,0x54a4,0x54be,0x54bc,0x54d8,0x54e5,0x54e6,
0x550f,0x5514,0x54fd,0x54ee,0x54ed,0x54fa,0x54e2,0x5539,
0x5540,0x5563,0x554c,0x552e,0x555c,0x5545,0x5556,0x5557,
0x5538,0x5533,0x555d,0x5599,0x5580,0x54af,0x558a,0x559f,
0x557b,0x557e,0x5598,0x559e,0x55ae,0x557c,0x5583,0x55a9,
0x5587,0x55a8,0x55da,0x55c5,0x55df,0x55c4,0x55dc,0x55e4,
0x55d4,0x5614,0x55f7,0x5616,0x55fe,0x55fd,0x561b,0x55f9,
0x564e,0x5650,0x71df,0x5634,0x5636,0x5632,0x5638,0x566b,
0x5664,0x562f,0x566c,0x566a,0x5686,0x5680,0x568a,0x56a0,
0x5694,0x568f,0x56a5,0x56ae,0x56b6,0x56b4,0x56c2,0x56bc,
0x56c1,0x56c3,0x56c0,0x56c8,0x56ce,0x56d1,0x56d3,0x56d7,
0x56ee,0x56f9,0x5700,0x56ff,0x5704,0x5709,
0x5708,0x570b,0x570d,0x5713,0x5718,0x5716,0x55c7,0x571c,
0x5726,0x5737,0x5738,0x574e,0x573b,0x5740,0x574f,0x5769,
0x57c0,0x5788,0x5761,0x577f,0x5789,0x5793,0x57a0,0x57b3,
0x57a4,0x57aa,0x57b0,0x57c3,0x57c6,0x57d4,0x57d2,0x57d3,
0x580a,0x57d6,0x57e3,0x580b,0x5819,0x581d,0x5872,0x5821,
0x5862,0x584b,0x5870,0x6bc0,0x5852,0x583d,0x5879,0x5885,
0x58b9,0x589f,0x58ab,0x58ba,0x58de,0x58bb,0x58b8,0x58ae,
0x58c5,0x58d3,0x58d1,0x58d7,0x58d9,0x58d8,0x58e5,0x58dc,
0x58e4,0x58df,0x58ef,0x58fa,0x58f9,0x58fb,0x58fc,0x58fd,
0x5902,0x590a,0x5910,0x591b,0x68a6,0x5925,0x592c,0x592d,
0x5932,0x5938,0x593e,0x7ad2,0x5955,0x5950,0x594e,0x595a,
0x5958,0x5962,0x5960,0x5967,0x596c,0x5969,
0x5978,0x5981,0x599d,0x4f5e,0x4fab,0x59a3,0x59b2,0x59c6,
0x59e8,0x59dc,0x598d,0x59d9,0x59da,0x5a25,0x5a1f,0x5a11,
0x5a1c,0x5a09,0x5a1a,0x5a40,0x5a6c,0x5a49,0x5a35,0x5a36,
0x5a62,0x5a6a,0x5a9a,0x5abc,0x5abe,0x5acb,0x5ac2,0x5abd,
0x5ae3,0x5ad7,0x5ae6,0x5ae9,0x5ad6,0x5afa,0x5afb,0x5b0c,
0x5b0b,0x5b16,0x5b32,0x5ad0,0x5b2a,0x5b36,0x5b3e,0x5b43,
0x5b45,0x5b40,0x5b51,0x5b55,0x5b5a,0x5b5b,0x5b65,0x5b69,
0x5b70,0x5b73,0x5b75,0x5b78,0x6588,0x5b7a,0x5b80,0x5b83,
0x5ba6,0x5bb8,0x5bc3,0x5bc7,0x5bc9,0x5bd4,0x5bd0,0x5be4,
0x5be6,0x5be2,0x5bde,0x5be5,0x5beb,0x5bf0,0x5bf6,0x5bf3,
0x5c05,0x5c07,0x5c08,0x5c0d,0x5c13,0x5c20,0x5c22,0x5c28,
0x5c38,0x5c39,0x5c41,0x5c46,0x5c4e,0x5c53,
0x5c50,0x5c4f,0x5b71,0x5c6c,0x5c6e,0x4e62,0x5c76,0x5c79,
0x5c8c,0x5c91,0x5c94,0x599b,0x5cab,0x5cbb,0x5cb6,0x5cbc,
0x5cb7,0x5cc5,0x5cbe,0x5cc7,0x5cd9,0x5ce9,0x5cfd,0x5cfa,
0x5ced,0x5d8c,0x5cea,0x5d0b,0x5d15,0x5d17,0x5d5c,0x5d1f,
0x5d1b,0x5d11,0x5d14,0x5d22,0x5d1a,0x5d19,0x5d18,0x5d4c,
0x5d52,0x5d4e,0x5d4b,0x5d6c,0x5d73,0x5d76,0x5d87,0x5d84,
0x5d82,0x5da2,0x5d9d,0x5dac,0x5dae,0x5dbd,0x5d90,0x5db7,
0x5dbc,0x5dc9,0x5dcd,0x5dd3,0x5dd2,0x5dd6,0x5ddb,0x5deb,
0x5df2,0x5df5,0x5e0b,0x5e1a,0x5e19,0x5e11,0x5e1b,0x5e36,
0x5e37,0x5e44,0x5e43,0x5e40,0x5e4e,0x5e57,0x5e54,0x5e5f,
0x5e62,0x5e64,0x5e47,0x5e75,0x5e76,0x5e7a,0x9ebc,0x5e7f,
0x5ea0,0x5ec1,0x5ec2,0x5ec8,0x5ed0,0x5ecf,
0x5ed6,0x5ee3,0x5edd,0x5eda,0x5edb,0x5ee2,0x5ee1,0x5ee8,
0x5ee9,0x5eec,0x5ef1,0x5ef3,0x5ef0,0x5ef4,0x5ef8,0x5efe,
0x5f03,0x5f09,0x5f5d,0x5f5c,0x5f0b,0x5f11,0x5f16,0x5f29,
0x5f2d,0x5f38,0x5f41,0x5f48,0x5f4c,0x5f4e,0x5f2f,0x5f51,
0x5f56,0x5f57,0x5f59,0x5f61,0x5f6d,0x5f73,0x5f77,0x5f83,
0x5f82,0x5f7f,0x5f8a,0x5f88,0x5f91,0x5f87,0x5f9e,0x5f99,
0x5f98,0x5fa0,0x5fa8,0x5fad,0x5fbc,0x5fd6,0x5ffb,0x5fe4,
0x5ff8,0x5ff1,0x5fdd,0x60b3,0x5fff,0x6021,0x6060,0x6019,
0x6010,0x6029,0x600e,0x6031,0x601b,0x6015,0x602b,0x6026,
0x600f,0x603a,0x605a,0x6041,0x606a,0x6077,0x605f,0x604a,
0x6046,0x604d,0x6063,0x6043,0x6064,0x6042,0x606c,0x606b,
0x6059,0x6081,0x608d,0x60e7,0x6083,0x609a,
0x6084,0x609b,0x6096,0x6097,0x6092,0x60a7,0x608b,0x60e1,
0x60b8,0x60e0,0x60d3,0x60b4,0x5ff0,0x60bd,0x60c6,0x60b5,
0x60d8,0x614d,0x6115,0x6106,0x60f6,0x60f7,0x6100,0x60f4,
0x60fa,0x6103,0x6121,0x60fb,0x60f1,0x610d,0x610e,0x6147,
0x613e,0x6128,0x6127,0x614a,0x613f,0x613c,0x612c,0x6134,
0x613d,0x6142,0x6144,0x6173,0x6177,0x6158,0x6159,0x615a,
0x616b,0x6174,0x616f,0x6165,0x6171,0x615f,0x615d,0x6153,
0x6175,0x6199,0x6196,0x6187,0x61ac,0x6194,0x619a,0x618a,
0x6191,0x61ab,0x61ae,0x61cc,0x61ca,0x61c9,0x61f7,0x61c8,
0x61c3,0x61c6,0x61ba,0x61cb,0x7f79,0x61cd,0x61e6,0x61e3,
0x61f6,0x61fa,0x61f4,0x61ff,0x61fd,0x61fc,0x61fe,0x6200,
0x6208,0x6209,0x620d,0x620c,0x6214,0x621b,
0x621e,0x6221,0x622a,0x622e,0x6230,0x6232,0x6233,0x6241,
0x624e,0x625e,0x6263,0x625b,0x6260,0x6268,0x627c,0x6282,
0x6289,0x627e,0x6292,0x6293,0x6296,0x62d4,0x6283,0x6294,
0x62d7,0x62d1,0x62bb,0x62cf,0x62ff,0x62c6,0x64d4,0x62c8,
0x62dc,0x62cc,0x62ca,0x62c2,0x62c7,0x629b,0x62c9,0x630c,
0x62ee,0x62f1,0x6327,0x6302,0x6308,0x62ef,0x62f5,0x6350,
0x633e,0x634d,0x641c,0x634f,0x6396,0x638e,0x6380,0x63ab,
0x6376,0x63a3,0x638f,0x6389,0x639f,0x63b5,0x636b,0x6369,
0x63be,0x63e9,0x63c0,0x63c6,0x63e3,0x63c9,0x63d2,0x63f6,
0x63c4,0x6416,0x6434,0x6406,0x6413,0x6426,0x6436,0x651d,
0x6417,0x6428,0x640f,0x6467,0x646f,0x6476,0x644e,0x652a,
0x6495,0x6493,0x64a5,0x64a9,0x6488,0x64bc,
0x64da,0x64d2,0x64c5,0x64c7,0x64bb,0x64d8,0x64c2,0x64f1,
0x64e7,0x8209,0x64e0,0x64e1,0x62ac,0x64e3,0x64ef,0x652c,
0x64f6,0x64f4,0x64f2,0x64fa,0x6500,0x64fd,0x6518,0x651c,
0x6505,0x6524,0x6523,0x652b,0x6534,0x6535,0x6537,0x6536,
0x6538,0x754b,0x6548,0x6556,0x6555,0x654d,0x6558,0x655e,
0x655d,0x6572,0x6578,0x6582,0x6583,0x8b8a,0x659b,0x659f,
0x65ab,0x65b7,0x65c3,0x65c6,0x65c1,0x65c4,0x65cc,0x65d2,
0x65db,0x65d9,0x65e0,0x65e1,0x65f1,0x6772,0x660a,0x6603,
0x65fb,0x6773,0x6635,0x6636,0x6634,0x661c,0x664f,0x6644,
0x6649,0x6641,0x665e,0x665d,0x6664,0x6667,0x6668,0x665f,
0x6662,0x6670,0x6683,0x6688,0x668e,0x6689,0x6684,0x6698,
0x669d,0x66c1,0x66b9,0x66c9,0x66be,0x66bc,
0x66c4,0x66b8,0x66d6,0x66da,0x66e0,0x663f,0x66e6,0x66e9,
0x66f0,0x66f5,0x66f7,0x670f,0x6716,0x671e,0x6726,0x6727,
0x9738,0x672e,0x673f,0x6736,0x6741,0x6738,0x6737,0x6746,
0x675e,0x6760,0x6759,0x6763,0x6764,0x6789,0x6770,0x67a9,
0x677c,0x676a,0x678c,0x678b,0x67a6,0x67a1,0x6785,0x67b7,
0x67ef,0x67b4,0x67ec,0x67b3,0x67e9,0x67b8,0x67e4,0x67de,
0x67dd,0x67e2,0x67ee,0x67b9,0x67ce,0x67c6,0x67e7,0x6a9c,
0x681e,0x6846,0x6829,0x6840,0x684d,0x6832,0x684e,0x68b3,
0x682b,0x6859,0x6863,0x6877,0x687f,0x689f,0x688f,0x68ad,
0x6894,0x689d,0x689b,0x6883,0x6aae,0x68b9,0x6874,0x68b5,
0x68a0,0x68ba,0x690f,0x688d,0x687e,0x6901,0x68ca,0x6908,
0x68d8,0x6922,0x6926,0x68e1,0x690c,0x68cd,
0x68d4,0x68e7,0x68d5,0x6936,0x6912,0x6904,0x68d7,0x68e3,
0x6925,0x68f9,0x68e0,0x68ef,0x6928,0x692a,0x691a,0x6923,
0x6921,0x68c6,0x6979,0x6977,0x695c,0x6978,0x696b,0x6954,
0x697e,0x696e,0x6939,0x6974,0x693d,0x6959,0x6930,0x6961,
0x695e,0x695d,0x6981,0x696a,0x69b2,0x69ae,0x69d0,0x69bf,
0x69c1,0x69d3,0x69be,0x69ce,0x5be8,0x69ca,0x69dd,0x69bb,
0x69c3,0x69a7,0x6a2e,0x6991,0x69a0,0x699c,0x6995,0x69b4,
0x69de,0x69e8,0x6a02,0x6a1b,0x69ff,0x6b0a,0x69f9,0x69f2,
0x69e7,0x6a05,0x69b1,0x6a1e,0x69ed,0x6a14,0x69eb,0x6a0a,
0x6a12,0x6ac1,0x6a23,0x6a13,0x6a44,0x6a0c,0x6a72,0x6a36,
0x6a78,0x6a47,0x6a62,0x6a59,0x6a66,0x6a48,0x6a38,0x6a22,
0x6a90,0x6a8d,0x6aa0,0x6a84,0x6aa2,0x6aa3,
0x6a97,0x8617,0x6abb,0x6ac3,0x6ac2,0x6ab8,0x6ab3,0x6aac,
0x6ade,0x6ad1,0x6adf,0x6aaa,0x6ada,0x6aea,0x6afb,0x6b05,
0x8616,0x6afa,0x6b12,0x6b16,0x9b31,0x6b1f,0x6b38,0x6b37,
0x76dc,0x6b39,0x98ee,0x6b47,0x6b43,0x6b49,0x6b50,0x6b59,
0x6b54,0x6b5b,0x6b5f,0x6b61,0x6b78,0x6b79,0x6b7f,0x6b80,
0x6b84,0x6b83,0x6b8d,0x6b98,0x6b95,0x6b9e,0x6ba4,0x6baa,
0x6bab,0x6baf,0x6bb2,0x6bb1,0x6bb3,0x6bb7,0x6bbc,0x6bc6,
0x6bcb,0x6bd3,0x6bdf,0x6bec,0x6beb,0x6bf3,0x6bef,0x9ebe,
0x6c08,0x6c13,0x6c14,0x6c1b,0x6c24,0x6c23,0x6c5e,0x6c55,
0x6c62,0x6c6a,0x6c82,0x6c8d,0x6c9a,0x6c81,0x6c9b,0x6c7e,
0x6c68,0x6c73,0x6c92,0x6c90,0x6cc4,0x6cf1,0x6cd3,0x6cbd,
0x6cd7,0x6cc5,0x6cdd,0x6cae,0x6cb1,0x6cbe,
0x6cba,0x6cdb,0x6cef,0x6cd9,0x6cea,0x6d1f,0x884d,0x6d36,
0x6d2b,0x6d3d,0x6d38,0x6d19,0x6d35,0x6d33,0x6d12,0x6d0c,
0x6d63,0x6d93,0x6d64,0x6d5a,0x6d79,0x6d59,0x6d8e,0x6d95,
0x6fe4,0x6d85,0x6df9,0x6e15,0x6e0a,0x6db5,0x6dc7,0x6de6,
0x6db8,0x6dc6,0x6dec,0x6dde,0x6dcc,0x6de8,0x6dd2,0x6dc5,
0x6dfa,0x6dd9,0x6de4,0x6dd5,0x6dea,0x6dee,0x6e2d,0x6e6e,
0x6e2e,0x6e19,0x6e72,0x6e5f,0x6e3e,0x6e23,0x6e6b,0x6e2b,
0x6e76,0x6e4d,0x6e1f,0x6e43,0x6e3a,0x6e4e,0x6e24,0x6eff,
0x6e1d,0x6e38,0x6e82,0x6eaa,0x6e98,0x6ec9,0x6eb7,0x6ed3,
0x6ebd,0x6eaf,0x6ec4,0x6eb2,0x6ed4,0x6ed5,0x6e8f,0x6ea5,
0x6ec2,0x6e9f,0x6f41,0x6f11,0x704c,0x6eec,0x6ef8,0x6efe,
0x6f3f,0x6ef2,0x6f31,0x6eef,0x6f32,0x6ecc,
0x6f3e,0x6f13,0x6ef7,0x6f86,0x6f7a,0x6f78,0x6f81,0x6f80,
0x6f6f,0x6f5b,0x6ff3,0x6f6d,0x6f82,0x6f7c,0x6f58,0x6f8e,
0x6f91,0x6fc2,0x6f66,0x6fb3,0x6fa3,0x6fa1,0x6fa4,0x6fb9,
0x6fc6,0x6faa,0x6fdf,0x6fd5,0x6fec,0x6fd4,0x6fd8,0x6ff1,
0x6fee,0x6fdb,0x7009,0x700b,0x6ffa,0x7011,0x7001,0x700f,
0x6ffe,0x701b,0x701a,0x6f74,0x701d,0x7018,0x701f,0x7030,
0x703e,0x7032,0x7051,0x7063,0x7099,0x7092,0x70af,0x70f1,
0x70ac,0x70b8,0x70b3,0x70ae,0x70df,0x70cb,0x70dd,0x70d9,
0x7109,0x70fd,0x711c,0x7119,0x7165,0x7155,0x7188,0x7166,
0x7162,0x714c,0x7156,0x716c,0x718f,0x71fb,0x7184,0x7195,
0x71a8,0x71ac,0x71d7,0x71b9,0x71be,0x71d2,0x71c9,0x71d4,
0x71ce,0x71e0,0x71ec,0x71e7,0x71f5,0x71fc,
0x71f9,0x71ff,0x720d,0x7210,0x721b,0x7228,0x722d,0x722c,
0x7230,0x7232,0x723b,0x723c,0x723f,0x7240,0x7246,0x724b,
0x7258,0x7274,0x727e,0x7282,0x7281,0x7287,0x7292,0x7296,
0x72a2,0x72a7,0x72b9,0x72b2,0x72c3,0x72c6,0x72c4,0x72ce,
0x72d2,0x72e2,0x72e0,0x72e1,0x72f9,0x72f7,0x500f,0x7317,
0x730a,0x731c,0x7316,0x731d,0x7334,0x732f,0x7329,0x7325,
0x733e,0x734e,0x734f,0x9ed8,0x7357,0x736a,0x7368,0x7370,
0x7378,0x7375,0x737b,0x737a,0x73c8,0x73b3,0x73ce,0x73bb,
0x73c0,0x73e5,0x73ee,0x73de,0x74a2,0x7405,0x746f,0x7425,
0x73f8,0x7432,0x743a,0x7455,0x743f,0x745f,0x7459,0x7441,
0x745c,0x7469,0x7470,0x7463,0x746a,0x7476,0x747e,0x748b,
0x749e,0x74a7,0x74ca,0x74cf,0x74d4,0x73f1,
0x74e0,0x74e3,0x74e7,0x74e9,0x74ee,0x74f2,0x74f0,0x74f1,
0x74f8,0x74f7,0x7504,0x7503,0x7505,0x750c,0x750e,0x750d,
0x7515,0x7513,0x751e,0x7526,0x752c,0x753c,0x7544,0x754d,
0x754a,0x7549,0x755b,0x7546,0x755a,0x7569,0x7564,0x7567,
0x756b,0x756d,0x7578,0x7576,0x7586,0x7587,0x7574,0x758a,
0x7589,0x7582,0x7594,0x759a,0x759d,0x75a5,0x75a3,0x75c2,
0x75b3,0x75c3,0x75b5,0x75bd,0x75b8,0x75bc,0x75b1,0x75cd,
0x75ca,0x75d2,0x75d9,0x75e3,0x75de,0x75fe,0x75ff,0x75fc,
0x7601,0x75f0,0x75fa,0x75f2,0x75f3,0x760b,0x760d,0x7609,
0x761f,0x7627,0x7620,0x7621,0x7622,0x7624,0x7634,0x7630,
0x763b,0x7647,0x7648,0x7646,0x765c,0x7658,0x7661,0x7662,
0x7668,0x7669,0x766a,0x7667,0x766c,0x7670,
0x7672,0x7676,0x7678,0x767c,0x7680,0x7683,0x7688,0x768b,
0x768e,0x7696,0x7693,0x7699,0x769a,0x76b0,0x76b4,0x76b8,
0x76b9,0x76ba,0x76c2,0x76cd,0x76d6,0x76d2,0x76de,0x76e1,
0x76e5,0x76e7,0x76ea,0x862f,0x76fb,0x7708,0x7707,0x7704,
0x7729,0x7724,0x771e,0x7725,0x7726,0x771b,0x7737,0x7738,
0x7747,0x775a,0x7768,0x776b,0x775b,0x7765,0x777f,0x777e,
0x7779,0x778e,0x778b,0x7791,0x77a0,0x779e,0x77b0,0x77b6,
0x77b9,0x77bf,0x77bc,0x77bd,0x77bb,0x77c7,0x77cd,0x77d7,
0x77da,0x77dc,0x77e3,0x77ee,0x77fc,0x780c,0x7812,0x7926,
0x7820,0x792a,0x7845,0x788e,0x7874,0x7886,0x787c,0x789a,
0x788c,0x78a3,0x78b5,0x78aa,0x78af,0x78d1,0x78c6,0x78cb,
0x78d4,0x78be,0x78bc,0x78c5,0x78ca,0x78ec,
0x78e7,0x78da,0x78fd,0x78f4,0x7907,0x7912,0x7911,0x7919,
0x792c,0x792b,0x7940,0x7960,0x7957,0x795f,0x795a,0x7955,
0x7953,0x797a,0x797f,0x798a,0x799d,0x79a7,0x9f4b,0x79aa,
0x79ae,0x79b3,0x79b9,0x79ba,0x79c9,0x79d5,0x79e7,0x79ec,
0x79e1,0x79e3,0x7a08,0x7a0d,0x7a18,0x7a19,0x7a20,0x7a1f,
0x7980,0x7a31,0x7a3b,0x7a3e,0x7a37,0x7a43,0x7a57,0x7a49,
0x7a61,0x7a62,0x7a69,0x9f9d,0x7a70,0x7a79,0x7a7d,0x7a88,
0x7a97,0x7a95,0x7a98,0x7a96,0x7aa9,0x7ac8,0x7ab0,0x7ab6,
0x7ac5,0x7ac4,0x7abf,0x9083,0x7ac7,0x7aca,0x7acd,0x7acf,
0x7ad5,0x7ad3,0x7ad9,0x7ada,0x7add,0x7ae1,0x7ae2,0x7ae6,
0x7aed,0x7af0,0x7b02,0x7b0f,0x7b0a,0x7b06,0x7b33,0x7b18,
0x7b19,0x7b1e,0x7b35,0x7b28,0x7b36,0x7b50,
0x7b7a,0x7b04,0x7b4d,0x7b0b,0x7b4c,0x7b45,0x7b75,0x7b65,
0x7b74,0x7b67,0x7b70,0x7b71,0x7b6c,0x7b6e,0x7b9d,0x7b98,
0x7b9f,0x7b8d,0x7b9c,0x7b9a,0x7b8b,0x7b92,0x7b8f,0x7b5d,
0x7b99,0x7bcb,0x7bc1,0x7bcc,0x7bcf,0x7bb4,0x7bc6,0x7bdd,
0x7be9,0x7c11,0x7c14,0x7be6,0x7be5,0x7c60,0x7c00,0x7c07,
0x7c13,0x7bf3,0x7bf7,0x7c17,0x7c0d,0x7bf6,0x7c23,0x7c27,
0x7c2a,0x7c1f,0x7c37,0x7c2b,0x7c3d,0x7c4c,0x7c43,0x7c54,
0x7c4f,0x7c40,0x7c50,0x7c58,0x7c5f,0x7c64,0x7c56,0x7c65,
0x7c6c,0x7c75,0x7c83,0x7c90,0x7ca4,0x7cad,0x7ca2,0x7cab,
0x7ca1,0x7ca8,0x7cb3,0x7cb2,0x7cb1,0x7cae,0x7cb9,0x7cbd,
0x7cc0,0x7cc5,0x7cc2,0x7cd8,0x7cd2,0x7cdc,0x7ce2,0x9b3b,
0x7cef,0x7cf2,0x7cf4,0x7cf6,0x7cfa,0x7d06,
0x7d02,0x7d1c,0x7d15,0x7d0a,0x7d45,0x7d4b,0x7d2e,0x7d32,
0x7d3f,0x7d35,0x7d46,0x7d73,0x7d56,0x7d4e,0x7d72,0x7d68,
0x7d6e,0x7d4f,0x7d63,0x7d93,0x7d89,0x7d5b,0x7d8f,0x7d7d,
0x7d9b,0x7dba,0x7dae,0x7da3,0x7db5,0x7dc7,0x7dbd,0x7dab,
0x7e3d,0x7da2,0x7daf,0x7ddc,0x7db8,0x7d9f,0x7db0,0x7dd8,
0x7ddd,0x7de4,0x7dde,0x7dfb,0x7df2,0x7de1,0x7e05,0x7e0a,
0x7e23,0x7e21,0x7e12,0x7e31,0x7e1f,0x7e09,0x7e0b,0x7e22,
0x7e46,0x7e66,0x7e3b,0x7e35,0x7e39,0x7e43,0x7e37,0x7e32,
0x7e3a,0x7e67,0x7e5d,0x7e56,0x7e5e,0x7e59,0x7e5a,0x7e79,
0x7e6a,0x7e69,0x7e7c,0x7e7b,0x7e83,0x7dd5,0x7e7d,0x8fae,
0x7e7f,0x7e88,0x7e89,0x7e8c,0x7e92,0x7e90,0x7e93,0x7e94,
0x7e96,0x7e8e,0x7e9b,0x7e9c,0x7f38,0x7f3a,
0x7f45,0x7f4c,0x7f4d,0x7f4e,0x7f50,0x7f51,0x7f55,0x7f54,
0x7f58,0x7f5f,0x7f60,0x7f68,0x7f69,0x7f67,0x7f78,0x7f82,
0x7f86,0x7f83,0x7f88,0x7f87,0x7f8c,0x7f94,0x7f9e,0x7f9d,
0x7f9a,0x7fa3,0x7faf,0x7fb2,0x7fb9,0x7fae,0x7fb6,0x7fb8,
0x8b71,0x7fc5,0x7fc6,0x7fca,0x7fd5,0x7fd4,0x7fe1,0x7fe6,
0x7fe9,0x7ff3,0x7ff9,0x98dc,0x8006,0x8004,0x800b,0x8012,
0x8018,0x8019,0x801c,0x8021,0x8028,0x803f,0x803b,0x804a,
0x8046,0x8052,0x8058,0x805a,0x805f,0x8062,0x8068,0x8073,
0x8072,0x8070,0x8076,0x8079,0x807d,0x807f,0x8084,0x8086,
0x8085,0x809b,0x8093,0x809a,0x80ad,0x5190,0x80ac,0x80db,
0x80e5,0x80d9,0x80dd,0x80c4,0x80da,0x80d6,0x8109,0x80ef,
0x80f1,0x811b,0x8129,0x8123,0x812f,0x814b,
0x968b,0x8146,0x813e,0x8153,0x8151,0x80fc,0x8171,0x816e,
0x8165,0x8166,0x8174,0x8183,0x8188,0x818a,0x8180,0x8182,
0x81a0,0x8195,0x81a4,0x81a3,0x815f,0x8193,0x81a9,0x81b0,
0x81b5,0x81be,0x81b8,0x81bd,0x81c0,0x81c2,0x81ba,0x81c9,
0x81cd,0x81d1,0x81d9,0x81d8,0x81c8,0x81da,0x81df,0x81e0,
0x81e7,0x81fa,0x81fb,0x81fe,0x8201,0x8202,0x8205,0x8207,
0x820a,0x820d,0x8210,0x8216,0x8229,0x822b,0x8238,0x8233,
0x8240,0x8259,0x8258,0x825d,0x825a,0x825f,0x8264,0x8262,
0x8268,0x826a,0x826b,0x822e,0x8271,0x8277,0x8278,0x827e,
0x828d,0x8292,0x82ab,0x829f,0x82bb,0x82ac,0x82e1,0x82e3,
0x82df,0x82d2,0x82f4,0x82f3,0x82fa,0x8393,0x8303,0x82fb,
0x82f9,0x82de,0x8306,0x82dc,0x8309,0x82d9,
0x8335,0x8334,0x8316,0x8332,0x8331,0x8340,0x8339,0x8350,
0x8345,0x832f,0x832b,0x8317,0x8318,0x8385,0x839a,0x83aa,
0x839f,0x83a2,0x8396,0x8323,0x838e,0x8387,0x838a,0x837c,
0x83b5,0x8373,0x8375,0x83a0,0x8389,0x83a8,0x83f4,0x8413,
0x83eb,0x83ce,0x83fd,0x8403,0x83d8,0x840b,0x83c1,0x83f7,
0x8407,0x83e0,0x83f2,0x840d,0x8422,0x8420,0x83bd,0x8438,
0x8506,0x83fb,0x846d,0x842a,0x843c,0x855a,0x8484,0x8477,
0x846b,0x84ad,0x846e,0x8482,0x8469,0x8446,0x842c,0x846f,
0x8479,0x8435,0x84ca,0x8462,0x84b9,0x84bf,0x849f,0x84d9,
0x84cd,0x84bb,0x84da,0x84d0,0x84c1,0x84c6,0x84d6,0x84a1,
0x8521,0x84ff,0x84f4,0x8517,0x8518,0x852c,0x851f,0x8515,
0x8514,0x84fc,0x8540,0x8563,0x8558,0x8548,
0x8541,0x8602,0x854b,0x8555,0x8580,0x85a4,0x8588,0x8591,
0x858a,0x85a8,0x856d,0x8594,0x859b,0x85ea,0x8587,0x859c,
0x8577,0x857e,0x8590,0x85c9,0x85ba,0x85cf,0x85b9,0x85d0,
0x85d5,0x85dd,0x85e5,0x85dc,0x85f9,0x860a,0x8613,0x860b,
0x85fe,0x85fa,0x8606,0x8622,0x861a,0x8630,0x863f,0x864d,
0x4e55,0x8654,0x865f,0x8667,0x8671,0x8693,0x86a3,0x86a9,
0x86aa,0x868b,0x868c,0x86b6,0x86af,0x86c4,0x86c6,0x86b0,
0x86c9,0x8823,0x86ab,0x86d4,0x86de,0x86e9,0x86ec,0x86df,
0x86db,0x86ef,0x8712,0x8706,0x8708,0x8700,0x8703,0x86fb,
0x8711,0x8709,0x870d,0x86f9,0x870a,0x8734,0x873f,0x8737,
0x873b,0x8725,0x8729,0x871a,0x8760,0x875f,0x8778,0x874c,
0x874e,0x8774,0x8757,0x8768,0x876e,0x8759,
0x8753,0x8763,0x876a,0x8805,0x87a2,0x879f,0x8782,0x87af,
0x87cb,0x87bd,0x87c0,0x87d0,0x96d6,0x87ab,0x87c4,0x87b3,
0x87c7,0x87c6,0x87bb,0x87ef,0x87f2,0x87e0,0x880f,0x880d,
0x87fe,0x87f6,0x87f7,0x880e,0x87d2,0x8811,0x8816,0x8815,
0x8822,0x8821,0x8831,0x8836,0x8839,0x8827,0x883b,0x8844,
0x8842,0x8852,0x8859,0x885e,0x8862,0x886b,0x8881,0x887e,
0x889e,0x8875,0x887d,0x88b5,0x8872,0x8882,0x8897,0x8892,
0x88ae,0x8899,0x88a2,0x888d,0x88a4,0x88b0,0x88bf,0x88b1,
0x88c3,0x88c4,0x88d4,0x88d8,0x88d9,0x88dd,0x88f9,0x8902,
0x88fc,0x88f4,0x88e8,0x88f2,0x8904,0x890c,0x890a,0x8913,
0x8943,0x891e,0x8925,0x892a,0x892b,0x8941,0x8944,0x893b,
0x8936,0x8938,0x894c,0x891d,0x8960,0x895e,
0x8966,0x8964,0x896d,0x896a,0x896f,0x8974,0x8977,0x897e,
0x8983,0x8988,0x898a,0x8993,0x8998,0x89a1,0x89a9,0x89a6,
0x89ac,0x89af,0x89b2,0x89ba,0x89bd,0x89bf,0x89c0,0x89da,
0x89dc,0x89dd,0x89e7,0x89f4,0x89f8,0x8a03,0x8a16,0x8a10,
0x8a0c,0x8a1b,0x8a1d,0x8a25,0x8a36,0x8a41,0x8a5b,0x8a52,
0x8a46,0x8a48,0x8a7c,0x8a6d,0x8a6c,0x8a62,0x8a85,0x8a82,
0x8a84,0x8aa8,0x8aa1,0x8a91,0x8aa5,0x8aa6,0x8a9a,0x8aa3,
0x8ac4,0x8acd,0x8ac2,0x8ada,0x8aeb,0x8af3,0x8ae7,0x8ae4,
0x8af1,0x8b14,0x8ae0,0x8ae2,0x8af7,0x8ade,0x8adb,0x8b0c,
0x8b07,0x8b1a,0x8ae1,0x8b16,0x8b10,0x8b17,0x8b20,0x8b33,
0x97ab,0x8b26,0x8b2b,0x8b3e,0x8b28,0x8b41,0x8b4c,0x8b4f,
0x8b4e,0x8b49,0x8b56,0x8b5b,0x8b5a,0x8b6b,
0x8b5f,0x8b6c,0x8b6f,0x8b74,0x8b7d,0x8b80,0x8b8c,0x8b8e,
0x8b92,0x8b93,0x8b96,0x8b99,0x8b9a,0x8c3a,0x8c41,0x8c3f,
0x8c48,0x8c4c,0x8c4e,0x8c50,0x8c55,0x8c62,0x8c6c,0x8c78,
0x8c7a,0x8c82,0x8c89,0x8c85,0x8c8a,0x8c8d,0x8c8e,0x8c94,
0x8c7c,0x8c98,0x621d,0x8cad,0x8caa,0x8cbd,0x8cb2,0x8cb3,
0x8cae,0x8cb6,0x8cc8,0x8cc1,0x8ce4,0x8ce3,0x8cda,0x8cfd,
0x8cfa,0x8cfb,0x8d04,0x8d05,0x8d0a,0x8d07,0x8d0f,0x8d0d,
0x8d10,0x9f4e,0x8d13,0x8ccd,0x8d14,0x8d16,0x8d67,0x8d6d,
0x8d71,0x8d73,0x8d81,0x8d99,0x8dc2,0x8dbe,0x8dba,0x8dcf,
0x8dda,0x8dd6,0x8dcc,0x8ddb,0x8dcb,0x8dea,0x8deb,0x8ddf,
0x8de3,0x8dfc,0x8e08,0x8e09,0x8dff,0x8e1d,0x8e1e,0x8e10,
0x8e1f,0x8e42,0x8e35,0x8e30,0x8e34,0x8e4a,
0x8e47,0x8e49,0x8e4c,0x8e50,0x8e48,0x8e59,0x8e64,0x8e60,
0x8e2a,0x8e63,0x8e55,0x8e76,0x8e72,0x8e7c,0x8e81,0x8e87,
0x8e85,0x8e84,0x8e8b,0x8e8a,0x8e93,0x8e91,0x8e94,0x8e99,
0x8eaa,0x8ea1,0x8eac,0x8eb0,0x8ec6,0x8eb1,0x8ebe,0x8ec5,
0x8ec8,0x8ecb,0x8edb,0x8ee3,0x8efc,0x8efb,0x8eeb,0x8efe,
0x8f0a,0x8f05,0x8f15,0x8f12,0x8f19,0x8f13,0x8f1c,0x8f1f,
0x8f1b,0x8f0c,0x8f26,0x8f33,0x8f3b,0x8f39,0x8f45,0x8f42,
0x8f3e,0x8f4c,0x8f49,0x8f46,0x8f4e,0x8f57,0x8f5c,0x8f62,
0x8f63,0x8f64,0x8f9c,0x8f9f,0x8fa3,0x8fad,0x8faf,0x8fb7,
0x8fda,0x8fe5,0x8fe2,0x8fea,0x8fef,0x9087,0x8ff4,0x9005,
0x8ff9,0x8ffa,0x9011,0x9015,0x9021,0x900d,0x901e,0x9016,
0x900b,0x9027,0x9036,0x9035,0x9039,0x8ff8,
0x904f,0x9050,0x9051,0x9052,0x900e,0x9049,0x903e,0x9056,
0x9058,0x905e,0x9068,0x906f,0x9076,0x96a8,0x9072,0x9082,
0x907d,0x9081,0x9080,0x908a,0x9089,0x908f,0x90a8,0x90af,
0x90b1,0x90b5,0x90e2,0x90e4,0x6248,0x90db,0x9102,0x9112,
0x9119,0x9132,0x9130,0x914a,0x9156,0x9158,0x9163,0x9165,
0x9169,0x9173,0x9172,0x918b,0x9189,0x9182,0x91a2,0x91ab,
0x91af,0x91aa,0x91b5,0x91b4,0x91ba,0x91c0,0x91c1,0x91c9,
0x91cb,0x91d0,0x91d6,0x91df,0x91e1,0x91db,0x91fc,0x91f5,
0x91f6,0x921e,0x91ff,0x9214,0x922c,0x9215,0x9211,0x925e,
0x9257,0x9245,0x9249,0x9264,0x9248,0x9295,0x923f,0x924b,
0x9250,0x929c,0x9296,0x9293,0x929b,0x925a,0x92cf,0x92b9,
0x92b7,0x92e9,0x930f,0x92fa,0x9344,0x932e,
0x9319,0x9322,0x931a,0x9323,0x933a,0x9335,0x933b,0x935c,
0x9360,0x937c,0x936e,0x9356,0x93b0,0x93ac,0x93ad,0x9394,
0x93b9,0x93d6,0x93d7,0x93e8,0x93e5,0x93d8,0x93c3,0x93dd,
0x93d0,0x93c8,0x93e4,0x941a,0x9414,0x9413,0x9403,0x9407,
0x9410,0x9436,0x942b,0x9435,0x9421,0x943a,0x9441,0x9452,
0x9444,0x945b,0x9460,0x9462,0x945e,0x946a,0x9229,0x9470,
0x9475,0x9477,0x947d,0x945a,0x947c,0x947e,0x9481,0x947f,
0x9582,0x9587,0x958a,0x9594,0x9596,0x9598,0x9599,0x95a0,
0x95a8,0x95a7,0x95ad,0x95bc,0x95bb,0x95b9,0x95be,0x95ca,
0x6ff6,0x95c3,0x95cd,0x95cc,0x95d5,0x95d4,0x95d6,0x95dc,
0x95e1,0x95e5,0x95e2,0x9621,0x9628,0x962e,0x962f,0x9642,
0x964c,0x964f,0x964b,0x9677,0x965c,0x965e,
0x965d,0x965f,0x9666,0x9672,0x966c,0x968d,0x9698,0x9695,
0x9697,0x96aa,0x96a7,0x96b1,0x96b2,0x96b0,0x96b4,0x96b6,
0x96b8,0x96b9,0x96ce,0x96cb,0x96c9,0x96cd,0x894d,0x96dc,
0x970d,0x96d5,0x96f9,0x9704,0x9706,0x9708,0x9713,0x970e,
0x9711,0x970f,0x9716,0x9719,0x9724,0x972a,0x9730,0x9739,
0x973d,0x973e,0x9744,0x9746,0x9748,0x9742,0x9749,0x975c,
0x9760,0x9764,0x9766,0x9768,0x52d2,0x976b,0x9771,0x9779,
0x9785,0x977c,0x9781,0x977a,0x9786,0x978b,0x978f,0x9790,
0x979c,0x97a8,0x97a6,0x97a3,0x97b3,0x97b4,0x97c3,0x97c6,
0x97c8,0x97cb,0x97dc,0x97ed,0x9f4f,0x97f2,0x7adf,0x97f6,
0x97f5,0x980f,0x980c,0x9838,0x9824,0x9821,0x9837,0x983d,
0x9846,0x984f,0x984b,0x986b,0x986f,0x9870,
0x9871,0x9874,0x9873,0x98aa,0x98af,0x98b1,0x98b6,0x98c4,
0x98c3,0x98c6,0x98e9,0x98eb,0x9903,0x9909,0x9912,0x9914,
0x9918,0x9921,0x991d,0x991e,0x9924,0x9920,0x992c,0x992e,
0x993d,0x993e,0x9942,0x9949,0x9945,0x9950,0x994b,0x9951,
0x9952,0x994c,0x9955,0x9997,0x9998,0x99a5,0x99ad,0x99ae,
0x99bc,0x99df,0x99db,0x99dd,0x99d8,0x99d1,0x99ed,0x99ee,
0x99f1,0x99f2,0x99fb,0x99f8,0x9a01,0x9a0f,0x9a05,0x99e2,
0x9a19,0x9a2b,0x9a37,0x9a45,0x9a42,0x9a40,0x9a43,0x9a3e,
0x9a55,0x9a4d,0x9a5b,0x9a57,0x9a5f,0x9a62,0x9a65,0x9a64,
0x9a69,0x9a6b,0x9a6a,0x9aad,0x9ab0,0x9abc,0x9ac0,0x9acf,
0x9ad1,0x9ad3,0x9ad4,0x9ade,0x9adf,0x9ae2,0x9ae3,0x9ae6,
0x9aef,0x9aeb,0x9aee,0x9af4,0x9af1,0x9af7,
0x9afb,0x9b06,0x9b18,0x9b1a,0x9b1f,0x9b22,0x9b23,0x9b25,
0x9b27,0x9b28,0x9b29,0x9b2a,0x9b2e,0x9b2f,0x9b32,0x9b44,
0x9b43,0x9b4f,0x9b4d,0x9b4e,0x9b51,0x9b58,0x9b74,0x9b93,
0x9b83,0x9b91,0x9b96,0x9b97,0x9b9f,0x9ba0,0x9ba8,0x9bb4,
0x9bc0,0x9bca,0x9bb9,0x9bc6,0x9bcf,0x9bd1,0x9bd2,0x9be3,
0x9be2,0x9be4,0x9bd4,0x9be1,0x9c3a,0x9bf2,0x9bf1,0x9bf0,
0x9c15,0x9c14,0x9c09,0x9c13,0x9c0c,0x9c06,0x9c08,0x9c12,
0x9c0a,0x9c04,0x9c2e,0x9c1b,0x9c25,0x9c24,0x9c21,0x9c30,
0x9c47,0x9c32,0x9c46,0x9c3e,0x9c5a,0x9c60,0x9c67,0x9c76,
0x9c78,0x9ce7,0x9cec,0x9cf0,0x9d09,0x9d08,0x9ceb,0x9d03,
0x9d06,0x9d2a,0x9d26,0x9daf,0x9d23,0x9d1f,0x9d44,0x9d15,
0x9d12,0x9d41,0x9d3f,0x9d3e,0x9d46,0x9d48,
0x9d5d,0x9d5e,0x9d64,0x9d51,0x9d50,0x9d59,0x9d72,0x9d89,
0x9d87,0x9dab,0x9d6f,0x9d7a,0x9d9a,0x9da4,0x9da9,0x9db2,
0x9dc4,0x9dc1,0x9dbb,0x9db8,0x9dba,0x9dc6,0x9dcf,0x9dc2,
0x9dd9,0x9dd3,0x9df8,0x9de6,0x9ded,0x9def,0x9dfd,0x9e1a,
0x9e1b,0x9e1e,0x9e75,0x9e79,0x9e7d,0x9e81,0x9e88,0x9e8b,
0x9e8c,0x9e92,0x9e95,0x9e91,0x9e9d,0x9ea5,0x9ea9,0x9eb8,
0x9eaa,0x9ead,0x9761,0x9ecc,0x9ece,0x9ecf,0x9ed0,0x9ed4,
0x9edc,0x9ede,0x9edd,0x9ee0,0x9ee5,0x9ee8,0x9eef,0x9ef4,
0x9ef6,0x9ef7,0x9ef9,0x9efb,0x9efc,0x9efd,0x9f07,0x9f08,
0x76b7,0x9f15,0x9f21,0x9f2c,0x9f3e,0x9f4a,0x9f52,0x9f54,
0x9f63,0x9f5f,0x9f60,0x9f61,0x9f66,0x9f67,0x9f6c,0x9f6a,
0x9f77,0x9f72,0x9f76,0x9f95,0x9f9c,0x9fa0,
/* 74xx */
       0x582f,0x69c7,0x9059,0x7464,0x51dc,0x7199,0xd84a,
0x5de2,0x5e14,0x5e18,0x5e58,0x5e5e,0x5ebe,0xf928,0x5ecb,
0x5ef9,0x5f00,0x5f02,0x5f07,0x5f1d,0x5f23,0x5f34,0x5f36,
0x5f3d,0x5f40,0x5f45,0x5f54,0x5f58,0x5f64,0x5f67,0x5f7d,
0x5f89,0x5f9c,0x5fa7,0x5faf,0x5fb5,0x5fb7,0x5fc9,0x5fde,
0x5fe1,0x5fe9,0x600d,0x6014,0x6018,0x6033,0x6035,0x6047,
0xfa3d,0x609d,0x609e,0x60cb,0x60d4,0x60d5,0x60dd,0x60f8,
0x611c,0x612b,0x6130,0x6137,0xfa3e,0x618d,0xfa3f,0x61bc,
0x61b9,0xfa40,0x6222,0x623e,0x6243,0x6256,0x625a,0x626f,
0x6285,0x62c4,0x62d6,0x62fc,0x630a,0x6318,0x6339,0x6343,
0x6365,0x637c,0x63e5,0x63ed,0x63f5,0x6410,0x6414,0x6422,
0x6479,0x6451,0x6460,0x646d,0x64ce,0x64be,0x64bf,
       0x64c4,0x64ca,0x64d0,0x64f7,0x64fb,0x6522,0x6529,
0xfa41,0x6567,0x659d,0xfa42,0x6600,0x6609,0x6615,0x661e,
0x663a,0x6622,0x6624,0x662b,0x6630,0x6631,0x6633,0x66fb,
0x6648,0x664c,0x231c4,0x6659,0x665a,0x6661,0x6665,0x6673,
0x6677,0x6678,0x668d,0xfa43,0x66a0,0x66b2,0x66bb,0x66c6,
0x66c8,0x3b22,0x66db,0x66e8,0x66fa,0x6713,0xf929,0x6733,
0x6766,0x6747,0x6748,0x677b,0x6781,0x6793,0x6798,0x679b,
0x67bb,0x67f9,0x67c0,0x67d7,0x67fc,0x6801,0x6852,0x681d,
0x682c,0x6831,0x685b,0x6872,0x6875,0xfa44,0x68a3,0x68a5,
0x68b2,0x68c8,0x68d0,0x68e8,0x68ed,0x68f0,0x68f1,0x68fc,
0x690a,0x6949,0x235c4,0x6935,0x6942,0x6957,0x6963,0x6964,
0x6968,0x6980,0xfa14,0x69a5,0x69ad,0x69cf,0x3bb6,
       0x3bc3,0x69e2,0x69e9,0x69ea,0x69f5,0x69f6,0x6a0f,
0x6a15,0x2373f,0x6a3b,0x6a3e,0x6a45,0x6a50,0x6a56,0x6a5b,
0x6a6b,0x6a73,0x23763,0x6a89,0x6a94,0x6a9d,0x6a9e,0x6aa5,
0x6ae4,0x6ae7,0x3c0f,0xf91d,0x6b1b,0x6b1e,0x6b2c,0x6b35,
0x6b46,0x6b56,0x6b60,0x6b65,0x6b67,0x6b77,0x6b82,0x6ba9,
0x6bad,0xf970,0x6bcf,0x6bd6,0x6bd7,0x6bff,0x6c05,0x6c10,
0x6c33,0x6c59,0x6c5c,0x6caa,0x6c74,0x6c76,0x6c85,0x6c86,
0x6c98,0x6c9c,0x6cfb,0x6cc6,0x6cd4,0x6ce0,0x6ceb,0x6cee,
0x23cfe,0x6d04,0x6d0e,0x6d2e,0x6d31,0x6d39,0x6d3f,0x6d58,
0x6d65,0xfa45,0x6d82,0x6d87,0x6d89,0x6d94,0x6daa,0x6dac,
0x6dbf,0x6dc4,0x6dd6,0x6dda,0x6ddb,0x6ddd,0x6dfc,0xfa46,
0x6e34,0x6e44,0x6e5c,0x6e5e,0x6eab,0x6eb1,0x6ec1,
       0x6ec7,0x6ece,0x6f10,0x6f1a,0xfa47,0x6f2a,0x6f2f,
0x6f33,0x6f51,0x6f59,0x6f5e,0x6f61,0x6f62,0x6f7e,0x6f88,
0x6f8c,0x6f8d,0x6f94,0x6fa0,0x6fa7,0x6fb6,0x6fbc,0x6fc7,
0x6fca,0x6ff9,0x6ff0,0x6ff5,0x7005,0x7006,0x7028,0x704a,
0x705d,0x705e,0x704e,0x7064,0x7075,0x7085,0x70a4,0x70ab,
0x70b7,0x70d4,0x70d8,0x70e4,0x710f,0x712b,0x711e,0x7120,
0x712e,0x7130,0x7146,0x7147,0x7151,0xfa48,0x7152,0x715c,
0x7160,0x7168,0xfa15,0x7185,0x7187,0x7192,0x71c1,0x71ba,
0x71c4,0x71fe,0x7200,0x7215,0x7255,0x7256,0x3e3f,0x728d,
0x729b,0x72be,0x72c0,0x72fb,0x247f1,0x7327,0x7328,0xfa16,
0x7350,0x7366,0x737c,0x7395,0x739f,0x73a0,0x73a2,0x73a6,
0x73ab,0x73c9,0x73cf,0x73d6,0x73d9,0x73e3,0x73e9,
/* 78xx */
       0x7407,0x740a,0x741a,0x741b,0xfa4a,0x7426,0x7428,
0x742a,0x742b,0x742c,0x742e,0x742f,0x7430,0x7444,0x7446,
0x7447,0x744b,0x7457,0x7462,0x746b,0x746d,0x7486,0x7487,
0x7489,0x7498,0x749c,0x749f,0x74a3,0x7490,0x74a6,0x74a8,
0x74a9,0x74b5,0x74bf,0x74c8,0x74c9,0x74da,0x74ff,0x7501,
0x7517,0x752f,0x756f,0x7579,0x7592,0x3f72,0x75ce,0x75e4,
0x7600,0x7602,0x7608,0x7615,0x7616,0x7619,0x761e,0x762d,
0x7635,0x7643,0x764b,0x7664,0x7665,0x766d,0x766f,0x7671,
0x7681,0x769b,0x769d,0x769e,0x76a6,0x76aa,0x76b6,0x76c5,
0x76cc,0x76ce,0x76d4,0x76e6,0x76f1,0x76fc,0x770a,0x7719,
0x7734,0x7736,0x7746,0x774d,0x774e,0x775c,0x775f,0x7762,
0x777a,0x7780,0x7794,0x77aa,0x77e0,0x782d,0x2548e,
       0x7843,0x784e,0x784f,0x7851,0x7868,0x786e,0xfa4b,
0x78b0,0x2550e,0x78ad,0x78e4,0x78f2,0x7900,0x78f7,0x791c,
0x792e,0x7931,0x7934,0xfa4c,0xfa4d,0x7945,0x7946,0xfa4e,
0xfa4f,0xfa50,0x795c,0xfa51,0xfa19,0xfa1a,0x7979,0xfa52,
0xfa53,0xfa1b,0x7998,0x79b1,0x79b8,0x79c8,0x79ca,0x25771,
0x79d4,0x79de,0x79eb,0x79ed,0x7a03,0xfa54,0x7a39,0x7a5d,
0x7a6d,0xfa55,0x7a85,0x7aa0,0x259c4,0x7ab3,0x7abb,0x7ace,
0x7aeb,0x7afd,0x7b12,0x7b2d,0x7b3b,0x7b47,0x7b4e,0x7b60,
0x7b6d,0x7b6f,0x7b72,0x7b9e,0xfa56,0x7bd7,0x7bd9,0x7c01,
0x7c31,0x7c1e,0x7c20,0x7c33,0x7c36,0x4264,0x25da1,0x7c59,
0x7c6d,0x7c79,0x7c8f,0x7c94,0x7ca0,0x7cbc,0x7cd5,0x7cd9,
0x7cdd,0x7d07,0x7d08,0x7d13,0x7d1d,0x7d23,0x7d31,
       0x7d41,0x7d48,0x7d53,0x7d5c,0x7d7a,0x7d83,0x7d8b,
0x7da0,0x7da6,0x7dc2,0x7dcc,0x7dd6,0x7de3,0xfa57,0x7e28,
0x7e08,0x7e11,0x7e15,0xfa59,0x7e47,0x7e52,0x7e61,0x7e8a,
0x7e8d,0x7f47,0xfa5a,0x7f91,0x7f97,0x7fbf,0x7fce,0x7fdb,
0x7fdf,0x7fec,0x7fee,0x7ffa,0xfa5b,0x8014,0x8026,0x8035,
0x8037,0x803c,0x80ca,0x80d7,0x80e0,0x80f3,0x8118,0x814a,
0x8160,0x8167,0x8168,0x816d,0x81bb,0x81ca,0x81cf,0x81d7,
0xfa5c,0x4453,0x445b,0x8260,0x8274,0x26aff,0x828e,0x82a1,
0x82a3,0x82a4,0x82a9,0x82ae,0x82b7,0x82be,0x82bf,0x82c6,
0x82d5,0x82fd,0x82fe,0x8300,0x8301,0x8362,0x8322,0x832d,
0x833a,0x8343,0x8347,0x8351,0x8355,0x837d,0x8386,0x8392,
0x8398,0x83a7,0x83a9,0x83bf,0x83c0,0x83c7,0x83cf,
       0x83d1,0x83e1,0x83ea,0x8401,0x8406,0x840a,0xfa5f,
0x8448,0x845f,0x8470,0x8473,0x8485,0x849e,0x84af,0x84b4,
0x84ba,0x84c0,0x84c2,0x26e40,0x8532,0x851e,0x8523,0x852f,
0x8559,0x8564,0xfa1f,0x85ad,0x857a,0x858c,0x858f,0x85a2,
0x85b0,0x85cb,0x85ce,0x85ed,0x8612,0x85ff,0x8604,0x8605,
0x8610,0x270f4,0x8618,0x8629,0x8638,0x8657,0x865b,0xf936,
0x8662,0x459d,0x866c,0x8675,0x8698,0x86b8,0x86fa,0x86fc,
0x86fd,0x870b,0x8771,0x8787,0x8788,0x87ac,0x87ad,0x87b5,
0x45ea,0x87d6,0x87ec,0x8806,0x880a,0x8810,0x8814,0x881f,
0x8898,0x88aa,0x88ca,0x88ce,0x27684,0x88f5,0x891c,0xfa60,
0x8918,0x8919,0x891a,0x8927,0x8930,0x8932,0x8939,0x8940,
0x8994,0xfa61,0x89d4,0x89e5,0x89f6,0x8a12,0x8a15,
/* 7cxx */
       0x8a22,0x8a37,0x8a47,0x8a4e,0x8a5d,0x8a61,0x8a75,
0x8a79,0x8aa7,0x8ad0,0x8adf,0x8af4,0x8af6,0xfa22,0xfa62,
0xfa63,0x8b46,0x8b54,0x8b59,0x8b69,0x8b9d,0x8c49,0x8c68,
0xfa64,0x8ce1,0x8cf4,0x8cf8,0x8cfe,0xfa65,0x8d12,0x8d1b,
0x8daf,0x8dce,0x8dd1,0x8dd7,0x8e20,0x8e23,0x8e3d,0x8e70,
0x8e7b,0x28277,0x8ec0,0x4844,0x8efa,0x8f1e,0x8f2d,0x8f36,
0x8f54,0x283cd,0x8fa6,0x8fb5,0x8fe4,0x8fe8,0x8fee,0x9008,
0x902d,0xfa67,0x9088,0x9095,0x9097,0x9099,0x909b,0x90a2,
0x90b3,0x90be,0x90c4,0x90c5,0x90c7,0x90d7,0x90dd,0x90de,
0x90ef,0x90f4,0xfa26,0x9114,0x9115,0x9116,0x9122,0x9123,
0x9127,0x912f,0x9131,0x9134,0x913d,0x9148,0x915b,0x9183,
0x919e,0x91ac,0x91b1,0x91bc,0x91d7,0x91fb,0x91e4,
       0x91e5,0x91ed,0x91f1,0x9207,0x9210,0x9238,0x9239,
0x923a,0x923c,0x9240,0x9243,0x924f,0x9278,0x9288,0x92c2,
0x92cb,0x92cc,0x92d3,0x92e0,0x92ff,0x9304,0x931f,0x9321,
0x9325,0x9348,0x9349,0x934a,0x9364,0x9365,0x936a,0x9370,
0x939b,0x93a3,0x93ba,0x93c6,0x93de,0x93df,0x9404,0x93fd,
0x9433,0x944a,0x9463,0x946b,0x9471,0x9472,0x958e,0x959f,
0x95a6,0x95a9,0x95ac,0x95b6,0x95bd,0x95cb,0x95d0,0x95d3,
0x49b0,0x95da,0x95de,0x9658,0x9684,0xf9dc,0x969d,0x96a4,
0x96a5,0x96d2,0x96de,0xfa68,0x96e9,0x96ef,0x9733,0x973b,
0x974d,0x974e,0x974f,0x975a,0x976e,0x9773,0x9795,0x97ae,
0x97ba,0x97c1,0x97c9,0x97de,0x97db,0x97f4,0xfa69,0x980a,
0x981e,0x982b,0x9830,0xfa6a,0x9852,0x9853,0x9856,
       0x9857,0x9859,0x985a,0xf9d0,0x9865,0x986c,0x98ba,
0x98c8,0x98e7,0x9958,0x999e,0x9a02,0x9a03,0x9a24,0x9a2d,
0x9a2e,0x9a38,0x9a4a,0x9a4e,0x9a52,0x9ab6,0x9ac1,0x9ac3,
0x9ace,0x9ad6,0x9af9,0x9b02,0x9b08,0x9b20,0x4c17,0x29c1a,
0x9b5e,0x9b79,0x9b66,0x9b72,0x9b75,0x9b84,0x9b8a,0x9b8f,
0x9b9e,0x9ba7,0x9bc1,0x9bce,0x9be5,0x9bf8,0x9bfd,0x9c00,
0x9c23,0x9c41,0x9c4f,0x9c50,0x9c53,0x9c63,0x9c65,0x9c77,
0x9d1d,0x9d1e,0x9d43,0x9d47,0x9d52,0x9d63,0x9d70,0x9d7c,
0x9d8a,0x9d96,0x9dc0,0x9dac,0x9dbc,0x9dd7,0x2a190,0x9de7,
0x9e07,0x9e15,0x9e7c,0x9e9e,0x9ea4,0x9eac,0x9eaf,0x9eb4,
0x9eb5,0x9ec3,0x9ed1,0x9f10,0x9f39,0x9f57,0x9f90,0x9f94,
0x9f97,0x9fa2,0xd84b,0xd84c,0xd84d,0xd84e,0xd84f
};

/* */
skf_ucode uni_t_0213_abbrev_q_21[JISX0213_Q_TBL_LEN] = {
       0x20089,0x4e02,0x4e0f,0x4e12,0x4e29,0x4e2b,0x4e2e,
0x4e40,0x4e47,0x4e48,0x200a2,0x4e51,0x3406,0x200a4,0x4e5a,
0x4e69,0x4e9d,0x342c,0x342e,0x4eb9,0x4ebb,0x201a2,0x4ebc,
0x4ec3,0x4ec8,0x4ed0,0x4eeb,0x4eda,0x4ef1,0x4ef5,0x4f00,
0x4f16,0x4f64,0x4f37,0x4f3e,0x4f54,0x4f58,0x20213,0x4f77,
0x4f78,0x4f7a,0x4f7d,0x4f82,0x4f85,0x4f92,0x4f9a,0x4fe6,
0x4fb2,0x4fbe,0x4fc5,0x4fcb,0x4fcf,0x4fd2,0x346a,0x4ff2,
0x5000,0x5010,0x5013,0x501c,0x501e,0x5022,0x3468,0x5042,
0x5046,0x504e,0x5053,0x5057,0x5063,0x5066,0x506a,0x5070,
0x50a3,0x5088,0x5092,0x5093,0x5095,0x5096,0x509c,0x50aa,
0x2032b,0x50b1,0x50ba,0x50bb,0x50c4,0x50c7,0x50f3,0x20381,
0x50ce,0x20371,0x50d4,0x50d9,0x50e1,0x50e9,0x3492,
       0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
/* 23xx */
       0x5108,0x203f9,0x5117,0x511b,0x2044a,0x5160,0x20509,
0x5173,0x5183,0x518b,0x34bc,0x5198,0x51a3,0x51ad,0x34c7,
0x51bc,0x205d6,0x20628,0x51f3,0x51f4,0x5202,0x5212,0x5216,
0x2074f,0x5255,0x525c,0x526c,0x5277,0x5284,0x5282,0x20807,
0x5298,0x2083a,0x52a4,0x52a6,0x52af,0x52ba,0x52bb,0x52ca,
0x351f,0x52d1,0x208b9,0x52f7,0x530a,0x530b,0x5324,0x5335,
0x533e,0x5342,0x2097c,0x2099d,0x5367,0x536c,0x537a,0x53a4,
0x53b4,0x20ad3,0x53b7,0x53c0,0x20b1d,0x355d,0x355e,0x53d5,
0x53da,0x3563,0x53f4,0x53f5,0x5455,0x5424,0x5428,0x356e,
0x5443,0x5462,0x5466,0x546c,0x548a,0x548d,0x5495,0x54a0,
0x54a6,0x54ad,0x54ae,0x54b7,0x54ba,0x54bf,0x54c3,0x20d45,
0x54ec,0x54ef,0x54f1,0x54f3,0x5500,0x5501,0x5509,
       0x553c,0x5541,0x35a6,0x5547,0x554a,0x35a8,0x5560,
0x5561,0x5564,0x20de1,0x557d,0x5582,0x5588,0x5591,0x35c5,
0x55d2,0x20e95,0x20e6d,0x55bf,0x55c9,0x55cc,0x55d1,0x55dd,
0x35da,0x55e2,0x20e64,0x55e9,0x5628,0x20f5f,0x5607,0x5610,
0x5630,0x5637,0x35f4,0x563d,0x563f,0x5640,0x5647,0x565e,
0x5660,0x566d,0x3605,0x5688,0x568c,0x5695,0x569a,0x569d,
0x56a8,0x56ad,0x56b2,0x56c5,0x56cd,0x56df,0x56e8,0x56f6,
0x56f7,0x21201,0x5715,0x5723,0x21255,0x5729,0x2127b,0x5745,
0x5746,0x574c,0x574d,0x21274,0x5768,0x576f,0x5773,0x5774,
0x5775,0x577b,0x212e4,0x212d7,0x57ac,0x579a,0x579d,0x579e,
0x57a8,0x57d7,0x212fd,0x57cc,0x21336,0x21344,0x57de,0x57e6,
0x57f0,0x364a,0x57f8,0x57fb,0x57fd,0x5804,0x581e,
       0x5820,0x5827,0x5832,0x5839,0x213c4,0x5849,0x584c,
0x5867,0x588a,0x588b,0x588d,0x588f,0x5890,0x5894,0x589d,
0x58aa,0x58b1,0x2146d,0x58c3,0x58cd,0x58e2,0x58f3,0x58f4,
0x5905,0x5906,0x590b,0x590d,0x5914,0x5924,0x215d7,0x3691,
0x593d,0x3699,0x5946,0x3696,0x26c29,0x595b,0x595f,0x21647,
0x5975,0x5976,0x597c,0x599f,0x59ae,0x59bc,0x59c8,0x59cd,
0x59de,0x59e3,0x59e4,0x59e7,0x59ee,0x21706,0x21742,0x36cf,
0x5a0c,0x5a0d,0x5a17,0x5a27,0x5a2d,0x5a55,0x5a65,0x5a7a,
0x5a8b,0x5a9c,0x5a9f,0x5aa0,0x5aa2,0x5ab1,0x5ab3,0x5ab5,
0x5aba,0x5abf,0x5ada,0x5adc,0x5ae0,0x5ae5,0x5af0,0x5aee,
0x5af5,0x5b00,0x5b08,0x5b17,0x5b34,0x5b2d,0x5b4c,0x5b52,
0x5b68,0x5b6f,0x5b7c,0x5b7f,0x5b81,0x5b84,0x219c3,
/* 26xx */
       0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
       0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
/* 28xx */
       0x5b96,0x5bac,0x3761,0x5bc0,0x3762,0x5bce,0x5bd6,
0x376c,0x376b,0x5bf1,0x5bfd,0x3775,0x5c03,0x5c29,0x5c30,
0x21c56,0x5c5f,0x5c63,0x5c67,0x5c68,0x5c69,0x5c70,0x21d2d,
0x21d45,0x5c7c,0x21d78,0x21d62,0x5c88,0x5c8a,0x37c1,0x21da1,
0x21d9c,0x5ca0,0x5ca2,0x5ca6,0x5ca7,0x21d92,0x5cad,0x5cb5,
0x21db7,0x5cc9,0x21de0,0x21e33,0x5d06,0x5d10,0x5d2b,0x5d1d,
0x5d20,0x5d24,0x5d26,0x5d31,0x5d39,0x5d42,0x37e8,0x5d61,
0x5d6a,0x37f4,0x5d70,0x21f1e,0x37fd,0x5d88,0x3800,0x5d92,
0x5d94,0x5d97,0x5d99,0x5db0,0x5db2,0x5db4,0x21f76,0x5db9,
0x5dd1,0x5dd7,0x5dd8,0x5de0,0x21ffa,0x5de4,0x5de9,0x382f,
0x5e00,0x3836,0x5e12,0x5e15,0x3840,0x5e1f,0x5e2e,0x5e3e,
0x5e49,0x385c,0x5e56,0x3861,0x5e6b,0x5e6c,0x5e6d,
       0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
       0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
       0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
/* 2cxx */
       0x5e6e,0x2217b,0x5ea5,0x5eaa,0x5eac,0x5eb9,0x5ebf,
0x5ec6,0x5ed2,0x5ed9,0x2231e,0x5efd,0x5f08,0x5f0e,0x5f1c,
0x223ad,0x5f1e,0x5f47,0x5f63,0x5f72,0x5f7e,0x5f8f,0x5fa2,
0x5fa4,0x5fb8,0x5fc4,0x38fa,0x5fc7,0x5fcb,0x5fd2,0x5fd3,
0x5fd4,0x5fe2,0x5fee,0x5fef,0x5ff3,0x5ffc,0x3917,0x6017,
0x6022,0x6024,0x391a,0x604c,0x607f,0x608a,0x6095,0x60a8,
0x226f3,0x60b0,0x60b1,0x60be,0x60c8,0x60d9,0x60db,0x60ee,
0x60f2,0x60f5,0x6110,0x6112,0x6113,0x6119,0x611e,0x613a,
0x396f,0x6141,0x6146,0x6160,0x617c,0x2285b,0x6192,0x6193,
0x6197,0x6198,0x61a5,0x61a8,0x61ad,0x228ab,0x61d5,0x61dd,
0x61df,0x61f5,0x2298f,0x6215,0x6223,0x6229,0x6246,0x624c,
0x6251,0x6252,0x6261,0x6264,0x627b,0x626d,0x6273,
       0x6299,0x62a6,0x62d5,0x22ab8,0x62fd,0x6303,0x630d,
0x6310,0x22b4f,0x22b50,0x6332,0x6335,0x633b,0x633c,0x6341,
0x6344,0x634e,0x22b46,0x6359,0x22c1d,0x22ba6,0x636c,0x6384,
0x6399,0x22c24,0x6394,0x63bd,0x63f7,0x63d4,0x63d5,0x63dc,
0x63e0,0x63eb,0x63ec,0x63f2,0x6409,0x641e,0x6425,0x6429,
0x642f,0x645a,0x645b,0x645d,0x6473,0x647d,0x6487,0x6491,
0x649d,0x649f,0x64cb,0x64cc,0x64d5,0x64d7,0x22de1,0x64e4,
0x64e5,0x64ff,0x6504,0x3a6e,0x650f,0x6514,0x6516,0x3a73,
0x651e,0x6532,0x6544,0x6554,0x656b,0x657a,0x6581,0x6584,
0x6585,0x658a,0x65b2,0x65b5,0x65b8,0x65bf,0x65c2,0x65c9,
0x65d4,0x3ad6,0x65f2,0x65f9,0x65fc,0x6604,0x6608,0x6621,
0x662a,0x6645,0x6651,0x664e,0x3aea,0x231c3,0x6657,
       0x665b,0x6663,0x231f5,0x231b6,0x666a,0x666b,0x666c,
0x666d,0x667b,0x6680,0x6690,0x6692,0x6699,0x3b0e,0x66ad,
0x66b1,0x66b5,0x3b1a,0x66bf,0x3b1c,0x66ec,0x3ad7,0x6701,
0x6705,0x6712,0x23372,0x6719,0x233d3,0x233d2,0x674c,0x674d,
0x6754,0x675d,0x233d0,0x233e4,0x233d5,0x6774,0x6776,0x233da,
0x6792,0x233df,0x8363,0x6810,0x67b0,0x67b2,0x67c3,0x67c8,
0x67d2,0x67d9,0x67db,0x67f0,0x67f7,0x2344a,0x23451,0x2344b,
0x6818,0x681f,0x682d,0x23465,0x6833,0x683b,0x683e,0x6844,
0x6845,0x6849,0x684c,0x6855,0x6857,0x3b77,0x686b,0x686e,
0x687a,0x687c,0x6882,0x6890,0x6896,0x3b6d,0x6898,0x6899,
0x689a,0x689c,0x68aa,0x68ab,0x68b4,0x68bb,0x68fb,0x234e4,
0x2355a,0xfa13,0x68c3,0x68c5,0x68cc,0x68cf,0x68d6,
       0x68d9,0x68e4,0x68e5,0x68ec,0x68f7,0x6903,0x6907,
0x3b87,0x3b88,0x23594,0x693b,0x3b8d,0x6946,0x6969,0x696c,
0x6972,0x697a,0x697f,0x6992,0x3ba4,0x6996,0x6998,0x69a6,
0x69b0,0x69b7,0x69ba,0x69bc,0x69c0,0x69d1,0x69d6,0x23639,
0x23647,0x6a30,0x23638,0x2363a,0x69e3,0x69ee,0x69ef,0x69f3,
0x3bcd,0x69f4,0x69fe,0x6a11,0x6a1a,0x6a1d,0x2371c,0x6a32,
0x6a33,0x6a34,0x6a3f,0x6a46,0x6a49,0x6a7a,0x6a4e,0x6a52,
0x6a64,0x2370c,0x6a7e,0x6a83,0x6a8b,0x3bf0,0x6a91,0x6a9f,
0x6aa1,0x23764,0x6aab,0x6abd,0x6ac6,0x6ad4,0x6ad0,0x6adc,
0x6add,0x237ff,0x237e7,0x6aec,0x6af1,0x6af2,0x6af3,0x6afd,
0x23824,0x6b0b,0x6b0f,0x6b10,0x6b11,0x2383d,0x6b17,0x3c26,
0x6b2f,0x6b4a,0x6b58,0x6b6c,0x6b75,0x6b7a,0x6b81,
/* 30xx */
       0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
       0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
       0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
       0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
       0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
       0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
       0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
       0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
       0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
       0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
       0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
       0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
       0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
       0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
       0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
       0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
/* 40xx */
       0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
       0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
       0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
       0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
       0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
       0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
       0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
       0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
       0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
       0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
       0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
       0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
       0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
       0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
       0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
       0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
/* 50xx */
       0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
       0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
       0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
       0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
       0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
       0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
       0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
       0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
       0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
       0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
       0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
       0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
       0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
       0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
       0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
       0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
/* 60xx */
       0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
       0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
       0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
       0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
       0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
       0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
       0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
       0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
       0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
       0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
       0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
       0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
       0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
       0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
/* 6exx */
       0x6b9b,0x6bae,0x23a98,0x6bbd,0x6bbe,0x6bc7,0x6bc8,
0x6bc9,0x6bda,0x6be6,0x6be7,0x6bee,0x6bf1,0x6c02,0x6c0a,
0x6c0e,0x6c35,0x6c36,0x6c3a,0x23c7f,0x6c3f,0x6c4d,0x6c5b,
0x6c6d,0x6c84,0x6c89,0x3cc3,0x6c94,0x6c95,0x6c97,0x6cad,
0x6cc2,0x6cd0,0x3cd2,0x6cd6,0x6cda,0x6cdc,0x6ce9,0x6cec,
0x6ced,0x23d00,0x6d00,0x6d0a,0x6d24,0x6d26,0x6d27,0x6c67,
0x6d2f,0x6d3c,0x6d5b,0x6d5e,0x6d60,0x6d70,0x6d80,0x6d81,
0x6d8a,0x6d8d,0x6d91,0x6d98,0x23d40,0x6e17,0x23dfa,0x23df9,
0x23dd3,0x6dab,0x6dae,0x6db4,0x6dc2,0x6d34,0x6dc8,0x6dce,
0x6dcf,0x6dd0,0x6ddf,0x6de9,0x6df6,0x6e36,0x6e1e,0x6e22,
0x6e27,0x3d11,0x6e32,0x6e3c,0x6e48,0x6e49,0x6e4b,0x6e4c,
0x6e4f,0x6e51,0x6e53,0x6e54,0x6e57,0x6e63,0x3d1e,
       0x6e93,0x6ea7,0x6eb4,0x6ebf,0x6ec3,0x6eca,0x6ed9,
0x6f35,0x6eeb,0x6ef9,0x6efb,0x6f0a,0x6f0c,0x6f18,0x6f25,
0x6f36,0x6f3c,0x23f7e,0x6f52,0x6f57,0x6f5a,0x6f60,0x6f68,
0x6f98,0x6f7d,0x6f90,0x6f96,0x6fbe,0x6f9f,0x6fa5,0x6faf,
0x3d64,0x6fb5,0x6fc8,0x6fc9,0x6fda,0x6fde,0x6fe9,0x24096,
0x6ffc,0x7000,0x7007,0x700a,0x7023,0x24103,0x7039,0x703a,
0x703c,0x7043,0x7047,0x704b,0x3d9a,0x7054,0x7065,0x7069,
0x706c,0x706e,0x7076,0x707e,0x7081,0x7086,0x7095,0x7097,
0x70bb,0x241c6,0x709f,0x70b1,0x241fe,0x70ec,0x70ca,0x70d1,
0x70d3,0x70dc,0x7103,0x7104,0x7106,0x7107,0x7108,0x710c,
0x3dc0,0x712f,0x7131,0x7150,0x714a,0x7153,0x715e,0x3dd4,
0x7196,0x7180,0x719b,0x71a0,0x71a2,0x71ae,0x71af,
/* 70xx */
       0x71b3,0x243bc,0x71cb,0x71d3,0x71d9,0x71dc,0x7207,
0x3e05,0xfa49,0x722b,0x7234,0x7238,0x7239,0x4e2c,0x7242,
0x7253,0x7257,0x7263,0x24629,0x726e,0x726f,0x7278,0x727f,
0x728e,0x246a5,0x72ad,0x72ae,0x72b0,0x72b1,0x72c1,0x3e60,
0x72cc,0x3e66,0x3e68,0x72f3,0x72fa,0x7307,0x7312,0x7318,
0x7319,0x3e83,0x7339,0x732c,0x7331,0x7333,0x733d,0x7352,
0x3e94,0x736b,0x736c,0x24896,0x736e,0x736f,0x7371,0x7377,
0x7381,0x7385,0x738a,0x7394,0x7398,0x739c,0x739e,0x73a5,
0x73a8,0x73b5,0x73b7,0x73b9,0x73bc,0x73bf,0x73c5,0x73cb,
0x73e1,0x73e7,0x73f9,0x7413,0x73fa,0x7401,0x7424,0x7431,
0x7439,0x7453,0x7440,0x7443,0x744d,0x7452,0x745d,0x7471,
0x7481,0x7485,0x7488,0x24a4d,0x7492,0x7497,0x7499,
       0x74a0,0x74a1,0x74a5,0x74aa,0x74ab,0x74b9,0x74bb,
0x74ba,0x74d6,0x74d8,0x74de,0x74ef,0x74eb,0x24b56,0x74fa,
0x24b6f,0x7520,0x7524,0x752a,0x3f57,0x24c16,0x753d,0x753e,
0x7540,0x7548,0x754e,0x7550,0x7552,0x756c,0x7572,0x7571,
0x757a,0x757d,0x757e,0x7581,0x24d14,0x758c,0x3f75,0x75a2,
0x3f77,0x75b0,0x75b7,0x75bf,0x75c0,0x75c6,0x75cf,0x75d3,
0x75dd,0x75df,0x75e0,0x75e7,0x75ec,0x75ee,0x75f1,0x75f9,
0x7603,0x7618,0x7607,0x760f,0x3fae,0x24e0e,0x7613,0x761b,
0x761c,0x24e37,0x7625,0x7628,0x763c,0x7633,0x24e6a,0x3fc9,
0x7641,0x24e8b,0x7649,0x7655,0x3fd7,0x766e,0x7695,0x769c,
0x76a1,0x76a0,0x76a7,0x76a8,0x76af,0x2504a,0x76c9,0x25055,
0x76e8,0x76ec,0x25122,0x7717,0x771a,0x772d,0x7735,
/* 72xx */
       0x251a9,0x4039,0x251e5,0x251cd,0x7758,0x7760,0x776a,
0x2521e,0x7772,0x777c,0x777d,0x2524c,0x4058,0x779a,0x779f,
0x77a2,0x77a4,0x77a9,0x77de,0x77df,0x77e4,0x77e6,0x77ea,
0x77ec,0x4093,0x77f0,0x77f4,0x77fb,0x2542e,0x7805,0x7806,
0x7809,0x780d,0x7819,0x7821,0x782c,0x7847,0x7864,0x786a,
0x254d9,0x788a,0x7894,0x78a4,0x789d,0x789e,0x789f,0x78bb,
0x78c8,0x78cc,0x78ce,0x78d5,0x78e0,0x78e1,0x78e6,0x78f9,
0x78fa,0x78fb,0x78fe,0x255a7,0x7910,0x791b,0x7930,0x7925,
0x793b,0x794a,0x7958,0x795b,0x4105,0x7967,0x7972,0x7994,
0x7995,0x7996,0x799b,0x79a1,0x79a9,0x79b4,0x79bb,0x79c2,
0x79c7,0x79cc,0x79cd,0x79d6,0x4148,0x257a9,0x257b4,0x414f,
0x7a0a,0x7a11,0x7a15,0x7a1b,0x7a1e,0x4163,0x7a2d,
       0x7a38,0x7a47,0x7a4c,0x7a56,0x7a59,0x7a5c,0x7a5f,
0x7a60,0x7a67,0x7a6a,0x7a75,0x7a78,0x7a82,0x7a8a,0x7a90,
0x7aa3,0x7aac,0x259d4,0x41b4,0x7ab9,0x7abc,0x7abe,0x41bf,
0x7acc,0x7ad1,0x7ae7,0x7ae8,0x7af4,0x25ae4,0x25ae3,0x7b07,
0x25af1,0x7b3d,0x7b27,0x7b2a,0x7b2e,0x7b2f,0x7b31,0x41e6,
0x41f3,0x7b7f,0x7b41,0x41ee,0x7b55,0x7b79,0x7b64,0x7b66,
0x7b69,0x7b73,0x25bb2,0x4207,0x7b90,0x7b91,0x7b9b,0x420e,
0x7baf,0x7bb5,0x7bbc,0x7bc5,0x7bca,0x25c4b,0x25c64,0x7bd4,
0x7bd6,0x7bda,0x7bea,0x7bf0,0x7c03,0x7c0b,0x7c0e,0x7c0f,
0x7c26,0x7c45,0x7c4a,0x7c51,0x7c57,0x7c5e,0x7c61,0x7c69,
0x7c6e,0x7c6f,0x7c70,0x25e2e,0x25e56,0x25e65,0x7ca6,0x25e62,
0x7cb6,0x7cb7,0x7cbf,0x25ed8,0x7cc4,0x25ec2,0x7cc8,
/* 74xx */
       0x7ccd,0x25ee8,0x7cd7,0x25f23,0x7ce6,0x7ceb,0x25f5c,
0x7cf5,0x7d03,0x7d09,0x42c6,0x7d12,0x7d1e,0x25fe0,0x25fd4,
0x7d3d,0x7d3e,0x7d40,0x7d47,0x2600c,0x25ffb,0x42d6,0x7d59,
0x7d5a,0x7d6a,0x7d70,0x42dd,0x7d7f,0x26017,0x7d86,0x7d88,
0x7d8c,0x7d97,0x26060,0x7d9d,0x7da7,0x7daa,0x7db6,0x7db7,
0x7dc0,0x7dd7,0x7dd9,0x7de6,0x7df1,0x7df9,0x4302,0x260ed,
0xfa58,0x7e10,0x7e17,0x7e1d,0x7e20,0x7e27,0x7e2c,0x7e45,
0x7e73,0x7e75,0x7e7e,0x7e86,0x7e87,0x432b,0x7e91,0x7e98,
0x7e9a,0x4343,0x7f3c,0x7f3b,0x7f3e,0x7f43,0x7f44,0x7f4f,
0x34c1,0x26270,0x7f52,0x26286,0x7f61,0x7f63,0x7f64,0x7f6d,
0x7f7d,0x7f7e,0x2634c,0x7f90,0x517b,0x23d0e,0x7f96,0x7f9c,
0x7fad,0x26402,0x7fc3,0x7fcf,0x7fe3,0x7fe5,0x7fef,
       0x7ff2,0x8002,0x800a,0x8008,0x800e,0x8011,0x8016,
0x8024,0x802c,0x8030,0x8043,0x8066,0x8071,0x8075,0x807b,
0x8099,0x809c,0x80a4,0x80a7,0x80b8,0x2667e,0x80c5,0x80d5,
0x80d8,0x80e6,0x266b0,0x810d,0x80f5,0x80fb,0x43ee,0x8135,
0x8116,0x811e,0x43f0,0x8124,0x8127,0x812c,0x2671d,0x813d,
0x4408,0x8169,0x4417,0x8181,0x441c,0x8184,0x8185,0x4422,
0x8198,0x81b2,0x81c1,0x81c3,0x81d6,0x81db,0x268dd,0x81e4,
0x268ea,0x81ec,0x26951,0x81fd,0x81ff,0x2696f,0x8204,0x269dd,
0x8219,0x8221,0x8222,0x26a1e,0x8232,0x8234,0x823c,0x8246,
0x8249,0x8245,0x26a58,0x824b,0x4476,0x824f,0x447a,0x8257,
0x26a8c,0x825c,0x8263,0x26ab7,0xfa5d,0xfa5e,0x8279,0x4491,
0x827d,0x827f,0x8283,0x828a,0x8293,0x82a7,0x82a8,
/* 76xx */
       0x82b2,0x82b4,0x82ba,0x82bc,0x82e2,0x82e8,0x82f7,
0x8307,0x8308,0x830c,0x8354,0x831b,0x831d,0x8330,0x833c,
0x8344,0x8357,0x44be,0x837f,0x44d4,0x44b3,0x838d,0x8394,
0x8395,0x839b,0x839d,0x83c9,0x83d0,0x83d4,0x83dd,0x83e5,
0x83f9,0x840f,0x8411,0x8415,0x26c73,0x8417,0x8439,0x844a,
0x844f,0x8451,0x8452,0x8459,0x845a,0x845c,0x26cdd,0x8465,
0x8476,0x8478,0x847c,0x8481,0x450d,0x84dc,0x8497,0x84a6,
0x84be,0x4508,0x84ce,0x84cf,0x84d3,0x26e65,0x84e7,0x84ea,
0x84ef,0x84f0,0x84f1,0x84fa,0x84fd,0x850c,0x851b,0x8524,
0x8525,0x852b,0x8534,0x854f,0x856f,0x4525,0x4543,0x853e,
0x8551,0x8553,0x855e,0x8561,0x8562,0x26f94,0x857b,0x857d,
0x857f,0x8581,0x8586,0x8593,0x859d,0x859f,0x26ff8,
       0x26ff6,0x26ff7,0x85b7,0x85bc,0x85c7,0x85ca,0x85d8,
0x85d9,0x85df,0x85e1,0x85e6,0x85f6,0x8600,0x8611,0x861e,
0x8621,0x8624,0x8627,0x2710d,0x8639,0x863c,0x27139,0x8640,
0xfa20,0x8653,0x8656,0x866f,0x8677,0x867a,0x8687,0x8689,
0x868d,0x8691,0x869c,0x869d,0x86a8,0xfa21,0x86b1,0x86b3,
0x86c1,0x86c3,0x86d1,0x86d5,0x86d7,0x86e3,0x86e6,0x45b8,
0x8705,0x8707,0x870e,0x8710,0x8713,0x8719,0x871f,0x8721,
0x8723,0x8731,0x873a,0x873e,0x8740,0x8743,0x8751,0x8758,
0x8764,0x8765,0x8772,0x877c,0x273db,0x273da,0x87a7,0x8789,
0x878b,0x8793,0x87a0,0x273fe,0x45e5,0x87be,0x27410,0x87c1,
0x87ce,0x87f5,0x87df,0x27449,0x87e3,0x87e5,0x87e6,0x87ea,
0x87eb,0x87ed,0x8801,0x8803,0x880b,0x8813,0x8828,
/* 78xx */
       0x882e,0x8832,0x883c,0x460f,0x884a,0x8858,0x885f,
0x8864,0x27615,0x27614,0x8869,0x27631,0x886f,0x88a0,0x88bc,
0x88bd,0x88be,0x88c0,0x88d2,0x27693,0x88d1,0x88d3,0x88db,
0x88f0,0x88f1,0x4641,0x8901,0x2770e,0x8937,0x27723,0x8942,
0x8945,0x8949,0x27752,0x4665,0x8962,0x8980,0x8989,0x8990,
0x899f,0x89b0,0x89b7,0x89d6,0x89d8,0x89eb,0x46a1,0x89f1,
0x89f3,0x89fd,0x89ff,0x46af,0x8a11,0x8a14,0x27985,0x8a21,
0x8a35,0x8a3e,0x8a45,0x8a4d,0x8a58,0x8aae,0x8a90,0x8ab7,
0x8abe,0x8ad7,0x8afc,0x27a84,0x8b0a,0x8b05,0x8b0d,0x8b1c,
0x8b1f,0x8b2d,0x8b43,0x470c,0x8b51,0x8b5e,0x8b76,0x8b7f,
0x8b81,0x8b8b,0x8b94,0x8b95,0x8b9c,0x8b9e,0x8c39,0x27bb3,
0x8c3d,0x27bbe,0x27bc7,0x8c45,0x8c47,0x8c4f,0x8c54,
       0x8c57,0x8c69,0x8c6d,0x8c73,0x27cb8,0x8c93,0x8c92,
0x8c99,0x4764,0x8c9b,0x8ca4,0x8cd6,0x8cd5,0x8cd9,0x27da0,
0x8cf0,0x8cf1,0x27e10,0x8d09,0x8d0e,0x8d6c,0x8d84,0x8d95,
0x8da6,0x27fb7,0x8dc6,0x8dc8,0x8dd9,0x8dec,0x8e0c,0x47fd,
0x8dfd,0x8e06,0x2808a,0x8e14,0x8e16,0x8e21,0x8e22,0x8e27,
0x280bb,0x4816,0x8e36,0x8e39,0x8e4b,0x8e54,0x8e62,0x8e6c,
0x8e6d,0x8e6f,0x8e98,0x8e9e,0x8eae,0x8eb3,0x8eb5,0x8eb6,
0x8ebb,0x28282,0x8ed1,0x8ed4,0x484e,0x8ef9,0x282f3,0x8f00,
0x8f08,0x8f17,0x8f2b,0x8f40,0x8f4a,0x8f58,0x2840c,0x8fa4,
0x8fb4,0xfa66,0x8fb6,0x28455,0x8fc1,0x8fc6,0xfa24,0x8fca,
0x8fcd,0x8fd3,0x8fd5,0x8fe0,0x8ff1,0x8ff5,0x8ffb,0x9002,
0x900c,0x9037,0x2856b,0x9043,0x9044,0x905d,0x285c8,
/* 7axx */
       0x285c9,0x9085,0x908c,0x9090,0x961d,0x90a1,0x48b5,
0x90b0,0x90b6,0x90c3,0x90c8,0x286d7,0x90dc,0x90df,0x286fa,
0x90f6,0x90f2,0x9100,0x90eb,0x90fe,0x90ff,0x9104,0x9106,
0x9118,0x911c,0x911e,0x9137,0x9139,0x913a,0x9146,0x9147,
0x9157,0x9159,0x9161,0x9164,0x9174,0x9179,0x9185,0x918e,
0x91a8,0x91ae,0x91b3,0x91b6,0x91c3,0x91c4,0x91da,0x28949,
0x28946,0x91ec,0x91ee,0x9201,0x920a,0x9216,0x9217,0x2896b,
0x9233,0x9242,0x9247,0x924a,0x924e,0x9251,0x9256,0x9259,
0x9260,0x9261,0x9265,0x9267,0x9268,0x28987,0x28988,0x927c,
0x927d,0x927f,0x9289,0x928d,0x9297,0x9299,0x929f,0x92a7,
0x92ab,0x289ba,0x289bb,0x92b2,0x92bf,0x92c0,0x92c6,0x92ce,
0x92d0,0x92d7,0x92d9,0x92e5,0x92e7,0x9311,0x28a1e,
       0x28a29,0x92f7,0x92f9,0x92fb,0x9302,0x930d,0x9315,
0x931d,0x931e,0x9327,0x9329,0x28a71,0x28a43,0x9347,0x9351,
0x9357,0x935a,0x936b,0x9371,0x9373,0x93a1,0x28a99,0x28acd,
0x9388,0x938b,0x938f,0x939e,0x93f5,0x28ae4,0x28add,0x93f1,
0x93c1,0x93c7,0x93dc,0x93e2,0x93e7,0x9409,0x940f,0x9416,
0x9417,0x93fb,0x9432,0x9434,0x943b,0x9445,0x28bc1,0x28bef,
0x946d,0x946f,0x9578,0x9579,0x9586,0x958c,0x958d,0x28d10,
0x95ab,0x95b4,0x28d71,0x95c8,0x28dfb,0x28e1f,0x962c,0x9633,
0x9634,0x28e36,0x963c,0x9641,0x9661,0x28e89,0x9682,0x28eeb,
0x969a,0x28f32,0x49e7,0x96a9,0x96af,0x96b3,0x96ba,0x96bd,
0x49fa,0x28ff8,0x96d8,0x96da,0x96dd,0x4a04,0x9714,0x9723,
0x4a29,0x9736,0x9741,0x9747,0x9755,0x9757,0x975b,
/* 7cxx */
       0x976a,0x292a0,0x292b1,0x9796,0x979a,0x979e,0x97a2,
0x97b1,0x97b2,0x97be,0x97cc,0x97d1,0x97d4,0x97d8,0x97d9,
0x97e1,0x97f1,0x9804,0x980d,0x980e,0x9814,0x9816,0x4abc,
0x29490,0x9823,0x9832,0x9833,0x9825,0x9847,0x9866,0x98ab,
0x98ad,0x98b0,0x295cf,0x98b7,0x98b8,0x98bb,0x98bc,0x98bf,
0x98c2,0x98c7,0x98cb,0x98e0,0x2967f,0x98e1,0x98e3,0x98e5,
0x98ea,0x98f0,0x98f1,0x98f3,0x9908,0x4b3b,0x296f0,0x9916,
0x9917,0x29719,0x991a,0x991b,0x991c,0x29750,0x9931,0x9932,
0x9933,0x993a,0x993b,0x993c,0x9940,0x9941,0x9946,0x994d,
0x994e,0x995c,0x995f,0x9960,0x99a3,0x99a6,0x99b9,0x99bd,
0x99bf,0x99c3,0x99c9,0x99d4,0x99d9,0x99de,0x298c6,0x99f0,
0x99f9,0x99fc,0x9a0a,0x9a11,0x9a16,0x9a1a,0x9a20,
       0x9a31,0x9a36,0x9a44,0x9a4c,0x9a58,0x4bc2,0x9aaf,
0x4bca,0x9ab7,0x4bd2,0x9ab9,0x29a72,0x9ac6,0x9ad0,0x9ad2,
0x9ad5,0x4be8,0x9adc,0x9ae0,0x9ae5,0x9ae9,0x9b03,0x9b0c,
0x9b10,0x9b12,0x9b16,0x9b1c,0x9b2b,0x9b33,0x9b3d,0x4c20,
0x9b4b,0x9b63,0x9b65,0x9b6b,0x9b6c,0x9b73,0x9b76,0x9b77,
0x9ba6,0x9bac,0x9bb1,0x29ddb,0x29e3d,0x9bb2,0x9bb8,0x9bbe,
0x9bc7,0x9bf3,0x9bd8,0x9bdd,0x9be7,0x9bea,0x9beb,0x9bef,
0x9bee,0x29e15,0x9bfa,0x29e8a,0x9bf7,0x29e49,0x9c16,0x9c18,
0x9c19,0x9c1a,0x9c1d,0x9c22,0x9c27,0x9c29,0x9c2a,0x29ec4,
0x9c31,0x9c36,0x9c37,0x9c45,0x9c5c,0x29ee9,0x9c49,0x9c4a,
0x29edb,0x9c54,0x9c58,0x9c5b,0x9c5d,0x9c5f,0x9c69,0x9c6a,
0x9c6b,0x9c6d,0x9c6e,0x9c70,0x9c72,0x9c75,0x9c7a,
/* 7exx */
       0x9ce6,0x9cf2,0x9d0b,0x9d02,0x29fce,0x9d11,0x9d17,
0x9d18,0x2a02f,0x4cc4,0x2a01a,0x9d32,0x4cd1,0x9d42,0x9d4a,
0x9d5f,0x9d62,0x2a0f9,0x9d69,0x9d6b,0x2a082,0x9d73,0x9d76,
0x9d77,0x9d7e,0x9d84,0x9d8d,0x9d99,0x9da1,0x9dbf,0x9db5,
0x9db9,0x9dbd,0x9dc3,0x9dc7,0x9dc9,0x9dd6,0x9dda,0x9ddf,
0x9de0,0x9de3,0x9df4,0x4d07,0x9e0a,0x9e02,0x9e0d,0x9e19,
0x9e1c,0x9e1d,0x9e7b,0x22218,0x9e80,0x9e85,0x9e9b,0x9ea8,
0x2a38c,0x9ebd,0x2a437,0x9edf,0x9ee7,0x9eee,0x9eff,0x9f02,
0x4d77,0x9f03,0x9f17,0x9f19,0x9f2f,0x9f37,0x9f3a,0x9f3d,
0x9f41,0x9f45,0x9f46,0x9f53,0x9f55,0x9f58,0x2a5f1,0x9f5d,
0x2a602,0x9f69,0x2a61a,0x9f6d,0x9f70,0x9f75,0x2a6b2,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000
};
#endif


#if defined(OUTPUT_DYNAMIC_TABLE) || !defined(DYNAMIC_LOADING) || defined(SWIG_EXT)
unsigned short uni_t_gb2312[GB2312_TBL_LEN] = {
  0x3000,0x3001,0x3002,0x30fb, 0x02c9,0x02c7,0x00a8,0x3003,
  0x3005,0x2015,0xff5e,0x2016, 0x2026,0x2018,0x2019,0x201c,
  0x201d,0x3014,0x3015,0x3008, 0x3009,0x300a,0x300b,0x300c,
  0x300d,0x300e,0x300f,0x3016, 0x3017,0x3010,0x3011,0x00b1,
  0x00d7,0x00f7,0x2236,0x2227, 0x2228,0x2211,0x220f,0x222a,
  0x2229,0x2208,0x2237,0x221a, 0x22a5,0x2225,0x2220,0x2312,
  0x2299,0x222b,0x222e,0x2261, 0x224c,0x2248,0x223d,0x221d,
  0x2260,0x226e,0x226f,0x2264, 0x2265,0x221e,0x2235,0x2234,
  0x2642,0x2640,0x00b0,0x2032, 0x2033,0x2103,0xff04,0x00a4,
  0xffe0,0xffe1,0x2030,0x00a7, 0x2116,0x2606,0x2605,0x25cb,
  0x25cf,0x25ce,0x25c7,0x25c6, 0x25a1,0x25a0,0x25b3,0x25b2,
  0x203b,0x2192,0x2190,0x2191, 0x2193,0x3013,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x2488,0x2489,
  0x248a,0x248b,0x248c,0x248d, 0x248e,0x248f,0x2490,0x2491,
  0x2492,0x2493,0x2494,0x2495, 0x2496,0x2497,0x2498,0x2499,
  0x249a,0x249b,0x2474,0x2475, 0x2476,0x2477,0x2478,0x2479,
  0x247a,0x247b,0x247c,0x247d, 0x247e,0x247f,0x2480,0x2481,
  0x2482,0x2483,0x2484,0x2485, 0x2486,0x2487,0x2460,0x2461,
  0x2462,0x2463,0x2464,0x2465, 0x2466,0x2467,0x2468,0x2469,
  0x0000,0x0000,0x3220,0x3221, 0x3222,0x3223,0x3224,0x3225,
  0x3226,0x3227,0x3228,0x3229, 0x0000,0x0000,0x2160,0x2161,
  0x2162,0x2163,0x2164,0x2165, 0x2166,0x2167,0x2168,0x2169,
  0x216a,0x216b,0x0000,0x0000, 0xff01,0xff02,0xff03,0xffe5,
  0xff05,0xff06,0xff07,0xff08, 0xff09,0xff0a,0xff0b,0xff0c,
  0xff0d,0xff0e,0xff0f,0xff10, 0xff11,0xff12,0xff13,0xff14,
  0xff15,0xff16,0xff17,0xff18, 0xff19,0xff1a,0xff1b,0xff1c,
  0xff1d,0xff1e,0xff1f,0xff20, 0xff21,0xff22,0xff23,0xff24,
  0xff25,0xff26,0xff27,0xff28, 0xff29,0xff2a,0xff2b,0xff2c,
  0xff2d,0xff2e,0xff2f,0xff30, 0xff31,0xff32,0xff33,0xff34,
  0xff35,0xff36,0xff37,0xff38, 0xff39,0xff3a,0xff3b,0xff3c,
  0xff3d,0xff3e,0xff3f,0xff40, 0xff41,0xff42,0xff43,0xff44,
  0xff45,0xff46,0xff47,0xff48, 0xff49,0xff4a,0xff4b,0xff4c,
  0xff4d,0xff4e,0xff4f,0xff50, 0xff51,0xff52,0xff53,0xff54,
  0xff55,0xff56,0xff57,0xff58, 0xff59,0xff5a,0xff5b,0xff5c,
  0xff5d,0xffe3,0x3041,0x3042, 0x3043,0x3044,0x3045,0x3046,
  0x3047,0x3048,0x3049,0x304a, 0x304b,0x304c,0x304d,0x304e,
  0x304f,0x3050,0x3051,0x3052, 0x3053,0x3054,0x3055,0x3056,
  0x3057,0x3058,0x3059,0x305a, 0x305b,0x305c,0x305d,0x305e,
  0x305f,0x3060,0x3061,0x3062, 0x3063,0x3064,0x3065,0x3066,
  0x3067,0x3068,0x3069,0x306a, 0x306b,0x306c,0x306d,0x306e,
  0x306f,0x3070,0x3071,0x3072, 0x3073,0x3074,0x3075,0x3076,
  0x3077,0x3078,0x3079,0x307a, 0x307b,0x307c,0x307d,0x307e,
  0x307f,0x3080,0x3081,0x3082, 0x3083,0x3084,0x3085,0x3086,
  0x3087,0x3088,0x3089,0x308a, 0x308b,0x308c,0x308d,0x308e,
  0x308f,0x3090,0x3091,0x3092, 0x3093,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x30a1,0x30a2,0x30a3,0x30a4, 0x30a5,0x30a6,0x30a7,0x30a8,
  0x30a9,0x30aa,0x30ab,0x30ac, 0x30ad,0x30ae,0x30af,0x30b0,
  0x30b1,0x30b2,0x30b3,0x30b4, 0x30b5,0x30b6,0x30b7,0x30b8,
  0x30b9,0x30ba,0x30bb,0x30bc, 0x30bd,0x30be,0x30bf,0x30c0,
  0x30c1,0x30c2,0x30c3,0x30c4, 0x30c5,0x30c6,0x30c7,0x30c8,
  0x30c9,0x30ca,0x30cb,0x30cc, 0x30cd,0x30ce,0x30cf,0x30d0,
  0x30d1,0x30d2,0x30d3,0x30d4, 0x30d5,0x30d6,0x30d7,0x30d8,
  0x30d9,0x30da,0x30db,0x30dc, 0x30dd,0x30de,0x30df,0x30e0,
  0x30e1,0x30e2,0x30e3,0x30e4, 0x30e5,0x30e6,0x30e7,0x30e8,
  0x30e9,0x30ea,0x30eb,0x30ec, 0x30ed,0x30ee,0x30ef,0x30f0,
  0x30f1,0x30f2,0x30f3,0x30f4, 0x30f5,0x30f6,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0391,0x0392,
  0x0393,0x0394,0x0395,0x0396, 0x0397,0x0398,0x0399,0x039a,
  0x039b,0x039c,0x039d,0x039e, 0x039f,0x03a0,0x03a1,0x03a3,
  0x03a4,0x03a5,0x03a6,0x03a7, 0x03a8,0x03a9,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x03b1,0x03b2,
  0x03b3,0x03b4,0x03b5,0x03b6, 0x03b7,0x03b8,0x03b9,0x03ba,
  0x03bb,0x03bc,0x03bd,0x03be, 0x03bf,0x03c0,0x03c1,0x03c3,
  0x03c4,0x03c5,0x03c6,0x03c7, 0x03c8,0x03c9,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0410,0x0411,0x0412,0x0413,
  0x0414,0x0415,0x0401,0x0416, 0x0417,0x0418,0x0419,0x041a,
  0x041b,0x041c,0x041d,0x041e, 0x041f,0x0420,0x0421,0x0422,
  0x0423,0x0424,0x0425,0x0426, 0x0427,0x0428,0x0429,0x042a,
  0x042b,0x042c,0x042d,0x042e, 0x042f,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0430,0x0431,0x0432,0x0433,
  0x0434,0x0435,0x0451,0x0436, 0x0437,0x0438,0x0439,0x043a,
  0x043b,0x043c,0x043d,0x043e, 0x043f,0x0440,0x0441,0x0442,
  0x0443,0x0444,0x0445,0x0446, 0x0447,0x0448,0x0449,0x044a,
  0x044b,0x044c,0x044d,0x044e, 0x044f,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0101,0x00e1, 0x01ce,0x00e0,0x0113,0x00e9,
  0x011b,0x00e8,0x012b,0x00ed, 0x01d0,0x00ec,0x014d,0x00f3,
  0x01d2,0x00f2,0x016b,0x00fa, 0x01d4,0x00f9,0x01d6,0x01d8,
  0x01da,0x01dc,0x00fc,0x00ea, 0x0251,0x1e3f,0x0144,0x0148,
  0x01f9,0x0261,0x0000,0x0000, 0x0000,0x0000,0x3105,0x3106,
  0x3107,0x3108,0x3109,0x310a, 0x310b,0x310c,0x310d,0x310e,
  0x310f,0x3110,0x3111,0x3112, 0x3113,0x3114,0x3115,0x3116,
  0x3117,0x3118,0x3119,0x311a, 0x311b,0x311c,0x311d,0x311e,
  0x311f,0x3120,0x3121,0x3122, 0x3123,0x3124,0x3125,0x3126,
  0x3127,0x3128,0x3129,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x2500, 0x2501,0x2502,0x2503,0x2504,
  0x2505,0x2506,0x2507,0x2508, 0x2509,0x250a,0x250b,0x250c,
  0x250d,0x250e,0x250f,0x2510, 0x2511,0x2512,0x2513,0x2514,
  0x2515,0x2516,0x2517,0x2518, 0x2519,0x251a,0x251b,0x251c,
  0x251d,0x251e,0x251f,0x2520, 0x2521,0x2522,0x2523,0x2524,
  0x2525,0x2526,0x2527,0x2528, 0x2529,0x252a,0x252b,0x252c,
  0x252d,0x252e,0x252f,0x2530, 0x2531,0x2532,0x2533,0x2534,
  0x2535,0x2536,0x2537,0x2538, 0x2539,0x253a,0x253b,0x253c,
  0x253d,0x253e,0x253f,0x2540, 0x2541,0x2542,0x2543,0x2544,
  0x2545,0x2546,0x2547,0x2548, 0x2549,0x254a,0x254b,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0021,0x0022,
  0x0023,0x0024,0x0025,0x0026, 0x0027,0x0028,0x0029,0x002a,
  0x002b,0x002c,0x002d,0x002e, 0x002f,0x0030,0x0031,0x0032,
  0x0033,0x0034,0x0035,0x0036, 0x0037,0x0038,0x0039,0x003a,
  0x003b,0x003c,0x003d,0x003e, 0x003f,0x0040,0x0041,0x0042,
  0x0043,0x0044,0x0045,0x0046, 0x0047,0x0048,0x0049,0x004a,
  0x004b,0x004c,0x004d,0x004e, 0x004f,0x0050,0x0051,0x0052,
  0x0053,0x0054,0x0055,0x0056, 0x0057,0x0058,0x0059,0x005a,
  0x005b,0x005c,0x005d,0x005e, 0x005f,0x0060,0x0061,0x0062,
  0x0063,0x0064,0x0065,0x0066, 0x0067,0x0068,0x0069,0x006a,
  0x006b,0x006c,0x006d,0x006e, 0x006f,0x0070,0x0071,0x0072,
  0x0073,0x0074,0x0075,0x0076, 0x0077,0x0078,0x0079,0x007a,
  0x007b,0x007c,0x007d,0x007e, 0x0101,0x00e1,0x01ce,0x00e0,
  0x0113,0x00e9,0x011b,0x00e8, 0x012b,0x00ed,0x01d0,0x00ec,
  0x014d,0x00f3,0x01d2,0x00f2, 0x016b,0x00fa,0x01d4,0x00f9,
  0x01d6,0x01d8,0x01da,0x01dc, 0x00fc,0x00ea,0x0251,0x1e3f,
  0x0144,0x0148,0x01f9,0x0261, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x554a,0x963f, 0x57c3,0x6328,0x54ce,0x5509,
  0x54c0,0x7691,0x764c,0x853c, 0x77ee,0x827e,0x788d,0x7231,
  0x9698,0x978d,0x6c28,0x5b89, 0x4ffa,0x6309,0x6697,0x5cb8,
  0x80fa,0x6848,0x80ae,0x6602, 0x76ce,0x51f9,0x6556,0x71ac,
  0x7ff1,0x8884,0x50b2,0x5965, 0x61ca,0x6fb3,0x82ad,0x634c,
  0x6252,0x53ed,0x5427,0x7b06, 0x516b,0x75a4,0x5df4,0x62d4,
  0x8dcb,0x9776,0x628a,0x8019, 0x575d,0x9738,0x7f62,0x7238,
  0x767d,0x67cf,0x767e,0x6446, 0x4f70,0x8d25,0x62dc,0x7a17,
  0x6591,0x73ed,0x642c,0x6273, 0x822c,0x9881,0x677f,0x7248,
  0x626e,0x62cc,0x4f34,0x74e3, 0x534a,0x529e,0x7eca,0x90a6,
  0x5e2e,0x6886,0x699c,0x8180, 0x7ed1,0x68d2,0x78c5,0x868c,
  0x9551,0x508d,0x8c24,0x82de, 0x80de,0x5305,0x8912,0x5265,
  0x8584,0x96f9,0x4fdd,0x5821, 0x9971,0x5b9d,0x62b1,0x62a5,
  0x66b4,0x8c79,0x9c8d,0x7206, 0x676f,0x7891,0x60b2,0x5351,
  0x5317,0x8f88,0x80cc,0x8d1d, 0x94a1,0x500d,0x72c8,0x5907,
  0x60eb,0x7119,0x88ab,0x5954, 0x82ef,0x672c,0x7b28,0x5d29,
  0x7ef7,0x752d,0x6cf5,0x8e66, 0x8ff8,0x903c,0x9f3b,0x6bd4,
  0x9119,0x7b14,0x5f7c,0x78a7, 0x84d6,0x853d,0x6bd5,0x6bd9,
  0x6bd6,0x5e01,0x5e87,0x75f9, 0x95ed,0x655d,0x5f0a,0x5fc5,
  0x8f9f,0x58c1,0x81c2,0x907f, 0x965b,0x97ad,0x8fb9,0x7f16,
  0x8d2c,0x6241,0x4fbf,0x53d8, 0x535e,0x8fa8,0x8fa9,0x8fab,
  0x904d,0x6807,0x5f6a,0x8198, 0x8868,0x9cd6,0x618b,0x522b,
  0x762a,0x5f6c,0x658c,0x6fd2, 0x6ee8,0x5bbe,0x6448,0x5175,
  0x51b0,0x67c4,0x4e19,0x79c9, 0x997c,0x70b3,0x75c5,0x5e76,
  0x73bb,0x83e0,0x64ad,0x62e8, 0x94b5,0x6ce2,0x535a,0x52c3,
  0x640f,0x94c2,0x7b94,0x4f2f, 0x5e1b,0x8236,0x8116,0x818a,
  0x6e24,0x6cca,0x9a73,0x6355, 0x535c,0x54fa,0x8865,0x57e0,
  0x4e0d,0x5e03,0x6b65,0x7c3f, 0x90e8,0x6016,0x64e6,0x731c,
  0x88c1,0x6750,0x624d,0x8d22, 0x776c,0x8e29,0x91c7,0x5f69,
  0x83dc,0x8521,0x9910,0x53c2, 0x8695,0x6b8b,0x60ed,0x60e8,
  0x707f,0x82cd,0x8231,0x4ed3, 0x6ca7,0x85cf,0x64cd,0x7cd9,
  0x69fd,0x66f9,0x8349,0x5395, 0x7b56,0x4fa7,0x518c,0x6d4b,
  0x5c42,0x8e6d,0x63d2,0x53c9, 0x832c,0x8336,0x67e5,0x78b4,
  0x643d,0x5bdf,0x5c94,0x5dee, 0x8be7,0x62c6,0x67f4,0x8c7a,
  0x6400,0x63ba,0x8749,0x998b, 0x8c17,0x7f20,0x94f2,0x4ea7,
  0x9610,0x98a4,0x660c,0x7316, 0x573a,0x5c1d,0x5e38,0x957f,
  0x507f,0x80a0,0x5382,0x655e, 0x7545,0x5531,0x5021,0x8d85,
  0x6284,0x949e,0x671d,0x5632, 0x6f6e,0x5de2,0x5435,0x7092,
  0x8f66,0x626f,0x64a4,0x63a3, 0x5f7b,0x6f88,0x90f4,0x81e3,
  0x8fb0,0x5c18,0x6668,0x5ff1, 0x6c89,0x9648,0x8d81,0x886c,
  0x6491,0x79f0,0x57ce,0x6a59, 0x6210,0x5448,0x4e58,0x7a0b,
  0x60e9,0x6f84,0x8bda,0x627f, 0x901e,0x9a8b,0x79e4,0x5403,
  0x75f4,0x6301,0x5319,0x6c60, 0x8fdf,0x5f1b,0x9a70,0x803b,
  0x9f7f,0x4f88,0x5c3a,0x8d64, 0x7fc5,0x65a5,0x70bd,0x5145,
  0x51b2,0x866b,0x5d07,0x5ba0, 0x62bd,0x916c,0x7574,0x8e0c,
  0x7a20,0x6101,0x7b79,0x4ec7, 0x7ef8,0x7785,0x4e11,0x81ed,
  0x521d,0x51fa,0x6a71,0x53a8, 0x8e87,0x9504,0x96cf,0x6ec1,
  0x9664,0x695a,0x7840,0x50a8, 0x77d7,0x6410,0x89e6,0x5904,
  0x63e3,0x5ddd,0x7a7f,0x693d, 0x4f20,0x8239,0x5598,0x4e32,
  0x75ae,0x7a97,0x5e62,0x5e8a, 0x95ef,0x521b,0x5439,0x708a,
  0x6376,0x9524,0x5782,0x6625, 0x693f,0x9187,0x5507,0x6df3,
  0x7eaf,0x8822,0x6233,0x7ef0, 0x75b5,0x8328,0x78c1,0x96cc,
  0x8f9e,0x6148,0x74f7,0x8bcd, 0x6b64,0x523a,0x8d50,0x6b21,
  0x806a,0x8471,0x56f1,0x5306, 0x4ece,0x4e1b,0x51d1,0x7c97,
  0x918b,0x7c07,0x4fc3,0x8e7f, 0x7be1,0x7a9c,0x6467,0x5d14,
  0x50ac,0x8106,0x7601,0x7cb9, 0x6dec,0x7fe0,0x6751,0x5b58,
  0x5bf8,0x78cb,0x64ae,0x6413, 0x63aa,0x632b,0x9519,0x642d,
  0x8fbe,0x7b54,0x7629,0x6253, 0x5927,0x5446,0x6b79,0x50a3,
  0x6234,0x5e26,0x6b86,0x4ee3, 0x8d37,0x888b,0x5f85,0x902e,
  0x6020,0x803d,0x62c5,0x4e39, 0x5355,0x90f8,0x63b8,0x80c6,
  0x65e6,0x6c2e,0x4f46,0x60ee, 0x6de1,0x8bde,0x5f39,0x86cb,
  0x5f53,0x6321,0x515a,0x8361, 0x6863,0x5200,0x6363,0x8e48,
  0x5012,0x5c9b,0x7977,0x5bfc, 0x5230,0x7a3b,0x60bc,0x9053,
  0x76d7,0x5fb7,0x5f97,0x7684, 0x8e6c,0x706f,0x767b,0x7b49,
  0x77aa,0x51f3,0x9093,0x5824, 0x4f4e,0x6ef4,0x8fea,0x654c,
  0x7b1b,0x72c4,0x6da4,0x7fdf, 0x5ae1,0x62b5,0x5e95,0x5730,
  0x8482,0x7b2c,0x5e1d,0x5f1f, 0x9012,0x7f14,0x98a0,0x6382,
  0x6ec7,0x7898,0x70b9,0x5178, 0x975b,0x57ab,0x7535,0x4f43,
  0x7538,0x5e97,0x60e6,0x5960, 0x6dc0,0x6bbf,0x7889,0x53fc,
  0x96d5,0x51cb,0x5201,0x6389, 0x540a,0x9493,0x8c03,0x8dcc,
  0x7239,0x789f,0x8776,0x8fed, 0x8c0d,0x53e0,0x4e01,0x76ef,
  0x53ee,0x9489,0x9876,0x9f0e, 0x952d,0x5b9a,0x8ba2,0x4e22,
  0x4e1c,0x51ac,0x8463,0x61c2, 0x52a8,0x680b,0x4f97,0x606b,
  0x51bb,0x6d1e,0x515c,0x6296, 0x6597,0x9661,0x8c46,0x9017,
  0x75d8,0x90fd,0x7763,0x6bd2, 0x728a,0x72ec,0x8bfb,0x5835,
  0x7779,0x8d4c,0x675c,0x9540, 0x809a,0x5ea6,0x6e21,0x5992,
  0x7aef,0x77ed,0x953b,0x6bb5, 0x65ad,0x7f0e,0x5806,0x5151,
  0x961f,0x5bf9,0x58a9,0x5428, 0x8e72,0x6566,0x987f,0x56e4,
  0x949d,0x76fe,0x9041,0x6387, 0x54c6,0x591a,0x593a,0x579b,
  0x8eb2,0x6735,0x8dfa,0x8235, 0x5241,0x60f0,0x5815,0x86fe,
  0x5ce8,0x9e45,0x4fc4,0x989d, 0x8bb9,0x5a25,0x6076,0x5384,
  0x627c,0x904f,0x9102,0x997f, 0x6069,0x800c,0x513f,0x8033,
  0x5c14,0x9975,0x6d31,0x4e8c, 0x8d30,0x53d1,0x7f5a,0x7b4f,
  0x4f10,0x4e4f,0x9600,0x6cd5, 0x73d0,0x85e9,0x5e06,0x756a,
  0x7ffb,0x6a0a,0x77fe,0x9492, 0x7e41,0x51e1,0x70e6,0x53cd,
  0x8fd4,0x8303,0x8d29,0x72af, 0x996d,0x6cdb,0x574a,0x82b3,
  0x65b9,0x80aa,0x623f,0x9632, 0x59a8,0x4eff,0x8bbf,0x7eba,
  0x653e,0x83f2,0x975e,0x5561, 0x98de,0x80a5,0x532a,0x8bfd,
  0x5420,0x80ba,0x5e9f,0x6cb8, 0x8d39,0x82ac,0x915a,0x5429,
  0x6c1b,0x5206,0x7eb7,0x575f, 0x711a,0x6c7e,0x7c89,0x594b,
  0x4efd,0x5fff,0x6124,0x7caa, 0x4e30,0x5c01,0x67ab,0x8702,
  0x5cf0,0x950b,0x98ce,0x75af, 0x70fd,0x9022,0x51af,0x7f1d,
  0x8bbd,0x5949,0x51e4,0x4f5b, 0x5426,0x592b,0x6577,0x80a4,
  0x5b75,0x6276,0x62c2,0x8f90, 0x5e45,0x6c1f,0x7b26,0x4f0f,
  0x4fd8,0x670d,0x6d6e,0x6daa, 0x798f,0x88b1,0x5f17,0x752b,
  0x629a,0x8f85,0x4fef,0x91dc, 0x65a7,0x812f,0x8151,0x5e9c,
  0x8150,0x8d74,0x526f,0x8986, 0x8d4b,0x590d,0x5085,0x4ed8,
  0x961c,0x7236,0x8179,0x8d1f, 0x5bcc,0x8ba3,0x9644,0x5987,
  0x7f1a,0x5490,0x5676,0x560e, 0x8be5,0x6539,0x6982,0x9499,
  0x76d6,0x6e89,0x5e72,0x7518, 0x6746,0x67d1,0x7aff,0x809d,
  0x8d76,0x611f,0x79c6,0x6562, 0x8d63,0x5188,0x521a,0x94a2,
  0x7f38,0x809b,0x7eb2,0x5c97, 0x6e2f,0x6760,0x7bd9,0x768b,
  0x9ad8,0x818f,0x7f94,0x7cd5, 0x641e,0x9550,0x7a3f,0x544a,
  0x54e5,0x6b4c,0x6401,0x6208, 0x9e3d,0x80f3,0x7599,0x5272,
  0x9769,0x845b,0x683c,0x86e4, 0x9601,0x9694,0x94ec,0x4e2a,
  0x5404,0x7ed9,0x6839,0x8ddf, 0x8015,0x66f4,0x5e9a,0x7fb9,
  0x57c2,0x803f,0x6897,0x5de5, 0x653b,0x529f,0x606d,0x9f9a,
  0x4f9b,0x8eac,0x516c,0x5bab, 0x5f13,0x5de9,0x6c5e,0x62f1,
  0x8d21,0x5171,0x94a9,0x52fe, 0x6c9f,0x82df,0x72d7,0x57a2,
  0x6784,0x8d2d,0x591f,0x8f9c, 0x83c7,0x5495,0x7b8d,0x4f30,
  0x6cbd,0x5b64,0x59d1,0x9f13, 0x53e4,0x86ca,0x9aa8,0x8c37,
  0x80a1,0x6545,0x987e,0x56fa, 0x96c7,0x522e,0x74dc,0x5250,
  0x5be1,0x6302,0x8902,0x4e56, 0x62d0,0x602a,0x68fa,0x5173,
  0x5b98,0x51a0,0x89c2,0x7ba1, 0x9986,0x7f50,0x60ef,0x704c,
  0x8d2f,0x5149,0x5e7f,0x901b, 0x7470,0x89c4,0x572d,0x7845,
  0x5f52,0x9f9f,0x95fa,0x8f68, 0x9b3c,0x8be1,0x7678,0x6842,
  0x67dc,0x8dea,0x8d35,0x523d, 0x8f8a,0x6eda,0x68cd,0x9505,
  0x90ed,0x56fd,0x679c,0x88f9, 0x8fc7,0x54c8,0x9ab8,0x5b69,
  0x6d77,0x6c26,0x4ea5,0x5bb3, 0x9a87,0x9163,0x61a8,0x90af,
  0x97e9,0x542b,0x6db5,0x5bd2, 0x51fd,0x558a,0x7f55,0x7ff0,
  0x64bc,0x634d,0x65f1,0x61be, 0x608d,0x710a,0x6c57,0x6c49,
  0x592f,0x676d,0x822a,0x58d5, 0x568e,0x8c6a,0x6beb,0x90dd,
  0x597d,0x8017,0x53f7,0x6d69, 0x5475,0x559d,0x8377,0x83cf,
  0x6838,0x79be,0x548c,0x4f55, 0x5408,0x76d2,0x8c89,0x9602,
  0x6cb3,0x6db8,0x8d6b,0x8910, 0x9e64,0x8d3a,0x563f,0x9ed1,
  0x75d5,0x5f88,0x72e0,0x6068, 0x54fc,0x4ea8,0x6a2a,0x8861,
  0x6052,0x8f70,0x54c4,0x70d8, 0x8679,0x9e3f,0x6d2a,0x5b8f,
  0x5f18,0x7ea2,0x5589,0x4faf, 0x7334,0x543c,0x539a,0x5019,
  0x540e,0x547c,0x4e4e,0x5ffd, 0x745a,0x58f6,0x846b,0x80e1,
  0x8774,0x72d0,0x7cca,0x6e56, 0x5f27,0x864e,0x552c,0x62a4,
  0x4e92,0x6caa,0x6237,0x82b1, 0x54d7,0x534e,0x733e,0x6ed1,
  0x753b,0x5212,0x5316,0x8bdd, 0x69d0,0x5f8a,0x6000,0x6dee,
  0x574f,0x6b22,0x73af,0x6853, 0x8fd8,0x7f13,0x6362,0x60a3,
  0x5524,0x75ea,0x8c62,0x7115, 0x6da3,0x5ba6,0x5e7b,0x8352,
  0x614c,0x9ec4,0x78fa,0x8757, 0x7c27,0x7687,0x51f0,0x60f6,
  0x714c,0x6643,0x5e4c,0x604d, 0x8c0e,0x7070,0x6325,0x8f89,
  0x5fbd,0x6062,0x86d4,0x56de, 0x6bc1,0x6094,0x6167,0x5349,
  0x60e0,0x6666,0x8d3f,0x79fd, 0x4f1a,0x70e9,0x6c47,0x8bb3,
  0x8bf2,0x7ed8,0x8364,0x660f, 0x5a5a,0x9b42,0x6d51,0x6df7,
  0x8c41,0x6d3b,0x4f19,0x706b, 0x83b7,0x6216,0x60d1,0x970d,
  0x8d27,0x7978,0x51fb,0x573e, 0x57fa,0x673a,0x7578,0x7a3d,
  0x79ef,0x7b95,0x808c,0x9965, 0x8ff9,0x6fc0,0x8ba5,0x9e21,
  0x59ec,0x7ee9,0x7f09,0x5409, 0x6781,0x68d8,0x8f91,0x7c4d,
  0x96c6,0x53ca,0x6025,0x75be, 0x6c72,0x5373,0x5ac9,0x7ea7,
  0x6324,0x51e0,0x810a,0x5df1, 0x84df,0x6280,0x5180,0x5b63,
  0x4f0e,0x796d,0x5242,0x60b8, 0x6d4e,0x5bc4,0x5bc2,0x8ba1,
  0x8bb0,0x65e2,0x5fcc,0x9645, 0x5993,0x7ee7,0x7eaa,0x5609,
  0x67b7,0x5939,0x4f73,0x5bb6, 0x52a0,0x835a,0x988a,0x8d3e,
  0x7532,0x94be,0x5047,0x7a3c, 0x4ef7,0x67b6,0x9a7e,0x5ac1,
  0x6b7c,0x76d1,0x575a,0x5c16, 0x7b3a,0x95f4,0x714e,0x517c,
  0x80a9,0x8270,0x5978,0x7f04, 0x8327,0x68c0,0x67ec,0x78b1,
  0x7877,0x62e3,0x6361,0x7b80, 0x4fed,0x526a,0x51cf,0x8350,
  0x69db,0x9274,0x8df5,0x8d31, 0x89c1,0x952e,0x7bad,0x4ef6,
  0x5065,0x8230,0x5251,0x996f, 0x6e10,0x6e85,0x6da7,0x5efa,
  0x50f5,0x59dc,0x5c06,0x6d46, 0x6c5f,0x7586,0x848b,0x6868,
  0x5956,0x8bb2,0x5320,0x9171, 0x964d,0x8549,0x6912,0x7901,
  0x7126,0x80f6,0x4ea4,0x90ca, 0x6d47,0x9a84,0x5a07,0x56bc,
  0x6405,0x94f0,0x77eb,0x4fa5, 0x811a,0x72e1,0x89d2,0x997a,
  0x7f34,0x7ede,0x527f,0x6559, 0x9175,0x8f7f,0x8f83,0x53eb,
  0x7a96,0x63ed,0x63a5,0x7686, 0x79f8,0x8857,0x9636,0x622a,
  0x52ab,0x8282,0x6854,0x6770, 0x6377,0x776b,0x7aed,0x6d01,
  0x7ed3,0x89e3,0x59d0,0x6212, 0x85c9,0x82a5,0x754c,0x501f,
  0x4ecb,0x75a5,0x8beb,0x5c4a, 0x5dfe,0x7b4b,0x65a4,0x91d1,
  0x4eca,0x6d25,0x895f,0x7d27, 0x9526,0x4ec5,0x8c28,0x8fdb,
  0x9773,0x664b,0x7981,0x8fd1, 0x70ec,0x6d78,0x5c3d,0x52b2,
  0x8346,0x5162,0x830e,0x775b, 0x6676,0x9cb8,0x4eac,0x60ca,
  0x7cbe,0x7cb3,0x7ecf,0x4e95, 0x8b66,0x666f,0x9888,0x9759,
  0x5883,0x656c,0x955c,0x5f84, 0x75c9,0x9756,0x7adf,0x7ade,
  0x51c0,0x70af,0x7a98,0x63ea, 0x7a76,0x7ea0,0x7396,0x97ed,
  0x4e45,0x7078,0x4e5d,0x9152, 0x53a9,0x6551,0x65e7,0x81fc,
  0x8205,0x548e,0x5c31,0x759a, 0x97a0,0x62d8,0x72d9,0x75bd,
  0x5c45,0x9a79,0x83ca,0x5c40, 0x5480,0x77e9,0x4e3e,0x6cae,
  0x805a,0x62d2,0x636e,0x5de8, 0x5177,0x8ddd,0x8e1e,0x952f,
  0x4ff1,0x53e5,0x60e7,0x70ac, 0x5267,0x6350,0x9e43,0x5a1f,
  0x5026,0x7737,0x5377,0x7ee2, 0x6485,0x652b,0x6289,0x6398,
  0x5014,0x7235,0x89c9,0x51b3, 0x8bc0,0x7edd,0x5747,0x83cc,
  0x94a7,0x519b,0x541b,0x5cfb, 0x4fca,0x7ae3,0x6d5a,0x90e1,
  0x9a8f,0x5580,0x5496,0x5361, 0x54af,0x5f00,0x63e9,0x6977,
  0x51ef,0x6168,0x520a,0x582a, 0x52d8,0x574e,0x780d,0x770b,
  0x5eb7,0x6177,0x7ce0,0x625b, 0x6297,0x4ea2,0x7095,0x8003,
  0x62f7,0x70e4,0x9760,0x5777, 0x82db,0x67ef,0x68f5,0x78d5,
  0x9897,0x79d1,0x58f3,0x54b3, 0x53ef,0x6e34,0x514b,0x523b,
  0x5ba2,0x8bfe,0x80af,0x5543, 0x57a6,0x6073,0x5751,0x542d,
  0x7a7a,0x6050,0x5b54,0x63a7, 0x62a0,0x53e3,0x6263,0x5bc7,
  0x67af,0x54ed,0x7a9f,0x82e6, 0x9177,0x5e93,0x88e4,0x5938,
  0x57ae,0x630e,0x8de8,0x80ef, 0x5757,0x7b77,0x4fa9,0x5feb,
  0x5bbd,0x6b3e,0x5321,0x7b50, 0x72c2,0x6846,0x77ff,0x7736,
  0x65f7,0x51b5,0x4e8f,0x76d4, 0x5cbf,0x7aa5,0x8475,0x594e,
  0x9b41,0x5080,0x9988,0x6127, 0x6e83,0x5764,0x6606,0x6346,
  0x56f0,0x62ec,0x6269,0x5ed3, 0x9614,0x5783,0x62c9,0x5587,
  0x8721,0x814a,0x8fa3,0x5566, 0x83b1,0x6765,0x8d56,0x84dd,
  0x5a6a,0x680f,0x62e6,0x7bee, 0x9611,0x5170,0x6f9c,0x8c30,
  0x63fd,0x89c8,0x61d2,0x7f06, 0x70c2,0x6ee5,0x7405,0x6994,
  0x72fc,0x5eca,0x90ce,0x6717, 0x6d6a,0x635e,0x52b3,0x7262,
  0x8001,0x4f6c,0x59e5,0x916a, 0x70d9,0x6d9d,0x52d2,0x4e50,
  0x96f7,0x956d,0x857e,0x78ca, 0x7d2f,0x5121,0x5792,0x64c2,
  0x808b,0x7c7b,0x6cea,0x68f1, 0x695e,0x51b7,0x5398,0x68a8,
  0x7281,0x9ece,0x7bf1,0x72f8, 0x79bb,0x6f13,0x7406,0x674e,
  0x91cc,0x9ca4,0x793c,0x8389, 0x8354,0x540f,0x6817,0x4e3d,
  0x5389,0x52b1,0x783e,0x5386, 0x5229,0x5088,0x4f8b,0x4fd0,
  0x75e2,0x7acb,0x7c92,0x6ca5, 0x96b6,0x529b,0x7483,0x54e9,
  0x4fe9,0x8054,0x83b2,0x8fde, 0x9570,0x5ec9,0x601c,0x6d9f,
  0x5e18,0x655b,0x8138,0x94fe, 0x604b,0x70bc,0x7ec3,0x7cae,
  0x51c9,0x6881,0x7cb1,0x826f, 0x4e24,0x8f86,0x91cf,0x667e,
  0x4eae,0x8c05,0x64a9,0x804a, 0x50da,0x7597,0x71ce,0x5be5,
  0x8fbd,0x6f66,0x4e86,0x6482, 0x9563,0x5ed6,0x6599,0x5217,
  0x88c2,0x70c8,0x52a3,0x730e, 0x7433,0x6797,0x78f7,0x9716,
  0x4e34,0x90bb,0x9cde,0x6dcb, 0x51db,0x8d41,0x541d,0x62ce,
  0x73b2,0x83f1,0x96f6,0x9f84, 0x94c3,0x4f36,0x7f9a,0x51cc,
  0x7075,0x9675,0x5cad,0x9886, 0x53e6,0x4ee4,0x6e9c,0x7409,
  0x69b4,0x786b,0x998f,0x7559, 0x5218,0x7624,0x6d41,0x67f3,
  0x516d,0x9f99,0x804b,0x5499, 0x7b3c,0x7abf,0x9686,0x5784,
  0x62e2,0x9647,0x697c,0x5a04, 0x6402,0x7bd3,0x6f0f,0x964b,
  0x82a6,0x5362,0x9885,0x5e90, 0x7089,0x63b3,0x5364,0x864f,
  0x9c81,0x9e93,0x788c,0x9732, 0x8def,0x8d42,0x9e7f,0x6f5e,
  0x7984,0x5f55,0x9646,0x622e, 0x9a74,0x5415,0x94dd,0x4fa3,
  0x65c5,0x5c65,0x5c61,0x7f15, 0x8651,0x6c2f,0x5f8b,0x7387,
  0x6ee4,0x7eff,0x5ce6,0x631b, 0x5b6a,0x6ee6,0x5375,0x4e71,
  0x63a0,0x7565,0x62a1,0x8f6e, 0x4f26,0x4ed1,0x6ca6,0x7eb6,
  0x8bba,0x841d,0x87ba,0x7f57, 0x903b,0x9523,0x7ba9,0x9aa1,
  0x88f8,0x843d,0x6d1b,0x9a86, 0x7edc,0x5988,0x9ebb,0x739b,
  0x7801,0x8682,0x9a6c,0x9a82, 0x561b,0x5417,0x57cb,0x4e70,
  0x9ea6,0x5356,0x8fc8,0x8109, 0x7792,0x9992,0x86ee,0x6ee1,
  0x8513,0x66fc,0x6162,0x6f2b, 0x8c29,0x8292,0x832b,0x76f2,
  0x6c13,0x5fd9,0x83bd,0x732b, 0x8305,0x951a,0x6bdb,0x77db,
  0x94c6,0x536f,0x8302,0x5192, 0x5e3d,0x8c8c,0x8d38,0x4e48,
  0x73ab,0x679a,0x6885,0x9176, 0x9709,0x7164,0x6ca1,0x7709,
  0x5a92,0x9541,0x6bcf,0x7f8e, 0x6627,0x5bd0,0x59b9,0x5a9a,
  0x95e8,0x95f7,0x4eec,0x840c, 0x8499,0x6aac,0x76df,0x9530,
  0x731b,0x68a6,0x5b5f,0x772f, 0x919a,0x9761,0x7cdc,0x8ff7,
  0x8c1c,0x5f25,0x7c73,0x79d8, 0x89c5,0x6ccc,0x871c,0x5bc6,
  0x5e42,0x68c9,0x7720,0x7ef5, 0x5195,0x514d,0x52c9,0x5a29,
  0x7f05,0x9762,0x82d7,0x63cf, 0x7784,0x85d0,0x79d2,0x6e3a,
  0x5e99,0x5999,0x8511,0x706d, 0x6c11,0x62bf,0x76bf,0x654f,
  0x60af,0x95fd,0x660e,0x879f, 0x9e23,0x94ed,0x540d,0x547d,
  0x8c2c,0x6478,0x6479,0x8611, 0x6a21,0x819c,0x78e8,0x6469,
  0x9b54,0x62b9,0x672b,0x83ab, 0x58a8,0x9ed8,0x6cab,0x6f20,
  0x5bde,0x964c,0x8c0b,0x725f, 0x67d0,0x62c7,0x7261,0x4ea9,
  0x59c6,0x6bcd,0x5893,0x66ae, 0x5e55,0x52df,0x6155,0x6728,
  0x76ee,0x7766,0x7267,0x7a46, 0x62ff,0x54ea,0x5450,0x94a0,
  0x90a3,0x5a1c,0x7eb3,0x6c16, 0x4e43,0x5976,0x8010,0x5948,
  0x5357,0x7537,0x96be,0x56ca, 0x6320,0x8111,0x607c,0x95f9,
  0x6dd6,0x5462,0x9981,0x5185, 0x5ae9,0x80fd,0x59ae,0x9713,
  0x502a,0x6ce5,0x5c3c,0x62df, 0x4f60,0x533f,0x817b,0x9006,
  0x6eba,0x852b,0x62c8,0x5e74, 0x78be,0x64b5,0x637b,0x5ff5,
  0x5a18,0x917f,0x9e1f,0x5c3f, 0x634f,0x8042,0x5b7d,0x556e,
  0x954a,0x954d,0x6d85,0x60a8, 0x67e0,0x72de,0x51dd,0x5b81,
  0x62e7,0x6cde,0x725b,0x626d, 0x94ae,0x7ebd,0x8113,0x6d53,
  0x519c,0x5f04,0x5974,0x52aa, 0x6012,0x5973,0x6696,0x8650,
  0x759f,0x632a,0x61e6,0x7cef, 0x8bfa,0x54e6,0x6b27,0x9e25,
  0x6bb4,0x85d5,0x5455,0x5076, 0x6ca4,0x556a,0x8db4,0x722c,
  0x5e15,0x6015,0x7436,0x62cd, 0x6392,0x724c,0x5f98,0x6e43,
  0x6d3e,0x6500,0x6f58,0x76d8, 0x78d0,0x76fc,0x7554,0x5224,
  0x53db,0x4e53,0x5e9e,0x65c1, 0x802a,0x80d6,0x629b,0x5486,
  0x5228,0x70ae,0x888d,0x8dd1, 0x6ce1,0x5478,0x80da,0x57f9,
  0x88f4,0x8d54,0x966a,0x914d, 0x4f69,0x6c9b,0x55b7,0x76c6,
  0x7830,0x62a8,0x70f9,0x6f8e, 0x5f6d,0x84ec,0x68da,0x787c,
  0x7bf7,0x81a8,0x670b,0x9e4f, 0x6367,0x78b0,0x576f,0x7812,
  0x9739,0x6279,0x62ab,0x5288, 0x7435,0x6bd7,0x5564,0x813e,
  0x75b2,0x76ae,0x5339,0x75de, 0x50fb,0x5c41,0x8b6c,0x7bc7,
  0x504f,0x7247,0x9a97,0x98d8, 0x6f02,0x74e2,0x7968,0x6487,
  0x77a5,0x62fc,0x9891,0x8d2b, 0x54c1,0x8058,0x4e52,0x576a,
  0x82f9,0x840d,0x5e73,0x51ed, 0x74f6,0x8bc4,0x5c4f,0x5761,
  0x6cfc,0x9887,0x5a46,0x7834, 0x9b44,0x8feb,0x7c95,0x5256,
  0x6251,0x94fa,0x4ec6,0x8386, 0x8461,0x83e9,0x84b2,0x57d4,
  0x6734,0x5703,0x666e,0x6d66, 0x8c31,0x66dd,0x7011,0x671f,
  0x6b3a,0x6816,0x621a,0x59bb, 0x4e03,0x51c4,0x6f06,0x67d2,
  0x6c8f,0x5176,0x68cb,0x5947, 0x6b67,0x7566,0x5d0e,0x8110,
  0x9f50,0x65d7,0x7948,0x7941, 0x9a91,0x8d77,0x5c82,0x4e5e,
  0x4f01,0x542f,0x5951,0x780c, 0x5668,0x6c14,0x8fc4,0x5f03,
  0x6c7d,0x6ce3,0x8bab,0x6390, 0x6070,0x6d3d,0x7275,0x6266,
  0x948e,0x94c5,0x5343,0x8fc1, 0x7b7e,0x4edf,0x8c26,0x4e7e,
  0x9ed4,0x94b1,0x94b3,0x524d, 0x6f5c,0x9063,0x6d45,0x8c34,
  0x5811,0x5d4c,0x6b20,0x6b49, 0x67aa,0x545b,0x8154,0x7f8c,
  0x5899,0x8537,0x5f3a,0x62a2, 0x6a47,0x9539,0x6572,0x6084,
  0x6865,0x77a7,0x4e54,0x4fa8, 0x5de7,0x9798,0x64ac,0x7fd8,
  0x5ced,0x4fcf,0x7a8d,0x5207, 0x8304,0x4e14,0x602f,0x7a83,
  0x94a6,0x4fb5,0x4eb2,0x79e6, 0x7434,0x52e4,0x82b9,0x64d2,
  0x79bd,0x5bdd,0x6c81,0x9752, 0x8f7b,0x6c22,0x503e,0x537f,
  0x6e05,0x64ce,0x6674,0x6c30, 0x60c5,0x9877,0x8bf7,0x5e86,
  0x743c,0x7a77,0x79cb,0x4e18, 0x90b1,0x7403,0x6c42,0x56da,
  0x914b,0x6cc5,0x8d8b,0x533a, 0x86c6,0x66f2,0x8eaf,0x5c48,
  0x9a71,0x6e20,0x53d6,0x5a36, 0x9f8b,0x8da3,0x53bb,0x5708,
  0x98a7,0x6743,0x919b,0x6cc9, 0x5168,0x75ca,0x62f3,0x72ac,
  0x5238,0x529d,0x7f3a,0x7094, 0x7638,0x5374,0x9e4a,0x69b7,
  0x786e,0x96c0,0x88d9,0x7fa4, 0x7136,0x71c3,0x5189,0x67d3,
  0x74e4,0x58e4,0x6518,0x56b7, 0x8ba9,0x9976,0x6270,0x7ed5,
  0x60f9,0x70ed,0x58ec,0x4ec1, 0x4eba,0x5fcd,0x97e7,0x4efb,
  0x8ba4,0x5203,0x598a,0x7eab, 0x6254,0x4ecd,0x65e5,0x620e,
  0x8338,0x84c9,0x8363,0x878d, 0x7194,0x6eb6,0x5bb9,0x7ed2,
  0x5197,0x63c9,0x67d4,0x8089, 0x8339,0x8815,0x5112,0x5b7a,
  0x5982,0x8fb1,0x4e73,0x6c5d, 0x5165,0x8925,0x8f6f,0x962e,
  0x854a,0x745e,0x9510,0x95f0, 0x6da6,0x82e5,0x5f31,0x6492,
  0x6d12,0x8428,0x816e,0x9cc3, 0x585e,0x8d5b,0x4e09,0x53c1,
  0x4f1e,0x6563,0x6851,0x55d3, 0x4e27,0x6414,0x9a9a,0x626b,
  0x5ac2,0x745f,0x8272,0x6da9, 0x68ee,0x50e7,0x838e,0x7802,
  0x6740,0x5239,0x6c99,0x7eb1, 0x50bb,0x5565,0x715e,0x7b5b,
  0x6652,0x73ca,0x82eb,0x6749, 0x5c71,0x5220,0x717d,0x886b,
  0x95ea,0x9655,0x64c5,0x8d61, 0x81b3,0x5584,0x6c55,0x6247,
  0x7f2e,0x5892,0x4f24,0x5546, 0x8d4f,0x664c,0x4e0a,0x5c1a,
  0x88f3,0x68a2,0x634e,0x7a0d, 0x70e7,0x828d,0x52fa,0x97f6,
  0x5c11,0x54e8,0x90b5,0x7ecd, 0x5962,0x8d4a,0x86c7,0x820c,
  0x820d,0x8d66,0x6444,0x5c04, 0x6151,0x6d89,0x793e,0x8bbe,
  0x7837,0x7533,0x547b,0x4f38, 0x8eab,0x6df1,0x5a20,0x7ec5,
  0x795e,0x6c88,0x5ba1,0x5a76, 0x751a,0x80be,0x614e,0x6e17,
  0x58f0,0x751f,0x7525,0x7272, 0x5347,0x7ef3,0x7701,0x76db,
  0x5269,0x80dc,0x5723,0x5e08, 0x5931,0x72ee,0x65bd,0x6e7f,
  0x8bd7,0x5c38,0x8671,0x5341, 0x77f3,0x62fe,0x65f6,0x4ec0,
  0x98df,0x8680,0x5b9e,0x8bc6, 0x53f2,0x77e2,0x4f7f,0x5c4e,
  0x9a76,0x59cb,0x5f0f,0x793a, 0x58eb,0x4e16,0x67ff,0x4e8b,
  0x62ed,0x8a93,0x901d,0x52bf, 0x662f,0x55dc,0x566c,0x9002,
  0x4ed5,0x4f8d,0x91ca,0x9970, 0x6c0f,0x5e02,0x6043,0x5ba4,
  0x89c6,0x8bd5,0x6536,0x624b, 0x9996,0x5b88,0x5bff,0x6388,
  0x552e,0x53d7,0x7626,0x517d, 0x852c,0x67a2,0x68b3,0x6b8a,
  0x6292,0x8f93,0x53d4,0x8212, 0x6dd1,0x758f,0x4e66,0x8d4e,
  0x5b70,0x719f,0x85af,0x6691, 0x66d9,0x7f72,0x8700,0x9ecd,
  0x9f20,0x5c5e,0x672f,0x8ff0, 0x6811,0x675f,0x620d,0x7ad6,
  0x5885,0x5eb6,0x6570,0x6f31, 0x6055,0x5237,0x800d,0x6454,
  0x8870,0x7529,0x5e05,0x6813, 0x62f4,0x971c,0x53cc,0x723d,
  0x8c01,0x6c34,0x7761,0x7a0e, 0x542e,0x77ac,0x987a,0x821c,
  0x8bf4,0x7855,0x6714,0x70c1, 0x65af,0x6495,0x5636,0x601d,
  0x79c1,0x53f8,0x4e1d,0x6b7b, 0x8086,0x5bfa,0x55e3,0x56db,
  0x4f3a,0x4f3c,0x9972,0x5df3, 0x677e,0x8038,0x6002,0x9882,
  0x9001,0x5b8b,0x8bbc,0x8bf5, 0x641c,0x8258,0x64de,0x55fd,
  0x82cf,0x9165,0x4fd7,0x7d20, 0x901f,0x7c9f,0x50f3,0x5851,
  0x6eaf,0x5bbf,0x8bc9,0x8083, 0x9178,0x849c,0x7b97,0x867d,
  0x968b,0x968f,0x7ee5,0x9ad3, 0x788e,0x5c81,0x7a57,0x9042,
  0x96a7,0x795f,0x5b59,0x635f, 0x7b0b,0x84d1,0x68ad,0x5506,
  0x7f29,0x7410,0x7d22,0x9501, 0x6240,0x584c,0x4ed6,0x5b83,
  0x5979,0x5854,0x736d,0x631e, 0x8e4b,0x8e0f,0x80ce,0x82d4,
  0x62ac,0x53f0,0x6cf0,0x915e, 0x592a,0x6001,0x6c70,0x574d,
  0x644a,0x8d2a,0x762b,0x6ee9, 0x575b,0x6a80,0x75f0,0x6f6d,
  0x8c2d,0x8c08,0x5766,0x6bef, 0x8892,0x78b3,0x63a2,0x53f9,
  0x70ad,0x6c64,0x5858,0x642a, 0x5802,0x68e0,0x819b,0x5510,
  0x7cd6,0x5018,0x8eba,0x6dcc, 0x8d9f,0x70eb,0x638f,0x6d9b,
  0x6ed4,0x7ee6,0x8404,0x6843, 0x9003,0x6dd8,0x9676,0x8ba8,
  0x5957,0x7279,0x85e4,0x817e, 0x75bc,0x8a8a,0x68af,0x5254,
  0x8e22,0x9511,0x63d0,0x9898, 0x8e44,0x557c,0x4f53,0x66ff,
  0x568f,0x60d5,0x6d95,0x5243, 0x5c49,0x5929,0x6dfb,0x586b,
  0x7530,0x751c,0x606c,0x8214, 0x8146,0x6311,0x6761,0x8fe2,
  0x773a,0x8df3,0x8d34,0x94c1, 0x5e16,0x5385,0x542c,0x70c3,
  0x6c40,0x5ef7,0x505c,0x4ead, 0x5ead,0x633a,0x8247,0x901a,
  0x6850,0x916e,0x77b3,0x540c, 0x94dc,0x5f64,0x7ae5,0x6876,
  0x6345,0x7b52,0x7edf,0x75db, 0x5077,0x6295,0x5934,0x900f,
  0x51f8,0x79c3,0x7a81,0x56fe, 0x5f92,0x9014,0x6d82,0x5c60,
  0x571f,0x5410,0x5154,0x6e4d, 0x56e2,0x63a8,0x9893,0x817f,
  0x8715,0x892a,0x9000,0x541e, 0x5c6f,0x81c0,0x62d6,0x6258,
  0x8131,0x9e35,0x9640,0x9a6e, 0x9a7c,0x692d,0x59a5,0x62d3,
  0x553e,0x6316,0x54c7,0x86d9, 0x6d3c,0x5a03,0x74e6,0x889c,
  0x6b6a,0x5916,0x8c4c,0x5f2f, 0x6e7e,0x73a9,0x987d,0x4e38,
  0x70f7,0x5b8c,0x7897,0x633d, 0x665a,0x7696,0x60cb,0x5b9b,
  0x5a49,0x4e07,0x8155,0x6c6a, 0x738b,0x4ea1,0x6789,0x7f51,
  0x5f80,0x65fa,0x671b,0x5fd8, 0x5984,0x5a01,0x5dcd,0x5fae,
  0x5371,0x97e6,0x8fdd,0x6845, 0x56f4,0x552f,0x60df,0x4e3a,
  0x6f4d,0x7ef4,0x82c7,0x840e, 0x59d4,0x4f1f,0x4f2a,0x5c3e,
  0x7eac,0x672a,0x851a,0x5473, 0x754f,0x80c3,0x5582,0x9b4f,
  0x4f4d,0x6e2d,0x8c13,0x5c09, 0x6170,0x536b,0x761f,0x6e29,
  0x868a,0x6587,0x95fb,0x7eb9, 0x543b,0x7a33,0x7d0a,0x95ee,
  0x55e1,0x7fc1,0x74ee,0x631d, 0x8717,0x6da1,0x7a9d,0x6211,
  0x65a1,0x5367,0x63e1,0x6c83, 0x5deb,0x545c,0x94a8,0x4e4c,
  0x6c61,0x8bec,0x5c4b,0x65e0, 0x829c,0x68a7,0x543e,0x5434,
  0x6bcb,0x6b66,0x4e94,0x6342, 0x5348,0x821e,0x4f0d,0x4fae,
  0x575e,0x620a,0x96fe,0x6664, 0x7269,0x52ff,0x52a1,0x609f,
  0x8bef,0x6614,0x7199,0x6790, 0x897f,0x7852,0x77fd,0x6670,
  0x563b,0x5438,0x9521,0x727a, 0x7a00,0x606f,0x5e0c,0x6089,
  0x819d,0x5915,0x60dc,0x7184, 0x70ef,0x6eaa,0x6c50,0x7280,
  0x6a84,0x88ad,0x5e2d,0x4e60, 0x5ab3,0x559c,0x94e3,0x6d17,
  0x7cfb,0x9699,0x620f,0x7ec6, 0x778e,0x867e,0x5323,0x971e,
  0x8f96,0x6687,0x5ce1,0x4fa0, 0x72ed,0x4e0b,0x53a6,0x590f,
  0x5413,0x6380,0x9528,0x5148, 0x4ed9,0x9c9c,0x7ea4,0x54b8,
  0x8d24,0x8854,0x8237,0x95f2, 0x6d8e,0x5f26,0x5acc,0x663e,
  0x9669,0x73b0,0x732e,0x53bf, 0x817a,0x9985,0x7fa1,0x5baa,
  0x9677,0x9650,0x7ebf,0x76f8, 0x53a2,0x9576,0x9999,0x7bb1,
  0x8944,0x6e58,0x4e61,0x7fd4, 0x7965,0x8be6,0x60f3,0x54cd,
  0x4eab,0x9879,0x5df7,0x6a61, 0x50cf,0x5411,0x8c61,0x8427,
  0x785d,0x9704,0x524a,0x54ee, 0x56a3,0x9500,0x6d88,0x5bb5,
  0x6dc6,0x6653,0x5c0f,0x5b5d, 0x6821,0x8096,0x5578,0x7b11,
  0x6548,0x6954,0x4e9b,0x6b47, 0x874e,0x978b,0x534f,0x631f,
  0x643a,0x90aa,0x659c,0x80c1, 0x8c10,0x5199,0x68b0,0x5378,
  0x87f9,0x61c8,0x6cc4,0x6cfb, 0x8c22,0x5c51,0x85aa,0x82af,
  0x950c,0x6b23,0x8f9b,0x65b0, 0x5ffb,0x5fc3,0x4fe1,0x8845,
  0x661f,0x8165,0x7329,0x60fa, 0x5174,0x5211,0x578b,0x5f62,
  0x90a2,0x884c,0x9192,0x5e78, 0x674f,0x6027,0x59d3,0x5144,
  0x51f6,0x80f8,0x5308,0x6c79, 0x96c4,0x718a,0x4f11,0x4fee,
  0x7f9e,0x673d,0x55c5,0x9508, 0x79c0,0x8896,0x7ee3,0x589f,
  0x620c,0x9700,0x865a,0x5618, 0x987b,0x5f90,0x8bb8,0x84c4,
  0x9157,0x53d9,0x65ed,0x5e8f, 0x755c,0x6064,0x7d6e,0x5a7f,
  0x7eea,0x7eed,0x8f69,0x55a7, 0x5ba3,0x60ac,0x65cb,0x7384,
  0x9009,0x7663,0x7729,0x7eda, 0x9774,0x859b,0x5b66,0x7a74,
  0x96ea,0x8840,0x52cb,0x718f, 0x5faa,0x65ec,0x8be2,0x5bfb,
  0x9a6f,0x5de1,0x6b89,0x6c5b, 0x8bad,0x8baf,0x900a,0x8fc5,
  0x538b,0x62bc,0x9e26,0x9e2d, 0x5440,0x4e2b,0x82bd,0x7259,
  0x869c,0x5d16,0x8859,0x6daf, 0x96c5,0x54d1,0x4e9a,0x8bb6,
  0x7109,0x54bd,0x9609,0x70df, 0x6df9,0x76d0,0x4e25,0x7814,
  0x8712,0x5ca9,0x5ef6,0x8a00, 0x989c,0x960e,0x708e,0x6cbf,
  0x5944,0x63a9,0x773c,0x884d, 0x6f14,0x8273,0x5830,0x71d5,
  0x538c,0x781a,0x96c1,0x5501, 0x5f66,0x7130,0x5bb4,0x8c1a,
  0x9a8c,0x6b83,0x592e,0x9e2f, 0x79e7,0x6768,0x626c,0x4f6f,
  0x75a1,0x7f8a,0x6d0b,0x9633, 0x6c27,0x4ef0,0x75d2,0x517b,
  0x6837,0x6f3e,0x9080,0x8170, 0x5996,0x7476,0x6447,0x5c27,
  0x9065,0x7a91,0x8c23,0x59da, 0x54ac,0x8200,0x836f,0x8981,
  0x8000,0x6930,0x564e,0x8036, 0x7237,0x91ce,0x51b6,0x4e5f,
  0x9875,0x6396,0x4e1a,0x53f6, 0x66f3,0x814b,0x591c,0x6db2,
  0x4e00,0x58f9,0x533b,0x63d6, 0x94f1,0x4f9d,0x4f0a,0x8863,
  0x9890,0x5937,0x9057,0x79fb, 0x4eea,0x80f0,0x7591,0x6c82,
  0x5b9c,0x59e8,0x5f5d,0x6905, 0x8681,0x501a,0x5df2,0x4e59,
  0x77e3,0x4ee5,0x827a,0x6291, 0x6613,0x9091,0x5c79,0x4ebf,
  0x5f79,0x81c6,0x9038,0x8084, 0x75ab,0x4ea6,0x88d4,0x610f,
  0x6bc5,0x5fc6,0x4e49,0x76ca, 0x6ea2,0x8be3,0x8bae,0x8c0a,
  0x8bd1,0x5f02,0x7ffc,0x7fcc, 0x7ece,0x8335,0x836b,0x56e0,
  0x6bb7,0x97f3,0x9634,0x59fb, 0x541f,0x94f6,0x6deb,0x5bc5,
  0x996e,0x5c39,0x5f15,0x9690, 0x5370,0x82f1,0x6a31,0x5a74,
  0x9e70,0x5e94,0x7f28,0x83b9, 0x8424,0x8425,0x8367,0x8747,
  0x8fce,0x8d62,0x76c8,0x5f71, 0x9896,0x786c,0x6620,0x54df,
  0x62e5,0x4f63,0x81c3,0x75c8, 0x5eb8,0x96cd,0x8e0a,0x86f9,
  0x548f,0x6cf3,0x6d8c,0x6c38, 0x607f,0x52c7,0x7528,0x5e7d,
  0x4f18,0x60a0,0x5fe7,0x5c24, 0x7531,0x90ae,0x94c0,0x72b9,
  0x6cb9,0x6e38,0x9149,0x6709, 0x53cb,0x53f3,0x4f51,0x91c9,
  0x8bf1,0x53c8,0x5e7c,0x8fc2, 0x6de4,0x4e8e,0x76c2,0x6986,
  0x865e,0x611a,0x8206,0x4f59, 0x4fde,0x903e,0x9c7c,0x6109,
  0x6e1d,0x6e14,0x9685,0x4e88, 0x5a31,0x96e8,0x4e0e,0x5c7f,
  0x79b9,0x5b87,0x8bed,0x7fbd, 0x7389,0x57df,0x828b,0x90c1,
  0x5401,0x9047,0x55bb,0x5cea, 0x5fa1,0x6108,0x6b32,0x72f1,
  0x80b2,0x8a89,0x6d74,0x5bd3, 0x88d5,0x9884,0x8c6b,0x9a6d,
  0x9e33,0x6e0a,0x51a4,0x5143, 0x57a3,0x8881,0x539f,0x63f4,
  0x8f95,0x56ed,0x5458,0x5706, 0x733f,0x6e90,0x7f18,0x8fdc,
  0x82d1,0x613f,0x6028,0x9662, 0x66f0,0x7ea6,0x8d8a,0x8dc3,
  0x94a5,0x5cb3,0x7ca4,0x6708, 0x60a6,0x9605,0x8018,0x4e91,
  0x90e7,0x5300,0x9668,0x5141, 0x8fd0,0x8574,0x915d,0x6655,
  0x97f5,0x5b55,0x531d,0x7838, 0x6742,0x683d,0x54c9,0x707e,
  0x5bb0,0x8f7d,0x518d,0x5728, 0x54b1,0x6512,0x6682,0x8d5e,
  0x8d43,0x810f,0x846c,0x906d, 0x7cdf,0x51ff,0x85fb,0x67a3,
  0x65e9,0x6fa1,0x86a4,0x8e81, 0x566a,0x9020,0x7682,0x7076,
  0x71e5,0x8d23,0x62e9,0x5219, 0x6cfd,0x8d3c,0x600e,0x589e,
  0x618e,0x66fe,0x8d60,0x624e, 0x55b3,0x6e23,0x672d,0x8f67,
  0x94e1,0x95f8,0x7728,0x6805, 0x69a8,0x548b,0x4e4d,0x70b8,
  0x8bc8,0x6458,0x658b,0x5b85, 0x7a84,0x503a,0x5be8,0x77bb,
  0x6be1,0x8a79,0x7c98,0x6cbe, 0x76cf,0x65a9,0x8f97,0x5d2d,
  0x5c55,0x8638,0x6808,0x5360, 0x6218,0x7ad9,0x6e5b,0x7efd,
  0x6a1f,0x7ae0,0x5f70,0x6f33, 0x5f20,0x638c,0x6da8,0x6756,
  0x4e08,0x5e10,0x8d26,0x4ed7, 0x80c0,0x7634,0x969c,0x62db,
  0x662d,0x627e,0x6cbc,0x8d75, 0x7167,0x7f69,0x5146,0x8087,
  0x53ec,0x906e,0x6298,0x54f2, 0x86f0,0x8f99,0x8005,0x9517,
  0x8517,0x8fd9,0x6d59,0x73cd, 0x659f,0x771f,0x7504,0x7827,
  0x81fb,0x8d1e,0x9488,0x4fa6, 0x6795,0x75b9,0x8bca,0x9707,
  0x632f,0x9547,0x9635,0x84b8, 0x6323,0x7741,0x5f81,0x72f0,
  0x4e89,0x6014,0x6574,0x62ef, 0x6b63,0x653f,0x5e27,0x75c7,
  0x90d1,0x8bc1,0x829d,0x679d, 0x652f,0x5431,0x8718,0x77e5,
  0x80a2,0x8102,0x6c41,0x4e4b, 0x7ec7,0x804c,0x76f4,0x690d,
  0x6b96,0x6267,0x503c,0x4f84, 0x5740,0x6307,0x6b62,0x8dbe,
  0x53ea,0x65e8,0x7eb8,0x5fd7, 0x631a,0x63b7,0x81f3,0x81f4,
  0x7f6e,0x5e1c,0x5cd9,0x5236, 0x667a,0x79e9,0x7a1a,0x8d28,
  0x7099,0x75d4,0x6ede,0x6cbb, 0x7a92,0x4e2d,0x76c5,0x5fe0,
  0x949f,0x8877,0x7ec8,0x79cd, 0x80bf,0x91cd,0x4ef2,0x4f17,
  0x821f,0x5468,0x5dde,0x6d32, 0x8bcc,0x7ca5,0x8f74,0x8098,
  0x5e1a,0x5492,0x76b1,0x5b99, 0x663c,0x9aa4,0x73e0,0x682a,
  0x86db,0x6731,0x732a,0x8bf8, 0x8bdb,0x9010,0x7af9,0x70db,
  0x716e,0x62c4,0x77a9,0x5631, 0x4e3b,0x8457,0x67f1,0x52a9,
  0x86c0,0x8d2e,0x94f8,0x7b51, 0x4f4f,0x6ce8,0x795d,0x9a7b,
  0x6293,0x722a,0x62fd,0x4e13, 0x7816,0x8f6c,0x64b0,0x8d5a,
  0x7bc6,0x6869,0x5e84,0x88c5, 0x5986,0x649e,0x58ee,0x72b6,
  0x690e,0x9525,0x8ffd,0x8d58, 0x5760,0x7f00,0x8c06,0x51c6,
  0x6349,0x62d9,0x5353,0x684c, 0x7422,0x8301,0x914c,0x5544,
  0x7740,0x707c,0x6d4a,0x5179, 0x54a8,0x8d44,0x59ff,0x6ecb,
  0x6dc4,0x5b5c,0x7d2b,0x4ed4, 0x7c7d,0x6ed3,0x5b50,0x81ea,
  0x6e0d,0x5b57,0x9b03,0x68d5, 0x8e2a,0x5b97,0x7efc,0x603b,
  0x7eb5,0x90b9,0x8d70,0x594f, 0x63cd,0x79df,0x8db3,0x5352,
  0x65cf,0x7956,0x8bc5,0x963b, 0x7ec4,0x94bb,0x7e82,0x5634,
  0x9189,0x6700,0x7f6a,0x5c0a, 0x9075,0x6628,0x5de6,0x4f50,
  0x67de,0x505a,0x4f5c,0x5750, 0x5ea7,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x4e8d,0x4e0c, 0x5140,0x4e10,0x5eff,0x5345,
  0x4e15,0x4e98,0x4e1e,0x9b32, 0x5b6c,0x5669,0x4e28,0x79ba,
  0x4e3f,0x5315,0x4e47,0x592d, 0x723b,0x536e,0x6c10,0x56df,
  0x80e4,0x9997,0x6bd3,0x777e, 0x9f17,0x4e36,0x4e9f,0x9f10,
  0x4e5c,0x4e69,0x4e93,0x8288, 0x5b5b,0x556c,0x560f,0x4ec4,
  0x538d,0x539d,0x53a3,0x53a5, 0x53ae,0x9765,0x8d5d,0x531a,
  0x53f5,0x5326,0x532e,0x533e, 0x8d5c,0x5366,0x5363,0x5202,
  0x5208,0x520e,0x522d,0x5233, 0x523f,0x5240,0x524c,0x525e,
  0x5261,0x525c,0x84af,0x527d, 0x5282,0x5281,0x5290,0x5293,
  0x5182,0x7f54,0x4ebb,0x4ec3, 0x4ec9,0x4ec2,0x4ee8,0x4ee1,
  0x4eeb,0x4ede,0x4f1b,0x4ef3, 0x4f22,0x4f64,0x4ef5,0x4f25,
  0x4f27,0x4f09,0x4f2b,0x4f5e, 0x4f67,0x6538,0x4f5a,0x4f5d,
  0x4f5f,0x4f57,0x4f32,0x4f3d, 0x4f76,0x4f74,0x4f91,0x4f89,
  0x4f83,0x4f8f,0x4f7e,0x4f7b, 0x4faa,0x4f7c,0x4fac,0x4f94,
  0x4fe6,0x4fe8,0x4fea,0x4fc5, 0x4fda,0x4fe3,0x4fdc,0x4fd1,
  0x4fdf,0x4ff8,0x5029,0x504c, 0x4ff3,0x502c,0x500f,0x502e,
  0x502d,0x4ffe,0x501c,0x500c, 0x5025,0x5028,0x507e,0x5043,
  0x5055,0x5048,0x504e,0x506c, 0x507b,0x50a5,0x50a7,0x50a9,
  0x50ba,0x50d6,0x5106,0x50ed, 0x50ec,0x50e6,0x50ee,0x5107,
  0x510b,0x4edd,0x6c3d,0x4f58, 0x4f65,0x4fce,0x9fa0,0x6c46,
  0x7c74,0x516e,0x5dfd,0x9ec9, 0x9998,0x5181,0x5914,0x52f9,
  0x530d,0x8a07,0x5310,0x51eb, 0x5919,0x5155,0x4ea0,0x5156,
  0x4eb3,0x886e,0x88a4,0x4eb5, 0x8114,0x88d2,0x7980,0x5b34,
  0x8803,0x7fb8,0x51ab,0x51b1, 0x51bd,0x51bc,0x51c7,0x5196,
  0x51a2,0x51a5,0x8ba0,0x8ba6, 0x8ba7,0x8baa,0x8bb4,0x8bb5,
  0x8bb7,0x8bc2,0x8bc3,0x8bcb, 0x8bcf,0x8bce,0x8bd2,0x8bd3,
  0x8bd4,0x8bd6,0x8bd8,0x8bd9, 0x8bdc,0x8bdf,0x8be0,0x8be4,
  0x8be8,0x8be9,0x8bee,0x8bf0, 0x8bf3,0x8bf6,0x8bf9,0x8bfc,
  0x8bff,0x8c00,0x8c02,0x8c04, 0x8c07,0x8c0c,0x8c0f,0x8c11,
  0x8c12,0x8c14,0x8c15,0x8c16, 0x8c19,0x8c1b,0x8c18,0x8c1d,
  0x8c1f,0x8c20,0x8c21,0x8c25, 0x8c27,0x8c2a,0x8c2b,0x8c2e,
  0x8c2f,0x8c32,0x8c33,0x8c35, 0x8c36,0x5369,0x537a,0x961d,
  0x9622,0x9621,0x9631,0x962a, 0x963d,0x963c,0x9642,0x9649,
  0x9654,0x965f,0x9667,0x966c, 0x9672,0x9674,0x9688,0x968d,
  0x9697,0x96b0,0x9097,0x909b, 0x909d,0x9099,0x90ac,0x90a1,
  0x90b4,0x90b3,0x90b6,0x90ba, 0x90b8,0x90b0,0x90cf,0x90c5,
  0x90be,0x90d0,0x90c4,0x90c7, 0x90d3,0x90e6,0x90e2,0x90dc,
  0x90d7,0x90db,0x90eb,0x90ef, 0x90fe,0x9104,0x9122,0x911e,
  0x9123,0x9131,0x912f,0x9139, 0x9143,0x9146,0x520d,0x5942,
  0x52a2,0x52ac,0x52ad,0x52be, 0x54ff,0x52d0,0x52d6,0x52f0,
  0x53df,0x71ee,0x77cd,0x5ef4, 0x51f5,0x51fc,0x9b2f,0x53b6,
  0x5f01,0x755a,0x5def,0x574c, 0x57a9,0x57a1,0x587e,0x58bc,
  0x58c5,0x58d1,0x5729,0x572c, 0x572a,0x5733,0x5739,0x572e,
  0x572f,0x575c,0x573b,0x5742, 0x5769,0x5785,0x576b,0x5786,
  0x577c,0x577b,0x5768,0x576d, 0x5776,0x5773,0x57ad,0x57a4,
  0x578c,0x57b2,0x57cf,0x57a7, 0x57b4,0x5793,0x57a0,0x57d5,
  0x57d8,0x57da,0x57d9,0x57d2, 0x57b8,0x57f4,0x57ef,0x57f8,
  0x57e4,0x57dd,0x580b,0x580d, 0x57fd,0x57ed,0x5800,0x581e,
  0x5819,0x5844,0x5820,0x5865, 0x586c,0x5881,0x5889,0x589a,
  0x5880,0x99a8,0x9f19,0x61ff, 0x8279,0x827d,0x827f,0x828f,
  0x828a,0x82a8,0x8284,0x828e, 0x8291,0x8297,0x8299,0x82ab,
  0x82b8,0x82be,0x82b0,0x82c8, 0x82ca,0x82e3,0x8298,0x82b7,
  0x82ae,0x82cb,0x82cc,0x82c1, 0x82a9,0x82b4,0x82a1,0x82aa,
  0x829f,0x82c4,0x82ce,0x82a4, 0x82e1,0x8309,0x82f7,0x82e4,
  0x830f,0x8307,0x82dc,0x82f4, 0x82d2,0x82d8,0x830c,0x82fb,
  0x82d3,0x8311,0x831a,0x8306, 0x8314,0x8315,0x82e0,0x82d5,
  0x831c,0x8351,0x835b,0x835c, 0x8308,0x8392,0x833c,0x8334,
  0x8331,0x839b,0x835e,0x832f, 0x834f,0x8347,0x8343,0x835f,
  0x8340,0x8317,0x8360,0x832d, 0x833a,0x8333,0x8366,0x8365,
  0x8368,0x831b,0x8369,0x836c, 0x836a,0x836d,0x836e,0x83b0,
  0x8378,0x83b3,0x83b4,0x83a0, 0x83aa,0x8393,0x839c,0x8385,
  0x837c,0x83b6,0x83a9,0x837d, 0x83b8,0x837b,0x8398,0x839e,
  0x83a8,0x83ba,0x83bc,0x83c1, 0x8401,0x83e5,0x83d8,0x5807,
  0x8418,0x840b,0x83dd,0x83fd, 0x83d6,0x841c,0x8438,0x8411,
  0x8406,0x83d4,0x83df,0x840f, 0x8403,0x83f8,0x83f9,0x83ea,
  0x83c5,0x83c0,0x8426,0x83f0, 0x83e1,0x845c,0x8451,0x845a,
  0x8459,0x8473,0x8487,0x8488, 0x847a,0x8489,0x8478,0x843c,
  0x8446,0x8469,0x8476,0x848c, 0x848e,0x8431,0x846d,0x84c1,
  0x84cd,0x84d0,0x84e6,0x84bd, 0x84d3,0x84ca,0x84bf,0x84ba,
  0x84e0,0x84a1,0x84b9,0x84b4, 0x8497,0x84e5,0x84e3,0x850c,
  0x750d,0x8538,0x84f0,0x8539, 0x851f,0x853a,0x8556,0x853b,
  0x84ff,0x84fc,0x8559,0x8548, 0x8568,0x8564,0x855e,0x857a,
  0x77a2,0x8543,0x8572,0x857b, 0x85a4,0x85a8,0x8587,0x858f,
  0x8579,0x85ae,0x859c,0x8585, 0x85b9,0x85b7,0x85b0,0x85d3,
  0x85c1,0x85dc,0x85ff,0x8627, 0x8605,0x8629,0x8616,0x863c,
  0x5efe,0x5f08,0x593c,0x5941, 0x8037,0x5955,0x595a,0x5958,
  0x530f,0x5c22,0x5c25,0x5c2c, 0x5c34,0x624c,0x626a,0x629f,
  0x62bb,0x62ca,0x62da,0x62d7, 0x62ee,0x6322,0x62f6,0x6339,
  0x634b,0x6343,0x63ad,0x63f6, 0x6371,0x637a,0x638e,0x63b4,
  0x636d,0x63ac,0x638a,0x6369, 0x63ae,0x63bc,0x63f2,0x63f8,
  0x63e0,0x63ff,0x63c4,0x63de, 0x63ce,0x6452,0x63c6,0x63be,
  0x6445,0x6441,0x640b,0x641b, 0x6420,0x640c,0x6426,0x6421,
  0x645e,0x6484,0x646d,0x6496, 0x647a,0x64b7,0x64b8,0x6499,
  0x64ba,0x64c0,0x64d0,0x64d7, 0x64e4,0x64e2,0x6509,0x6525,
  0x652e,0x5f0b,0x5fd2,0x7519, 0x5f11,0x535f,0x53f1,0x53fd,
  0x53e9,0x53e8,0x53fb,0x5412, 0x5416,0x5406,0x544b,0x5452,
  0x5453,0x5454,0x5456,0x5443, 0x5421,0x5457,0x5459,0x5423,
  0x5432,0x5482,0x5494,0x5477, 0x5471,0x5464,0x549a,0x549b,
  0x5484,0x5476,0x5466,0x549d, 0x54d0,0x54ad,0x54c2,0x54b4,
  0x54d2,0x54a7,0x54a6,0x54d3, 0x54d4,0x5472,0x54a3,0x54d5,
  0x54bb,0x54bf,0x54cc,0x54d9, 0x54da,0x54dc,0x54a9,0x54aa,
  0x54a4,0x54dd,0x54cf,0x54de, 0x551b,0x54e7,0x5520,0x54fd,
  0x5514,0x54f3,0x5522,0x5523, 0x550f,0x5511,0x5527,0x552a,
  0x5567,0x558f,0x55b5,0x5549, 0x556d,0x5541,0x5555,0x553f,
  0x5550,0x553c,0x5537,0x5556, 0x5575,0x5576,0x5577,0x5533,
  0x5530,0x555c,0x558b,0x55d2, 0x5583,0x55b1,0x55b9,0x5588,
  0x5581,0x559f,0x557e,0x55d6, 0x5591,0x557b,0x55df,0x55bd,
  0x55be,0x5594,0x5599,0x55ea, 0x55f7,0x55c9,0x561f,0x55d1,
  0x55eb,0x55ec,0x55d4,0x55e6, 0x55dd,0x55c4,0x55ef,0x55e5,
  0x55f2,0x55f3,0x55cc,0x55cd, 0x55e8,0x55f5,0x55e4,0x8f94,
  0x561e,0x5608,0x560c,0x5601, 0x5624,0x5623,0x55fe,0x5600,
  0x5627,0x562d,0x5658,0x5639, 0x5657,0x562c,0x564d,0x5662,
  0x5659,0x565c,0x564c,0x5654, 0x5686,0x5664,0x5671,0x566b,
  0x567b,0x567c,0x5685,0x5693, 0x56af,0x56d4,0x56d7,0x56dd,
  0x56e1,0x56f5,0x56eb,0x56f9, 0x56ff,0x5704,0x570a,0x5709,
  0x571c,0x5e0f,0x5e19,0x5e14, 0x5e11,0x5e31,0x5e3b,0x5e3c,
  0x5e37,0x5e44,0x5e54,0x5e5b, 0x5e5e,0x5e61,0x5c8c,0x5c7a,
  0x5c8d,0x5c90,0x5c96,0x5c88, 0x5c98,0x5c99,0x5c91,0x5c9a,
  0x5c9c,0x5cb5,0x5ca2,0x5cbd, 0x5cac,0x5cab,0x5cb1,0x5ca3,
  0x5cc1,0x5cb7,0x5cc4,0x5cd2, 0x5ce4,0x5ccb,0x5ce5,0x5d02,
  0x5d03,0x5d27,0x5d26,0x5d2e, 0x5d24,0x5d1e,0x5d06,0x5d1b,
  0x5d58,0x5d3e,0x5d34,0x5d3d, 0x5d6c,0x5d5b,0x5d6f,0x5d5d,
  0x5d6b,0x5d4b,0x5d4a,0x5d69, 0x5d74,0x5d82,0x5d99,0x5d9d,
  0x8c73,0x5db7,0x5dc5,0x5f73, 0x5f77,0x5f82,0x5f87,0x5f89,
  0x5f8c,0x5f95,0x5f99,0x5f9c, 0x5fa8,0x5fad,0x5fb5,0x5fbc,
  0x8862,0x5f61,0x72ad,0x72b0, 0x72b4,0x72b7,0x72b8,0x72c3,
  0x72c1,0x72ce,0x72cd,0x72d2, 0x72e8,0x72ef,0x72e9,0x72f2,
  0x72f4,0x72f7,0x7301,0x72f3, 0x7303,0x72fa,0x72fb,0x7317,
  0x7313,0x7321,0x730a,0x731e, 0x731d,0x7315,0x7322,0x7339,
  0x7325,0x732c,0x7338,0x7331, 0x7350,0x734d,0x7357,0x7360,
  0x736c,0x736f,0x737e,0x821b, 0x5925,0x98e7,0x5924,0x5902,
  0x9963,0x9967,0x9968,0x9969, 0x996a,0x996b,0x996c,0x9974,
  0x9977,0x997d,0x9980,0x9984, 0x9987,0x998a,0x998d,0x9990,
  0x9991,0x9993,0x9994,0x9995, 0x5e80,0x5e91,0x5e8b,0x5e96,
  0x5ea5,0x5ea0,0x5eb9,0x5eb5, 0x5ebe,0x5eb3,0x8d53,0x5ed2,
  0x5ed1,0x5edb,0x5ee8,0x5eea, 0x81ba,0x5fc4,0x5fc9,0x5fd6,
  0x5fcf,0x6003,0x5fee,0x6004, 0x5fe1,0x5fe4,0x5ffe,0x6005,
  0x6006,0x5fea,0x5fed,0x5ff8, 0x6019,0x6035,0x6026,0x601b,
  0x600f,0x600d,0x6029,0x602b, 0x600a,0x603f,0x6021,0x6078,
  0x6079,0x607b,0x607a,0x6042, 0x606a,0x607d,0x6096,0x609a,
  0x60ad,0x609d,0x6083,0x6092, 0x608c,0x609b,0x60ec,0x60bb,
  0x60b1,0x60dd,0x60d8,0x60c6, 0x60da,0x60b4,0x6120,0x6126,
  0x6115,0x6123,0x60f4,0x6100, 0x610e,0x612b,0x614a,0x6175,
  0x61ac,0x6194,0x61a7,0x61b7, 0x61d4,0x61f5,0x5fdd,0x96b3,
  0x95e9,0x95eb,0x95f1,0x95f3, 0x95f5,0x95f6,0x95fc,0x95fe,
  0x9603,0x9604,0x9606,0x9608, 0x960a,0x960b,0x960c,0x960d,
  0x960f,0x9612,0x9615,0x9616, 0x9617,0x9619,0x961a,0x4e2c,
  0x723f,0x6215,0x6c35,0x6c54, 0x6c5c,0x6c4a,0x6ca3,0x6c85,
  0x6c90,0x6c94,0x6c8c,0x6c68, 0x6c69,0x6c74,0x6c76,0x6c86,
  0x6ca9,0x6cd0,0x6cd4,0x6cad, 0x6cf7,0x6cf8,0x6cf1,0x6cd7,
  0x6cb2,0x6ce0,0x6cd6,0x6cfa, 0x6ceb,0x6cee,0x6cb1,0x6cd3,
  0x6cef,0x6cfe,0x6d39,0x6d27, 0x6d0c,0x6d43,0x6d48,0x6d07,
  0x6d04,0x6d19,0x6d0e,0x6d2b, 0x6d4d,0x6d2e,0x6d35,0x6d1a,
  0x6d4f,0x6d52,0x6d54,0x6d33, 0x6d91,0x6d6f,0x6d9e,0x6da0,
  0x6d5e,0x6d93,0x6d94,0x6d5c, 0x6d60,0x6d7c,0x6d63,0x6e1a,
  0x6dc7,0x6dc5,0x6dde,0x6e0e, 0x6dbf,0x6de0,0x6e11,0x6de6,
  0x6ddd,0x6dd9,0x6e16,0x6dab, 0x6e0c,0x6dae,0x6e2b,0x6e6e,
  0x6e4e,0x6e6b,0x6eb2,0x6e5f, 0x6e86,0x6e53,0x6e54,0x6e32,
  0x6e25,0x6e44,0x6edf,0x6eb1, 0x6e98,0x6ee0,0x6f2d,0x6ee2,
  0x6ea5,0x6ea7,0x6ebd,0x6ebb, 0x6eb7,0x6ed7,0x6eb4,0x6ecf,
  0x6e8f,0x6ec2,0x6e9f,0x6f62, 0x6f46,0x6f47,0x6f24,0x6f15,
  0x6ef9,0x6f2f,0x6f36,0x6f4b, 0x6f74,0x6f2a,0x6f09,0x6f29,
  0x6f89,0x6f8d,0x6f8c,0x6f78, 0x6f72,0x6f7c,0x6f7a,0x6fd1,
  0x6fc9,0x6fa7,0x6fb9,0x6fb6, 0x6fc2,0x6fe1,0x6fee,0x6fde,
  0x6fe0,0x6fef,0x701a,0x7023, 0x701b,0x7039,0x7035,0x704f,
  0x705e,0x5b80,0x5b84,0x5b95, 0x5b93,0x5ba5,0x5bb8,0x752f,
  0x9a9e,0x6434,0x5be4,0x5bee, 0x8930,0x5bf0,0x8e47,0x8b07,
  0x8fb6,0x8fd3,0x8fd5,0x8fe5, 0x8fee,0x8fe4,0x8fe9,0x8fe6,
  0x8ff3,0x8fe8,0x9005,0x9004, 0x900b,0x9026,0x9011,0x900d,
  0x9016,0x9021,0x9035,0x9036, 0x902d,0x902f,0x9044,0x9051,
  0x9052,0x9050,0x9068,0x9058, 0x9062,0x905b,0x66b9,0x9074,
  0x907d,0x9082,0x9088,0x9083, 0x908b,0x5f50,0x5f57,0x5f56,
  0x5f58,0x5c3b,0x54ab,0x5c50, 0x5c59,0x5b71,0x5c63,0x5c66,
  0x7fbc,0x5f2a,0x5f29,0x5f2d, 0x8274,0x5f3c,0x9b3b,0x5c6e,
  0x5981,0x5983,0x598d,0x59a9, 0x59aa,0x59a3,0x5997,0x59ca,
  0x59ab,0x599e,0x59a4,0x59d2, 0x59b2,0x59af,0x59d7,0x59be,
  0x5a05,0x5a06,0x59dd,0x5a08, 0x59e3,0x59d8,0x59f9,0x5a0c,
  0x5a09,0x5a32,0x5a34,0x5a11, 0x5a23,0x5a13,0x5a40,0x5a67,
  0x5a4a,0x5a55,0x5a3c,0x5a62, 0x5a75,0x80ec,0x5aaa,0x5a9b,
  0x5a77,0x5a7a,0x5abe,0x5aeb, 0x5ab2,0x5ad2,0x5ad4,0x5ab8,
  0x5ae0,0x5ae3,0x5af1,0x5ad6, 0x5ae6,0x5ad8,0x5adc,0x5b09,
  0x5b17,0x5b16,0x5b32,0x5b37, 0x5b40,0x5c15,0x5c1c,0x5b5a,
  0x5b65,0x5b73,0x5b51,0x5b53, 0x5b62,0x9a75,0x9a77,0x9a78,
  0x9a7a,0x9a7f,0x9a7d,0x9a80, 0x9a81,0x9a85,0x9a88,0x9a8a,
  0x9a90,0x9a92,0x9a93,0x9a96, 0x9a98,0x9a9b,0x9a9c,0x9a9d,
  0x9a9f,0x9aa0,0x9aa2,0x9aa3, 0x9aa5,0x9aa7,0x7e9f,0x7ea1,
  0x7ea3,0x7ea5,0x7ea8,0x7ea9, 0x7ead,0x7eb0,0x7ebe,0x7ec0,
  0x7ec1,0x7ec2,0x7ec9,0x7ecb, 0x7ecc,0x7ed0,0x7ed4,0x7ed7,
  0x7edb,0x7ee0,0x7ee1,0x7ee8, 0x7eeb,0x7eee,0x7eef,0x7ef1,
  0x7ef2,0x7f0d,0x7ef6,0x7efa, 0x7efb,0x7efe,0x7f01,0x7f02,
  0x7f03,0x7f07,0x7f08,0x7f0b, 0x7f0c,0x7f0f,0x7f11,0x7f12,
  0x7f17,0x7f19,0x7f1c,0x7f1b, 0x7f1f,0x7f21,0x7f22,0x7f23,
  0x7f24,0x7f25,0x7f26,0x7f27, 0x7f2a,0x7f2b,0x7f2c,0x7f2d,
  0x7f2f,0x7f30,0x7f31,0x7f32, 0x7f33,0x7f35,0x5e7a,0x757f,
  0x5ddb,0x753e,0x9095,0x738e, 0x7391,0x73ae,0x73a2,0x739f,
  0x73cf,0x73c2,0x73d1,0x73b7, 0x73b3,0x73c0,0x73c9,0x73c8,
  0x73e5,0x73d9,0x987c,0x740a, 0x73e9,0x73e7,0x73de,0x73ba,
  0x73f2,0x740f,0x742a,0x745b, 0x7426,0x7425,0x7428,0x7430,
  0x742e,0x742c,0x741b,0x741a, 0x7441,0x745c,0x7457,0x7455,
  0x7459,0x7477,0x746d,0x747e, 0x749c,0x748e,0x7480,0x7481,
  0x7487,0x748b,0x749e,0x74a8, 0x74a9,0x7490,0x74a7,0x74d2,
  0x74ba,0x97ea,0x97eb,0x97ec, 0x674c,0x6753,0x675e,0x6748,
  0x6769,0x67a5,0x6787,0x676a, 0x6773,0x6798,0x67a7,0x6775,
  0x67a8,0x679e,0x67ad,0x678b, 0x6777,0x677c,0x67f0,0x6809,
  0x67d8,0x680a,0x67e9,0x67b0, 0x680c,0x67d9,0x67b5,0x67da,
  0x67b3,0x67dd,0x6800,0x67c3, 0x67b8,0x67e2,0x680e,0x67c1,
  0x67fd,0x6832,0x6833,0x6860, 0x6861,0x684e,0x6862,0x6844,
  0x6864,0x6883,0x681d,0x6855, 0x6866,0x6841,0x6867,0x6840,
  0x683e,0x684a,0x6849,0x6829, 0x68b5,0x688f,0x6874,0x6877,
  0x6893,0x686b,0x68c2,0x696e, 0x68fc,0x691f,0x6920,0x68f9,
  0x6924,0x68f0,0x690b,0x6901, 0x6957,0x68e3,0x6910,0x6971,
  0x6939,0x6960,0x6942,0x695d, 0x6984,0x696b,0x6980,0x6998,
  0x6978,0x6934,0x69cc,0x6987, 0x6988,0x69ce,0x6989,0x6966,
  0x6963,0x6979,0x699b,0x69a7, 0x69bb,0x69ab,0x69ad,0x69d4,
  0x69b1,0x69c1,0x69ca,0x69df, 0x6995,0x69e0,0x698d,0x69ff,
  0x6a2f,0x69ed,0x6a17,0x6a18, 0x6a65,0x69f2,0x6a44,0x6a3e,
  0x6aa0,0x6a50,0x6a5b,0x6a35, 0x6a8e,0x6a79,0x6a3d,0x6a28,
  0x6a58,0x6a7c,0x6a91,0x6a90, 0x6aa9,0x6a97,0x6aab,0x7337,
  0x7352,0x6b81,0x6b82,0x6b87, 0x6b84,0x6b92,0x6b93,0x6b8d,
  0x6b9a,0x6b9b,0x6ba1,0x6baa, 0x8f6b,0x8f6d,0x8f71,0x8f72,
  0x8f73,0x8f75,0x8f76,0x8f78, 0x8f77,0x8f79,0x8f7a,0x8f7c,
  0x8f7e,0x8f81,0x8f82,0x8f84, 0x8f87,0x8f8b,0x8f8d,0x8f8e,
  0x8f8f,0x8f98,0x8f9a,0x8ece, 0x620b,0x6217,0x621b,0x621f,
  0x6222,0x6221,0x6225,0x6224, 0x622c,0x81e7,0x74ef,0x74f4,
  0x74ff,0x750f,0x7511,0x7513, 0x6534,0x65ee,0x65ef,0x65f0,
  0x660a,0x6619,0x6772,0x6603, 0x6615,0x6600,0x7085,0x66f7,
  0x661d,0x6634,0x6631,0x6636, 0x6635,0x8006,0x665f,0x6654,
  0x6641,0x664f,0x6656,0x6661, 0x6657,0x6677,0x6684,0x668c,
  0x66a7,0x669d,0x66be,0x66db, 0x66dc,0x66e6,0x66e9,0x8d32,
  0x8d33,0x8d36,0x8d3b,0x8d3d, 0x8d40,0x8d45,0x8d46,0x8d48,
  0x8d49,0x8d47,0x8d4d,0x8d55, 0x8d59,0x89c7,0x89ca,0x89cb,
  0x89cc,0x89ce,0x89cf,0x89d0, 0x89d1,0x726e,0x729f,0x725d,
  0x7266,0x726f,0x727e,0x727f, 0x7284,0x728b,0x728d,0x728f,
  0x7292,0x6308,0x6332,0x63b0, 0x643f,0x64d8,0x8004,0x6bea,
  0x6bf3,0x6bfd,0x6bf5,0x6bf9, 0x6c05,0x6c07,0x6c06,0x6c0d,
  0x6c15,0x6c18,0x6c19,0x6c1a, 0x6c21,0x6c29,0x6c24,0x6c2a,
  0x6c32,0x6535,0x6555,0x656b, 0x724d,0x7252,0x7256,0x7230,
  0x8662,0x5216,0x809f,0x809c, 0x8093,0x80bc,0x670a,0x80bd,
  0x80b1,0x80ab,0x80ad,0x80b4, 0x80b7,0x80e7,0x80e8,0x80e9,
  0x80ea,0x80db,0x80c2,0x80c4, 0x80d9,0x80cd,0x80d7,0x6710,
  0x80dd,0x80eb,0x80f1,0x80f4, 0x80ed,0x810d,0x810e,0x80f2,
  0x80fc,0x6715,0x8112,0x8c5a, 0x8136,0x811e,0x812c,0x8118,
  0x8132,0x8148,0x814c,0x8153, 0x8174,0x8159,0x815a,0x8171,
  0x8160,0x8169,0x817c,0x817d, 0x816d,0x8167,0x584d,0x5ab5,
  0x8188,0x8182,0x8191,0x6ed5, 0x81a3,0x81aa,0x81cc,0x6726,
  0x81ca,0x81bb,0x81c1,0x81a6, 0x6b24,0x6b37,0x6b39,0x6b43,
  0x6b46,0x6b59,0x98d1,0x98d2, 0x98d3,0x98d5,0x98d9,0x98da,
  0x6bb3,0x5f40,0x6bc2,0x89f3, 0x6590,0x9f51,0x6593,0x65bc,
  0x65c6,0x65c4,0x65c3,0x65cc, 0x65ce,0x65d2,0x65d6,0x7080,
  0x709c,0x7096,0x709d,0x70bb, 0x70c0,0x70b7,0x70ab,0x70b1,
  0x70e8,0x70ca,0x7110,0x7113, 0x7116,0x712f,0x7131,0x7173,
  0x715c,0x7168,0x7145,0x7172, 0x714a,0x7178,0x717a,0x7198,
  0x71b3,0x71b5,0x71a8,0x71a0, 0x71e0,0x71d4,0x71e7,0x71f9,
  0x721d,0x7228,0x706c,0x7118, 0x7166,0x71b9,0x623e,0x623d,
  0x6243,0x6248,0x6249,0x793b, 0x7940,0x7946,0x7949,0x795b,
  0x795c,0x7953,0x795a,0x7962, 0x7957,0x7960,0x796f,0x7967,
  0x797a,0x7985,0x798a,0x799a, 0x79a7,0x79b3,0x5fd1,0x5fd0,
  0x603c,0x605d,0x605a,0x6067, 0x6041,0x6059,0x6063,0x60ab,
  0x6106,0x610d,0x615d,0x61a9, 0x619d,0x61cb,0x61d1,0x6206,
  0x8080,0x807f,0x6c93,0x6cf6, 0x6dfc,0x77f6,0x77f8,0x7800,
  0x7809,0x7817,0x7818,0x7811, 0x65ab,0x782d,0x781c,0x781d,
  0x7839,0x783a,0x783b,0x781f, 0x783c,0x7825,0x782c,0x7823,
  0x7829,0x784e,0x786d,0x7856, 0x7857,0x7826,0x7850,0x7847,
  0x784c,0x786a,0x789b,0x7893, 0x789a,0x7887,0x789c,0x78a1,
  0x78a3,0x78b2,0x78b9,0x78a5, 0x78d4,0x78d9,0x78c9,0x78ec,
  0x78f2,0x7905,0x78f4,0x7913, 0x7924,0x791e,0x7934,0x9f9b,
  0x9ef9,0x9efb,0x9efc,0x76f1, 0x7704,0x770d,0x76f9,0x7707,
  0x7708,0x771a,0x7722,0x7719, 0x772d,0x7726,0x7735,0x7738,
  0x7750,0x7751,0x7747,0x7743, 0x775a,0x7768,0x7762,0x7765,
  0x777f,0x778d,0x777d,0x7780, 0x778c,0x7791,0x779f,0x77a0,
  0x77b0,0x77b5,0x77bd,0x753a, 0x7540,0x754e,0x754b,0x7548,
  0x755b,0x7572,0x7579,0x7583, 0x7f58,0x7f61,0x7f5f,0x8a48,
  0x7f68,0x7f74,0x7f71,0x7f79, 0x7f81,0x7f7e,0x76cd,0x76e5,
  0x8832,0x9485,0x9486,0x9487, 0x948b,0x948a,0x948c,0x948d,
  0x948f,0x9490,0x9494,0x9497, 0x9495,0x949a,0x949b,0x949c,
  0x94a3,0x94a4,0x94ab,0x94aa, 0x94ad,0x94ac,0x94af,0x94b0,
  0x94b2,0x94b4,0x94b6,0x94b7, 0x94b8,0x94b9,0x94ba,0x94bc,
  0x94bd,0x94bf,0x94c4,0x94c8, 0x94c9,0x94ca,0x94cb,0x94cc,
  0x94cd,0x94ce,0x94d0,0x94d1, 0x94d2,0x94d5,0x94d6,0x94d7,
  0x94d9,0x94d8,0x94db,0x94de, 0x94df,0x94e0,0x94e2,0x94e4,
  0x94e5,0x94e7,0x94e8,0x94ea, 0x94e9,0x94eb,0x94ee,0x94ef,
  0x94f3,0x94f4,0x94f5,0x94f7, 0x94f9,0x94fc,0x94fd,0x94ff,
  0x9503,0x9502,0x9506,0x9507, 0x9509,0x950a,0x950d,0x950e,
  0x950f,0x9512,0x9513,0x9514, 0x9515,0x9516,0x9518,0x951b,
  0x951d,0x951e,0x951f,0x9522, 0x952a,0x952b,0x9529,0x952c,
  0x9531,0x9532,0x9534,0x9536, 0x9537,0x9538,0x953c,0x953e,
  0x953f,0x9542,0x9535,0x9544, 0x9545,0x9546,0x9549,0x954c,
  0x954e,0x954f,0x9552,0x9553, 0x9554,0x9556,0x9557,0x9558,
  0x9559,0x955b,0x955e,0x955f, 0x955d,0x9561,0x9562,0x9564,
  0x9565,0x9566,0x9567,0x9568, 0x9569,0x956a,0x956b,0x956c,
  0x956f,0x9571,0x9572,0x9573, 0x953a,0x77e7,0x77ec,0x96c9,
  0x79d5,0x79ed,0x79e3,0x79eb, 0x7a06,0x5d47,0x7a03,0x7a02,
  0x7a1e,0x7a14,0x7a39,0x7a37, 0x7a51,0x9ecf,0x99a5,0x7a70,
  0x7688,0x768e,0x7693,0x7699, 0x76a4,0x74de,0x74e0,0x752c,
  0x9e20,0x9e22,0x9e28,0x9e29, 0x9e2a,0x9e2b,0x9e2c,0x9e32,
  0x9e31,0x9e36,0x9e38,0x9e37, 0x9e39,0x9e3a,0x9e3e,0x9e41,
  0x9e42,0x9e44,0x9e46,0x9e47, 0x9e48,0x9e49,0x9e4b,0x9e4c,
  0x9e4e,0x9e51,0x9e55,0x9e57, 0x9e5a,0x9e5b,0x9e5c,0x9e5e,
  0x9e63,0x9e66,0x9e67,0x9e68, 0x9e69,0x9e6a,0x9e6b,0x9e6c,
  0x9e71,0x9e6d,0x9e73,0x7592, 0x7594,0x7596,0x75a0,0x759d,
  0x75ac,0x75a3,0x75b3,0x75b4, 0x75b8,0x75c4,0x75b1,0x75b0,
  0x75c3,0x75c2,0x75d6,0x75cd, 0x75e3,0x75e8,0x75e6,0x75e4,
  0x75eb,0x75e7,0x7603,0x75f1, 0x75fc,0x75ff,0x7610,0x7600,
  0x7605,0x760c,0x7617,0x760a, 0x7625,0x7618,0x7615,0x7619,
  0x761b,0x763c,0x7622,0x7620, 0x7640,0x762d,0x7630,0x763f,
  0x7635,0x7643,0x763e,0x7633, 0x764d,0x765e,0x7654,0x765c,
  0x7656,0x766b,0x766f,0x7fca, 0x7ae6,0x7a78,0x7a79,0x7a80,
  0x7a86,0x7a88,0x7a95,0x7aa6, 0x7aa0,0x7aac,0x7aa8,0x7aad,
  0x7ab3,0x8864,0x8869,0x8872, 0x887d,0x887f,0x8882,0x88a2,
  0x88c6,0x88b7,0x88bc,0x88c9, 0x88e2,0x88ce,0x88e3,0x88e5,
  0x88f1,0x891a,0x88fc,0x88e8, 0x88fe,0x88f0,0x8921,0x8919,
  0x8913,0x891b,0x890a,0x8934, 0x892b,0x8936,0x8941,0x8966,
  0x897b,0x758b,0x80e5,0x76b2, 0x76b4,0x77dc,0x8012,0x8014,
  0x8016,0x801c,0x8020,0x8022, 0x8025,0x8026,0x8027,0x8029,
  0x8028,0x8031,0x800b,0x8035, 0x8043,0x8046,0x804d,0x8052,
  0x8069,0x8071,0x8983,0x9878, 0x9880,0x9883,0x9889,0x988c,
  0x988d,0x988f,0x9894,0x989a, 0x989b,0x989e,0x989f,0x98a1,
  0x98a2,0x98a5,0x98a6,0x864d, 0x8654,0x866c,0x866e,0x867f,
  0x867a,0x867c,0x867b,0x86a8, 0x868d,0x868b,0x86ac,0x869d,
  0x86a7,0x86a3,0x86aa,0x8693, 0x86a9,0x86b6,0x86c4,0x86b5,
  0x86ce,0x86b0,0x86ba,0x86b1, 0x86af,0x86c9,0x86cf,0x86b4,
  0x86e9,0x86f1,0x86f2,0x86ed, 0x86f3,0x86d0,0x8713,0x86de,
  0x86f4,0x86df,0x86d8,0x86d1, 0x8703,0x8707,0x86f8,0x8708,
  0x870a,0x870d,0x8709,0x8723, 0x873b,0x871e,0x8725,0x872e,
  0x871a,0x873e,0x8748,0x8734, 0x8731,0x8729,0x8737,0x873f,
  0x8782,0x8722,0x877d,0x877e, 0x877b,0x8760,0x8770,0x874c,
  0x876e,0x878b,0x8753,0x8763, 0x877c,0x8764,0x8759,0x8765,
  0x8793,0x87af,0x87a8,0x87d2, 0x87c6,0x8788,0x8785,0x87ad,
  0x8797,0x8783,0x87ab,0x87e5, 0x87ac,0x87b5,0x87b3,0x87cb,
  0x87d3,0x87bd,0x87d1,0x87c0, 0x87ca,0x87db,0x87ea,0x87e0,
  0x87ee,0x8816,0x8813,0x87fe, 0x880a,0x881b,0x8821,0x8839,
  0x883c,0x7f36,0x7f42,0x7f44, 0x7f45,0x8210,0x7afa,0x7afd,
  0x7b08,0x7b03,0x7b04,0x7b15, 0x7b0a,0x7b2b,0x7b0f,0x7b47,
  0x7b38,0x7b2a,0x7b19,0x7b2e, 0x7b31,0x7b20,0x7b25,0x7b24,
  0x7b33,0x7b3e,0x7b1e,0x7b58, 0x7b5a,0x7b45,0x7b75,0x7b4c,
  0x7b5d,0x7b60,0x7b6e,0x7b7b, 0x7b62,0x7b72,0x7b71,0x7b90,
  0x7ba6,0x7ba7,0x7bb8,0x7bac, 0x7b9d,0x7ba8,0x7b85,0x7baa,
  0x7b9c,0x7ba2,0x7bab,0x7bb4, 0x7bd1,0x7bc1,0x7bcc,0x7bdd,
  0x7bda,0x7be5,0x7be6,0x7bea, 0x7c0c,0x7bfe,0x7bfc,0x7c0f,
  0x7c16,0x7c0b,0x7c1f,0x7c2a, 0x7c26,0x7c38,0x7c41,0x7c40,
  0x81fe,0x8201,0x8202,0x8204, 0x81ec,0x8844,0x8221,0x8222,
  0x8223,0x822d,0x822f,0x8228, 0x822b,0x8238,0x823b,0x8233,
  0x8234,0x823e,0x8244,0x8249, 0x824b,0x824f,0x825a,0x825f,
  0x8268,0x887e,0x8885,0x8888, 0x88d8,0x88df,0x895e,0x7f9d,
  0x7f9f,0x7fa7,0x7faf,0x7fb0, 0x7fb2,0x7c7c,0x6549,0x7c91,
  0x7c9d,0x7c9c,0x7c9e,0x7ca2, 0x7cb2,0x7cbc,0x7cbd,0x7cc1,
  0x7cc7,0x7ccc,0x7ccd,0x7cc8, 0x7cc5,0x7cd7,0x7ce8,0x826e,
  0x66a8,0x7fbf,0x7fce,0x7fd5, 0x7fe5,0x7fe1,0x7fe6,0x7fe9,
  0x7fee,0x7ff3,0x7cf8,0x7d77, 0x7da6,0x7dae,0x7e47,0x7e9b,
  0x9eb8,0x9eb4,0x8d73,0x8d84, 0x8d94,0x8d91,0x8db1,0x8d67,
  0x8d6d,0x8c47,0x8c49,0x914a, 0x9150,0x914e,0x914f,0x9164,
  0x9162,0x9161,0x9170,0x9169, 0x916f,0x917d,0x917e,0x9172,
  0x9174,0x9179,0x918c,0x9185, 0x9190,0x918d,0x9191,0x91a2,
  0x91a3,0x91aa,0x91ad,0x91ae, 0x91af,0x91b5,0x91b4,0x91ba,
  0x8c55,0x9e7e,0x8db8,0x8deb, 0x8e05,0x8e59,0x8e69,0x8db5,
  0x8dbf,0x8dbc,0x8dba,0x8dc4, 0x8dd6,0x8dd7,0x8dda,0x8dde,
  0x8dce,0x8dcf,0x8ddb,0x8dc6, 0x8dec,0x8df7,0x8df8,0x8de3,
  0x8df9,0x8dfb,0x8de4,0x8e09, 0x8dfd,0x8e14,0x8e1d,0x8e1f,
  0x8e2c,0x8e2e,0x8e23,0x8e2f, 0x8e3a,0x8e40,0x8e39,0x8e35,
  0x8e3d,0x8e31,0x8e49,0x8e41, 0x8e42,0x8e51,0x8e52,0x8e4a,
  0x8e70,0x8e76,0x8e7c,0x8e6f, 0x8e74,0x8e85,0x8e8f,0x8e94,
  0x8e90,0x8e9c,0x8e9e,0x8c78, 0x8c82,0x8c8a,0x8c85,0x8c98,
  0x8c94,0x659b,0x89d6,0x89de, 0x89da,0x89dc,0x89e5,0x89eb,
  0x89ef,0x8a3e,0x8b26,0x9753, 0x96e9,0x96f3,0x96ef,0x9706,
  0x9701,0x9708,0x970f,0x970e, 0x972a,0x972d,0x9730,0x973e,
  0x9f80,0x9f83,0x9f85,0x9f86, 0x9f87,0x9f88,0x9f89,0x9f8a,
  0x9f8c,0x9efe,0x9f0b,0x9f0d, 0x96b9,0x96bc,0x96bd,0x96ce,
  0x96d2,0x77bf,0x96e0,0x928e, 0x92ae,0x92c8,0x933e,0x936a,
  0x93ca,0x938f,0x943e,0x946b, 0x9c7f,0x9c82,0x9c85,0x9c86,
  0x9c87,0x9c88,0x7a23,0x9c8b, 0x9c8e,0x9c90,0x9c91,0x9c92,
  0x9c94,0x9c95,0x9c9a,0x9c9b, 0x9c9e,0x9c9f,0x9ca0,0x9ca1,
  0x9ca2,0x9ca3,0x9ca5,0x9ca6, 0x9ca7,0x9ca8,0x9ca9,0x9cab,
  0x9cad,0x9cae,0x9cb0,0x9cb1, 0x9cb2,0x9cb3,0x9cb4,0x9cb5,
  0x9cb6,0x9cb7,0x9cba,0x9cbb, 0x9cbc,0x9cbd,0x9cc4,0x9cc5,
  0x9cc6,0x9cc7,0x9cca,0x9ccb, 0x9ccc,0x9ccd,0x9cce,0x9ccf,
  0x9cd0,0x9cd3,0x9cd4,0x9cd5, 0x9cd7,0x9cd8,0x9cd9,0x9cdc,
  0x9cdd,0x9cdf,0x9ce2,0x977c, 0x9785,0x9791,0x9792,0x9794,
  0x97af,0x97ab,0x97a3,0x97b2, 0x97b4,0x9ab1,0x9ab0,0x9ab7,
  0x9e58,0x9ab6,0x9aba,0x9abc, 0x9ac1,0x9ac0,0x9ac5,0x9ac2,
  0x9acb,0x9acc,0x9ad1,0x9b45, 0x9b43,0x9b47,0x9b49,0x9b48,
  0x9b4d,0x9b51,0x98e8,0x990d, 0x992e,0x9955,0x9954,0x9adf,
  0x9ae1,0x9ae6,0x9aef,0x9aeb, 0x9afb,0x9aed,0x9af9,0x9b08,
  0x9b0f,0x9b13,0x9b1f,0x9b23, 0x9ebd,0x9ebe,0x7e3b,0x9e82,
  0x9e87,0x9e88,0x9e8b,0x9e92, 0x93d6,0x9e9d,0x9e9f,0x9edb,
  0x9edc,0x9edd,0x9ee0,0x9edf, 0x9ee2,0x9ee9,0x9ee7,0x9ee5,
  0x9eea,0x9eef,0x9f22,0x9f2c, 0x9f2f,0x9f39,0x9f37,0x9f3d,
  0x9f3e,0x9f44,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000
  };

unsigned short uni_t_x1001[KRX1001_TBL_LEN] = {
  0x3000,0x3001,0x3002,0x00b7, 0x2025,0x2026,0x00a8,0x3003,
  0x00ad,0x2015,0x2225,0xff3c, 0x223c,0x2018,0x2019,0x201c,
  0x201d,0x3014,0x3015,0x3008, 0x3009,0x300a,0x300b,0x300c,
  0x300d,0x300e,0x300f,0x3010, 0x3011,0x00b1,0x00d7,0x00f7,
  0x2260,0x2264,0x2265,0x221e, 0x2234,0x00b0,0x2032,0x2033,
  0x2103,0x212b,0xffe0,0xffe1, 0xffe5,0x2642,0x2640,0x2220,
  0x22a5,0x2312,0x2202,0x2207, 0x2261,0x2252,0x00a7,0x203b,
  0x2606,0x2605,0x25cb,0x25cf, 0x25ce,0x25c7,0x25c6,0x25a1,
  0x25a0,0x25b3,0x25b2,0x25bd, 0x25bc,0x2192,0x2190,0x2191,
  0x2193,0x2194,0x3013,0x226a, 0x226b,0x221a,0x223d,0x221d,
  0x2235,0x222b,0x222c,0x2208, 0x220b,0x2286,0x2287,0x2282,
  0x2283,0x222a,0x2229,0x2227, 0x2228,0xffe2,0x21d2,0x21d4,
  0x2200,0x2203,0x00b4,0xff5e, 0x02c7,0x02d8,0x02dd,0x02da,
  0x02d9,0x00b8,0x02db,0x00a1, 0x00bf,0x02d0,0x222e,0x2211,
  0x220f,0x00a4,0x2109,0x2030, 0x25c1,0x25c0,0x25b7,0x25b6,
  0x2664,0x2660,0x2661,0x2665, 0x2667,0x2663,0x2299,0x25c8,
  0x25a3,0x25d0,0x25d1,0x2592, 0x25a4,0x25a5,0x25a8,0x25a7,
  0x25a6,0x25a9,0x2668,0x260f, 0x260e,0x261c,0x261e,0x00b6,
  0x2020,0x2021,0x2195,0x2197, 0x2199,0x2196,0x2198,0x266d,
  0x2669,0x266a,0x266c,0x327f, 0x321c,0x2116,0x33c7,0x2122,
  0x33c2,0x33d8,0x2121,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0xff01,0xff02,0xff03,0xff04,
  0xff05,0xff06,0xff07,0xff08, 0xff09,0xff0a,0xff0b,0xff0c,
  0xff0d,0xff0e,0xff0f,0xff10, 0xff11,0xff12,0xff13,0xff14,
  0xff15,0xff16,0xff17,0xff18, 0xff19,0xff1a,0xff1b,0xff1c,
  0xff1d,0xff1e,0xff1f,0xff20, 0xff21,0xff22,0xff23,0xff24,
  0xff25,0xff26,0xff27,0xff28, 0xff29,0xff2a,0xff2b,0xff2c,
  0xff2d,0xff2e,0xff2f,0xff30, 0xff31,0xff32,0xff33,0xff34,
  0xff35,0xff36,0xff37,0xff38, 0xff39,0xff3a,0xff3b,0xffe6,
  0xff3d,0xff3e,0xff3f,0xff40, 0xff41,0xff42,0xff43,0xff44,
  0xff45,0xff46,0xff47,0xff48, 0xff49,0xff4a,0xff4b,0xff4c,
  0xff4d,0xff4e,0xff4f,0xff50, 0xff51,0xff52,0xff53,0xff54,
  0xff55,0xff56,0xff57,0xff58, 0xff59,0xff5a,0xff5b,0xff5c,
  0xff5d,0xffe3,0x3131,0x3132, 0x3133,0x3134,0x3135,0x3136,
  0x3137,0x3138,0x3139,0x313a, 0x313b,0x313c,0x313d,0x313e,
  0x313f,0x3140,0x3141,0x3142, 0x3143,0x3144,0x3145,0x3146,
  0x3147,0x3148,0x3149,0x314a, 0x314b,0x314c,0x314d,0x314e,
  0x314f,0x3150,0x3151,0x3152, 0x3153,0x3154,0x3155,0x3156,
  0x3157,0x3158,0x3159,0x315a, 0x315b,0x315c,0x315d,0x315e,
  0x315f,0x3160,0x3161,0x3162, 0x3163,0x3164,0x3165,0x3166,
  0x3167,0x3168,0x3169,0x316a, 0x316b,0x316c,0x316d,0x316e,
  0x316f,0x3170,0x3171,0x3172, 0x3173,0x3174,0x3175,0x3176,
  0x3177,0x3178,0x3179,0x317a, 0x317b,0x317c,0x317d,0x317e,
  0x317f,0x3180,0x3181,0x3182, 0x3183,0x3184,0x3185,0x3186,
  0x3187,0x3188,0x3189,0x318a, 0x318b,0x318c,0x318d,0x318e,
  0x2170,0x2171,0x2172,0x2173, 0x2174,0x2175,0x2176,0x2177,
  0x2178,0x2179,0x0000,0x0000, 0x0000,0x0000,0x0000,0x2160,
  0x2161,0x2162,0x2163,0x2164, 0x2165,0x2166,0x2167,0x2168,
  0x2169,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0391,0x0392,0x0393,0x0394, 0x0395,0x0396,0x0397,0x0398,
  0x0399,0x039a,0x039b,0x039c, 0x039d,0x039e,0x039f,0x03a0,
  0x03a1,0x03a3,0x03a4,0x03a5, 0x03a6,0x03a7,0x03a8,0x03a9,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x03b1,0x03b2,0x03b3,0x03b4, 0x03b5,0x03b6,0x03b7,0x03b8,
  0x03b9,0x03ba,0x03bb,0x03bc, 0x03bd,0x03be,0x03bf,0x03c0,
  0x03c1,0x03c3,0x03c4,0x03c5, 0x03c6,0x03c7,0x03c8,0x03c9,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x2500,0x2502,
  0x250c,0x2510,0x2518,0x2514, 0x251c,0x252c,0x2524,0x2534,
  0x253c,0x2501,0x2503,0x250f, 0x2513,0x251b,0x2517,0x2523,
  0x2533,0x252b,0x253b,0x254b, 0x2520,0x252f,0x2528,0x2537,
  0x253f,0x251d,0x2530,0x2525, 0x2538,0x2542,0x2512,0x2511,
  0x251a,0x2519,0x2516,0x2515, 0x250e,0x250d,0x251e,0x251f,
  0x2521,0x2522,0x2526,0x2527, 0x2529,0x252a,0x252d,0x252e,
  0x2531,0x2532,0x2535,0x2536, 0x2539,0x253a,0x253d,0x253e,
  0x2540,0x2541,0x2543,0x2544, 0x2545,0x2546,0x2547,0x2548,
  0x2549,0x254a,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x3395,0x3396,0x3397,0x2113,
  0x3398,0x33c4,0x33a3,0x33a4, 0x33a5,0x33a6,0x3399,0x339a,
  0x339b,0x339c,0x339d,0x339e, 0x339f,0x33a0,0x33a1,0x33a2,
  0x33ca,0x338d,0x338e,0x338f, 0x33cf,0x3388,0x3389,0x33c8,
  0x33a7,0x33a8,0x33b0,0x33b1, 0x33b2,0x33b3,0x33b4,0x33b5,
  0x33b6,0x33b7,0x33b8,0x33b9, 0x3380,0x3381,0x3382,0x3383,
  0x3384,0x33ba,0x33bb,0x33bc, 0x33bd,0x33be,0x33bf,0x3390,
  0x3391,0x3392,0x3393,0x3394, 0x2126,0x33c0,0x33c1,0x338a,
  0x338b,0x338c,0x33d6,0x33c5, 0x33ad,0x33ae,0x33af,0x33db,
  0x33a9,0x33aa,0x33ab,0x33ac, 0x33dd,0x33d0,0x33d3,0x33c3,
  0x33c9,0x33dc,0x33c6,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x00c6,0x00d0, 0x00aa,0x0126,0x0000,0x0132,
  0x0000,0x013f,0x0141,0x00d8, 0x0152,0x00ba,0x00de,0x0166,
  0x014a,0x0000,0x3260,0x3261, 0x3262,0x3263,0x3264,0x3265,
  0x3266,0x3267,0x3268,0x3269, 0x326a,0x326b,0x326c,0x326d,
  0x326e,0x326f,0x3270,0x3271, 0x3272,0x3273,0x3274,0x3275,
  0x3276,0x3277,0x3278,0x3279, 0x327a,0x327b,0x24d0,0x24d1,
  0x24d2,0x24d3,0x24d4,0x24d5, 0x24d6,0x24d7,0x24d8,0x24d9,
  0x24da,0x24db,0x24dc,0x24dd, 0x24de,0x24df,0x24e0,0x24e1,
  0x24e2,0x24e3,0x24e4,0x24e5, 0x24e6,0x24e7,0x24e8,0x24e9,
  0x2460,0x2461,0x2462,0x2463, 0x2464,0x2465,0x2466,0x2467,
  0x2468,0x2469,0x246a,0x246b, 0x246c,0x246d,0x246e,0x00bd,
  0x2153,0x2154,0x00bc,0x00be, 0x215b,0x215c,0x215d,0x215e,
  0x00e6,0x0111,0x00f0,0x0127, 0x0131,0x0133,0x0138,0x0140,
  0x0142,0x00f8,0x0153,0x00df, 0x00fe,0x0167,0x014b,0x0149,
  0x3200,0x3201,0x3202,0x3203, 0x3204,0x3205,0x3206,0x3207,
  0x3208,0x3209,0x320a,0x320b, 0x320c,0x320d,0x320e,0x320f,
  0x3210,0x3211,0x3212,0x3213, 0x3214,0x3215,0x3216,0x3217,
  0x3218,0x3219,0x321a,0x321b, 0x249c,0x249d,0x249e,0x249f,
  0x24a0,0x24a1,0x24a2,0x24a3, 0x24a4,0x24a5,0x24a6,0x24a7,
  0x24a8,0x24a9,0x24aa,0x24ab, 0x24ac,0x24ad,0x24ae,0x24af,
  0x24b0,0x24b1,0x24b2,0x24b3, 0x24b4,0x24b5,0x2474,0x2475,
  0x2476,0x2477,0x2478,0x2479, 0x247a,0x247b,0x247c,0x247d,
  0x247e,0x247f,0x2480,0x2481, 0x2482,0x00b9,0x00b2,0x00b3,
  0x2074,0x207f,0x2081,0x2082, 0x2083,0x2084,0x3041,0x3042,
  0x3043,0x3044,0x3045,0x3046, 0x3047,0x3048,0x3049,0x304a,
  0x304b,0x304c,0x304d,0x304e, 0x304f,0x3050,0x3051,0x3052,
  0x3053,0x3054,0x3055,0x3056, 0x3057,0x3058,0x3059,0x305a,
  0x305b,0x305c,0x305d,0x305e, 0x305f,0x3060,0x3061,0x3062,
  0x3063,0x3064,0x3065,0x3066, 0x3067,0x3068,0x3069,0x306a,
  0x306b,0x306c,0x306d,0x306e, 0x306f,0x3070,0x3071,0x3072,
  0x3073,0x3074,0x3075,0x3076, 0x3077,0x3078,0x3079,0x307a,
  0x307b,0x307c,0x307d,0x307e, 0x307f,0x3080,0x3081,0x3082,
  0x3083,0x3084,0x3085,0x3086, 0x3087,0x3088,0x3089,0x308a,
  0x308b,0x308c,0x308d,0x308e, 0x308f,0x3090,0x3091,0x3092,
  0x3093,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x30a1,0x30a2,0x30a3,0x30a4,
  0x30a5,0x30a6,0x30a7,0x30a8, 0x30a9,0x30aa,0x30ab,0x30ac,
  0x30ad,0x30ae,0x30af,0x30b0, 0x30b1,0x30b2,0x30b3,0x30b4,
  0x30b5,0x30b6,0x30b7,0x30b8, 0x30b9,0x30ba,0x30bb,0x30bc,
  0x30bd,0x30be,0x30bf,0x30c0, 0x30c1,0x30c2,0x30c3,0x30c4,
  0x30c5,0x30c6,0x30c7,0x30c8, 0x30c9,0x30ca,0x30cb,0x30cc,
  0x30cd,0x30ce,0x30cf,0x30d0, 0x30d1,0x30d2,0x30d3,0x30d4,
  0x30d5,0x30d6,0x30d7,0x30d8, 0x30d9,0x30da,0x30db,0x30dc,
  0x30dd,0x30de,0x30df,0x30e0, 0x30e1,0x30e2,0x30e3,0x30e4,
  0x30e5,0x30e6,0x30e7,0x30e8, 0x30e9,0x30ea,0x30eb,0x30ec,
  0x30ed,0x30ee,0x30ef,0x30f0, 0x30f1,0x30f2,0x30f3,0x30f4,
  0x30f5,0x30f6,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0410,0x0411, 0x0412,0x0413,0x0414,0x0415,
  0x0401,0x0416,0x0417,0x0418, 0x0419,0x041a,0x041b,0x041c,
  0x041d,0x041e,0x041f,0x0420, 0x0421,0x0422,0x0423,0x0424,
  0x0425,0x0426,0x0427,0x0428, 0x0429,0x042a,0x042b,0x042c,
  0x042d,0x042e,0x042f,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0430,0x0431, 0x0432,0x0433,0x0434,0x0435,
  0x0451,0x0436,0x0437,0x0438, 0x0439,0x043a,0x043b,0x043c,
  0x043d,0x043e,0x043f,0x0440, 0x0441,0x0442,0x0443,0x0444,
  0x0445,0x0446,0x0447,0x0448, 0x0449,0x044a,0x044b,0x044c,
  0x044d,0x044e,0x044f,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0xac00,0xac01, 0xac04,0xac07,0xac08,0xac09,
  0xac0a,0xac10,0xac11,0xac12, 0xac13,0xac14,0xac15,0xac16,
  0xac17,0xac19,0xac1a,0xac1b, 0xac1c,0xac1d,0xac20,0xac24,
  0xac2c,0xac2d,0xac2f,0xac30, 0xac31,0xac38,0xac39,0xac3c,
  0xac40,0xac4b,0xac4d,0xac54, 0xac58,0xac5c,0xac70,0xac71,
  0xac74,0xac77,0xac78,0xac7a, 0xac80,0xac81,0xac83,0xac84,
  0xac85,0xac86,0xac89,0xac8a, 0xac8b,0xac8c,0xac90,0xac94,
  0xac9c,0xac9d,0xac9f,0xaca0, 0xaca1,0xaca8,0xaca9,0xacaa,
  0xacac,0xacaf,0xacb0,0xacb8, 0xacb9,0xacbb,0xacbc,0xacbd,
  0xacc1,0xacc4,0xacc8,0xaccc, 0xacd5,0xacd7,0xace0,0xace1,
  0xace4,0xace7,0xace8,0xacea, 0xacec,0xacef,0xacf0,0xacf1,
  0xacf3,0xacf5,0xacf6,0xacfc, 0xacfd,0xad00,0xad04,0xad06,
  0xad0c,0xad0d,0xad0f,0xad11, 0xad18,0xad1c,0xad20,0xad29,
  0xad2c,0xad2d,0xad34,0xad35, 0xad38,0xad3c,0xad44,0xad45,
  0xad47,0xad49,0xad50,0xad54, 0xad58,0xad61,0xad63,0xad6c,
  0xad6d,0xad70,0xad73,0xad74, 0xad75,0xad76,0xad7b,0xad7c,
  0xad7d,0xad7f,0xad81,0xad82, 0xad88,0xad89,0xad8c,0xad90,
  0xad9c,0xad9d,0xada4,0xadb7, 0xadc0,0xadc1,0xadc4,0xadc8,
  0xadd0,0xadd1,0xadd3,0xaddc, 0xade0,0xade4,0xadf8,0xadf9,
  0xadfc,0xadff,0xae00,0xae01, 0xae08,0xae09,0xae0b,0xae0d,
  0xae14,0xae30,0xae31,0xae34, 0xae37,0xae38,0xae3a,0xae40,
  0xae41,0xae43,0xae45,0xae46, 0xae4a,0xae4c,0xae4d,0xae4e,
  0xae50,0xae54,0xae56,0xae5c, 0xae5d,0xae5f,0xae60,0xae61,
  0xae65,0xae68,0xae69,0xae6c, 0xae70,0xae78,0xae79,0xae7b,
  0xae7c,0xae7d,0xae84,0xae85, 0xae8c,0xaebc,0xaebd,0xaebe,
  0xaec0,0xaec4,0xaecc,0xaecd, 0xaecf,0xaed0,0xaed1,0xaed8,
  0xaed9,0xaedc,0xaee8,0xaeeb, 0xaeed,0xaef4,0xaef8,0xaefc,
  0xaf07,0xaf08,0xaf0d,0xaf10, 0xaf2c,0xaf2d,0xaf30,0xaf32,
  0xaf34,0xaf3c,0xaf3d,0xaf3f, 0xaf41,0xaf42,0xaf43,0xaf48,
  0xaf49,0xaf50,0xaf5c,0xaf5d, 0xaf64,0xaf65,0xaf79,0xaf80,
  0xaf84,0xaf88,0xaf90,0xaf91, 0xaf95,0xaf9c,0xafb8,0xafb9,
  0xafbc,0xafc0,0xafc7,0xafc8, 0xafc9,0xafcb,0xafcd,0xafce,
  0xafd4,0xafdc,0xafe8,0xafe9, 0xaff0,0xaff1,0xaff4,0xaff8,
  0xb000,0xb001,0xb004,0xb00c, 0xb010,0xb014,0xb01c,0xb01d,
  0xb028,0xb044,0xb045,0xb048, 0xb04a,0xb04c,0xb04e,0xb053,
  0xb054,0xb055,0xb057,0xb059, 0xb05d,0xb07c,0xb07d,0xb080,
  0xb084,0xb08c,0xb08d,0xb08f, 0xb091,0xb098,0xb099,0xb09a,
  0xb09c,0xb09f,0xb0a0,0xb0a1, 0xb0a2,0xb0a8,0xb0a9,0xb0ab,
  0xb0ac,0xb0ad,0xb0ae,0xb0af, 0xb0b1,0xb0b3,0xb0b4,0xb0b5,
  0xb0b8,0xb0bc,0xb0c4,0xb0c5, 0xb0c7,0xb0c8,0xb0c9,0xb0d0,
  0xb0d1,0xb0d4,0xb0d8,0xb0e0, 0xb0e5,0xb108,0xb109,0xb10b,
  0xb10c,0xb110,0xb112,0xb113, 0xb118,0xb119,0xb11b,0xb11c,
  0xb11d,0xb123,0xb124,0xb125, 0xb128,0xb12c,0xb134,0xb135,
  0xb137,0xb138,0xb139,0xb140, 0xb141,0xb144,0xb148,0xb150,
  0xb151,0xb154,0xb155,0xb158, 0xb15c,0xb160,0xb178,0xb179,
  0xb17c,0xb180,0xb182,0xb188, 0xb189,0xb18b,0xb18d,0xb192,
  0xb193,0xb194,0xb198,0xb19c, 0xb1a8,0xb1cc,0xb1d0,0xb1d4,
  0xb1dc,0xb1dd,0xb1df,0xb1e8, 0xb1e9,0xb1ec,0xb1f0,0xb1f9,
  0xb1fb,0xb1fd,0xb204,0xb205, 0xb208,0xb20b,0xb20c,0xb214,
  0xb215,0xb217,0xb219,0xb220, 0xb234,0xb23c,0xb258,0xb25c,
  0xb260,0xb268,0xb269,0xb274, 0xb275,0xb27c,0xb284,0xb285,
  0xb289,0xb290,0xb291,0xb294, 0xb298,0xb299,0xb29a,0xb2a0,
  0xb2a1,0xb2a3,0xb2a5,0xb2a6, 0xb2aa,0xb2ac,0xb2b0,0xb2b4,
  0xb2c8,0xb2c9,0xb2cc,0xb2d0, 0xb2d2,0xb2d8,0xb2d9,0xb2db,
  0xb2dd,0xb2e2,0xb2e4,0xb2e5, 0xb2e6,0xb2e8,0xb2eb,0xb2ec,
  0xb2ed,0xb2ee,0xb2ef,0xb2f3, 0xb2f4,0xb2f5,0xb2f7,0xb2f8,
  0xb2f9,0xb2fa,0xb2fb,0xb2ff, 0xb300,0xb301,0xb304,0xb308,
  0xb310,0xb311,0xb313,0xb314, 0xb315,0xb31c,0xb354,0xb355,
  0xb356,0xb358,0xb35b,0xb35c, 0xb35e,0xb35f,0xb364,0xb365,
  0xb367,0xb369,0xb36b,0xb36e, 0xb370,0xb371,0xb374,0xb378,
  0xb380,0xb381,0xb383,0xb384, 0xb385,0xb38c,0xb390,0xb394,
  0xb3a0,0xb3a1,0xb3a8,0xb3ac, 0xb3c4,0xb3c5,0xb3c8,0xb3cb,
  0xb3cc,0xb3ce,0xb3d0,0xb3d4, 0xb3d5,0xb3d7,0xb3d9,0xb3db,
  0xb3dd,0xb3e0,0xb3e4,0xb3e8, 0xb3fc,0xb410,0xb418,0xb41c,
  0xb420,0xb428,0xb429,0xb42b, 0xb434,0xb450,0xb451,0xb454,
  0xb458,0xb460,0xb461,0xb463, 0xb465,0xb46c,0xb480,0xb488,
  0xb49d,0xb4a4,0xb4a8,0xb4ac, 0xb4b5,0xb4b7,0xb4b9,0xb4c0,
  0xb4c4,0xb4c8,0xb4d0,0xb4d5, 0xb4dc,0xb4dd,0xb4e0,0xb4e3,
  0xb4e4,0xb4e6,0xb4ec,0xb4ed, 0xb4ef,0xb4f1,0xb4f8,0xb514,
  0xb515,0xb518,0xb51b,0xb51c, 0xb524,0xb525,0xb527,0xb528,
  0xb529,0xb52a,0xb530,0xb531, 0xb534,0xb538,0xb540,0xb541,
  0xb543,0xb544,0xb545,0xb54b, 0xb54c,0xb54d,0xb550,0xb554,
  0xb55c,0xb55d,0xb55f,0xb560, 0xb561,0xb5a0,0xb5a1,0xb5a4,
  0xb5a8,0xb5aa,0xb5ab,0xb5b0, 0xb5b1,0xb5b3,0xb5b4,0xb5b5,
  0xb5bb,0xb5bc,0xb5bd,0xb5c0, 0xb5c4,0xb5cc,0xb5cd,0xb5cf,
  0xb5d0,0xb5d1,0xb5d8,0xb5ec, 0xb610,0xb611,0xb614,0xb618,
  0xb625,0xb62c,0xb634,0xb648, 0xb664,0xb668,0xb69c,0xb69d,
  0xb6a0,0xb6a4,0xb6ab,0xb6ac, 0xb6b1,0xb6d4,0xb6f0,0xb6f4,
  0xb6f8,0xb700,0xb701,0xb705, 0xb728,0xb729,0xb72c,0xb72f,
  0xb730,0xb738,0xb739,0xb73b, 0xb744,0xb748,0xb74c,0xb754,
  0xb755,0xb760,0xb764,0xb768, 0xb770,0xb771,0xb773,0xb775,
  0xb77c,0xb77d,0xb780,0xb784, 0xb78c,0xb78d,0xb78f,0xb790,
  0xb791,0xb792,0xb796,0xb797, 0xb798,0xb799,0xb79c,0xb7a0,
  0xb7a8,0xb7a9,0xb7ab,0xb7ac, 0xb7ad,0xb7b4,0xb7b5,0xb7b8,
  0xb7c7,0xb7c9,0xb7ec,0xb7ed, 0xb7f0,0xb7f4,0xb7fc,0xb7fd,
  0xb7ff,0xb800,0xb801,0xb807, 0xb808,0xb809,0xb80c,0xb810,
  0xb818,0xb819,0xb81b,0xb81d, 0xb824,0xb825,0xb828,0xb82c,
  0xb834,0xb835,0xb837,0xb838, 0xb839,0xb840,0xb844,0xb851,
  0xb853,0xb85c,0xb85d,0xb860, 0xb864,0xb86c,0xb86d,0xb86f,
  0xb871,0xb878,0xb87c,0xb88d, 0xb8a8,0xb8b0,0xb8b4,0xb8b8,
  0xb8c0,0xb8c1,0xb8c3,0xb8c5, 0xb8cc,0xb8d0,0xb8d4,0xb8dd,
  0xb8df,0xb8e1,0xb8e8,0xb8e9, 0xb8ec,0xb8f0,0xb8f8,0xb8f9,
  0xb8fb,0xb8fd,0xb904,0xb918, 0xb920,0xb93c,0xb93d,0xb940,
  0xb944,0xb94c,0xb94f,0xb951, 0xb958,0xb959,0xb95c,0xb960,
  0xb968,0xb969,0xb96b,0xb96d, 0xb974,0xb975,0xb978,0xb97c,
  0xb984,0xb985,0xb987,0xb989, 0xb98a,0xb98d,0xb98e,0xb9ac,
  0xb9ad,0xb9b0,0xb9b4,0xb9bc, 0xb9bd,0xb9bf,0xb9c1,0xb9c8,
  0xb9c9,0xb9cc,0xb9ce,0xb9cf, 0xb9d0,0xb9d1,0xb9d2,0xb9d8,
  0xb9d9,0xb9db,0xb9dd,0xb9de, 0xb9e1,0xb9e3,0xb9e4,0xb9e5,
  0xb9e8,0xb9ec,0xb9f4,0xb9f5, 0xb9f7,0xb9f8,0xb9f9,0xb9fa,
  0xba00,0xba01,0xba08,0xba15, 0xba38,0xba39,0xba3c,0xba40,
  0xba42,0xba48,0xba49,0xba4b, 0xba4d,0xba4e,0xba53,0xba54,
  0xba55,0xba58,0xba5c,0xba64, 0xba65,0xba67,0xba68,0xba69,
  0xba70,0xba71,0xba74,0xba78, 0xba83,0xba84,0xba85,0xba87,
  0xba8c,0xbaa8,0xbaa9,0xbaab, 0xbaac,0xbab0,0xbab2,0xbab8,
  0xbab9,0xbabb,0xbabd,0xbac4, 0xbac8,0xbad8,0xbad9,0xbafc,
  0xbb00,0xbb04,0xbb0d,0xbb0f, 0xbb11,0xbb18,0xbb1c,0xbb20,
  0xbb29,0xbb2b,0xbb34,0xbb35, 0xbb36,0xbb38,0xbb3b,0xbb3c,
  0xbb3d,0xbb3e,0xbb44,0xbb45, 0xbb47,0xbb49,0xbb4d,0xbb4f,
  0xbb50,0xbb54,0xbb58,0xbb61, 0xbb63,0xbb6c,0xbb88,0xbb8c,
  0xbb90,0xbba4,0xbba8,0xbbac, 0xbbb4,0xbbb7,0xbbc0,0xbbc4,
  0xbbc8,0xbbd0,0xbbd3,0xbbf8, 0xbbf9,0xbbfc,0xbbff,0xbc00,
  0xbc02,0xbc08,0xbc09,0xbc0b, 0xbc0c,0xbc0d,0xbc0f,0xbc11,
  0xbc14,0xbc15,0xbc16,0xbc17, 0xbc18,0xbc1b,0xbc1c,0xbc1d,
  0xbc1e,0xbc1f,0xbc24,0xbc25, 0xbc27,0xbc29,0xbc2d,0xbc30,
  0xbc31,0xbc34,0xbc38,0xbc40, 0xbc41,0xbc43,0xbc44,0xbc45,
  0xbc49,0xbc4c,0xbc4d,0xbc50, 0xbc5d,0xbc84,0xbc85,0xbc88,
  0xbc8b,0xbc8c,0xbc8e,0xbc94, 0xbc95,0xbc97,0xbc99,0xbc9a,
  0xbca0,0xbca1,0xbca4,0xbca7, 0xbca8,0xbcb0,0xbcb1,0xbcb3,
  0xbcb4,0xbcb5,0xbcbc,0xbcbd, 0xbcc0,0xbcc4,0xbccd,0xbccf,
  0xbcd0,0xbcd1,0xbcd5,0xbcd8, 0xbcdc,0xbcf4,0xbcf5,0xbcf6,
  0xbcf8,0xbcfc,0xbd04,0xbd05, 0xbd07,0xbd09,0xbd10,0xbd14,
  0xbd24,0xbd2c,0xbd40,0xbd48, 0xbd49,0xbd4c,0xbd50,0xbd58,
  0xbd59,0xbd64,0xbd68,0xbd80, 0xbd81,0xbd84,0xbd87,0xbd88,
  0xbd89,0xbd8a,0xbd90,0xbd91, 0xbd93,0xbd95,0xbd99,0xbd9a,
  0xbd9c,0xbda4,0xbdb0,0xbdb8, 0xbdd4,0xbdd5,0xbdd8,0xbddc,
  0xbde9,0xbdf0,0xbdf4,0xbdf8, 0xbe00,0xbe03,0xbe05,0xbe0c,
  0xbe0d,0xbe10,0xbe14,0xbe1c, 0xbe1d,0xbe1f,0xbe44,0xbe45,
  0xbe48,0xbe4c,0xbe4e,0xbe54, 0xbe55,0xbe57,0xbe59,0xbe5a,
  0xbe5b,0xbe60,0xbe61,0xbe64, 0xbe68,0xbe6a,0xbe70,0xbe71,
  0xbe73,0xbe74,0xbe75,0xbe7b, 0xbe7c,0xbe7d,0xbe80,0xbe84,
  0xbe8c,0xbe8d,0xbe8f,0xbe90, 0xbe91,0xbe98,0xbe99,0xbea8,
  0xbed0,0xbed1,0xbed4,0xbed7, 0xbed8,0xbee0,0xbee3,0xbee4,
  0xbee5,0xbeec,0xbf01,0xbf08, 0xbf09,0xbf18,0xbf19,0xbf1b,
  0xbf1c,0xbf1d,0xbf40,0xbf41, 0xbf44,0xbf48,0xbf50,0xbf51,
  0xbf55,0xbf94,0xbfb0,0xbfc5, 0xbfcc,0xbfcd,0xbfd0,0xbfd4,
  0xbfdc,0xbfdf,0xbfe1,0xc03c, 0xc051,0xc058,0xc05c,0xc060,
  0xc068,0xc069,0xc090,0xc091, 0xc094,0xc098,0xc0a0,0xc0a1,
  0xc0a3,0xc0a5,0xc0ac,0xc0ad, 0xc0af,0xc0b0,0xc0b3,0xc0b4,
  0xc0b5,0xc0b6,0xc0bc,0xc0bd, 0xc0bf,0xc0c0,0xc0c1,0xc0c5,
  0xc0c8,0xc0c9,0xc0cc,0xc0d0, 0xc0d8,0xc0d9,0xc0db,0xc0dc,
  0xc0dd,0xc0e4,0xc0e5,0xc0e8, 0xc0ec,0xc0f4,0xc0f5,0xc0f7,
  0xc0f9,0xc100,0xc104,0xc108, 0xc110,0xc115,0xc11c,0xc11d,
  0xc11e,0xc11f,0xc120,0xc123, 0xc124,0xc126,0xc127,0xc12c,
  0xc12d,0xc12f,0xc130,0xc131, 0xc136,0xc138,0xc139,0xc13c,
  0xc140,0xc148,0xc149,0xc14b, 0xc14c,0xc14d,0xc154,0xc155,
  0xc158,0xc15c,0xc164,0xc165, 0xc167,0xc168,0xc169,0xc170,
  0xc174,0xc178,0xc185,0xc18c, 0xc18d,0xc18e,0xc190,0xc194,
  0xc196,0xc19c,0xc19d,0xc19f, 0xc1a1,0xc1a5,0xc1a8,0xc1a9,
  0xc1ac,0xc1b0,0xc1bd,0xc1c4, 0xc1c8,0xc1cc,0xc1d4,0xc1d7,
  0xc1d8,0xc1e0,0xc1e4,0xc1e8, 0xc1f0,0xc1f1,0xc1f3,0xc1fc,
  0xc1fd,0xc200,0xc204,0xc20c, 0xc20d,0xc20f,0xc211,0xc218,
  0xc219,0xc21c,0xc21f,0xc220, 0xc228,0xc229,0xc22b,0xc22d,
  0xc22f,0xc231,0xc232,0xc234, 0xc248,0xc250,0xc251,0xc254,
  0xc258,0xc260,0xc265,0xc26c, 0xc26d,0xc270,0xc274,0xc27c,
  0xc27d,0xc27f,0xc281,0xc288, 0xc289,0xc290,0xc298,0xc29b,
  0xc29d,0xc2a4,0xc2a5,0xc2a8, 0xc2ac,0xc2ad,0xc2b4,0xc2b5,
  0xc2b7,0xc2b9,0xc2dc,0xc2dd, 0xc2e0,0xc2e3,0xc2e4,0xc2eb,
  0xc2ec,0xc2ed,0xc2ef,0xc2f1, 0xc2f6,0xc2f8,0xc2f9,0xc2fb,
  0xc2fc,0xc300,0xc308,0xc309, 0xc30c,0xc30d,0xc313,0xc314,
  0xc315,0xc318,0xc31c,0xc324, 0xc325,0xc328,0xc329,0xc345,
  0xc368,0xc369,0xc36c,0xc370, 0xc372,0xc378,0xc379,0xc37c,
  0xc37d,0xc384,0xc388,0xc38c, 0xc3c0,0xc3d8,0xc3d9,0xc3dc,
  0xc3df,0xc3e0,0xc3e2,0xc3e8, 0xc3e9,0xc3ed,0xc3f4,0xc3f5,
  0xc3f8,0xc408,0xc410,0xc424, 0xc42c,0xc430,0xc434,0xc43c,
  0xc43d,0xc448,0xc464,0xc465, 0xc468,0xc46c,0xc474,0xc475,
  0xc479,0xc480,0xc494,0xc49c, 0xc4b8,0xc4bc,0xc4e9,0xc4f0,
  0xc4f1,0xc4f4,0xc4f8,0xc4fa, 0xc4ff,0xc500,0xc501,0xc50c,
  0xc510,0xc514,0xc51c,0xc528, 0xc529,0xc52c,0xc530,0xc538,
  0xc539,0xc53b,0xc53d,0xc544, 0xc545,0xc548,0xc549,0xc54a,
  0xc54c,0xc54d,0xc54e,0xc553, 0xc554,0xc555,0xc557,0xc558,
  0xc559,0xc55d,0xc55e,0xc560, 0xc561,0xc564,0xc568,0xc570,
  0xc571,0xc573,0xc574,0xc575, 0xc57c,0xc57d,0xc580,0xc584,
  0xc587,0xc58c,0xc58d,0xc58f, 0xc591,0xc595,0xc597,0xc598,
  0xc59c,0xc5a0,0xc5a9,0xc5b4, 0xc5b5,0xc5b8,0xc5b9,0xc5bb,
  0xc5bc,0xc5bd,0xc5be,0xc5c4, 0xc5c5,0xc5c6,0xc5c7,0xc5c8,
  0xc5c9,0xc5ca,0xc5cc,0xc5ce, 0xc5d0,0xc5d1,0xc5d4,0xc5d8,
  0xc5e0,0xc5e1,0xc5e3,0xc5e5, 0xc5ec,0xc5ed,0xc5ee,0xc5f0,
  0xc5f4,0xc5f6,0xc5f7,0xc5fc, 0xc5fd,0xc5fe,0xc5ff,0xc600,
  0xc601,0xc605,0xc606,0xc607, 0xc608,0xc60c,0xc610,0xc618,
  0xc619,0xc61b,0xc61c,0xc624, 0xc625,0xc628,0xc62c,0xc62d,
  0xc62e,0xc630,0xc633,0xc634, 0xc635,0xc637,0xc639,0xc63b,
  0xc640,0xc641,0xc644,0xc648, 0xc650,0xc651,0xc653,0xc654,
  0xc655,0xc65c,0xc65d,0xc660, 0xc66c,0xc66f,0xc671,0xc678,
  0xc679,0xc67c,0xc680,0xc688, 0xc689,0xc68b,0xc68d,0xc694,
  0xc695,0xc698,0xc69c,0xc6a4, 0xc6a5,0xc6a7,0xc6a9,0xc6b0,
  0xc6b1,0xc6b4,0xc6b8,0xc6b9, 0xc6ba,0xc6c0,0xc6c1,0xc6c3,
  0xc6c5,0xc6cc,0xc6cd,0xc6d0, 0xc6d4,0xc6dc,0xc6dd,0xc6e0,
  0xc6e1,0xc6e8,0xc6e9,0xc6ec, 0xc6f0,0xc6f8,0xc6f9,0xc6fd,
  0xc704,0xc705,0xc708,0xc70c, 0xc714,0xc715,0xc717,0xc719,
  0xc720,0xc721,0xc724,0xc728, 0xc730,0xc731,0xc733,0xc735,
  0xc737,0xc73c,0xc73d,0xc740, 0xc744,0xc74a,0xc74c,0xc74d,
  0xc74f,0xc751,0xc752,0xc753, 0xc754,0xc755,0xc756,0xc757,
  0xc758,0xc75c,0xc760,0xc768, 0xc76b,0xc774,0xc775,0xc778,
  0xc77c,0xc77d,0xc77e,0xc783, 0xc784,0xc785,0xc787,0xc788,
  0xc789,0xc78a,0xc78e,0xc790, 0xc791,0xc794,0xc796,0xc797,
  0xc798,0xc79a,0xc7a0,0xc7a1, 0xc7a3,0xc7a4,0xc7a5,0xc7a6,
  0xc7ac,0xc7ad,0xc7b0,0xc7b4, 0xc7bc,0xc7bd,0xc7bf,0xc7c0,
  0xc7c1,0xc7c8,0xc7c9,0xc7cc, 0xc7ce,0xc7d0,0xc7d8,0xc7dd,
  0xc7e4,0xc7e8,0xc7ec,0xc800, 0xc801,0xc804,0xc808,0xc80a,
  0xc810,0xc811,0xc813,0xc815, 0xc816,0xc81c,0xc81d,0xc820,
  0xc824,0xc82c,0xc82d,0xc82f, 0xc831,0xc838,0xc83c,0xc840,
  0xc848,0xc849,0xc84c,0xc84d, 0xc854,0xc870,0xc871,0xc874,
  0xc878,0xc87a,0xc880,0xc881, 0xc883,0xc885,0xc886,0xc887,
  0xc88b,0xc88c,0xc88d,0xc894, 0xc89d,0xc89f,0xc8a1,0xc8a8,
  0xc8bc,0xc8bd,0xc8c4,0xc8c8, 0xc8cc,0xc8d4,0xc8d5,0xc8d7,
  0xc8d9,0xc8e0,0xc8e1,0xc8e4, 0xc8f5,0xc8fc,0xc8fd,0xc900,
  0xc904,0xc905,0xc906,0xc90c, 0xc90d,0xc90f,0xc911,0xc918,
  0xc92c,0xc934,0xc950,0xc951, 0xc954,0xc958,0xc960,0xc961,
  0xc963,0xc96c,0xc970,0xc974, 0xc97c,0xc988,0xc989,0xc98c,
  0xc990,0xc998,0xc999,0xc99b, 0xc99d,0xc9c0,0xc9c1,0xc9c4,
  0xc9c7,0xc9c8,0xc9ca,0xc9d0, 0xc9d1,0xc9d3,0xc9d5,0xc9d6,
  0xc9d9,0xc9da,0xc9dc,0xc9dd, 0xc9e0,0xc9e2,0xc9e4,0xc9e7,
  0xc9ec,0xc9ed,0xc9ef,0xc9f0, 0xc9f1,0xc9f8,0xc9f9,0xc9fc,
  0xca00,0xca08,0xca09,0xca0b, 0xca0c,0xca0d,0xca14,0xca18,
  0xca29,0xca4c,0xca4d,0xca50, 0xca54,0xca5c,0xca5d,0xca5f,
  0xca60,0xca61,0xca68,0xca7d, 0xca84,0xca98,0xcabc,0xcabd,
  0xcac0,0xcac4,0xcacc,0xcacd, 0xcacf,0xcad1,0xcad3,0xcad8,
  0xcad9,0xcae0,0xcaec,0xcaf4, 0xcb08,0xcb10,0xcb14,0xcb18,
  0xcb20,0xcb21,0xcb41,0xcb48, 0xcb49,0xcb4c,0xcb50,0xcb58,
  0xcb59,0xcb5d,0xcb64,0xcb78, 0xcb79,0xcb9c,0xcbb8,0xcbd4,
  0xcbe4,0xcbe7,0xcbe9,0xcc0c, 0xcc0d,0xcc10,0xcc14,0xcc1c,
  0xcc1d,0xcc21,0xcc22,0xcc27, 0xcc28,0xcc29,0xcc2c,0xcc2e,
  0xcc30,0xcc38,0xcc39,0xcc3b, 0xcc3c,0xcc3d,0xcc3e,0xcc44,
  0xcc45,0xcc48,0xcc4c,0xcc54, 0xcc55,0xcc57,0xcc58,0xcc59,
  0xcc60,0xcc64,0xcc66,0xcc68, 0xcc70,0xcc75,0xcc98,0xcc99,
  0xcc9c,0xcca0,0xcca8,0xcca9, 0xccab,0xccac,0xccad,0xccb4,
  0xccb5,0xccb8,0xccbc,0xccc4, 0xccc5,0xccc7,0xccc9,0xccd0,
  0xccd4,0xcce4,0xccec,0xccf0, 0xcd01,0xcd08,0xcd09,0xcd0c,
  0xcd10,0xcd18,0xcd19,0xcd1b, 0xcd1d,0xcd24,0xcd28,0xcd2c,
  0xcd39,0xcd5c,0xcd60,0xcd64, 0xcd6c,0xcd6d,0xcd6f,0xcd71,
  0xcd78,0xcd88,0xcd94,0xcd95, 0xcd98,0xcd9c,0xcda4,0xcda5,
  0xcda7,0xcda9,0xcdb0,0xcdc4, 0xcdcc,0xcdd0,0xcde8,0xcdec,
  0xcdf0,0xcdf8,0xcdf9,0xcdfb, 0xcdfd,0xce04,0xce08,0xce0c,
  0xce14,0xce19,0xce20,0xce21, 0xce24,0xce28,0xce30,0xce31,
  0xce33,0xce35,0xce58,0xce59, 0xce5c,0xce5f,0xce60,0xce61,
  0xce68,0xce69,0xce6b,0xce6d, 0xce74,0xce75,0xce78,0xce7c,
  0xce84,0xce85,0xce87,0xce89, 0xce90,0xce91,0xce94,0xce98,
  0xcea0,0xcea1,0xcea3,0xcea4, 0xcea5,0xceac,0xcead,0xcec1,
  0xcee4,0xcee5,0xcee8,0xceeb, 0xceec,0xcef4,0xcef5,0xcef7,
  0xcef8,0xcef9,0xcf00,0xcf01, 0xcf04,0xcf08,0xcf10,0xcf11,
  0xcf13,0xcf15,0xcf1c,0xcf20, 0xcf24,0xcf2c,0xcf2d,0xcf2f,
  0xcf30,0xcf31,0xcf38,0xcf54, 0xcf55,0xcf58,0xcf5c,0xcf64,
  0xcf65,0xcf67,0xcf69,0xcf70, 0xcf71,0xcf74,0xcf78,0xcf80,
  0xcf85,0xcf8c,0xcfa1,0xcfa8, 0xcfb0,0xcfc4,0xcfe0,0xcfe1,
  0xcfe4,0xcfe8,0xcff0,0xcff1, 0xcff3,0xcff5,0xcffc,0xd000,
  0xd004,0xd011,0xd018,0xd02d, 0xd034,0xd035,0xd038,0xd03c,
  0xd044,0xd045,0xd047,0xd049, 0xd050,0xd054,0xd058,0xd060,
  0xd06c,0xd06d,0xd070,0xd074, 0xd07c,0xd07d,0xd081,0xd0a4,
  0xd0a5,0xd0a8,0xd0ac,0xd0b4, 0xd0b5,0xd0b7,0xd0b9,0xd0c0,
  0xd0c1,0xd0c4,0xd0c8,0xd0c9, 0xd0d0,0xd0d1,0xd0d3,0xd0d4,
  0xd0d5,0xd0dc,0xd0dd,0xd0e0, 0xd0e4,0xd0ec,0xd0ed,0xd0ef,
  0xd0f0,0xd0f1,0xd0f8,0xd10d, 0xd130,0xd131,0xd134,0xd138,
  0xd13a,0xd140,0xd141,0xd143, 0xd144,0xd145,0xd14c,0xd14d,
  0xd150,0xd154,0xd15c,0xd15d, 0xd15f,0xd161,0xd168,0xd16c,
  0xd17c,0xd184,0xd188,0xd1a0, 0xd1a1,0xd1a4,0xd1a8,0xd1b0,
  0xd1b1,0xd1b3,0xd1b5,0xd1ba, 0xd1bc,0xd1c0,0xd1d8,0xd1f4,
  0xd1f8,0xd207,0xd209,0xd210, 0xd22c,0xd22d,0xd230,0xd234,
  0xd23c,0xd23d,0xd23f,0xd241, 0xd248,0xd25c,0xd264,0xd280,
  0xd281,0xd284,0xd288,0xd290, 0xd291,0xd295,0xd29c,0xd2a0,
  0xd2a4,0xd2ac,0xd2b1,0xd2b8, 0xd2b9,0xd2bc,0xd2bf,0xd2c0,
  0xd2c2,0xd2c8,0xd2c9,0xd2cb, 0xd2d4,0xd2d8,0xd2dc,0xd2e4,
  0xd2e5,0xd2f0,0xd2f1,0xd2f4, 0xd2f8,0xd300,0xd301,0xd303,
  0xd305,0xd30c,0xd30d,0xd30e, 0xd310,0xd314,0xd316,0xd31c,
  0xd31d,0xd31f,0xd320,0xd321, 0xd325,0xd328,0xd329,0xd32c,
  0xd330,0xd338,0xd339,0xd33b, 0xd33c,0xd33d,0xd344,0xd345,
  0xd37c,0xd37d,0xd380,0xd384, 0xd38c,0xd38d,0xd38f,0xd390,
  0xd391,0xd398,0xd399,0xd39c, 0xd3a0,0xd3a8,0xd3a9,0xd3ab,
  0xd3ad,0xd3b4,0xd3b8,0xd3bc, 0xd3c4,0xd3c5,0xd3c8,0xd3c9,
  0xd3d0,0xd3d8,0xd3e1,0xd3e3, 0xd3ec,0xd3ed,0xd3f0,0xd3f4,
  0xd3fc,0xd3fd,0xd3ff,0xd401, 0xd408,0xd41d,0xd440,0xd444,
  0xd45c,0xd460,0xd464,0xd46d, 0xd46f,0xd478,0xd479,0xd47c,
  0xd47f,0xd480,0xd482,0xd488, 0xd489,0xd48b,0xd48d,0xd494,
  0xd4a9,0xd4cc,0xd4d0,0xd4d4, 0xd4dc,0xd4df,0xd4e8,0xd4ec,
  0xd4f0,0xd4f8,0xd4fb,0xd4fd, 0xd504,0xd508,0xd50c,0xd514,
  0xd515,0xd517,0xd53c,0xd53d, 0xd540,0xd544,0xd54c,0xd54d,
  0xd54f,0xd551,0xd558,0xd559, 0xd55c,0xd560,0xd565,0xd568,
  0xd569,0xd56b,0xd56d,0xd574, 0xd575,0xd578,0xd57c,0xd584,
  0xd585,0xd587,0xd588,0xd589, 0xd590,0xd5a5,0xd5c8,0xd5c9,
  0xd5cc,0xd5d0,0xd5d2,0xd5d8, 0xd5d9,0xd5db,0xd5dd,0xd5e4,
  0xd5e5,0xd5e8,0xd5ec,0xd5f4, 0xd5f5,0xd5f7,0xd5f9,0xd600,
  0xd601,0xd604,0xd608,0xd610, 0xd611,0xd613,0xd614,0xd615,
  0xd61c,0xd620,0xd624,0xd62d, 0xd638,0xd639,0xd63c,0xd640,
  0xd645,0xd648,0xd649,0xd64b, 0xd64d,0xd651,0xd654,0xd655,
  0xd658,0xd65c,0xd667,0xd669, 0xd670,0xd671,0xd674,0xd683,
  0xd685,0xd68c,0xd68d,0xd690, 0xd694,0xd69d,0xd69f,0xd6a1,
  0xd6a8,0xd6ac,0xd6b0,0xd6b9, 0xd6bb,0xd6c4,0xd6c5,0xd6c8,
  0xd6cc,0xd6d1,0xd6d4,0xd6d7, 0xd6d9,0xd6e0,0xd6e4,0xd6e8,
  0xd6f0,0xd6f5,0xd6fc,0xd6fd, 0xd700,0xd704,0xd711,0xd718,
  0xd719,0xd71c,0xd720,0xd728, 0xd729,0xd72b,0xd72d,0xd734,
  0xd735,0xd738,0xd73c,0xd744, 0xd747,0xd749,0xd750,0xd751,
  0xd754,0xd756,0xd757,0xd758, 0xd759,0xd760,0xd761,0xd763,
  0xd765,0xd769,0xd76c,0xd770, 0xd774,0xd77c,0xd77d,0xd781,
  0xd788,0xd789,0xd78c,0xd790, 0xd798,0xd799,0xd79b,0xd79d,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x4f3d,0x4f73,
  0x5047,0x50f9,0x52a0,0x53ef, 0x5475,0x54e5,0x5609,0x5ac1,
  0x5bb6,0x6687,0x67b6,0x67b7, 0x67ef,0x6b4c,0x73c2,0x75c2,
  0x7a3c,0x82db,0x8304,0x8857, 0x8888,0x8a36,0x8cc8,0x8dcf,
  0x8efb,0x8fe6,0x99d5,0x523b, 0x5374,0x5404,0x606a,0x6164,
  0x6bbc,0x73cf,0x811a,0x89ba, 0x89d2,0x95a3,0x4f83,0x520a,
  0x58be,0x5978,0x59e6,0x5e72, 0x5e79,0x61c7,0x63c0,0x6746,
  0x67ec,0x687f,0x6f97,0x764e, 0x770b,0x78f5,0x7a08,0x7aff,
  0x7c21,0x809d,0x826e,0x8271, 0x8aeb,0x9593,0x4e6b,0x559d,
  0x66f7,0x6e34,0x78a3,0x7aed, 0x845b,0x8910,0x874e,0x97a8,
  0x52d8,0x574e,0x582a,0x5d4c, 0x611f,0x61be,0x6221,0x6562,
  0x67d1,0x6a44,0x6e1b,0x7518, 0x75b3,0x76e3,0x77b0,0x7d3a,
  0x90af,0x9451,0x9452,0x9f95, 0x5323,0x5cac,0x7532,0x80db,
  0x9240,0x9598,0x525b,0x5808, 0x59dc,0x5ca1,0x5d17,0x5eb7,
  0x5f3a,0x5f4a,0x6177,0x6c5f, 0x757a,0x7586,0x7ce0,0x7d73,
  0x7db1,0x7f8c,0x8154,0x8221, 0x8591,0x8941,0x8b1b,0x92fc,
  0x964d,0x9c47,0x4ecb,0x4ef7, 0x500b,0x51f1,0x584f,0x6137,
  0x613e,0x6168,0x6539,0x69ea, 0x6f11,0x75a5,0x7686,0x76d6,
  0x7b87,0x82a5,0x84cb,0xf900, 0x93a7,0x958b,0x5580,0x5ba2,
  0x5751,0xf901,0x7cb3,0x7fb9, 0x91b5,0x5028,0x53bb,0x5c45,
  0x5de8,0x62d2,0x636e,0x64da, 0x64e7,0x6e20,0x70ac,0x795b,
  0x8ddd,0x8e1e,0xf902,0x907d, 0x9245,0x92f8,0x4e7e,0x4ef6,
  0x5065,0x5dfe,0x5efa,0x6106, 0x6957,0x8171,0x8654,0x8e47,
  0x9375,0x9a2b,0x4e5e,0x5091, 0x6770,0x6840,0x5109,0x528d,
  0x5292,0x6aa2,0x77bc,0x9210, 0x9ed4,0x52ab,0x602f,0x8ff2,
  0x5048,0x61a9,0x63ed,0x64ca, 0x683c,0x6a84,0x6fc0,0x8188,
  0x89a1,0x9694,0x5805,0x727d, 0x72ac,0x7504,0x7d79,0x7e6d,
  0x80a9,0x898b,0x8b74,0x9063, 0x9d51,0x6289,0x6c7a,0x6f54,
  0x7d50,0x7f3a,0x8a23,0x517c, 0x614a,0x7b9d,0x8b19,0x9257,
  0x938c,0x4eac,0x4fd3,0x501e, 0x50be,0x5106,0x52c1,0x52cd,
  0x537f,0x5770,0x5883,0x5e9a, 0x5f91,0x6176,0x61ac,0x64ce,
  0x656c,0x666f,0x66bb,0x66f4, 0x6897,0x6d87,0x7085,0x70f1,
  0x749f,0x74a5,0x74ca,0x75d9, 0x786c,0x78ec,0x7adf,0x7af6,
  0x7d45,0x7d93,0x8015,0x803f, 0x811b,0x8396,0x8b66,0x8f15,
  0x9015,0x93e1,0x9803,0x9838, 0x9a5a,0x9be8,0x4fc2,0x5553,
  0x583a,0x5951,0x5b63,0x5c46, 0x60b8,0x6212,0x6842,0x68b0,
  0x68e8,0x6eaa,0x754c,0x7678, 0x78ce,0x7a3d,0x7cfb,0x7e6b,
  0x7e7c,0x8a08,0x8aa1,0x8c3f, 0x968e,0x9dc4,0x53e4,0x53e9,
  0x544a,0x5471,0x56fa,0x59d1, 0x5b64,0x5c3b,0x5eab,0x62f7,
  0x6537,0x6545,0x6572,0x66a0, 0x67af,0x69c1,0x6cbd,0x75fc,
  0x7690,0x777e,0x7a3f,0x7f94, 0x8003,0x80a1,0x818f,0x82e6,
  0x82fd,0x83f0,0x85c1,0x8831, 0x88b4,0x8aa5,0xf903,0x8f9c,
  0x932e,0x96c7,0x9867,0x9ad8, 0x9f13,0x54ed,0x659b,0x66f2,
  0x688f,0x7a40,0x8c37,0x9d60, 0x56f0,0x5764,0x5d11,0x6606,
  0x68b1,0x68cd,0x6efe,0x7428, 0x889e,0x9be4,0x6c68,0xf904,
  0x9aa8,0x4f9b,0x516c,0x5171, 0x529f,0x5b54,0x5de5,0x6050,
  0x606d,0x62f1,0x63a7,0x653b, 0x73d9,0x7a7a,0x86a3,0x8ca2,
  0x978f,0x4e32,0x5be1,0x6208, 0x679c,0x74dc,0x79d1,0x83d3,
  0x8a87,0x8ab2,0x8de8,0x904e, 0x934b,0x9846,0x5ed3,0x69e8,
  0x85ff,0x90ed,0xf905,0x51a0, 0x5b98,0x5bec,0x6163,0x68fa,
  0x6b3e,0x704c,0x742f,0x74d8, 0x7ba1,0x7f50,0x83c5,0x89c0,
  0x8cab,0x95dc,0x9928,0x522e, 0x605d,0x62ec,0x9002,0x4f8a,
  0x5149,0x5321,0x58d9,0x5ee3, 0x66e0,0x6d38,0x709a,0x72c2,
  0x73d6,0x7b50,0x80f1,0x945b, 0x5366,0x639b,0x7f6b,0x4e56,
  0x5080,0x584a,0x58de,0x602a, 0x6127,0x62d0,0x69d0,0x9b41,
  0x5b8f,0x7d18,0x80b1,0x8f5f, 0x4ea4,0x50d1,0x54ac,0x55ac,
  0x5b0c,0x5da0,0x5de7,0x652a, 0x654e,0x6821,0x6a4b,0x72e1,
  0x768e,0x77ef,0x7d5e,0x7ff9, 0x81a0,0x854e,0x86df,0x8f03,
  0x8f4e,0x90ca,0x9903,0x9a55, 0x9bab,0x4e18,0x4e45,0x4e5d,
  0x4ec7,0x4ff1,0x5177,0x52fe, 0x5340,0x53e3,0x53e5,0x548e,
  0x5614,0x5775,0x57a2,0x5bc7, 0x5d87,0x5ed0,0x61fc,0x62d8,
  0x6551,0x67b8,0x67e9,0x69cb, 0x6b50,0x6bc6,0x6bec,0x6c42,
  0x6e9d,0x7078,0x72d7,0x7396, 0x7403,0x77bf,0x77e9,0x7a76,
  0x7d7f,0x8009,0x81fc,0x8205, 0x820a,0x82df,0x8862,0x8b33,
  0x8cfc,0x8ec0,0x9011,0x90b1, 0x9264,0x92b6,0x99d2,0x9a45,
  0x9ce9,0x9dd7,0x9f9c,0x570b, 0x5c40,0x83ca,0x97a0,0x97ab,
  0x9eb4,0x541b,0x7a98,0x7fa4, 0x88d9,0x8ecd,0x90e1,0x5800,
  0x5c48,0x6398,0x7a9f,0x5bae, 0x5f13,0x7a79,0x7aae,0x828e,
  0x8eac,0x5026,0x5238,0x52f8, 0x5377,0x5708,0x62f3,0x6372,
  0x6b0a,0x6dc3,0x7737,0x53a5, 0x7357,0x8568,0x8e76,0x95d5,
  0x673a,0x6ac3,0x6f70,0x8a6d, 0x8ecc,0x994b,0xf906,0x6677,
  0x6b78,0x8cb4,0x9b3c,0xf907, 0x53eb,0x572d,0x594e,0x63c6,
  0x69fb,0x73ea,0x7845,0x7aba, 0x7ac5,0x7cfe,0x8475,0x898f,
  0x8d73,0x9035,0x95a8,0x52fb, 0x5747,0x7547,0x7b60,0x83cc,
  0x921e,0xf908,0x6a58,0x514b, 0x524b,0x5287,0x621f,0x68d8,
  0x6975,0x9699,0x50c5,0x52a4, 0x52e4,0x61c3,0x65a4,0x6839,
  0x69ff,0x747e,0x7b4b,0x82b9, 0x83eb,0x89b2,0x8b39,0x8fd1,
  0x9949,0xf909,0x4eca,0x5997, 0x64d2,0x6611,0x6a8e,0x7434,
  0x7981,0x79bd,0x82a9,0x887e, 0x887f,0x895f,0xf90a,0x9326,
  0x4f0b,0x53ca,0x6025,0x6271, 0x6c72,0x7d1a,0x7d66,0x4e98,
  0x5162,0x77dc,0x80af,0x4f01, 0x4f0e,0x5176,0x5180,0x55dc,
  0x5668,0x573b,0x57fa,0x57fc, 0x5914,0x5947,0x5993,0x5bc4,
  0x5c90,0x5d0e,0x5df1,0x5e7e, 0x5fcc,0x6280,0x65d7,0x65e3,
  0x671e,0x671f,0x675e,0x68cb, 0x68c4,0x6a5f,0x6b3a,0x6c23,
  0x6c7d,0x6c82,0x6dc7,0x7398, 0x7426,0x742a,0x7482,0x74a3,
  0x7578,0x757f,0x7881,0x78ef, 0x7941,0x7947,0x7948,0x797a,
  0x7b95,0x7d00,0x7dba,0x7f88, 0x8006,0x802d,0x808c,0x8a18,
  0x8b4f,0x8c48,0x8d77,0x9321, 0x9324,0x98e2,0x9951,0x9a0e,
  0x9a0f,0x9a65,0x9e92,0x7dca, 0x4f76,0x5409,0x62ee,0x6854,
  0x91d1,0x55ab,0x513a,0xf90b, 0xf90c,0x5a1c,0x61e6,0xf90d,
  0x62cf,0x62ff,0xf90e,0xf90f, 0xf910,0xf911,0xf912,0xf913,
  0x90a3,0xf914,0xf915,0xf916, 0xf917,0xf918,0x8afe,0xf919,
  0xf91a,0xf91b,0xf91c,0x6696, 0xf91d,0x7156,0xf91e,0xf91f,
  0x96e3,0xf920,0x634f,0x637a, 0x5357,0xf921,0x678f,0x6960,
  0x6e73,0xf922,0x7537,0xf923, 0xf924,0xf925,0x7d0d,0xf926,
  0xf927,0x8872,0x56ca,0x5a18, 0xf928,0xf929,0xf92a,0xf92b,
  0xf92c,0x4e43,0xf92d,0x5167, 0x5948,0x67f0,0x8010,0xf92e,
  0x5973,0x5e74,0x649a,0x79ca, 0x5ff5,0x606c,0x62c8,0x637b,
  0x5be7,0x5bd7,0x52aa,0xf92f, 0x5974,0x5f29,0x6012,0xf930,
  0xf931,0xf932,0x7459,0xf933, 0xf934,0xf935,0xf936,0xf937,
  0xf938,0x99d1,0xf939,0xf93a, 0xf93b,0xf93c,0xf93d,0xf93e,
  0xf93f,0xf940,0xf941,0xf942, 0xf943,0x6fc3,0xf944,0xf945,
  0x81bf,0x8fb2,0x60f1,0xf946, 0xf947,0x8166,0xf948,0xf949,
  0x5c3f,0xf94a,0xf94b,0xf94c, 0xf94d,0xf94e,0xf94f,0xf950,
  0xf951,0x5ae9,0x8a25,0x677b, 0x7d10,0xf952,0xf953,0xf954,
  0xf955,0xf956,0xf957,0x80fd, 0xf958,0xf959,0x5c3c,0x6ce5,
  0x533f,0x6eba,0x591a,0x8336, 0x4e39,0x4eb6,0x4f46,0x55ae,
  0x5718,0x58c7,0x5f56,0x65b7, 0x65e6,0x6a80,0x6bb5,0x6e4d,
  0x77ed,0x7aef,0x7c1e,0x7dde, 0x86cb,0x8892,0x9132,0x935b,
  0x64bb,0x6fbe,0x737a,0x75b8, 0x9054,0x5556,0x574d,0x61ba,
  0x64d4,0x66c7,0x6de1,0x6e5b, 0x6f6d,0x6fb9,0x75f0,0x8043,
  0x81bd,0x8541,0x8983,0x8ac7, 0x8b5a,0x931f,0x6c93,0x7553,
  0x7b54,0x8e0f,0x905d,0x5510, 0x5802,0x5858,0x5e62,0x6207,
  0x649e,0x68e0,0x7576,0x7cd6, 0x87b3,0x9ee8,0x4ee3,0x5788,
  0x576e,0x5927,0x5c0d,0x5cb1, 0x5e36,0x5f85,0x6234,0x64e1,
  0x73b3,0x81fa,0x888b,0x8cb8, 0x968a,0x9edb,0x5b85,0x5fb7,
  0x60b3,0x5012,0x5200,0x5230, 0x5716,0x5835,0x5857,0x5c0e,
  0x5c60,0x5cf6,0x5d8b,0x5ea6, 0x5f92,0x60bc,0x6311,0x6389,
  0x6417,0x6843,0x68f9,0x6ac2, 0x6dd8,0x6e21,0x6ed4,0x6fe4,
  0x71fe,0x76dc,0x7779,0x79b1, 0x7a3b,0x8404,0x89a9,0x8ced,
  0x8df3,0x8e48,0x9003,0x9014, 0x9053,0x90fd,0x934d,0x9676,
  0x97dc,0x6bd2,0x7006,0x7258, 0x72a2,0x7368,0x7763,0x79bf,
  0x7be4,0x7e9b,0x8b80,0x58a9, 0x60c7,0x6566,0x65fd,0x66be,
  0x6c8c,0x711e,0x71c9,0x8c5a, 0x9813,0x4e6d,0x7a81,0x4edd,
  0x51ac,0x51cd,0x52d5,0x540c, 0x61a7,0x6771,0x6850,0x68df,
  0x6d1e,0x6f7c,0x75bc,0x77b3, 0x7ae5,0x80f4,0x8463,0x9285,
  0x515c,0x6597,0x675c,0x6793, 0x75d8,0x7ac7,0x8373,0xf95a,
  0x8c46,0x9017,0x982d,0x5c6f, 0x81c0,0x829a,0x9041,0x906f,
  0x920d,0x5f97,0x5d9d,0x6a59, 0x71c8,0x767b,0x7b49,0x85e4,
  0x8b04,0x9127,0x9a30,0x5587, 0x61f6,0xf95b,0x7669,0x7f85,
  0x863f,0x87ba,0x88f8,0x908f, 0xf95c,0x6d1b,0x70d9,0x73de,
  0x7d61,0x843d,0xf95d,0x916a, 0x99f1,0xf95e,0x4e82,0x5375,
  0x6b04,0x6b12,0x703e,0x721b, 0x862d,0x9e1e,0x524c,0x8fa3,
  0x5d50,0x64e5,0x652c,0x6b16, 0x6feb,0x7c43,0x7e9c,0x85cd,
  0x8964,0x89bd,0x62c9,0x81d8, 0x881f,0x5eca,0x6717,0x6d6a,
  0x72fc,0x7405,0x746f,0x8782, 0x90de,0x4f86,0x5d0d,0x5fa0,
  0x840a,0x51b7,0x63a0,0x7565, 0x4eae,0x5006,0x5169,0x51c9,
  0x6881,0x6a11,0x7cae,0x7cb1, 0x7ce7,0x826f,0x8ad2,0x8f1b,
  0x91cf,0x4fb6,0x5137,0x52f5, 0x5442,0x5eec,0x616e,0x623e,
  0x65c5,0x6ada,0x6ffe,0x792a, 0x85dc,0x8823,0x95ad,0x9a62,
  0x9a6a,0x9e97,0x9ece,0x529b, 0x66c6,0x6b77,0x701d,0x792b,
  0x8f62,0x9742,0x6190,0x6200, 0x6523,0x6f23,0x7149,0x7489,
  0x7df4,0x806f,0x84ee,0x8f26, 0x9023,0x934a,0x51bd,0x5217,
  0x52a3,0x6d0c,0x70c8,0x88c2, 0x5ec9,0x6582,0x6bae,0x6fc2,
  0x7c3e,0x7375,0x4ee4,0x4f36, 0x56f9,0xf95f,0x5cba,0x5dba,
  0x601c,0x73b2,0x7b2d,0x7f9a, 0x7fce,0x8046,0x901e,0x9234,
  0x96f6,0x9748,0x9818,0x9f61, 0x4f8b,0x6fa7,0x79ae,0x91b4,
  0x96b7,0x52de,0xf960,0x6488, 0x64c4,0x6ad3,0x6f5e,0x7018,
  0x7210,0x76e7,0x8001,0x8606, 0x865c,0x8def,0x8f05,0x9732,
  0x9b6f,0x9dfa,0x9e75,0x788c, 0x797f,0x7da0,0x83c9,0x9304,
  0x9e7f,0x9e93,0x8ad6,0x58df, 0x5f04,0x6727,0x7027,0x74cf,
  0x7c60,0x807e,0x5121,0x7028, 0x7262,0x78ca,0x8cc2,0x8cda,
  0x8cf4,0x96f7,0x4e86,0x50da, 0x5bee,0x5ed6,0x6599,0x71ce,
  0x7642,0x77ad,0x804a,0x84fc, 0x907c,0x9b27,0x9f8d,0x58d8,
  0x5a41,0x5c62,0x6a13,0x6dda, 0x6f0f,0x763b,0x7d2f,0x7e37,
  0x851e,0x8938,0x93e4,0x964b, 0x5289,0x65d2,0x67f3,0x69b4,
  0x6d41,0x6e9c,0x700f,0x7409, 0x7460,0x7559,0x7624,0x786b,
  0x8b2c,0x985e,0x516d,0x622e, 0x9678,0x4f96,0x502b,0x5d19,
  0x6dea,0x7db8,0x8f2a,0x5f8b, 0x6144,0x6817,0xf961,0x9686,
  0x52d2,0x808b,0x51dc,0x51cc, 0x695e,0x7a1c,0x7dbe,0x83f1,
  0x9675,0x4fda,0x5229,0x5398, 0x540f,0x550e,0x5c65,0x60a7,
  0x674e,0x68a8,0x6d6c,0x7281, 0x72f8,0x7406,0x7483,0xf962,
  0x75e2,0x7c6c,0x7f79,0x7fb8, 0x8389,0x88cf,0x88e1,0x91cc,
  0x91d0,0x96e2,0x9bc9,0x541d, 0x6f7e,0x71d0,0x7498,0x85fa,
  0x8eaa,0x96a3,0x9c57,0x9e9f, 0x6797,0x6dcb,0x7433,0x81e8,
  0x9716,0x782c,0x7acb,0x7b20, 0x7c92,0x6469,0x746a,0x75f2,
  0x78bc,0x78e8,0x99ac,0x9b54, 0x9ebb,0x5bde,0x5e55,0x6f20,
  0x819c,0x83ab,0x9088,0x4e07, 0x534d,0x5a29,0x5dd2,0x5f4e,
  0x6162,0x633d,0x6669,0x66fc, 0x6eff,0x6f2b,0x7063,0x779e,
  0x842c,0x8513,0x883b,0x8f13, 0x9945,0x9c3b,0x551c,0x62b9,
  0x672b,0x6cab,0x8309,0x896a, 0x977a,0x4ea1,0x5984,0x5fd8,
  0x5fd9,0x671b,0x7db2,0x7f54, 0x8292,0x832b,0x83bd,0x8f1e,
  0x9099,0x57cb,0x59b9,0x5a92, 0x5bd0,0x6627,0x679a,0x6885,
  0x6bcf,0x7164,0x7f75,0x8cb7, 0x8ce3,0x9081,0x9b45,0x8108,
  0x8c8a,0x964c,0x9a40,0x9ea5, 0x5b5f,0x6c13,0x731b,0x76f2,
  0x76df,0x840c,0x51aa,0x8993, 0x514d,0x5195,0x52c9,0x68c9,
  0x6c94,0x7704,0x7720,0x7dbf, 0x7dec,0x9762,0x9eb5,0x6ec5,
  0x8511,0x51a5,0x540d,0x547d, 0x660e,0x669d,0x6927,0x6e9f,
  0x76bf,0x7791,0x8317,0x84c2, 0x879f,0x9169,0x9298,0x9cf4,
  0x8882,0x4fae,0x5192,0x52df, 0x59c6,0x5e3d,0x6155,0x6478,
  0x6479,0x66ae,0x67d0,0x6a21, 0x6bcd,0x6bdb,0x725f,0x7261,
  0x7441,0x7738,0x77db,0x8017, 0x82bc,0x8305,0x8b00,0x8b28,
  0x8c8c,0x6728,0x6c90,0x7267, 0x76ee,0x7766,0x7a46,0x9da9,
  0x6b7f,0x6c92,0x5922,0x6726, 0x8499,0x536f,0x5893,0x5999,
  0x5edf,0x63cf,0x6634,0x6773, 0x6e3a,0x732b,0x7ad7,0x82d7,
  0x9328,0x52d9,0x5deb,0x61ae, 0x61cb,0x620a,0x62c7,0x64ab,
  0x65e0,0x6959,0x6b66,0x6bcb, 0x7121,0x73f7,0x755d,0x7e46,
  0x821e,0x8302,0x856a,0x8aa3, 0x8cbf,0x9727,0x9d61,0x58a8,
  0x9ed8,0x5011,0x520e,0x543b, 0x554f,0x6587,0x6c76,0x7d0a,
  0x7d0b,0x805e,0x868a,0x9580, 0x96ef,0x52ff,0x6c95,0x7269,
  0x5473,0x5a9a,0x5c3e,0x5d4b, 0x5f4c,0x5fae,0x672a,0x68b6,
  0x6963,0x6e3c,0x6e44,0x7709, 0x7c73,0x7f8e,0x8587,0x8b0e,
  0x8ff7,0x9761,0x9ef4,0x5cb7, 0x60b6,0x610d,0x61ab,0x654f,
  0x65fb,0x65fc,0x6c11,0x6cef, 0x739f,0x73c9,0x7de1,0x9594,
  0x5bc6,0x871c,0x8b10,0x525d, 0x535a,0x62cd,0x640f,0x64b2,
  0x6734,0x6a38,0x6cca,0x73c0, 0x749e,0x7b94,0x7c95,0x7e1b,
  0x818a,0x8236,0x8584,0x8feb, 0x96f9,0x99c1,0x4f34,0x534a,
  0x53cd,0x53db,0x62cc,0x642c, 0x6500,0x6591,0x69c3,0x6cee,
  0x6f58,0x73ed,0x7554,0x7622, 0x76e4,0x76fc,0x78d0,0x78fb,
  0x792c,0x7d46,0x822c,0x87e0, 0x8fd4,0x9812,0x98ef,0x52c3,
  0x62d4,0x64a5,0x6e24,0x6f51, 0x767c,0x8dcb,0x91b1,0x9262,
  0x9aee,0x9b43,0x5023,0x508d, 0x574a,0x59a8,0x5c28,0x5e47,
  0x5f77,0x623f,0x653e,0x65b9, 0x65c1,0x6609,0x678b,0x699c,
  0x6ec2,0x78c5,0x7d21,0x80aa, 0x8180,0x822b,0x82b3,0x84a1,
  0x868c,0x8a2a,0x8b17,0x90a6, 0x9632,0x9f90,0x500d,0x4ff3,
  0xf963,0x57f9,0x5f98,0x62dc, 0x6392,0x676f,0x6e43,0x7119,
  0x76c3,0x80cc,0x80da,0x88f4, 0x88f5,0x8919,0x8ce0,0x8f29,
  0x914d,0x966a,0x4f2f,0x4f70, 0x5e1b,0x67cf,0x6822,0x767d,
  0x767e,0x9b44,0x5e61,0x6a0a, 0x7169,0x71d4,0x756a,0xf964,
  0x7e41,0x8543,0x85e9,0x98dc, 0x4f10,0x7b4f,0x7f70,0x95a5,
  0x51e1,0x5e06,0x68b5,0x6c3e, 0x6c4e,0x6cdb,0x72af,0x7bc4,
  0x8303,0x6cd5,0x743a,0x50fb, 0x5288,0x58c1,0x64d8,0x6a97,
  0x74a7,0x7656,0x78a7,0x8617, 0x95e2,0x9739,0xf965,0x535e,
  0x5f01,0x8b8a,0x8fa8,0x8faf, 0x908a,0x5225,0x77a5,0x9c49,
  0x9f08,0x4e19,0x5002,0x5175, 0x5c5b,0x5e77,0x661e,0x663a,
  0x67c4,0x68c5,0x70b3,0x7501, 0x75c5,0x79c9,0x7add,0x8f27,
  0x9920,0x9a08,0x4fdd,0x5821, 0x5831,0x5bf6,0x666e,0x6b65,
  0x6d11,0x6e7a,0x6f7d,0x73e4, 0x752b,0x83e9,0x88dc,0x8913,
  0x8b5c,0x8f14,0x4f0f,0x50d5, 0x5310,0x535c,0x5b93,0x5fa9,
  0x670d,0x798f,0x8179,0x832f, 0x8514,0x8907,0x8986,0x8f39,
  0x8f3b,0x99a5,0x9c12,0x672c, 0x4e76,0x4ff8,0x5949,0x5c01,
  0x5cef,0x5cf0,0x6367,0x68d2, 0x70fd,0x71a2,0x742b,0x7e2b,
  0x84ec,0x8702,0x9022,0x92d2, 0x9cf3,0x4e0d,0x4ed8,0x4fef,
  0x5085,0x5256,0x526f,0x5426, 0x5490,0x57e0,0x592b,0x5a66,
  0x5b5a,0x5b75,0x5bcc,0x5e9c, 0xf966,0x6276,0x6577,0x65a7,
  0x6d6e,0x6ea5,0x7236,0x7b26, 0x7c3f,0x7f36,0x8150,0x8151,
  0x819a,0x8240,0x8299,0x83a9, 0x8a03,0x8ca0,0x8ce6,0x8cfb,
  0x8d74,0x8dba,0x90e8,0x91dc, 0x961c,0x9644,0x99d9,0x9ce7,
  0x5317,0x5206,0x5429,0x5674, 0x58b3,0x5954,0x596e,0x5fff,
  0x61a4,0x626e,0x6610,0x6c7e, 0x711a,0x76c6,0x7c89,0x7cde,
  0x7d1b,0x82ac,0x8cc1,0x96f0, 0xf967,0x4f5b,0x5f17,0x5f7f,
  0x62c2,0x5d29,0x670b,0x68da, 0x787c,0x7e43,0x9d6c,0x4e15,
  0x5099,0x5315,0x532a,0x5351, 0x5983,0x5a62,0x5e87,0x60b2,
  0x618a,0x6249,0x6279,0x6590, 0x6787,0x69a7,0x6bd4,0x6bd6,
  0x6bd7,0x6bd8,0x6cb8,0xf968, 0x7435,0x75fa,0x7812,0x7891,
  0x79d5,0x79d8,0x7c83,0x7dcb, 0x7fe1,0x80a5,0x813e,0x81c2,
  0x83f2,0x871a,0x88e8,0x8ab9, 0x8b6c,0x8cbb,0x9119,0x975e,
  0x98db,0x9f3b,0x56ac,0x5b2a, 0x5f6c,0x658c,0x6ab3,0x6baf,
  0x6d5c,0x6ff1,0x7015,0x725d, 0x73ad,0x8ca7,0x8cd3,0x983b,
  0x6191,0x6c37,0x8058,0x9a01, 0x4e4d,0x4e8b,0x4e9b,0x4ed5,
  0x4f3a,0x4f3c,0x4f7f,0x4fdf, 0x50ff,0x53f2,0x53f8,0x5506,
  0x55e3,0x56db,0x58eb,0x5962, 0x5a11,0x5beb,0x5bfa,0x5c04,
  0x5df3,0x5e2b,0x5f99,0x601d, 0x6368,0x659c,0x65af,0x67f6,
  0x67fb,0x68ad,0x6b7b,0x6c99, 0x6cd7,0x6e23,0x7009,0x7345,
  0x7802,0x793e,0x7940,0x7960, 0x79c1,0x7be9,0x7d17,0x7d72,
  0x8086,0x820d,0x838e,0x84d1, 0x86c7,0x88df,0x8a50,0x8a5e,
  0x8b1d,0x8cdc,0x8d66,0x8fad, 0x90aa,0x98fc,0x99df,0x9e9d,
  0x524a,0xf969,0x6714,0xf96a, 0x5098,0x522a,0x5c71,0x6563,
  0x6c55,0x73ca,0x7523,0x759d, 0x7b97,0x849c,0x9178,0x9730,
  0x4e77,0x6492,0x6bba,0x715e, 0x85a9,0x4e09,0xf96b,0x6749,
  0x68ee,0x6e17,0x829f,0x8518, 0x886b,0x63f7,0x6f81,0x9212,
  0x98af,0x4e0a,0x50b7,0x50cf, 0x511f,0x5546,0x55aa,0x5617,
  0x5b40,0x5c19,0x5ce0,0x5e38, 0x5e8a,0x5ea0,0x5ec2,0x60f3,
  0x6851,0x6a61,0x6e58,0x723d, 0x7240,0x72c0,0x76f8,0x7965,
  0x7bb1,0x7fd4,0x88f3,0x89f4, 0x8a73,0x8c61,0x8cde,0x971c,
  0x585e,0x74bd,0x8cfd,0x55c7, 0xf96c,0x7a61,0x7d22,0x8272,
  0x7272,0x751f,0x7525,0xf96d, 0x7b19,0x5885,0x58fb,0x5dbc,
  0x5e8f,0x5eb6,0x5f90,0x6055, 0x6292,0x637f,0x654d,0x6691,
  0x66d9,0x66f8,0x6816,0x68f2, 0x7280,0x745e,0x7b6e,0x7d6e,
  0x7dd6,0x7f72,0x80e5,0x8212, 0x85af,0x897f,0x8a93,0x901d,
  0x92e4,0x9ecd,0x9f20,0x5915, 0x596d,0x5e2d,0x60dc,0x6614,
  0x6673,0x6790,0x6c50,0x6dc5, 0x6f5f,0x77f3,0x78a9,0x84c6,
  0x91cb,0x932b,0x4ed9,0x50ca, 0x5148,0x5584,0x5b0b,0x5ba3,
  0x6247,0x657e,0x65cb,0x6e32, 0x717d,0x7401,0x7444,0x7487,
  0x74bf,0x766c,0x79aa,0x7dda, 0x7e55,0x7fa8,0x817a,0x81b3,
  0x8239,0x861a,0x87ec,0x8a75, 0x8de3,0x9078,0x9291,0x9425,
  0x994d,0x9bae,0x5368,0x5c51, 0x6954,0x6cc4,0x6d29,0x6e2b,
  0x820c,0x859b,0x893b,0x8a2d, 0x8aaa,0x96ea,0x9f67,0x5261,
  0x66b9,0x6bb2,0x7e96,0x87fe, 0x8d0d,0x9583,0x965d,0x651d,
  0x6d89,0x71ee,0xf96e,0x57ce, 0x59d3,0x5bac,0x6027,0x60fa,
  0x6210,0x661f,0x665f,0x7329, 0x73f9,0x76db,0x7701,0x7b6c,
  0x8056,0x8072,0x8165,0x8aa0, 0x9192,0x4e16,0x52e2,0x6b72,
  0x6d17,0x7a05,0x7b39,0x7d30, 0xf96f,0x8cb0,0x53ec,0x562f,
  0x5851,0x5bb5,0x5c0f,0x5c11, 0x5de2,0x6240,0x6383,0x6414,
  0x662d,0x68b3,0x6cbc,0x6d88, 0x6eaf,0x701f,0x70a4,0x71d2,
  0x7526,0x758f,0x758e,0x7619, 0x7b11,0x7be0,0x7c2b,0x7d20,
  0x7d39,0x852c,0x856d,0x8607, 0x8a34,0x900d,0x9061,0x90b5,
  0x92b7,0x97f6,0x9a37,0x4fd7, 0x5c6c,0x675f,0x6d91,0x7c9f,
  0x7e8c,0x8b16,0x8d16,0x901f, 0x5b6b,0x5dfd,0x640d,0x84c0,
  0x905c,0x98e1,0x7387,0x5b8b, 0x609a,0x677e,0x6dde,0x8a1f,
  0x8aa6,0x9001,0x980c,0x5237, 0xf970,0x7051,0x788e,0x9396,
  0x8870,0x91d7,0x4fee,0x53d7, 0x55fd,0x56da,0x5782,0x58fd,
  0x5ac2,0x5b88,0x5cab,0x5cc0, 0x5e25,0x6101,0x620d,0x624b,
  0x6388,0x641c,0x6536,0x6578, 0x6a39,0x6b8a,0x6c34,0x6d19,
  0x6f31,0x71e7,0x72e9,0x7378, 0x7407,0x74b2,0x7626,0x7761,
  0x79c0,0x7a57,0x7aea,0x7cb9, 0x7d8f,0x7dac,0x7e61,0x7f9e,
  0x8129,0x8331,0x8490,0x84da, 0x85ea,0x8896,0x8ab0,0x8b90,
  0x8f38,0x9042,0x9083,0x916c, 0x9296,0x92b9,0x968b,0x96a7,
  0x96a8,0x96d6,0x9700,0x9808, 0x9996,0x9ad3,0x9b1a,0x53d4,
  0x587e,0x5919,0x5b70,0x5bbf, 0x6dd1,0x6f5a,0x719f,0x7421,
  0x74b9,0x8085,0x83fd,0x5de1, 0x5f87,0x5faa,0x6042,0x65ec,
  0x6812,0x696f,0x6a53,0x6b89, 0x6d35,0x6df3,0x73e3,0x76fe,
  0x77ac,0x7b4d,0x7d14,0x8123, 0x821c,0x8340,0x84f4,0x8563,
  0x8a62,0x8ac4,0x9187,0x931e, 0x9806,0x99b4,0x620c,0x8853,
  0x8ff0,0x9265,0x5d07,0x5d27, 0x5d69,0x745f,0x819d,0x8768,
  0x6fd5,0x62fe,0x7fd2,0x8936, 0x8972,0x4e1e,0x4e58,0x50e7,
  0x52dd,0x5347,0x627f,0x6607, 0x7e69,0x8805,0x965e,0x4f8d,
  0x5319,0x5636,0x59cb,0x5aa4, 0x5c38,0x5c4e,0x5c4d,0x5e02,
  0x5f11,0x6043,0x65bd,0x662f, 0x6642,0x67be,0x67f4,0x731c,
  0x77e2,0x793a,0x7fc5,0x8494, 0x84cd,0x8996,0x8a66,0x8a69,
  0x8ae1,0x8c55,0x8c7a,0x57f4, 0x5bd4,0x5f0f,0x606f,0x62ed,
  0x690d,0x6b96,0x6e5c,0x7184, 0x7bd2,0x8755,0x8b58,0x8efe,
  0x98df,0x98fe,0x4f38,0x4f81, 0x4fe1,0x547b,0x5a20,0x5bb8,
  0x613c,0x65b0,0x6668,0x71fc, 0x7533,0x795e,0x7d33,0x814e,
  0x81e3,0x8398,0x85aa,0x85ce, 0x8703,0x8a0a,0x8eab,0x8f9b,
  0xf971,0x8fc5,0x5931,0x5ba4, 0x5be6,0x6089,0x5be9,0x5c0b,
  0x5fc3,0x6c81,0xf972,0x6df1, 0x700b,0x751a,0x82af,0x8af6,
  0x4ec0,0x5341,0xf973,0x96d9, 0x6c0f,0x4e9e,0x4fc4,0x5152,
  0x555e,0x5a25,0x5ce8,0x6211, 0x7259,0x82bd,0x83aa,0x86fe,
  0x8859,0x8a1d,0x963f,0x96c5, 0x9913,0x9d09,0x9d5d,0x580a,
  0x5cb3,0x5dbd,0x5e44,0x60e1, 0x6115,0x63e1,0x6a02,0x6e25,
  0x9102,0x9354,0x984e,0x9c10, 0x9f77,0x5b89,0x5cb8,0x6309,
  0x664f,0x6848,0x773c,0x96c1, 0x978d,0x9854,0x9b9f,0x65a1,
  0x8b01,0x8ecb,0x95bc,0x5535, 0x5ca9,0x5dd6,0x5eb5,0x6697,
  0x764c,0x83f4,0x95c7,0x58d3, 0x62bc,0x72ce,0x9d28,0x4ef0,
  0x592e,0x600f,0x663b,0x6b83, 0x79e7,0x9d26,0x5393,0x54c0,
  0x57c3,0x5d16,0x611b,0x66d6, 0x6daf,0x788d,0x827e,0x9698,
  0x9744,0x5384,0x627c,0x6396, 0x6db2,0x7e0a,0x814b,0x984d,
  0x6afb,0x7f4c,0x9daf,0x9e1a, 0x4e5f,0x503b,0x51b6,0x591c,
  0x60f9,0x63f6,0x6930,0x723a, 0x8036,0xf974,0x91ce,0x5f31,
  0xf975,0xf976,0x7d04,0x82e5, 0x846f,0x84bb,0x85e5,0x8e8d,
  0xf977,0x4f6f,0xf978,0xf979, 0x58e4,0x5b43,0x6059,0x63da,
  0x6518,0x656d,0x6698,0xf97a, 0x694a,0x6a23,0x6d0b,0x7001,
  0x716c,0x75d2,0x760d,0x79b3, 0x7a70,0xf97b,0x7f8a,0xf97c,
  0x8944,0xf97d,0x8b93,0x91c0, 0x967d,0xf97e,0x990a,0x5704,
  0x5fa1,0x65bc,0x6f01,0x7600, 0x79a6,0x8a9e,0x99ad,0x9b5a,
  0x9f6c,0x5104,0x61b6,0x6291, 0x6a8d,0x81c6,0x5043,0x5830,
  0x5f66,0x7109,0x8a00,0x8afa, 0x5b7c,0x8616,0x4ffa,0x513c,
  0x56b4,0x5944,0x63a9,0x6df9, 0x5daa,0x696d,0x5186,0x4e88,
  0x4f59,0xf97f,0xf980,0xf981, 0x5982,0xf982,0xf983,0x6b5f,
  0x6c5d,0xf984,0x74b5,0x7916, 0xf985,0x8207,0x8245,0x8339,
  0x8f3f,0x8f5d,0xf986,0x9918, 0xf987,0xf988,0xf989,0x4ea6,
  0xf98a,0x57df,0x5f79,0x6613, 0xf98b,0xf98c,0x75ab,0x7e79,
  0x8b6f,0xf98d,0x9006,0x9a5b, 0x56a5,0x5827,0x59f8,0x5a1f,
  0x5bb4,0xf98e,0x5ef6,0xf98f, 0xf990,0x6350,0x633b,0xf991,
  0x693d,0x6c87,0x6cbf,0x6d8e, 0x6d93,0x6df5,0x6f14,0xf992,
  0x70df,0x7136,0x7159,0xf993, 0x71c3,0x71d5,0xf994,0x784f,
  0x786f,0xf995,0x7b75,0x7de3, 0xf996,0x7e2f,0xf997,0x884d,
  0x8edf,0xf998,0xf999,0xf99a, 0x925b,0xf99b,0x9cf6,0xf99c,
  0xf99d,0xf99e,0x6085,0x6d85, 0xf99f,0x71b1,0xf9a0,0xf9a1,
  0x95b1,0x53ad,0xf9a2,0xf9a3, 0xf9a4,0x67d3,0xf9a5,0x708e,
  0x7130,0x7430,0x8276,0x82d2, 0xf9a6,0x95bb,0x9ae5,0x9e7d,
  0x66c4,0xf9a7,0x71c1,0x8449, 0xf9a8,0xf9a9,0x584b,0xf9aa,
  0xf9ab,0x5db8,0x5f71,0xf9ac, 0x6620,0x668e,0x6979,0x69ae,
  0x6c38,0x6cf3,0x6e36,0x6f41, 0x6fda,0x701b,0x702f,0x7150,
  0x71df,0x7370,0xf9ad,0x745b, 0xf9ae,0x74d4,0x76c8,0x7a4e,
  0x7e93,0xf9af,0xf9b0,0x82f1, 0x8a60,0x8fce,0xf9b1,0x9348,
  0xf9b2,0x9719,0xf9b3,0xf9b4, 0x4e42,0x502a,0xf9b5,0x5208,
  0x53e1,0x66f3,0x6c6d,0x6fca, 0x730a,0x777f,0x7a62,0x82ae,
  0x85dd,0x8602,0xf9b6,0x88d4, 0x8a63,0x8b7d,0x8c6b,0xf9b7,
  0x92b3,0xf9b8,0x9713,0x9810, 0x4e94,0x4f0d,0x4fc9,0x50b2,
  0x5348,0x543e,0x5433,0x55da, 0x5862,0x58ba,0x5967,0x5a1b,
  0x5be4,0x609f,0xf9b9,0x61ca, 0x6556,0x65ff,0x6664,0x68a7,
  0x6c5a,0x6fb3,0x70cf,0x71ac, 0x7352,0x7b7d,0x8708,0x8aa4,
  0x9c32,0x9f07,0x5c4b,0x6c83, 0x7344,0x7389,0x923a,0x6eab,
  0x7465,0x761f,0x7a69,0x7e15, 0x860a,0x5140,0x58c5,0x64c1,
  0x74ee,0x7515,0x7670,0x7fc1, 0x9095,0x96cd,0x9954,0x6e26,
  0x74e6,0x7aa9,0x7aaa,0x81e5, 0x86d9,0x8778,0x8a1b,0x5a49,
  0x5b8c,0x5b9b,0x68a1,0x6900, 0x6d63,0x73a9,0x7413,0x742c,
  0x7897,0x7de9,0x7feb,0x8118, 0x8155,0x839e,0x8c4c,0x962e,
  0x9811,0x66f0,0x5f80,0x65fa, 0x6789,0x6c6a,0x738b,0x502d,
  0x5a03,0x6b6a,0x77ee,0x5916, 0x5d6c,0x5dcd,0x7325,0x754f,
  0xf9ba,0xf9bb,0x50e5,0x51f9, 0x582f,0x592d,0x5996,0x59da,
  0x5be5,0xf9bc,0xf9bd,0x5da2, 0x62d7,0x6416,0x6493,0x64fe,
  0xf9be,0x66dc,0xf9bf,0x6a48, 0xf9c0,0x71ff,0x7464,0xf9c1,
  0x7a88,0x7aaf,0x7e47,0x7e5e, 0x8000,0x8170,0xf9c2,0x87ef,
  0x8981,0x8b20,0x9059,0xf9c3, 0x9080,0x9952,0x617e,0x6b32,
  0x6d74,0x7e1f,0x8925,0x8fb1, 0x4fd1,0x50ad,0x5197,0x52c7,
  0x57c7,0x5889,0x5bb9,0x5eb8, 0x6142,0x6995,0x6d8c,0x6e67,
  0x6eb6,0x7194,0x7462,0x7528, 0x752c,0x8073,0x8338,0x84c9,
  0x8e0a,0x9394,0x93de,0xf9c4, 0x4e8e,0x4f51,0x5076,0x512a,
  0x53c8,0x53cb,0x53f3,0x5b87, 0x5bd3,0x5c24,0x611a,0x6182,
  0x65f4,0x725b,0x7397,0x7440, 0x76c2,0x7950,0x7991,0x79b9,
  0x7d06,0x7fbd,0x828b,0x85d5, 0x865e,0x8fc2,0x9047,0x90f5,
  0x91ea,0x9685,0x96e8,0x96e9, 0x52d6,0x5f67,0x65ed,0x6631,
  0x682f,0x715c,0x7a36,0x90c1, 0x980a,0x4e91,0xf9c5,0x6a52,
  0x6b9e,0x6f90,0x7189,0x8018, 0x82b8,0x8553,0x904b,0x9695,
  0x96f2,0x97fb,0x851a,0x9b31, 0x4e90,0x718a,0x96c4,0x5143,
  0x539f,0x54e1,0x5713,0x5712, 0x57a3,0x5a9b,0x5ac4,0x5bc3,
  0x6028,0x613f,0x63f4,0x6c85, 0x6d39,0x6e72,0x6e90,0x7230,
  0x733f,0x7457,0x82d1,0x8881, 0x8f45,0x9060,0xf9c6,0x9662,
  0x9858,0x9d1b,0x6708,0x8d8a, 0x925e,0x4f4d,0x5049,0x50de,
  0x5371,0x570d,0x59d4,0x5a01, 0x5c09,0x6170,0x6690,0x6e2d,
  0x7232,0x744b,0x7def,0x80c3, 0x840e,0x8466,0x853f,0x875f,
  0x885b,0x8918,0x8b02,0x9055, 0x97cb,0x9b4f,0x4e73,0x4f91,
  0x5112,0x516a,0xf9c7,0x552f, 0x55a9,0x5b7a,0x5ba5,0x5e7c,
  0x5e7d,0x5ebe,0x60a0,0x60df, 0x6108,0x6109,0x63c4,0x6538,
  0x6709,0xf9c8,0x67d4,0x67da, 0xf9c9,0x6961,0x6962,0x6cb9,
  0x6d27,0xf9ca,0x6e38,0xf9cb, 0x6fe1,0x7336,0x7337,0xf9cc,
  0x745c,0x7531,0xf9cd,0x7652, 0xf9ce,0xf9cf,0x7dad,0x81fe,
  0x8438,0x88d5,0x8a98,0x8adb, 0x8aed,0x8e30,0x8e42,0x904a,
  0x903e,0x907a,0x9149,0x91c9, 0x936e,0xf9d0,0xf9d1,0x5809,
  0xf9d2,0x6bd3,0x8089,0x80b2, 0xf9d3,0xf9d4,0x5141,0x596b,
  0x5c39,0xf9d5,0xf9d6,0x6f64, 0x73a7,0x80e4,0x8d07,0xf9d7,
  0x9217,0x958f,0xf9d8,0xf9d9, 0xf9da,0xf9db,0x807f,0x620e,
  0x701c,0x7d68,0x878d,0xf9dc, 0x57a0,0x6069,0x6147,0x6bb7,
  0x8abe,0x9280,0x96b1,0x4e59, 0x541f,0x6deb,0x852d,0x9670,
  0x97f3,0x98ee,0x63d6,0x6ce3, 0x9091,0x51dd,0x61c9,0x81ba,
  0x9df9,0x4f9d,0x501a,0x5100, 0x5b9c,0x610f,0x61ff,0x64ec,
  0x6905,0x6bc5,0x7591,0x77e3, 0x7fa9,0x8264,0x858f,0x87fb,
  0x8863,0x8abc,0x8b70,0x91ab, 0x4e8c,0x4ee5,0x4f0a,0xf9dd,
  0xf9de,0x5937,0x59e8,0xf9df, 0x5df2,0x5f1b,0x5f5b,0x6021,
  0xf9e0,0xf9e1,0xf9e2,0xf9e3, 0x723e,0x73e5,0xf9e4,0x7570,
  0x75cd,0xf9e5,0x79fb,0xf9e6, 0x800c,0x8033,0x8084,0x82e1,
  0x8351,0xf9e7,0xf9e8,0x8cbd, 0x8cb3,0x9087,0xf9e9,0xf9ea,
  0x98f4,0x990c,0xf9eb,0xf9ec, 0x7037,0x76ca,0x7fca,0x7fcc,
  0x7ffc,0x8b1a,0x4eba,0x4ec1, 0x5203,0x5370,0xf9ed,0x54bd,
  0x56e0,0x59fb,0x5bc5,0x5f15, 0x5fcd,0x6e6e,0xf9ee,0xf9ef,
  0x7d6a,0x8335,0xf9f0,0x8693, 0x8a8d,0xf9f1,0x976d,0x9777,
  0xf9f2,0xf9f3,0x4e00,0x4f5a, 0x4f7e,0x58f9,0x65e5,0x6ea2,
  0x9038,0x93b0,0x99b9,0x4efb, 0x58ec,0x598a,0x59d9,0x6041,
  0xf9f4,0xf9f5,0x7a14,0xf9f6, 0x834f,0x8cc3,0x5165,0x5344,
  0xf9f7,0xf9f8,0xf9f9,0x4ecd, 0x5269,0x5b55,0x82bf,0x4ed4,
  0x523a,0x54a8,0x59c9,0x59ff, 0x5b50,0x5b57,0x5b5c,0x6063,
  0x6148,0x6ecb,0x7099,0x716e, 0x7386,0x74f7,0x75b5,0x78c1,
  0x7d2b,0x8005,0x81ea,0x8328, 0x8517,0x85c9,0x8aee,0x8cc7,
  0x96cc,0x4f5c,0x52fa,0x56bc, 0x65ab,0x6628,0x707c,0x70b8,
  0x7235,0x7dbd,0x828d,0x914c, 0x96c0,0x9d72,0x5b71,0x68e7,
  0x6b98,0x6f7a,0x76de,0x5c91, 0x66ab,0x6f5b,0x7bb4,0x7c2a,
  0x8836,0x96dc,0x4e08,0x4ed7, 0x5320,0x5834,0x58bb,0x58ef,
  0x596c,0x5c07,0x5e33,0x5e84, 0x5f35,0x638c,0x66b2,0x6756,
  0x6a1f,0x6aa3,0x6b0c,0x6f3f, 0x7246,0xf9fa,0x7350,0x748b,
  0x7ae0,0x7ca7,0x8178,0x81df, 0x81e7,0x838a,0x846c,0x8523,
  0x8594,0x85cf,0x88dd,0x8d13, 0x91ac,0x9577,0x969c,0x518d,
  0x54c9,0x5728,0x5bb0,0x624d, 0x6750,0x683d,0x6893,0x6e3d,
  0x6ed3,0x707d,0x7e21,0x88c1, 0x8ca1,0x8f09,0x9f4b,0x9f4e,
  0x722d,0x7b8f,0x8acd,0x931a, 0x4f47,0x4f4e,0x5132,0x5480,
  0x59d0,0x5e95,0x62b5,0x6775, 0x696e,0x6a17,0x6cae,0x6e1a,
  0x72d9,0x732a,0x75bd,0x7bb8, 0x7d35,0x82e7,0x83f9,0x8457,
  0x85f7,0x8a5b,0x8caf,0x8e87, 0x9019,0x90b8,0x96ce,0x9f5f,
  0x52e3,0x540a,0x5ae1,0x5bc2, 0x6458,0x6575,0x6ef4,0x72c4,
  0xf9fb,0x7684,0x7a4d,0x7b1b, 0x7c4d,0x7e3e,0x7fdf,0x837b,
  0x8b2b,0x8cca,0x8d64,0x8de1, 0x8e5f,0x8fea,0x8ff9,0x9069,
  0x93d1,0x4f43,0x4f7a,0x50b3, 0x5168,0x5178,0x524d,0x526a,
  0x5861,0x587c,0x5960,0x5c08, 0x5c55,0x5edb,0x609b,0x6230,
  0x6813,0x6bbf,0x6c08,0x6fb1, 0x714e,0x7420,0x7530,0x7538,
  0x7551,0x7672,0x7b4c,0x7b8b, 0x7bad,0x7bc6,0x7e8f,0x8a6e,
  0x8f3e,0x8f49,0x923f,0x9293, 0x9322,0x942b,0x96fb,0x985a,
  0x986b,0x991e,0x5207,0x622a, 0x6298,0x6d59,0x7664,0x7aca,
  0x7bc0,0x7d76,0x5360,0x5cbe, 0x5e97,0x6f38,0x70b9,0x7c98,
  0x9711,0x9b8e,0x9ede,0x63a5, 0x647a,0x8776,0x4e01,0x4e95,
  0x4ead,0x505c,0x5075,0x5448, 0x59c3,0x5b9a,0x5e40,0x5ead,
  0x5ef7,0x5f81,0x60c5,0x633a, 0x653f,0x6574,0x65cc,0x6676,
  0x6678,0x67fe,0x6968,0x6a89, 0x6b63,0x6c40,0x6dc0,0x6de8,
  0x6e1f,0x6e5e,0x701e,0x70a1, 0x738e,0x73fd,0x753a,0x775b,
  0x7887,0x798e,0x7a0b,0x7a7d, 0x7cbe,0x7d8e,0x8247,0x8a02,
  0x8aea,0x8c9e,0x912d,0x914a, 0x91d8,0x9266,0x92cc,0x9320,
  0x9706,0x9756,0x975c,0x9802, 0x9f0e,0x5236,0x5291,0x557c,
  0x5824,0x5e1d,0x5f1f,0x608c, 0x63d0,0x68af,0x6fdf,0x796d,
  0x7b2c,0x81cd,0x85ba,0x88fd, 0x8af8,0x8e44,0x918d,0x9664,
  0x969b,0x973d,0x984c,0x9f4a, 0x4fce,0x5146,0x51cb,0x52a9,
  0x5632,0x5f14,0x5f6b,0x63aa, 0x64cd,0x65e9,0x6641,0x66fa,
  0x66f9,0x671d,0x689d,0x68d7, 0x69fd,0x6f15,0x6f6e,0x7167,
  0x71e5,0x722a,0x74aa,0x773a, 0x7956,0x795a,0x79df,0x7a20,
  0x7a95,0x7c97,0x7cdf,0x7d44, 0x7e70,0x8087,0x85fb,0x86a4,
  0x8a54,0x8abf,0x8d99,0x8e81, 0x9020,0x906d,0x91e3,0x963b,
  0x96d5,0x9ce5,0x65cf,0x7c07, 0x8db3,0x93c3,0x5b58,0x5c0a,
  0x5352,0x62d9,0x731d,0x5027, 0x5b97,0x5f9e,0x60b0,0x616b,
  0x68d5,0x6dd9,0x742e,0x7a2e, 0x7d42,0x7d9c,0x7e31,0x816b,
  0x8e2a,0x8e35,0x937e,0x9418, 0x4f50,0x5750,0x5de6,0x5ea7,
  0x632b,0x7f6a,0x4e3b,0x4f4f, 0x4f8f,0x505a,0x59dd,0x80c4,
  0x546a,0x5468,0x55fe,0x594f, 0x5b99,0x5dde,0x5eda,0x665d,
  0x6731,0x67f1,0x682a,0x6ce8, 0x6d32,0x6e4a,0x6f8d,0x70b7,
  0x73e0,0x7587,0x7c4c,0x7d02, 0x7d2c,0x7da2,0x821f,0x86db,
  0x8a3b,0x8a85,0x8d70,0x8e8a, 0x8f33,0x9031,0x914e,0x9152,
  0x9444,0x99d0,0x7af9,0x7ca5, 0x4fca,0x5101,0x51c6,0x57c8,
  0x5bef,0x5cfb,0x6659,0x6a3d, 0x6d5a,0x6e96,0x6fec,0x710c,
  0x756f,0x7ae3,0x8822,0x9021, 0x9075,0x96cb,0x99ff,0x8301,
  0x4e2d,0x4ef2,0x8846,0x91cd, 0x537d,0x6adb,0x696b,0x6c41,
  0x847a,0x589e,0x618e,0x66fe, 0x62ef,0x70dd,0x7511,0x75c7,
  0x7e52,0x84b8,0x8b49,0x8d08, 0x4e4b,0x53ea,0x54ab,0x5730,
  0x5740,0x5fd7,0x6301,0x6307, 0x646f,0x652f,0x65e8,0x667a,
  0x679d,0x67b3,0x6b62,0x6c60, 0x6c9a,0x6f2c,0x77e5,0x7825,
  0x7949,0x7957,0x7d19,0x80a2, 0x8102,0x81f3,0x829d,0x82b7,
  0x8718,0x8a8c,0xf9fc,0x8d04, 0x8dbe,0x9072,0x76f4,0x7a19,
  0x7a37,0x7e54,0x8077,0x5507, 0x55d4,0x5875,0x632f,0x6422,
  0x6649,0x664b,0x686d,0x699b, 0x6b84,0x6d25,0x6eb1,0x73cd,
  0x7468,0x74a1,0x755b,0x75b9, 0x76e1,0x771e,0x778b,0x79e6,
  0x7e09,0x7e1d,0x81fb,0x852f, 0x8897,0x8a3a,0x8cd1,0x8eeb,
  0x8fb0,0x9032,0x93ad,0x9663, 0x9673,0x9707,0x4f84,0x53f1,
  0x59ea,0x5ac9,0x5e19,0x684e, 0x74c6,0x75be,0x79e9,0x7a92,
  0x81a3,0x86ed,0x8cea,0x8dcc, 0x8fed,0x659f,0x6715,0xf9fd,
  0x57f7,0x6f57,0x7ddd,0x8f2f, 0x93f6,0x96c6,0x5fb5,0x61f2,
  0x6f84,0x4e14,0x4f98,0x501f, 0x53c9,0x55df,0x5d6f,0x5dee,
  0x6b21,0x6b64,0x78cb,0x7b9a, 0xf9fe,0x8e49,0x8eca,0x906e,
  0x6349,0x643e,0x7740,0x7a84, 0x932f,0x947f,0x9f6a,0x64b0,
  0x6faf,0x71e6,0x74a8,0x74da, 0x7ac4,0x7c12,0x7e82,0x7cb2,
  0x7e98,0x8b9a,0x8d0a,0x947d, 0x9910,0x994c,0x5239,0x5bdf,
  0x64e6,0x672d,0x7d2e,0x50ed, 0x53c3,0x5879,0x6158,0x6159,
  0x61fa,0x65ac,0x7ad9,0x8b92, 0x8b96,0x5009,0x5021,0x5275,
  0x5531,0x5a3c,0x5ee0,0x5f70, 0x6134,0x655e,0x660c,0x6636,
  0x66a2,0x69cd,0x6ec4,0x6f32, 0x7316,0x7621,0x7a93,0x8139,
  0x8259,0x83d6,0x84bc,0x50b5, 0x57f0,0x5bc0,0x5be8,0x5f69,
  0x63a1,0x7826,0x7db5,0x83dc, 0x8521,0x91c7,0x91f5,0x518a,
  0x67f5,0x7b56,0x8cac,0x51c4, 0x59bb,0x60bd,0x8655,0x501c,
  0xf9ff,0x5254,0x5c3a,0x617d, 0x621a,0x62d3,0x64f2,0x65a5,
  0x6ecc,0x7620,0x810a,0x8e60, 0x965f,0x96bb,0x4edf,0x5343,
  0x5598,0x5929,0x5ddd,0x64c5, 0x6cc9,0x6dfa,0x7394,0x7a7f,
  0x821b,0x85a6,0x8ce4,0x8e10, 0x9077,0x91e7,0x95e1,0x9621,
  0x97c6,0x51f8,0x54f2,0x5586, 0x5fb9,0x64a4,0x6f88,0x7db4,
  0x8f1f,0x8f4d,0x9435,0x50c9, 0x5c16,0x6cbe,0x6dfb,0x751b,
  0x77bb,0x7c3d,0x7c64,0x8a79, 0x8ac2,0x581e,0x59be,0x5e16,
  0x6377,0x7252,0x758a,0x776b, 0x8adc,0x8cbc,0x8f12,0x5ef3,
  0x6674,0x6df8,0x807d,0x83c1, 0x8acb,0x9751,0x9bd6,0xfa00,
  0x5243,0x66ff,0x6d95,0x6eef, 0x7de0,0x8ae6,0x902e,0x905e,
  0x9ad4,0x521d,0x527f,0x54e8, 0x6194,0x6284,0x62db,0x68a2,
  0x6912,0x695a,0x6a35,0x7092, 0x7126,0x785d,0x7901,0x790e,
  0x79d2,0x7a0d,0x8096,0x8278, 0x82d5,0x8349,0x8549,0x8c82,
  0x8d85,0x9162,0x918b,0x91ae, 0x4fc3,0x56d1,0x71ed,0x77d7,
  0x8700,0x89f8,0x5bf8,0x5fd6, 0x6751,0x90a8,0x53e2,0x585a,
  0x5bf5,0x60a4,0x6181,0x6460, 0x7e3d,0x8070,0x8525,0x9283,
  0x64ae,0x50ac,0x5d14,0x6700, 0x589c,0x62bd,0x63a8,0x690e,
  0x6978,0x6a1e,0x6e6b,0x76ba, 0x79cb,0x82bb,0x8429,0x8acf,
  0x8da8,0x8ffd,0x9112,0x914b, 0x919c,0x9310,0x9318,0x939a,
  0x96db,0x9a36,0x9c0d,0x4e11, 0x755c,0x795d,0x7afa,0x7b51,
  0x7bc9,0x7e2e,0x84c4,0x8e59, 0x8e74,0x8ef8,0x9010,0x6625,
  0x693f,0x7443,0x51fa,0x672e, 0x9edc,0x5145,0x5fe0,0x6c96,
  0x87f2,0x885d,0x8877,0x60b4, 0x81b5,0x8403,0x8d05,0x53d6,
  0x5439,0x5634,0x5a36,0x5c31, 0x708a,0x7fe0,0x805a,0x8106,
  0x81ed,0x8da3,0x9189,0x9a5f, 0x9df2,0x5074,0x4ec4,0x53a0,
  0x60fb,0x6e2c,0x5c64,0x4f88, 0x5024,0x55e4,0x5cd9,0x5e5f,
  0x6065,0x6894,0x6cbb,0x6dc4, 0x71be,0x75d4,0x75f4,0x7661,
  0x7a1a,0x7a49,0x7dc7,0x7dfb, 0x7f6e,0x81f4,0x86a9,0x8f1c,
  0x96c9,0x99b3,0x9f52,0x5247, 0x52c5,0x98ed,0x89aa,0x4e03,
  0x67d2,0x6f06,0x4fb5,0x5be2, 0x6795,0x6c88,0x6d78,0x741b,
  0x7827,0x91dd,0x937c,0x87c4, 0x79e4,0x7a31,0x5feb,0x4ed6,
  0x54a4,0x553e,0x58ae,0x59a5, 0x60f0,0x6253,0x62d6,0x6736,
  0x6955,0x8235,0x9640,0x99b1, 0x99dd,0x502c,0x5353,0x5544,
  0x577c,0xfa01,0x6258,0xfa02, 0x64e2,0x666b,0x67dd,0x6fc1,
  0x6fef,0x7422,0x7438,0x8a17, 0x9438,0x5451,0x5606,0x5766,
  0x5f48,0x619a,0x6b4e,0x7058, 0x70ad,0x7dbb,0x8a95,0x596a,
  0x812b,0x63a2,0x7708,0x803d, 0x8caa,0x5854,0x642d,0x69bb,
  0x5b95,0x5e11,0x6e6f,0xfa03, 0x8569,0x514c,0x53f0,0x592a,
  0x6020,0x614b,0x6b86,0x6c70, 0x6cf0,0x7b1e,0x80ce,0x82d4,
  0x8dc6,0x90b0,0x98b1,0xfa04, 0x64c7,0x6fa4,0x6491,0x6504,
  0x514e,0x5410,0x571f,0x8a0e, 0x615f,0x6876,0xfa05,0x75db,
  0x7b52,0x7d71,0x901a,0x5806, 0x69cc,0x817f,0x892a,0x9000,
  0x9839,0x5078,0x5957,0x59ac, 0x6295,0x900f,0x9b2a,0x615d,
  0x7279,0x95d6,0x5761,0x5a46, 0x5df4,0x628a,0x64ad,0x64fa,
  0x6777,0x6ce2,0x6d3e,0x722c, 0x7436,0x7834,0x7f77,0x82ad,
  0x8ddb,0x9817,0x5224,0x5742, 0x677f,0x7248,0x74e3,0x8ca9,
  0x8fa6,0x9211,0x962a,0x516b, 0x53ed,0x634c,0x4f69,0x5504,
  0x6096,0x6557,0x6c9b,0x6d7f, 0x724c,0x72fd,0x7a17,0x8987,
  0x8c9d,0x5f6d,0x6f8e,0x70f9, 0x81a8,0x610e,0x4fbf,0x504f,
  0x6241,0x7247,0x7bc7,0x7de8, 0x7fe9,0x904d,0x97ad,0x9a19,
  0x8cb6,0x576a,0x5e73,0x67b0, 0x840d,0x8a55,0x5420,0x5b16,
  0x5e63,0x5ee2,0x5f0a,0x6583, 0x80ba,0x853d,0x9589,0x965b,
  0x4f48,0x5305,0x530d,0x530f, 0x5486,0x54fa,0x5703,0x5e03,
  0x6016,0x629b,0x62b1,0x6355, 0xfa06,0x6ce1,0x6d66,0x75b1,
  0x7832,0x80de,0x812f,0x82de, 0x8461,0x84b2,0x888d,0x8912,
  0x900b,0x92ea,0x98fd,0x9b91, 0x5e45,0x66b4,0x66dd,0x7011,
  0x7206,0xfa07,0x4ff5,0x527d, 0x5f6a,0x6153,0x6753,0x6a19,
  0x6f02,0x74e2,0x7968,0x8868, 0x8c79,0x98c7,0x98c4,0x9a43,
  0x54c1,0x7a1f,0x6953,0x8af7, 0x8c4a,0x98a8,0x99ae,0x5f7c,
  0x62ab,0x75b2,0x76ae,0x88ab, 0x907f,0x9642,0x5339,0x5f3c,
  0x5fc5,0x6ccc,0x73cc,0x7562, 0x758b,0x7b46,0x82fe,0x999d,
  0x4e4f,0x903c,0x4e0b,0x4f55, 0x53a6,0x590f,0x5ec8,0x6630,
  0x6cb3,0x7455,0x8377,0x8766, 0x8cc0,0x9050,0x971e,0x9c15,
  0x58d1,0x5b78,0x8650,0x8b14, 0x9db4,0x5bd2,0x6068,0x608d,
  0x65f1,0x6c57,0x6f22,0x6fa3, 0x701a,0x7f55,0x7ff0,0x9591,
  0x9592,0x9650,0x97d3,0x5272, 0x8f44,0x51fd,0x542b,0x54b8,
  0x5563,0x558a,0x6abb,0x6db5, 0x7dd8,0x8266,0x929c,0x9677,
  0x9e79,0x5408,0x54c8,0x76d2, 0x86e4,0x95a4,0x95d4,0x965c,
  0x4ea2,0x4f09,0x59ee,0x5ae6, 0x5df7,0x6052,0x6297,0x676d,
  0x6841,0x6c86,0x6e2f,0x7f38, 0x809b,0x822a,0xfa08,0xfa09,
  0x9805,0x4ea5,0x5055,0x54b3, 0x5793,0x595a,0x5b69,0x5bb3,
  0x61c8,0x6977,0x6d77,0x7023, 0x87f9,0x89e3,0x8a72,0x8ae7,
  0x9082,0x99ed,0x9ab8,0x52be, 0x6838,0x5016,0x5e78,0x674f,
  0x8347,0x884c,0x4eab,0x5411, 0x56ae,0x73e6,0x9115,0x97ff,
  0x9909,0x9957,0x9999,0x5653, 0x589f,0x865b,0x8a31,0x61b2,
  0x6af6,0x737b,0x8ed2,0x6b47, 0x96aa,0x9a57,0x5955,0x7200,
  0x8d6b,0x9769,0x4fd4,0x5cf4, 0x5f26,0x61f8,0x665b,0x6ceb,
  0x70ab,0x7384,0x73b9,0x73fe, 0x7729,0x774d,0x7d43,0x7d62,
  0x7e23,0x8237,0x8852,0xfa0a, 0x8ce2,0x9249,0x986f,0x5b51,
  0x7a74,0x8840,0x9801,0x5acc, 0x4fe0,0x5354,0x593e,0x5cfd,
  0x633e,0x6d79,0x72f9,0x8105, 0x8107,0x83a2,0x92cf,0x9830,
  0x4ea8,0x5144,0x5211,0x578b, 0x5f62,0x6cc2,0x6ece,0x7005,
  0x7050,0x70af,0x7192,0x73e9, 0x7469,0x834a,0x87a2,0x8861,
  0x9008,0x90a2,0x93a3,0x99a8, 0x516e,0x5f57,0x60e0,0x6167,
  0x66b3,0x8559,0x8e4a,0x91af, 0x978b,0x4e4e,0x4e92,0x547c,
  0x58d5,0x58fa,0x597d,0x5cb5, 0x5f27,0x6236,0x6248,0x660a,
  0x6667,0x6beb,0x6d69,0x6dcf, 0x6e56,0x6ef8,0x6f94,0x6fe0,
  0x6fe9,0x705d,0x72d0,0x7425, 0x745a,0x74e0,0x7693,0x795c,
  0x7cca,0x7e1e,0x80e1,0x82a6, 0x846b,0x84bf,0x864e,0x865f,
  0x8774,0x8b77,0x8c6a,0x93ac, 0x9800,0x9865,0x60d1,0x6216,
  0x9177,0x5a5a,0x660f,0x6df7, 0x6e3e,0x743f,0x9b42,0x5ffd,
  0x60da,0x7b0f,0x54c4,0x5f18, 0x6c5e,0x6cd3,0x6d2a,0x70d8,
  0x7d05,0x8679,0x8a0c,0x9d3b, 0x5316,0x548c,0x5b05,0x6a3a,
  0x706b,0x7575,0x798d,0x79be, 0x82b1,0x83ef,0x8a71,0x8b41,
  0x8ca8,0x9774,0xfa0b,0x64f4, 0x652b,0x78ba,0x78bb,0x7a6b,
  0x4e38,0x559a,0x5950,0x5ba6, 0x5e7b,0x60a3,0x63db,0x6b61,
  0x6665,0x6853,0x6e19,0x7165, 0x74b0,0x7d08,0x9084,0x9a69,
  0x9c25,0x6d3b,0x6ed1,0x733e, 0x8c41,0x95ca,0x51f0,0x5e4c,
  0x5fa8,0x604d,0x60f6,0x6130, 0x614c,0x6643,0x6644,0x69a5,
  0x6cc1,0x6e5f,0x6ec9,0x6f62, 0x714c,0x749c,0x7687,0x7bc1,
  0x7c27,0x8352,0x8757,0x9051, 0x968d,0x9ec3,0x532f,0x56de,
  0x5efb,0x5f8a,0x6062,0x6094, 0x61f7,0x6666,0x6703,0x6a9c,
  0x6dee,0x6fae,0x7070,0x736a, 0x7e6a,0x81be,0x8334,0x86d4,
  0x8aa8,0x8cc4,0x5283,0x7372, 0x5b96,0x6a6b,0x9404,0x54ee,
  0x5686,0x5b5d,0x6548,0x6585, 0x66c9,0x689f,0x6d8d,0x6dc6,
  0x723b,0x80b4,0x9175,0x9a4d, 0x4faf,0x5019,0x539a,0x540e,
  0x543c,0x5589,0x55c5,0x5e3f, 0x5f8c,0x673d,0x7166,0x73dd,
  0x9005,0x52db,0x52f3,0x5864, 0x58ce,0x7104,0x718f,0x71fb,
  0x85b0,0x8a13,0x6688,0x85a8, 0x55a7,0x6684,0x714a,0x8431,
  0x5349,0x5599,0x6bc1,0x5f59, 0x5fbd,0x63ee,0x6689,0x7147,
  0x8af1,0x8f1d,0x9ebe,0x4f11, 0x643a,0x70cb,0x7566,0x8667,
  0x6064,0x8b4e,0x9df8,0x5147, 0x51f6,0x5308,0x6d36,0x80f8,
  0x9ed1,0x6615,0x6b23,0x7098, 0x75d5,0x5403,0x5c79,0x7d07,
  0x8a16,0x6b20,0x6b3d,0x6b46, 0x5438,0x6070,0x6d3d,0x7fd5,
  0x8208,0x50d6,0x51de,0x559c, 0x566b,0x56cd,0x59ec,0x5b09,
  0x5e0c,0x6199,0x6198,0x6231, 0x665e,0x66e6,0x7199,0x71b9,
  0x71ba,0x72a7,0x79a7,0x7a00, 0x7fb2,0x8a70,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000
  };

unsigned short cp949_uni_byte[BIG5P_TBL_LEN] = {
/* 0x8100 */
  0x0000,0xac02,0xac03,0xac05,0xac06,0xac0b,0xac0c,0xac0d,
  0xac0e,0xac0f,0xac18,0xac1e,0xac1f,0xac21,0xac22,0xac23,
  0xac25,0xac26,0xac27,0xac28,0xac29,0xac2a,0xac2b,0xac2e,
  0xac32,0xac33,0xac34,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xac35,0xac36,0xac37,0xac3a,0xac3b,0xac3d,0xac3e,
  0xac3f,0xac41,0xac42,0xac43,0xac44,0xac45,0xac46,0xac47,
  0xac48,0xac49,0xac4a,0xac4c,0xac4e,0xac4f,0xac50,0xac51,
  0xac52,0xac53,0xac55,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xac56,0xac57,0xac59,0xac5a,0xac5b,0xac5d,0xac5e,0xac5f,
  0xac60,0xac61,0xac62,0xac63,0xac64,0xac65,0xac66,0xac67,
  0xac68,0xac69,0xac6a,0xac6b,0xac6c,0xac6d,0xac6e,0xac6f,
  0xac72,0xac73,0xac75,0xac76,0xac79,0xac7b,0xac7c,0xac7d,
  0xac7e,0xac7f,0xac82,0xac87,0xac88,0xac8d,0xac8e,0xac8f,
  0xac91,0xac92,0xac93,0xac95,0xac96,0xac97,0xac98,0xac99,
  0xac9a,0xac9b,0xac9e,0xaca2,0xaca3,0xaca4,0xaca5,0xaca6,
  0xaca7,0xacab,0xacad,0xacae,0xacb1,0xacb2,0xacb3,0xacb4,
  0xacb5,0xacb6,0xacb7,0xacba,0xacbe,0xacbf,0xacc0,0xacc2,
  0xacc3,0xacc5,0xacc6,0xacc7,0xacc9,0xacca,0xaccb,0xaccd,
  0xacce,0xaccf,0xacd0,0xacd1,0xacd2,0xacd3,0xacd4,0xacd6,
  0xacd8,0xacd9,0xacda,0xacdb,0xacdc,0xacdd,0xacde,0xacdf,
  0xace2,0xace3,0xace5,0xace6,0xace9,0xaceb,0xaced,0xacee,
  0xacf2,0xacf4,0xacf7,0xacf8,0xacf9,0xacfa,0xacfb,0xacfe,
  0xacff,0xad01,0xad02,0xad03,0xad05,0xad07,0xad08,0xad09,
  0xad0a,0xad0b,0xad0e,0xad10,0xad12,0xad13,
/* 0x8200 */
  0x0000,0xad14,0xad15,0xad16,0xad17,0xad19,0xad1a,0xad1b,
  0xad1d,0xad1e,0xad1f,0xad21,0xad22,0xad23,0xad24,0xad25,
  0xad26,0xad27,0xad28,0xad2a,0xad2b,0xad2e,0xad2f,0xad30,
  0xad31,0xad32,0xad33,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xad36,0xad37,0xad39,0xad3a,0xad3b,0xad3d,0xad3e,
  0xad3f,0xad40,0xad41,0xad42,0xad43,0xad46,0xad48,0xad4a,
  0xad4b,0xad4c,0xad4d,0xad4e,0xad4f,0xad51,0xad52,0xad53,
  0xad55,0xad56,0xad57,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xad59,0xad5a,0xad5b,0xad5c,0xad5d,0xad5e,0xad5f,0xad60,
  0xad62,0xad64,0xad65,0xad66,0xad67,0xad68,0xad69,0xad6a,
  0xad6b,0xad6e,0xad6f,0xad71,0xad72,0xad77,0xad78,0xad79,
  0xad7a,0xad7e,0xad80,0xad83,0xad84,0xad85,0xad86,0xad87,
  0xad8a,0xad8b,0xad8d,0xad8e,0xad8f,0xad91,0xad92,0xad93,
  0xad94,0xad95,0xad96,0xad97,0xad98,0xad99,0xad9a,0xad9b,
  0xad9e,0xad9f,0xada0,0xada1,0xada2,0xada3,0xada5,0xada6,
  0xada7,0xada8,0xada9,0xadaa,0xadab,0xadac,0xadad,0xadae,
  0xadaf,0xadb0,0xadb1,0xadb2,0xadb3,0xadb4,0xadb5,0xadb6,
  0xadb8,0xadb9,0xadba,0xadbb,0xadbc,0xadbd,0xadbe,0xadbf,
  0xadc2,0xadc3,0xadc5,0xadc6,0xadc7,0xadc9,0xadca,0xadcb,
  0xadcc,0xadcd,0xadce,0xadcf,0xadd2,0xadd4,0xadd5,0xadd6,
  0xadd7,0xadd8,0xadd9,0xadda,0xaddb,0xaddd,0xadde,0xaddf,
  0xade1,0xade2,0xade3,0xade5,0xade6,0xade7,0xade8,0xade9,
  0xadea,0xadeb,0xadec,0xaded,0xadee,0xadef,0xadf0,0xadf1,
  0xadf2,0xadf3,0xadf4,0xadf5,0xadf6,0xadf7,
/* 0x8300 */
  0x0000,0xadfa,0xadfb,0xadfd,0xadfe,0xae02,0xae03,0xae04,
  0xae05,0xae06,0xae07,0xae0a,0xae0c,0xae0e,0xae0f,0xae10,
  0xae11,0xae12,0xae13,0xae15,0xae16,0xae17,0xae18,0xae19,
  0xae1a,0xae1b,0xae1c,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xae1d,0xae1e,0xae1f,0xae20,0xae21,0xae22,0xae23,
  0xae24,0xae25,0xae26,0xae27,0xae28,0xae29,0xae2a,0xae2b,
  0xae2c,0xae2d,0xae2e,0xae2f,0xae32,0xae33,0xae35,0xae36,
  0xae39,0xae3b,0xae3c,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xae3d,0xae3e,0xae3f,0xae42,0xae44,0xae47,0xae48,0xae49,
  0xae4b,0xae4f,0xae51,0xae52,0xae53,0xae55,0xae57,0xae58,
  0xae59,0xae5a,0xae5b,0xae5e,0xae62,0xae63,0xae64,0xae66,
  0xae67,0xae6a,0xae6b,0xae6d,0xae6e,0xae6f,0xae71,0xae72,
  0xae73,0xae74,0xae75,0xae76,0xae77,0xae7a,0xae7e,0xae7f,
  0xae80,0xae81,0xae82,0xae83,0xae86,0xae87,0xae88,0xae89,
  0xae8a,0xae8b,0xae8d,0xae8e,0xae8f,0xae90,0xae91,0xae92,
  0xae93,0xae94,0xae95,0xae96,0xae97,0xae98,0xae99,0xae9a,
  0xae9b,0xae9c,0xae9d,0xae9e,0xae9f,0xaea0,0xaea1,0xaea2,
  0xaea3,0xaea4,0xaea5,0xaea6,0xaea7,0xaea8,0xaea9,0xaeaa,
  0xaeab,0xaeac,0xaead,0xaeae,0xaeaf,0xaeb0,0xaeb1,0xaeb2,
  0xaeb3,0xaeb4,0xaeb5,0xaeb6,0xaeb7,0xaeb8,0xaeb9,0xaeba,
  0xaebb,0xaebf,0xaec1,0xaec2,0xaec3,0xaec5,0xaec6,0xaec7,
  0xaec8,0xaec9,0xaeca,0xaecb,0xaece,0xaed2,0xaed3,0xaed4,
  0xaed5,0xaed6,0xaed7,0xaeda,0xaedb,0xaedd,0xaede,0xaedf,
  0xaee0,0xaee1,0xaee2,0xaee3,0xaee4,0xaee5,
/* 0x8400 */
  0x0000,0xaee6,0xaee7,0xaee9,0xaeea,0xaeec,0xaeee,0xaeef,
  0xaef0,0xaef1,0xaef2,0xaef3,0xaef5,0xaef6,0xaef7,0xaef9,
  0xaefa,0xaefb,0xaefd,0xaefe,0xaeff,0xaf00,0xaf01,0xaf02,
  0xaf03,0xaf04,0xaf05,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xaf06,0xaf09,0xaf0a,0xaf0b,0xaf0c,0xaf0e,0xaf0f,
  0xaf11,0xaf12,0xaf13,0xaf14,0xaf15,0xaf16,0xaf17,0xaf18,
  0xaf19,0xaf1a,0xaf1b,0xaf1c,0xaf1d,0xaf1e,0xaf1f,0xaf20,
  0xaf21,0xaf22,0xaf23,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xaf24,0xaf25,0xaf26,0xaf27,0xaf28,0xaf29,0xaf2a,0xaf2b,
  0xaf2e,0xaf2f,0xaf31,0xaf33,0xaf35,0xaf36,0xaf37,0xaf38,
  0xaf39,0xaf3a,0xaf3b,0xaf3e,0xaf40,0xaf44,0xaf45,0xaf46,
  0xaf47,0xaf4a,0xaf4b,0xaf4c,0xaf4d,0xaf4e,0xaf4f,0xaf51,
  0xaf52,0xaf53,0xaf54,0xaf55,0xaf56,0xaf57,0xaf58,0xaf59,
  0xaf5a,0xaf5b,0xaf5e,0xaf5f,0xaf60,0xaf61,0xaf62,0xaf63,
  0xaf66,0xaf67,0xaf68,0xaf69,0xaf6a,0xaf6b,0xaf6c,0xaf6d,
  0xaf6e,0xaf6f,0xaf70,0xaf71,0xaf72,0xaf73,0xaf74,0xaf75,
  0xaf76,0xaf77,0xaf78,0xaf7a,0xaf7b,0xaf7c,0xaf7d,0xaf7e,
  0xaf7f,0xaf81,0xaf82,0xaf83,0xaf85,0xaf86,0xaf87,0xaf89,
  0xaf8a,0xaf8b,0xaf8c,0xaf8d,0xaf8e,0xaf8f,0xaf92,0xaf93,
  0xaf94,0xaf96,0xaf97,0xaf98,0xaf99,0xaf9a,0xaf9b,0xaf9d,
  0xaf9e,0xaf9f,0xafa0,0xafa1,0xafa2,0xafa3,0xafa4,0xafa5,
  0xafa6,0xafa7,0xafa8,0xafa9,0xafaa,0xafab,0xafac,0xafad,
  0xafae,0xafaf,0xafb0,0xafb1,0xafb2,0xafb3,0xafb4,0xafb5,
  0xafb6,0xafb7,0xafba,0xafbb,0xafbd,0xafbe,
/* 0x8500 */
  0x0000,0xafbf,0xafc1,0xafc2,0xafc3,0xafc4,0xafc5,0xafc6,
  0xafca,0xafcc,0xafcf,0xafd0,0xafd1,0xafd2,0xafd3,0xafd5,
  0xafd6,0xafd7,0xafd8,0xafd9,0xafda,0xafdb,0xafdd,0xafde,
  0xafdf,0xafe0,0xafe1,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xafe2,0xafe3,0xafe4,0xafe5,0xafe6,0xafe7,0xafea,
  0xafeb,0xafec,0xafed,0xafee,0xafef,0xaff2,0xaff3,0xaff5,
  0xaff6,0xaff7,0xaff9,0xaffa,0xaffb,0xaffc,0xaffd,0xaffe,
  0xafff,0xb002,0xb003,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xb005,0xb006,0xb007,0xb008,0xb009,0xb00a,0xb00b,0xb00d,
  0xb00e,0xb00f,0xb011,0xb012,0xb013,0xb015,0xb016,0xb017,
  0xb018,0xb019,0xb01a,0xb01b,0xb01e,0xb01f,0xb020,0xb021,
  0xb022,0xb023,0xb024,0xb025,0xb026,0xb027,0xb029,0xb02a,
  0xb02b,0xb02c,0xb02d,0xb02e,0xb02f,0xb030,0xb031,0xb032,
  0xb033,0xb034,0xb035,0xb036,0xb037,0xb038,0xb039,0xb03a,
  0xb03b,0xb03c,0xb03d,0xb03e,0xb03f,0xb040,0xb041,0xb042,
  0xb043,0xb046,0xb047,0xb049,0xb04b,0xb04d,0xb04f,0xb050,
  0xb051,0xb052,0xb056,0xb058,0xb05a,0xb05b,0xb05c,0xb05e,
  0xb05f,0xb060,0xb061,0xb062,0xb063,0xb064,0xb065,0xb066,
  0xb067,0xb068,0xb069,0xb06a,0xb06b,0xb06c,0xb06d,0xb06e,
  0xb06f,0xb070,0xb071,0xb072,0xb073,0xb074,0xb075,0xb076,
  0xb077,0xb078,0xb079,0xb07a,0xb07b,0xb07e,0xb07f,0xb081,
  0xb082,0xb083,0xb085,0xb086,0xb087,0xb088,0xb089,0xb08a,
  0xb08b,0xb08e,0xb090,0xb092,0xb093,0xb094,0xb095,0xb096,
  0xb097,0xb09b,0xb09d,0xb09e,0xb0a3,0xb0a4,
/* 0x8600 */
  0x0000,0xb0a5,0xb0a6,0xb0a7,0xb0aa,0xb0b0,0xb0b2,0xb0b6,
  0xb0b7,0xb0b9,0xb0ba,0xb0bb,0xb0bd,0xb0be,0xb0bf,0xb0c0,
  0xb0c1,0xb0c2,0xb0c3,0xb0c6,0xb0ca,0xb0cb,0xb0cc,0xb0cd,
  0xb0ce,0xb0cf,0xb0d2,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xb0d3,0xb0d5,0xb0d6,0xb0d7,0xb0d9,0xb0da,0xb0db,
  0xb0dc,0xb0dd,0xb0de,0xb0df,0xb0e1,0xb0e2,0xb0e3,0xb0e4,
  0xb0e6,0xb0e7,0xb0e8,0xb0e9,0xb0ea,0xb0eb,0xb0ec,0xb0ed,
  0xb0ee,0xb0ef,0xb0f0,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xb0f1,0xb0f2,0xb0f3,0xb0f4,0xb0f5,0xb0f6,0xb0f7,0xb0f8,
  0xb0f9,0xb0fa,0xb0fb,0xb0fc,0xb0fd,0xb0fe,0xb0ff,0xb100,
  0xb101,0xb102,0xb103,0xb104,0xb105,0xb106,0xb107,0xb10a,
  0xb10d,0xb10e,0xb10f,0xb111,0xb114,0xb115,0xb116,0xb117,
  0xb11a,0xb11e,0xb11f,0xb120,0xb121,0xb122,0xb126,0xb127,
  0xb129,0xb12a,0xb12b,0xb12d,0xb12e,0xb12f,0xb130,0xb131,
  0xb132,0xb133,0xb136,0xb13a,0xb13b,0xb13c,0xb13d,0xb13e,
  0xb13f,0xb142,0xb143,0xb145,0xb146,0xb147,0xb149,0xb14a,
  0xb14b,0xb14c,0xb14d,0xb14e,0xb14f,0xb152,0xb153,0xb156,
  0xb157,0xb159,0xb15a,0xb15b,0xb15d,0xb15e,0xb15f,0xb161,
  0xb162,0xb163,0xb164,0xb165,0xb166,0xb167,0xb168,0xb169,
  0xb16a,0xb16b,0xb16c,0xb16d,0xb16e,0xb16f,0xb170,0xb171,
  0xb172,0xb173,0xb174,0xb175,0xb176,0xb177,0xb17a,0xb17b,
  0xb17d,0xb17e,0xb17f,0xb181,0xb183,0xb184,0xb185,0xb186,
  0xb187,0xb18a,0xb18c,0xb18e,0xb18f,0xb190,0xb191,0xb195,
  0xb196,0xb197,0xb199,0xb19a,0xb19b,0xb19d,
/* 0x8700 */
  0x0000,0xb19e,0xb19f,0xb1a0,0xb1a1,0xb1a2,0xb1a3,0xb1a4,
  0xb1a5,0xb1a6,0xb1a7,0xb1a9,0xb1aa,0xb1ab,0xb1ac,0xb1ad,
  0xb1ae,0xb1af,0xb1b0,0xb1b1,0xb1b2,0xb1b3,0xb1b4,0xb1b5,
  0xb1b6,0xb1b7,0xb1b8,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xb1b9,0xb1ba,0xb1bb,0xb1bc,0xb1bd,0xb1be,0xb1bf,
  0xb1c0,0xb1c1,0xb1c2,0xb1c3,0xb1c4,0xb1c5,0xb1c6,0xb1c7,
  0xb1c8,0xb1c9,0xb1ca,0xb1cb,0xb1cd,0xb1ce,0xb1cf,0xb1d1,
  0xb1d2,0xb1d3,0xb1d5,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xb1d6,0xb1d7,0xb1d8,0xb1d9,0xb1da,0xb1db,0xb1de,0xb1e0,
  0xb1e1,0xb1e2,0xb1e3,0xb1e4,0xb1e5,0xb1e6,0xb1e7,0xb1ea,
  0xb1eb,0xb1ed,0xb1ee,0xb1ef,0xb1f1,0xb1f2,0xb1f3,0xb1f4,
  0xb1f5,0xb1f6,0xb1f7,0xb1f8,0xb1fa,0xb1fc,0xb1fe,0xb1ff,
  0xb200,0xb201,0xb202,0xb203,0xb206,0xb207,0xb209,0xb20a,
  0xb20d,0xb20e,0xb20f,0xb210,0xb211,0xb212,0xb213,0xb216,
  0xb218,0xb21a,0xb21b,0xb21c,0xb21d,0xb21e,0xb21f,0xb221,
  0xb222,0xb223,0xb224,0xb225,0xb226,0xb227,0xb228,0xb229,
  0xb22a,0xb22b,0xb22c,0xb22d,0xb22e,0xb22f,0xb230,0xb231,
  0xb232,0xb233,0xb235,0xb236,0xb237,0xb238,0xb239,0xb23a,
  0xb23b,0xb23d,0xb23e,0xb23f,0xb240,0xb241,0xb242,0xb243,
  0xb244,0xb245,0xb246,0xb247,0xb248,0xb249,0xb24a,0xb24b,
  0xb24c,0xb24d,0xb24e,0xb24f,0xb250,0xb251,0xb252,0xb253,
  0xb254,0xb255,0xb256,0xb257,0xb259,0xb25a,0xb25b,0xb25d,
  0xb25e,0xb25f,0xb261,0xb262,0xb263,0xb264,0xb265,0xb266,
  0xb267,0xb26a,0xb26b,0xb26c,0xb26d,0xb26e,
/* 0x8800 */
  0x0000,0xb26f,0xb270,0xb271,0xb272,0xb273,0xb276,0xb277,
  0xb278,0xb279,0xb27a,0xb27b,0xb27d,0xb27e,0xb27f,0xb280,
  0xb281,0xb282,0xb283,0xb286,0xb287,0xb288,0xb28a,0xb28b,
  0xb28c,0xb28d,0xb28e,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xb28f,0xb292,0xb293,0xb295,0xb296,0xb297,0xb29b,
  0xb29c,0xb29d,0xb29e,0xb29f,0xb2a2,0xb2a4,0xb2a7,0xb2a8,
  0xb2a9,0xb2ab,0xb2ad,0xb2ae,0xb2af,0xb2b1,0xb2b2,0xb2b3,
  0xb2b5,0xb2b6,0xb2b7,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xb2b8,0xb2b9,0xb2ba,0xb2bb,0xb2bc,0xb2bd,0xb2be,0xb2bf,
  0xb2c0,0xb2c1,0xb2c2,0xb2c3,0xb2c4,0xb2c5,0xb2c6,0xb2c7,
  0xb2ca,0xb2cb,0xb2cd,0xb2ce,0xb2cf,0xb2d1,0xb2d3,0xb2d4,
  0xb2d5,0xb2d6,0xb2d7,0xb2da,0xb2dc,0xb2de,0xb2df,0xb2e0,
  0xb2e1,0xb2e3,0xb2e7,0xb2e9,0xb2ea,0xb2f0,0xb2f1,0xb2f2,
  0xb2f6,0xb2fc,0xb2fd,0xb2fe,0xb302,0xb303,0xb305,0xb306,
  0xb307,0xb309,0xb30a,0xb30b,0xb30c,0xb30d,0xb30e,0xb30f,
  0xb312,0xb316,0xb317,0xb318,0xb319,0xb31a,0xb31b,0xb31d,
  0xb31e,0xb31f,0xb320,0xb321,0xb322,0xb323,0xb324,0xb325,
  0xb326,0xb327,0xb328,0xb329,0xb32a,0xb32b,0xb32c,0xb32d,
  0xb32e,0xb32f,0xb330,0xb331,0xb332,0xb333,0xb334,0xb335,
  0xb336,0xb337,0xb338,0xb339,0xb33a,0xb33b,0xb33c,0xb33d,
  0xb33e,0xb33f,0xb340,0xb341,0xb342,0xb343,0xb344,0xb345,
  0xb346,0xb347,0xb348,0xb349,0xb34a,0xb34b,0xb34c,0xb34d,
  0xb34e,0xb34f,0xb350,0xb351,0xb352,0xb353,0xb357,0xb359,
  0xb35a,0xb35d,0xb360,0xb361,0xb362,0xb363,
/* 0x8900 */
  0x0000,0xb366,0xb368,0xb36a,0xb36c,0xb36d,0xb36f,0xb372,
  0xb373,0xb375,0xb376,0xb377,0xb379,0xb37a,0xb37b,0xb37c,
  0xb37d,0xb37e,0xb37f,0xb382,0xb386,0xb387,0xb388,0xb389,
  0xb38a,0xb38b,0xb38d,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xb38e,0xb38f,0xb391,0xb392,0xb393,0xb395,0xb396,
  0xb397,0xb398,0xb399,0xb39a,0xb39b,0xb39c,0xb39d,0xb39e,
  0xb39f,0xb3a2,0xb3a3,0xb3a4,0xb3a5,0xb3a6,0xb3a7,0xb3a9,
  0xb3aa,0xb3ab,0xb3ad,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xb3ae,0xb3af,0xb3b0,0xb3b1,0xb3b2,0xb3b3,0xb3b4,0xb3b5,
  0xb3b6,0xb3b7,0xb3b8,0xb3b9,0xb3ba,0xb3bb,0xb3bc,0xb3bd,
  0xb3be,0xb3bf,0xb3c0,0xb3c1,0xb3c2,0xb3c3,0xb3c6,0xb3c7,
  0xb3c9,0xb3ca,0xb3cd,0xb3cf,0xb3d1,0xb3d2,0xb3d3,0xb3d6,
  0xb3d8,0xb3da,0xb3dc,0xb3de,0xb3df,0xb3e1,0xb3e2,0xb3e3,
  0xb3e5,0xb3e6,0xb3e7,0xb3e9,0xb3ea,0xb3eb,0xb3ec,0xb3ed,
  0xb3ee,0xb3ef,0xb3f0,0xb3f1,0xb3f2,0xb3f3,0xb3f4,0xb3f5,
  0xb3f6,0xb3f7,0xb3f8,0xb3f9,0xb3fa,0xb3fb,0xb3fd,0xb3fe,
  0xb3ff,0xb400,0xb401,0xb402,0xb403,0xb404,0xb405,0xb406,
  0xb407,0xb408,0xb409,0xb40a,0xb40b,0xb40c,0xb40d,0xb40e,
  0xb40f,0xb411,0xb412,0xb413,0xb414,0xb415,0xb416,0xb417,
  0xb419,0xb41a,0xb41b,0xb41d,0xb41e,0xb41f,0xb421,0xb422,
  0xb423,0xb424,0xb425,0xb426,0xb427,0xb42a,0xb42c,0xb42d,
  0xb42e,0xb42f,0xb430,0xb431,0xb432,0xb433,0xb435,0xb436,
  0xb437,0xb438,0xb439,0xb43a,0xb43b,0xb43c,0xb43d,0xb43e,
  0xb43f,0xb440,0xb441,0xb442,0xb443,0xb444,
/* 0x8a00 */
  0x0000,0xb445,0xb446,0xb447,0xb448,0xb449,0xb44a,0xb44b,
  0xb44c,0xb44d,0xb44e,0xb44f,0xb452,0xb453,0xb455,0xb456,
  0xb457,0xb459,0xb45a,0xb45b,0xb45c,0xb45d,0xb45e,0xb45f,
  0xb462,0xb464,0xb466,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xb467,0xb468,0xb469,0xb46a,0xb46b,0xb46d,0xb46e,
  0xb46f,0xb470,0xb471,0xb472,0xb473,0xb474,0xb475,0xb476,
  0xb477,0xb478,0xb479,0xb47a,0xb47b,0xb47c,0xb47d,0xb47e,
  0xb47f,0xb481,0xb482,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xb483,0xb484,0xb485,0xb486,0xb487,0xb489,0xb48a,0xb48b,
  0xb48c,0xb48d,0xb48e,0xb48f,0xb490,0xb491,0xb492,0xb493,
  0xb494,0xb495,0xb496,0xb497,0xb498,0xb499,0xb49a,0xb49b,
  0xb49c,0xb49e,0xb49f,0xb4a0,0xb4a1,0xb4a2,0xb4a3,0xb4a5,
  0xb4a6,0xb4a7,0xb4a9,0xb4aa,0xb4ab,0xb4ad,0xb4ae,0xb4af,
  0xb4b0,0xb4b1,0xb4b2,0xb4b3,0xb4b4,0xb4b6,0xb4b8,0xb4ba,
  0xb4bb,0xb4bc,0xb4bd,0xb4be,0xb4bf,0xb4c1,0xb4c2,0xb4c3,
  0xb4c5,0xb4c6,0xb4c7,0xb4c9,0xb4ca,0xb4cb,0xb4cc,0xb4cd,
  0xb4ce,0xb4cf,0xb4d1,0xb4d2,0xb4d3,0xb4d4,0xb4d6,0xb4d7,
  0xb4d8,0xb4d9,0xb4da,0xb4db,0xb4de,0xb4df,0xb4e1,0xb4e2,
  0xb4e5,0xb4e7,0xb4e8,0xb4e9,0xb4ea,0xb4eb,0xb4ee,0xb4f0,
  0xb4f2,0xb4f3,0xb4f4,0xb4f5,0xb4f6,0xb4f7,0xb4f9,0xb4fa,
  0xb4fb,0xb4fc,0xb4fd,0xb4fe,0xb4ff,0xb500,0xb501,0xb502,
  0xb503,0xb504,0xb505,0xb506,0xb507,0xb508,0xb509,0xb50a,
  0xb50b,0xb50c,0xb50d,0xb50e,0xb50f,0xb510,0xb511,0xb512,
  0xb513,0xb516,0xb517,0xb519,0xb51a,0xb51d,
/* 0x8b00 */
  0x0000,0xb51e,0xb51f,0xb520,0xb521,0xb522,0xb523,0xb526,
  0xb52b,0xb52c,0xb52d,0xb52e,0xb52f,0xb532,0xb533,0xb535,
  0xb536,0xb537,0xb539,0xb53a,0xb53b,0xb53c,0xb53d,0xb53e,
  0xb53f,0xb542,0xb546,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xb547,0xb548,0xb549,0xb54a,0xb54e,0xb54f,0xb551,
  0xb552,0xb553,0xb555,0xb556,0xb557,0xb558,0xb559,0xb55a,
  0xb55b,0xb55e,0xb562,0xb563,0xb564,0xb565,0xb566,0xb567,
  0xb568,0xb569,0xb56a,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xb56b,0xb56c,0xb56d,0xb56e,0xb56f,0xb570,0xb571,0xb572,
  0xb573,0xb574,0xb575,0xb576,0xb577,0xb578,0xb579,0xb57a,
  0xb57b,0xb57c,0xb57d,0xb57e,0xb57f,0xb580,0xb581,0xb582,
  0xb583,0xb584,0xb585,0xb586,0xb587,0xb588,0xb589,0xb58a,
  0xb58b,0xb58c,0xb58d,0xb58e,0xb58f,0xb590,0xb591,0xb592,
  0xb593,0xb594,0xb595,0xb596,0xb597,0xb598,0xb599,0xb59a,
  0xb59b,0xb59c,0xb59d,0xb59e,0xb59f,0xb5a2,0xb5a3,0xb5a5,
  0xb5a6,0xb5a7,0xb5a9,0xb5ac,0xb5ad,0xb5ae,0xb5af,0xb5b2,
  0xb5b6,0xb5b7,0xb5b8,0xb5b9,0xb5ba,0xb5be,0xb5bf,0xb5c1,
  0xb5c2,0xb5c3,0xb5c5,0xb5c6,0xb5c7,0xb5c8,0xb5c9,0xb5ca,
  0xb5cb,0xb5ce,0xb5d2,0xb5d3,0xb5d4,0xb5d5,0xb5d6,0xb5d7,
  0xb5d9,0xb5da,0xb5db,0xb5dc,0xb5dd,0xb5de,0xb5df,0xb5e0,
  0xb5e1,0xb5e2,0xb5e3,0xb5e4,0xb5e5,0xb5e6,0xb5e7,0xb5e8,
  0xb5e9,0xb5ea,0xb5eb,0xb5ed,0xb5ee,0xb5ef,0xb5f0,0xb5f1,
  0xb5f2,0xb5f3,0xb5f4,0xb5f5,0xb5f6,0xb5f7,0xb5f8,0xb5f9,
  0xb5fa,0xb5fb,0xb5fc,0xb5fd,0xb5fe,0xb5ff,
/* 0x8c00 */
  0x0000,0xb600,0xb601,0xb602,0xb603,0xb604,0xb605,0xb606,
  0xb607,0xb608,0xb609,0xb60a,0xb60b,0xb60c,0xb60d,0xb60e,
  0xb60f,0xb612,0xb613,0xb615,0xb616,0xb617,0xb619,0xb61a,
  0xb61b,0xb61c,0xb61d,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xb61e,0xb61f,0xb620,0xb621,0xb622,0xb623,0xb624,
  0xb626,0xb627,0xb628,0xb629,0xb62a,0xb62b,0xb62d,0xb62e,
  0xb62f,0xb630,0xb631,0xb632,0xb633,0xb635,0xb636,0xb637,
  0xb638,0xb639,0xb63a,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xb63b,0xb63c,0xb63d,0xb63e,0xb63f,0xb640,0xb641,0xb642,
  0xb643,0xb644,0xb645,0xb646,0xb647,0xb649,0xb64a,0xb64b,
  0xb64c,0xb64d,0xb64e,0xb64f,0xb650,0xb651,0xb652,0xb653,
  0xb654,0xb655,0xb656,0xb657,0xb658,0xb659,0xb65a,0xb65b,
  0xb65c,0xb65d,0xb65e,0xb65f,0xb660,0xb661,0xb662,0xb663,
  0xb665,0xb666,0xb667,0xb669,0xb66a,0xb66b,0xb66c,0xb66d,
  0xb66e,0xb66f,0xb670,0xb671,0xb672,0xb673,0xb674,0xb675,
  0xb676,0xb677,0xb678,0xb679,0xb67a,0xb67b,0xb67c,0xb67d,
  0xb67e,0xb67f,0xb680,0xb681,0xb682,0xb683,0xb684,0xb685,
  0xb686,0xb687,0xb688,0xb689,0xb68a,0xb68b,0xb68c,0xb68d,
  0xb68e,0xb68f,0xb690,0xb691,0xb692,0xb693,0xb694,0xb695,
  0xb696,0xb697,0xb698,0xb699,0xb69a,0xb69b,0xb69e,0xb69f,
  0xb6a1,0xb6a2,0xb6a3,0xb6a5,0xb6a6,0xb6a7,0xb6a8,0xb6a9,
  0xb6aa,0xb6ad,0xb6ae,0xb6af,0xb6b0,0xb6b2,0xb6b3,0xb6b4,
  0xb6b5,0xb6b6,0xb6b7,0xb6b8,0xb6b9,0xb6ba,0xb6bb,0xb6bc,
  0xb6bd,0xb6be,0xb6bf,0xb6c0,0xb6c1,0xb6c2,
/* 0x8d00 */
  0x0000,0xb6c3,0xb6c4,0xb6c5,0xb6c6,0xb6c7,0xb6c8,0xb6c9,
  0xb6ca,0xb6cb,0xb6cc,0xb6cd,0xb6ce,0xb6cf,0xb6d0,0xb6d1,
  0xb6d2,0xb6d3,0xb6d5,0xb6d6,0xb6d7,0xb6d8,0xb6d9,0xb6da,
  0xb6db,0xb6dc,0xb6dd,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xb6de,0xb6df,0xb6e0,0xb6e1,0xb6e2,0xb6e3,0xb6e4,
  0xb6e5,0xb6e6,0xb6e7,0xb6e8,0xb6e9,0xb6ea,0xb6eb,0xb6ec,
  0xb6ed,0xb6ee,0xb6ef,0xb6f1,0xb6f2,0xb6f3,0xb6f5,0xb6f6,
  0xb6f7,0xb6f9,0xb6fa,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xb6fb,0xb6fc,0xb6fd,0xb6fe,0xb6ff,0xb702,0xb703,0xb704,
  0xb706,0xb707,0xb708,0xb709,0xb70a,0xb70b,0xb70c,0xb70d,
  0xb70e,0xb70f,0xb710,0xb711,0xb712,0xb713,0xb714,0xb715,
  0xb716,0xb717,0xb718,0xb719,0xb71a,0xb71b,0xb71c,0xb71d,
  0xb71e,0xb71f,0xb720,0xb721,0xb722,0xb723,0xb724,0xb725,
  0xb726,0xb727,0xb72a,0xb72b,0xb72d,0xb72e,0xb731,0xb732,
  0xb733,0xb734,0xb735,0xb736,0xb737,0xb73a,0xb73c,0xb73d,
  0xb73e,0xb73f,0xb740,0xb741,0xb742,0xb743,0xb745,0xb746,
  0xb747,0xb749,0xb74a,0xb74b,0xb74d,0xb74e,0xb74f,0xb750,
  0xb751,0xb752,0xb753,0xb756,0xb757,0xb758,0xb759,0xb75a,
  0xb75b,0xb75c,0xb75d,0xb75e,0xb75f,0xb761,0xb762,0xb763,
  0xb765,0xb766,0xb767,0xb769,0xb76a,0xb76b,0xb76c,0xb76d,
  0xb76e,0xb76f,0xb772,0xb774,0xb776,0xb777,0xb778,0xb779,
  0xb77a,0xb77b,0xb77e,0xb77f,0xb781,0xb782,0xb783,0xb785,
  0xb786,0xb787,0xb788,0xb789,0xb78a,0xb78b,0xb78e,0xb793,
  0xb794,0xb795,0xb79a,0xb79b,0xb79d,0xb79e,
/* 0x8e00 */
  0x0000,0xb79f,0xb7a1,0xb7a2,0xb7a3,0xb7a4,0xb7a5,0xb7a6,
  0xb7a7,0xb7aa,0xb7ae,0xb7af,0xb7b0,0xb7b1,0xb7b2,0xb7b3,
  0xb7b6,0xb7b7,0xb7b9,0xb7ba,0xb7bb,0xb7bc,0xb7bd,0xb7be,
  0xb7bf,0xb7c0,0xb7c1,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xb7c2,0xb7c3,0xb7c4,0xb7c5,0xb7c6,0xb7c8,0xb7ca,
  0xb7cb,0xb7cc,0xb7cd,0xb7ce,0xb7cf,0xb7d0,0xb7d1,0xb7d2,
  0xb7d3,0xb7d4,0xb7d5,0xb7d6,0xb7d7,0xb7d8,0xb7d9,0xb7da,
  0xb7db,0xb7dc,0xb7dd,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xb7de,0xb7df,0xb7e0,0xb7e1,0xb7e2,0xb7e3,0xb7e4,0xb7e5,
  0xb7e6,0xb7e7,0xb7e8,0xb7e9,0xb7ea,0xb7eb,0xb7ee,0xb7ef,
  0xb7f1,0xb7f2,0xb7f3,0xb7f5,0xb7f6,0xb7f7,0xb7f8,0xb7f9,
  0xb7fa,0xb7fb,0xb7fe,0xb802,0xb803,0xb804,0xb805,0xb806,
  0xb80a,0xb80b,0xb80d,0xb80e,0xb80f,0xb811,0xb812,0xb813,
  0xb814,0xb815,0xb816,0xb817,0xb81a,0xb81c,0xb81e,0xb81f,
  0xb820,0xb821,0xb822,0xb823,0xb826,0xb827,0xb829,0xb82a,
  0xb82b,0xb82d,0xb82e,0xb82f,0xb830,0xb831,0xb832,0xb833,
  0xb836,0xb83a,0xb83b,0xb83c,0xb83d,0xb83e,0xb83f,0xb841,
  0xb842,0xb843,0xb845,0xb846,0xb847,0xb848,0xb849,0xb84a,
  0xb84b,0xb84c,0xb84d,0xb84e,0xb84f,0xb850,0xb852,0xb854,
  0xb855,0xb856,0xb857,0xb858,0xb859,0xb85a,0xb85b,0xb85e,
  0xb85f,0xb861,0xb862,0xb863,0xb865,0xb866,0xb867,0xb868,
  0xb869,0xb86a,0xb86b,0xb86e,0xb870,0xb872,0xb873,0xb874,
  0xb875,0xb876,0xb877,0xb879,0xb87a,0xb87b,0xb87d,0xb87e,
  0xb87f,0xb880,0xb881,0xb882,0xb883,0xb884,
/* 0x8f00 */
  0x0000,0xb885,0xb886,0xb887,0xb888,0xb889,0xb88a,0xb88b,
  0xb88c,0xb88e,0xb88f,0xb890,0xb891,0xb892,0xb893,0xb894,
  0xb895,0xb896,0xb897,0xb898,0xb899,0xb89a,0xb89b,0xb89c,
  0xb89d,0xb89e,0xb89f,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xb8a0,0xb8a1,0xb8a2,0xb8a3,0xb8a4,0xb8a5,0xb8a6,
  0xb8a7,0xb8a9,0xb8aa,0xb8ab,0xb8ac,0xb8ad,0xb8ae,0xb8af,
  0xb8b1,0xb8b2,0xb8b3,0xb8b5,0xb8b6,0xb8b7,0xb8b9,0xb8ba,
  0xb8bb,0xb8bc,0xb8bd,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xb8be,0xb8bf,0xb8c2,0xb8c4,0xb8c6,0xb8c7,0xb8c8,0xb8c9,
  0xb8ca,0xb8cb,0xb8cd,0xb8ce,0xb8cf,0xb8d1,0xb8d2,0xb8d3,
  0xb8d5,0xb8d6,0xb8d7,0xb8d8,0xb8d9,0xb8da,0xb8db,0xb8dc,
  0xb8de,0xb8e0,0xb8e2,0xb8e3,0xb8e4,0xb8e5,0xb8e6,0xb8e7,
  0xb8ea,0xb8eb,0xb8ed,0xb8ee,0xb8ef,0xb8f1,0xb8f2,0xb8f3,
  0xb8f4,0xb8f5,0xb8f6,0xb8f7,0xb8fa,0xb8fc,0xb8fe,0xb8ff,
  0xb900,0xb901,0xb902,0xb903,0xb905,0xb906,0xb907,0xb908,
  0xb909,0xb90a,0xb90b,0xb90c,0xb90d,0xb90e,0xb90f,0xb910,
  0xb911,0xb912,0xb913,0xb914,0xb915,0xb916,0xb917,0xb919,
  0xb91a,0xb91b,0xb91c,0xb91d,0xb91e,0xb91f,0xb921,0xb922,
  0xb923,0xb924,0xb925,0xb926,0xb927,0xb928,0xb929,0xb92a,
  0xb92b,0xb92c,0xb92d,0xb92e,0xb92f,0xb930,0xb931,0xb932,
  0xb933,0xb934,0xb935,0xb936,0xb937,0xb938,0xb939,0xb93a,
  0xb93b,0xb93e,0xb93f,0xb941,0xb942,0xb943,0xb945,0xb946,
  0xb947,0xb948,0xb949,0xb94a,0xb94b,0xb94d,0xb94e,0xb950,
  0xb952,0xb953,0xb954,0xb955,0xb956,0xb957,
/* 0x9000 */
  0x0000,0xb95a,0xb95b,0xb95d,0xb95e,0xb95f,0xb961,0xb962,
  0xb963,0xb964,0xb965,0xb966,0xb967,0xb96a,0xb96c,0xb96e,
  0xb96f,0xb970,0xb971,0xb972,0xb973,0xb976,0xb977,0xb979,
  0xb97a,0xb97b,0xb97d,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xb97e,0xb97f,0xb980,0xb981,0xb982,0xb983,0xb986,
  0xb988,0xb98b,0xb98c,0xb98f,0xb990,0xb991,0xb992,0xb993,
  0xb994,0xb995,0xb996,0xb997,0xb998,0xb999,0xb99a,0xb99b,
  0xb99c,0xb99d,0xb99e,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xb99f,0xb9a0,0xb9a1,0xb9a2,0xb9a3,0xb9a4,0xb9a5,0xb9a6,
  0xb9a7,0xb9a8,0xb9a9,0xb9aa,0xb9ab,0xb9ae,0xb9af,0xb9b1,
  0xb9b2,0xb9b3,0xb9b5,0xb9b6,0xb9b7,0xb9b8,0xb9b9,0xb9ba,
  0xb9bb,0xb9be,0xb9c0,0xb9c2,0xb9c3,0xb9c4,0xb9c5,0xb9c6,
  0xb9c7,0xb9ca,0xb9cb,0xb9cd,0xb9d3,0xb9d4,0xb9d5,0xb9d6,
  0xb9d7,0xb9da,0xb9dc,0xb9df,0xb9e0,0xb9e2,0xb9e6,0xb9e7,
  0xb9e9,0xb9ea,0xb9eb,0xb9ed,0xb9ee,0xb9ef,0xb9f0,0xb9f1,
  0xb9f2,0xb9f3,0xb9f6,0xb9fb,0xb9fc,0xb9fd,0xb9fe,0xb9ff,
  0xba02,0xba03,0xba04,0xba05,0xba06,0xba07,0xba09,0xba0a,
  0xba0b,0xba0c,0xba0d,0xba0e,0xba0f,0xba10,0xba11,0xba12,
  0xba13,0xba14,0xba16,0xba17,0xba18,0xba19,0xba1a,0xba1b,
  0xba1c,0xba1d,0xba1e,0xba1f,0xba20,0xba21,0xba22,0xba23,
  0xba24,0xba25,0xba26,0xba27,0xba28,0xba29,0xba2a,0xba2b,
  0xba2c,0xba2d,0xba2e,0xba2f,0xba30,0xba31,0xba32,0xba33,
  0xba34,0xba35,0xba36,0xba37,0xba3a,0xba3b,0xba3d,0xba3e,
  0xba3f,0xba41,0xba43,0xba44,0xba45,0xba46,
/* 0x9100 */
  0x0000,0xba47,0xba4a,0xba4c,0xba4f,0xba50,0xba51,0xba52,
  0xba56,0xba57,0xba59,0xba5a,0xba5b,0xba5d,0xba5e,0xba5f,
  0xba60,0xba61,0xba62,0xba63,0xba66,0xba6a,0xba6b,0xba6c,
  0xba6d,0xba6e,0xba6f,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xba72,0xba73,0xba75,0xba76,0xba77,0xba79,0xba7a,
  0xba7b,0xba7c,0xba7d,0xba7e,0xba7f,0xba80,0xba81,0xba82,
  0xba86,0xba88,0xba89,0xba8a,0xba8b,0xba8d,0xba8e,0xba8f,
  0xba90,0xba91,0xba92,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xba93,0xba94,0xba95,0xba96,0xba97,0xba98,0xba99,0xba9a,
  0xba9b,0xba9c,0xba9d,0xba9e,0xba9f,0xbaa0,0xbaa1,0xbaa2,
  0xbaa3,0xbaa4,0xbaa5,0xbaa6,0xbaa7,0xbaaa,0xbaad,0xbaae,
  0xbaaf,0xbab1,0xbab3,0xbab4,0xbab5,0xbab6,0xbab7,0xbaba,
  0xbabc,0xbabe,0xbabf,0xbac0,0xbac1,0xbac2,0xbac3,0xbac5,
  0xbac6,0xbac7,0xbac9,0xbaca,0xbacb,0xbacc,0xbacd,0xbace,
  0xbacf,0xbad0,0xbad1,0xbad2,0xbad3,0xbad4,0xbad5,0xbad6,
  0xbad7,0xbada,0xbadb,0xbadc,0xbadd,0xbade,0xbadf,0xbae0,
  0xbae1,0xbae2,0xbae3,0xbae4,0xbae5,0xbae6,0xbae7,0xbae8,
  0xbae9,0xbaea,0xbaeb,0xbaec,0xbaed,0xbaee,0xbaef,0xbaf0,
  0xbaf1,0xbaf2,0xbaf3,0xbaf4,0xbaf5,0xbaf6,0xbaf7,0xbaf8,
  0xbaf9,0xbafa,0xbafb,0xbafd,0xbafe,0xbaff,0xbb01,0xbb02,
  0xbb03,0xbb05,0xbb06,0xbb07,0xbb08,0xbb09,0xbb0a,0xbb0b,
  0xbb0c,0xbb0e,0xbb10,0xbb12,0xbb13,0xbb14,0xbb15,0xbb16,
  0xbb17,0xbb19,0xbb1a,0xbb1b,0xbb1d,0xbb1e,0xbb1f,0xbb21,
  0xbb22,0xbb23,0xbb24,0xbb25,0xbb26,0xbb27,
/* 0x9200 */
  0x0000,0xbb28,0xbb2a,0xbb2c,0xbb2d,0xbb2e,0xbb2f,0xbb30,
  0xbb31,0xbb32,0xbb33,0xbb37,0xbb39,0xbb3a,0xbb3f,0xbb40,
  0xbb41,0xbb42,0xbb43,0xbb46,0xbb48,0xbb4a,0xbb4b,0xbb4c,
  0xbb4e,0xbb51,0xbb52,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xbb53,0xbb55,0xbb56,0xbb57,0xbb59,0xbb5a,0xbb5b,
  0xbb5c,0xbb5d,0xbb5e,0xbb5f,0xbb60,0xbb62,0xbb64,0xbb65,
  0xbb66,0xbb67,0xbb68,0xbb69,0xbb6a,0xbb6b,0xbb6d,0xbb6e,
  0xbb6f,0xbb70,0xbb71,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xbb72,0xbb73,0xbb74,0xbb75,0xbb76,0xbb77,0xbb78,0xbb79,
  0xbb7a,0xbb7b,0xbb7c,0xbb7d,0xbb7e,0xbb7f,0xbb80,0xbb81,
  0xbb82,0xbb83,0xbb84,0xbb85,0xbb86,0xbb87,0xbb89,0xbb8a,
  0xbb8b,0xbb8d,0xbb8e,0xbb8f,0xbb91,0xbb92,0xbb93,0xbb94,
  0xbb95,0xbb96,0xbb97,0xbb98,0xbb99,0xbb9a,0xbb9b,0xbb9c,
  0xbb9d,0xbb9e,0xbb9f,0xbba0,0xbba1,0xbba2,0xbba3,0xbba5,
  0xbba6,0xbba7,0xbba9,0xbbaa,0xbbab,0xbbad,0xbbae,0xbbaf,
  0xbbb0,0xbbb1,0xbbb2,0xbbb3,0xbbb5,0xbbb6,0xbbb8,0xbbb9,
  0xbbba,0xbbbb,0xbbbc,0xbbbd,0xbbbe,0xbbbf,0xbbc1,0xbbc2,
  0xbbc3,0xbbc5,0xbbc6,0xbbc7,0xbbc9,0xbbca,0xbbcb,0xbbcc,
  0xbbcd,0xbbce,0xbbcf,0xbbd1,0xbbd2,0xbbd4,0xbbd5,0xbbd6,
  0xbbd7,0xbbd8,0xbbd9,0xbbda,0xbbdb,0xbbdc,0xbbdd,0xbbde,
  0xbbdf,0xbbe0,0xbbe1,0xbbe2,0xbbe3,0xbbe4,0xbbe5,0xbbe6,
  0xbbe7,0xbbe8,0xbbe9,0xbbea,0xbbeb,0xbbec,0xbbed,0xbbee,
  0xbbef,0xbbf0,0xbbf1,0xbbf2,0xbbf3,0xbbf4,0xbbf5,0xbbf6,
  0xbbf7,0xbbfa,0xbbfb,0xbbfd,0xbbfe,0xbc01,
/* 0x9300 */
  0x0000,0xbc03,0xbc04,0xbc05,0xbc06,0xbc07,0xbc0a,0xbc0e,
  0xbc10,0xbc12,0xbc13,0xbc19,0xbc1a,0xbc20,0xbc21,0xbc22,
  0xbc23,0xbc26,0xbc28,0xbc2a,0xbc2b,0xbc2c,0xbc2e,0xbc2f,
  0xbc32,0xbc33,0xbc35,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xbc36,0xbc37,0xbc39,0xbc3a,0xbc3b,0xbc3c,0xbc3d,
  0xbc3e,0xbc3f,0xbc42,0xbc46,0xbc47,0xbc48,0xbc4a,0xbc4b,
  0xbc4e,0xbc4f,0xbc51,0xbc52,0xbc53,0xbc54,0xbc55,0xbc56,
  0xbc57,0xbc58,0xbc59,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xbc5a,0xbc5b,0xbc5c,0xbc5e,0xbc5f,0xbc60,0xbc61,0xbc62,
  0xbc63,0xbc64,0xbc65,0xbc66,0xbc67,0xbc68,0xbc69,0xbc6a,
  0xbc6b,0xbc6c,0xbc6d,0xbc6e,0xbc6f,0xbc70,0xbc71,0xbc72,
  0xbc73,0xbc74,0xbc75,0xbc76,0xbc77,0xbc78,0xbc79,0xbc7a,
  0xbc7b,0xbc7c,0xbc7d,0xbc7e,0xbc7f,0xbc80,0xbc81,0xbc82,
  0xbc83,0xbc86,0xbc87,0xbc89,0xbc8a,0xbc8d,0xbc8f,0xbc90,
  0xbc91,0xbc92,0xbc93,0xbc96,0xbc98,0xbc9b,0xbc9c,0xbc9d,
  0xbc9e,0xbc9f,0xbca2,0xbca3,0xbca5,0xbca6,0xbca9,0xbcaa,
  0xbcab,0xbcac,0xbcad,0xbcae,0xbcaf,0xbcb2,0xbcb6,0xbcb7,
  0xbcb8,0xbcb9,0xbcba,0xbcbb,0xbcbe,0xbcbf,0xbcc1,0xbcc2,
  0xbcc3,0xbcc5,0xbcc6,0xbcc7,0xbcc8,0xbcc9,0xbcca,0xbccb,
  0xbccc,0xbcce,0xbcd2,0xbcd3,0xbcd4,0xbcd6,0xbcd7,0xbcd9,
  0xbcda,0xbcdb,0xbcdd,0xbcde,0xbcdf,0xbce0,0xbce1,0xbce2,
  0xbce3,0xbce4,0xbce5,0xbce6,0xbce7,0xbce8,0xbce9,0xbcea,
  0xbceb,0xbcec,0xbced,0xbcee,0xbcef,0xbcf0,0xbcf1,0xbcf2,
  0xbcf3,0xbcf7,0xbcf9,0xbcfa,0xbcfb,0xbcfd,
/* 0x9400 */
  0x0000,0xbcfe,0xbcff,0xbd00,0xbd01,0xbd02,0xbd03,0xbd06,
  0xbd08,0xbd0a,0xbd0b,0xbd0c,0xbd0d,0xbd0e,0xbd0f,0xbd11,
  0xbd12,0xbd13,0xbd15,0xbd16,0xbd17,0xbd18,0xbd19,0xbd1a,
  0xbd1b,0xbd1c,0xbd1d,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xbd1e,0xbd1f,0xbd20,0xbd21,0xbd22,0xbd23,0xbd25,
  0xbd26,0xbd27,0xbd28,0xbd29,0xbd2a,0xbd2b,0xbd2d,0xbd2e,
  0xbd2f,0xbd30,0xbd31,0xbd32,0xbd33,0xbd34,0xbd35,0xbd36,
  0xbd37,0xbd38,0xbd39,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xbd3a,0xbd3b,0xbd3c,0xbd3d,0xbd3e,0xbd3f,0xbd41,0xbd42,
  0xbd43,0xbd44,0xbd45,0xbd46,0xbd47,0xbd4a,0xbd4b,0xbd4d,
  0xbd4e,0xbd4f,0xbd51,0xbd52,0xbd53,0xbd54,0xbd55,0xbd56,
  0xbd57,0xbd5a,0xbd5b,0xbd5c,0xbd5d,0xbd5e,0xbd5f,0xbd60,
  0xbd61,0xbd62,0xbd63,0xbd65,0xbd66,0xbd67,0xbd69,0xbd6a,
  0xbd6b,0xbd6c,0xbd6d,0xbd6e,0xbd6f,0xbd70,0xbd71,0xbd72,
  0xbd73,0xbd74,0xbd75,0xbd76,0xbd77,0xbd78,0xbd79,0xbd7a,
  0xbd7b,0xbd7c,0xbd7d,0xbd7e,0xbd7f,0xbd82,0xbd83,0xbd85,
  0xbd86,0xbd8b,0xbd8c,0xbd8d,0xbd8e,0xbd8f,0xbd92,0xbd94,
  0xbd96,0xbd97,0xbd98,0xbd9b,0xbd9d,0xbd9e,0xbd9f,0xbda0,
  0xbda1,0xbda2,0xbda3,0xbda5,0xbda6,0xbda7,0xbda8,0xbda9,
  0xbdaa,0xbdab,0xbdac,0xbdad,0xbdae,0xbdaf,0xbdb1,0xbdb2,
  0xbdb3,0xbdb4,0xbdb5,0xbdb6,0xbdb7,0xbdb9,0xbdba,0xbdbb,
  0xbdbc,0xbdbd,0xbdbe,0xbdbf,0xbdc0,0xbdc1,0xbdc2,0xbdc3,
  0xbdc4,0xbdc5,0xbdc6,0xbdc7,0xbdc8,0xbdc9,0xbdca,0xbdcb,
  0xbdcc,0xbdcd,0xbdce,0xbdcf,0xbdd0,0xbdd1,
/* 0x9500 */
  0x0000,0xbdd2,0xbdd3,0xbdd6,0xbdd7,0xbdd9,0xbdda,0xbddb,
  0xbddd,0xbdde,0xbddf,0xbde0,0xbde1,0xbde2,0xbde3,0xbde4,
  0xbde5,0xbde6,0xbde7,0xbde8,0xbdea,0xbdeb,0xbdec,0xbded,
  0xbdee,0xbdef,0xbdf1,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xbdf2,0xbdf3,0xbdf5,0xbdf6,0xbdf7,0xbdf9,0xbdfa,
  0xbdfb,0xbdfc,0xbdfd,0xbdfe,0xbdff,0xbe01,0xbe02,0xbe04,
  0xbe06,0xbe07,0xbe08,0xbe09,0xbe0a,0xbe0b,0xbe0e,0xbe0f,
  0xbe11,0xbe12,0xbe13,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xbe15,0xbe16,0xbe17,0xbe18,0xbe19,0xbe1a,0xbe1b,0xbe1e,
  0xbe20,0xbe21,0xbe22,0xbe23,0xbe24,0xbe25,0xbe26,0xbe27,
  0xbe28,0xbe29,0xbe2a,0xbe2b,0xbe2c,0xbe2d,0xbe2e,0xbe2f,
  0xbe30,0xbe31,0xbe32,0xbe33,0xbe34,0xbe35,0xbe36,0xbe37,
  0xbe38,0xbe39,0xbe3a,0xbe3b,0xbe3c,0xbe3d,0xbe3e,0xbe3f,
  0xbe40,0xbe41,0xbe42,0xbe43,0xbe46,0xbe47,0xbe49,0xbe4a,
  0xbe4b,0xbe4d,0xbe4f,0xbe50,0xbe51,0xbe52,0xbe53,0xbe56,
  0xbe58,0xbe5c,0xbe5d,0xbe5e,0xbe5f,0xbe62,0xbe63,0xbe65,
  0xbe66,0xbe67,0xbe69,0xbe6b,0xbe6c,0xbe6d,0xbe6e,0xbe6f,
  0xbe72,0xbe76,0xbe77,0xbe78,0xbe79,0xbe7a,0xbe7e,0xbe7f,
  0xbe81,0xbe82,0xbe83,0xbe85,0xbe86,0xbe87,0xbe88,0xbe89,
  0xbe8a,0xbe8b,0xbe8e,0xbe92,0xbe93,0xbe94,0xbe95,0xbe96,
  0xbe97,0xbe9a,0xbe9b,0xbe9c,0xbe9d,0xbe9e,0xbe9f,0xbea0,
  0xbea1,0xbea2,0xbea3,0xbea4,0xbea5,0xbea6,0xbea7,0xbea9,
  0xbeaa,0xbeab,0xbeac,0xbead,0xbeae,0xbeaf,0xbeb0,0xbeb1,
  0xbeb2,0xbeb3,0xbeb4,0xbeb5,0xbeb6,0xbeb7,
/* 0x9600 */
  0x0000,0xbeb8,0xbeb9,0xbeba,0xbebb,0xbebc,0xbebd,0xbebe,
  0xbebf,0xbec0,0xbec1,0xbec2,0xbec3,0xbec4,0xbec5,0xbec6,
  0xbec7,0xbec8,0xbec9,0xbeca,0xbecb,0xbecc,0xbecd,0xbece,
  0xbecf,0xbed2,0xbed3,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xbed5,0xbed6,0xbed9,0xbeda,0xbedb,0xbedc,0xbedd,
  0xbede,0xbedf,0xbee1,0xbee2,0xbee6,0xbee7,0xbee8,0xbee9,
  0xbeea,0xbeeb,0xbeed,0xbeee,0xbeef,0xbef0,0xbef1,0xbef2,
  0xbef3,0xbef4,0xbef5,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xbef6,0xbef7,0xbef8,0xbef9,0xbefa,0xbefb,0xbefc,0xbefd,
  0xbefe,0xbeff,0xbf00,0xbf02,0xbf03,0xbf04,0xbf05,0xbf06,
  0xbf07,0xbf0a,0xbf0b,0xbf0c,0xbf0d,0xbf0e,0xbf0f,0xbf10,
  0xbf11,0xbf12,0xbf13,0xbf14,0xbf15,0xbf16,0xbf17,0xbf1a,
  0xbf1e,0xbf1f,0xbf20,0xbf21,0xbf22,0xbf23,0xbf24,0xbf25,
  0xbf26,0xbf27,0xbf28,0xbf29,0xbf2a,0xbf2b,0xbf2c,0xbf2d,
  0xbf2e,0xbf2f,0xbf30,0xbf31,0xbf32,0xbf33,0xbf34,0xbf35,
  0xbf36,0xbf37,0xbf38,0xbf39,0xbf3a,0xbf3b,0xbf3c,0xbf3d,
  0xbf3e,0xbf3f,0xbf42,0xbf43,0xbf45,0xbf46,0xbf47,0xbf49,
  0xbf4a,0xbf4b,0xbf4c,0xbf4d,0xbf4e,0xbf4f,0xbf52,0xbf53,
  0xbf54,0xbf56,0xbf57,0xbf58,0xbf59,0xbf5a,0xbf5b,0xbf5c,
  0xbf5d,0xbf5e,0xbf5f,0xbf60,0xbf61,0xbf62,0xbf63,0xbf64,
  0xbf65,0xbf66,0xbf67,0xbf68,0xbf69,0xbf6a,0xbf6b,0xbf6c,
  0xbf6d,0xbf6e,0xbf6f,0xbf70,0xbf71,0xbf72,0xbf73,0xbf74,
  0xbf75,0xbf76,0xbf77,0xbf78,0xbf79,0xbf7a,0xbf7b,0xbf7c,
  0xbf7d,0xbf7e,0xbf7f,0xbf80,0xbf81,0xbf82,
/* 0x9700 */
  0x0000,0xbf83,0xbf84,0xbf85,0xbf86,0xbf87,0xbf88,0xbf89,
  0xbf8a,0xbf8b,0xbf8c,0xbf8d,0xbf8e,0xbf8f,0xbf90,0xbf91,
  0xbf92,0xbf93,0xbf95,0xbf96,0xbf97,0xbf98,0xbf99,0xbf9a,
  0xbf9b,0xbf9c,0xbf9d,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xbf9e,0xbf9f,0xbfa0,0xbfa1,0xbfa2,0xbfa3,0xbfa4,
  0xbfa5,0xbfa6,0xbfa7,0xbfa8,0xbfa9,0xbfaa,0xbfab,0xbfac,
  0xbfad,0xbfae,0xbfaf,0xbfb1,0xbfb2,0xbfb3,0xbfb4,0xbfb5,
  0xbfb6,0xbfb7,0xbfb8,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xbfb9,0xbfba,0xbfbb,0xbfbc,0xbfbd,0xbfbe,0xbfbf,0xbfc0,
  0xbfc1,0xbfc2,0xbfc3,0xbfc4,0xbfc6,0xbfc7,0xbfc8,0xbfc9,
  0xbfca,0xbfcb,0xbfce,0xbfcf,0xbfd1,0xbfd2,0xbfd3,0xbfd5,
  0xbfd6,0xbfd7,0xbfd8,0xbfd9,0xbfda,0xbfdb,0xbfdd,0xbfde,
  0xbfe0,0xbfe2,0xbfe3,0xbfe4,0xbfe5,0xbfe6,0xbfe7,0xbfe8,
  0xbfe9,0xbfea,0xbfeb,0xbfec,0xbfed,0xbfee,0xbfef,0xbff0,
  0xbff1,0xbff2,0xbff3,0xbff4,0xbff5,0xbff6,0xbff7,0xbff8,
  0xbff9,0xbffa,0xbffb,0xbffc,0xbffd,0xbffe,0xbfff,0xc000,
  0xc001,0xc002,0xc003,0xc004,0xc005,0xc006,0xc007,0xc008,
  0xc009,0xc00a,0xc00b,0xc00c,0xc00d,0xc00e,0xc00f,0xc010,
  0xc011,0xc012,0xc013,0xc014,0xc015,0xc016,0xc017,0xc018,
  0xc019,0xc01a,0xc01b,0xc01c,0xc01d,0xc01e,0xc01f,0xc020,
  0xc021,0xc022,0xc023,0xc024,0xc025,0xc026,0xc027,0xc028,
  0xc029,0xc02a,0xc02b,0xc02c,0xc02d,0xc02e,0xc02f,0xc030,
  0xc031,0xc032,0xc033,0xc034,0xc035,0xc036,0xc037,0xc038,
  0xc039,0xc03a,0xc03b,0xc03d,0xc03e,0xc03f,
/* 0x9800 */
  0x0000,0xc040,0xc041,0xc042,0xc043,0xc044,0xc045,0xc046,
  0xc047,0xc048,0xc049,0xc04a,0xc04b,0xc04c,0xc04d,0xc04e,
  0xc04f,0xc050,0xc052,0xc053,0xc054,0xc055,0xc056,0xc057,
  0xc059,0xc05a,0xc05b,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xc05d,0xc05e,0xc05f,0xc061,0xc062,0xc063,0xc064,
  0xc065,0xc066,0xc067,0xc06a,0xc06b,0xc06c,0xc06d,0xc06e,
  0xc06f,0xc070,0xc071,0xc072,0xc073,0xc074,0xc075,0xc076,
  0xc077,0xc078,0xc079,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xc07a,0xc07b,0xc07c,0xc07d,0xc07e,0xc07f,0xc080,0xc081,
  0xc082,0xc083,0xc084,0xc085,0xc086,0xc087,0xc088,0xc089,
  0xc08a,0xc08b,0xc08c,0xc08d,0xc08e,0xc08f,0xc092,0xc093,
  0xc095,0xc096,0xc097,0xc099,0xc09a,0xc09b,0xc09c,0xc09d,
  0xc09e,0xc09f,0xc0a2,0xc0a4,0xc0a6,0xc0a7,0xc0a8,0xc0a9,
  0xc0aa,0xc0ab,0xc0ae,0xc0b1,0xc0b2,0xc0b7,0xc0b8,0xc0b9,
  0xc0ba,0xc0bb,0xc0be,0xc0c2,0xc0c3,0xc0c4,0xc0c6,0xc0c7,
  0xc0ca,0xc0cb,0xc0cd,0xc0ce,0xc0cf,0xc0d1,0xc0d2,0xc0d3,
  0xc0d4,0xc0d5,0xc0d6,0xc0d7,0xc0da,0xc0de,0xc0df,0xc0e0,
  0xc0e1,0xc0e2,0xc0e3,0xc0e6,0xc0e7,0xc0e9,0xc0ea,0xc0eb,
  0xc0ed,0xc0ee,0xc0ef,0xc0f0,0xc0f1,0xc0f2,0xc0f3,0xc0f6,
  0xc0f8,0xc0fa,0xc0fb,0xc0fc,0xc0fd,0xc0fe,0xc0ff,0xc101,
  0xc102,0xc103,0xc105,0xc106,0xc107,0xc109,0xc10a,0xc10b,
  0xc10c,0xc10d,0xc10e,0xc10f,0xc111,0xc112,0xc113,0xc114,
  0xc116,0xc117,0xc118,0xc119,0xc11a,0xc11b,0xc121,0xc122,
  0xc125,0xc128,0xc129,0xc12a,0xc12b,0xc12e,
/* 0x9900 */
  0x0000,0xc132,0xc133,0xc134,0xc135,0xc137,0xc13a,0xc13b,
  0xc13d,0xc13e,0xc13f,0xc141,0xc142,0xc143,0xc144,0xc145,
  0xc146,0xc147,0xc14a,0xc14e,0xc14f,0xc150,0xc151,0xc152,
  0xc153,0xc156,0xc157,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xc159,0xc15a,0xc15b,0xc15d,0xc15e,0xc15f,0xc160,
  0xc161,0xc162,0xc163,0xc166,0xc16a,0xc16b,0xc16c,0xc16d,
  0xc16e,0xc16f,0xc171,0xc172,0xc173,0xc175,0xc176,0xc177,
  0xc179,0xc17a,0xc17b,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xc17c,0xc17d,0xc17e,0xc17f,0xc180,0xc181,0xc182,0xc183,
  0xc184,0xc186,0xc187,0xc188,0xc189,0xc18a,0xc18b,0xc18f,
  0xc191,0xc192,0xc193,0xc195,0xc197,0xc198,0xc199,0xc19a,
  0xc19b,0xc19e,0xc1a0,0xc1a2,0xc1a3,0xc1a4,0xc1a6,0xc1a7,
  0xc1aa,0xc1ab,0xc1ad,0xc1ae,0xc1af,0xc1b1,0xc1b2,0xc1b3,
  0xc1b4,0xc1b5,0xc1b6,0xc1b7,0xc1b8,0xc1b9,0xc1ba,0xc1bb,
  0xc1bc,0xc1be,0xc1bf,0xc1c0,0xc1c1,0xc1c2,0xc1c3,0xc1c5,
  0xc1c6,0xc1c7,0xc1c9,0xc1ca,0xc1cb,0xc1cd,0xc1ce,0xc1cf,
  0xc1d0,0xc1d1,0xc1d2,0xc1d3,0xc1d5,0xc1d6,0xc1d9,0xc1da,
  0xc1db,0xc1dc,0xc1dd,0xc1de,0xc1df,0xc1e1,0xc1e2,0xc1e3,
  0xc1e5,0xc1e6,0xc1e7,0xc1e9,0xc1ea,0xc1eb,0xc1ec,0xc1ed,
  0xc1ee,0xc1ef,0xc1f2,0xc1f4,0xc1f5,0xc1f6,0xc1f7,0xc1f8,
  0xc1f9,0xc1fa,0xc1fb,0xc1fe,0xc1ff,0xc201,0xc202,0xc203,
  0xc205,0xc206,0xc207,0xc208,0xc209,0xc20a,0xc20b,0xc20e,
  0xc210,0xc212,0xc213,0xc214,0xc215,0xc216,0xc217,0xc21a,
  0xc21b,0xc21d,0xc21e,0xc221,0xc222,0xc223,
/* 0x9a00 */
  0x0000,0xc224,0xc225,0xc226,0xc227,0xc22a,0xc22c,0xc22e,
  0xc230,0xc233,0xc235,0xc236,0xc237,0xc238,0xc239,0xc23a,
  0xc23b,0xc23c,0xc23d,0xc23e,0xc23f,0xc240,0xc241,0xc242,
  0xc243,0xc244,0xc245,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xc246,0xc247,0xc249,0xc24a,0xc24b,0xc24c,0xc24d,
  0xc24e,0xc24f,0xc252,0xc253,0xc255,0xc256,0xc257,0xc259,
  0xc25a,0xc25b,0xc25c,0xc25d,0xc25e,0xc25f,0xc261,0xc262,
  0xc263,0xc264,0xc266,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xc267,0xc268,0xc269,0xc26a,0xc26b,0xc26e,0xc26f,0xc271,
  0xc272,0xc273,0xc275,0xc276,0xc277,0xc278,0xc279,0xc27a,
  0xc27b,0xc27e,0xc280,0xc282,0xc283,0xc284,0xc285,0xc286,
  0xc287,0xc28a,0xc28b,0xc28c,0xc28d,0xc28e,0xc28f,0xc291,
  0xc292,0xc293,0xc294,0xc295,0xc296,0xc297,0xc299,0xc29a,
  0xc29c,0xc29e,0xc29f,0xc2a0,0xc2a1,0xc2a2,0xc2a3,0xc2a6,
  0xc2a7,0xc2a9,0xc2aa,0xc2ab,0xc2ae,0xc2af,0xc2b0,0xc2b1,
  0xc2b2,0xc2b3,0xc2b6,0xc2b8,0xc2ba,0xc2bb,0xc2bc,0xc2bd,
  0xc2be,0xc2bf,0xc2c0,0xc2c1,0xc2c2,0xc2c3,0xc2c4,0xc2c5,
  0xc2c6,0xc2c7,0xc2c8,0xc2c9,0xc2ca,0xc2cb,0xc2cc,0xc2cd,
  0xc2ce,0xc2cf,0xc2d0,0xc2d1,0xc2d2,0xc2d3,0xc2d4,0xc2d5,
  0xc2d6,0xc2d7,0xc2d8,0xc2d9,0xc2da,0xc2db,0xc2de,0xc2df,
  0xc2e1,0xc2e2,0xc2e5,0xc2e6,0xc2e7,0xc2e8,0xc2e9,0xc2ea,
  0xc2ee,0xc2f0,0xc2f2,0xc2f3,0xc2f4,0xc2f5,0xc2f7,0xc2fa,
  0xc2fd,0xc2fe,0xc2ff,0xc301,0xc302,0xc303,0xc304,0xc305,
  0xc306,0xc307,0xc30a,0xc30b,0xc30e,0xc30f,
/* 0x9b00 */
  0x0000,0xc310,0xc311,0xc312,0xc316,0xc317,0xc319,0xc31a,
  0xc31b,0xc31d,0xc31e,0xc31f,0xc320,0xc321,0xc322,0xc323,
  0xc326,0xc327,0xc32a,0xc32b,0xc32c,0xc32d,0xc32e,0xc32f,
  0xc330,0xc331,0xc332,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xc333,0xc334,0xc335,0xc336,0xc337,0xc338,0xc339,
  0xc33a,0xc33b,0xc33c,0xc33d,0xc33e,0xc33f,0xc340,0xc341,
  0xc342,0xc343,0xc344,0xc346,0xc347,0xc348,0xc349,0xc34a,
  0xc34b,0xc34c,0xc34d,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xc34e,0xc34f,0xc350,0xc351,0xc352,0xc353,0xc354,0xc355,
  0xc356,0xc357,0xc358,0xc359,0xc35a,0xc35b,0xc35c,0xc35d,
  0xc35e,0xc35f,0xc360,0xc361,0xc362,0xc363,0xc364,0xc365,
  0xc366,0xc367,0xc36a,0xc36b,0xc36d,0xc36e,0xc36f,0xc371,
  0xc373,0xc374,0xc375,0xc376,0xc377,0xc37a,0xc37b,0xc37e,
  0xc37f,0xc380,0xc381,0xc382,0xc383,0xc385,0xc386,0xc387,
  0xc389,0xc38a,0xc38b,0xc38d,0xc38e,0xc38f,0xc390,0xc391,
  0xc392,0xc393,0xc394,0xc395,0xc396,0xc397,0xc398,0xc399,
  0xc39a,0xc39b,0xc39c,0xc39d,0xc39e,0xc39f,0xc3a0,0xc3a1,
  0xc3a2,0xc3a3,0xc3a4,0xc3a5,0xc3a6,0xc3a7,0xc3a8,0xc3a9,
  0xc3aa,0xc3ab,0xc3ac,0xc3ad,0xc3ae,0xc3af,0xc3b0,0xc3b1,
  0xc3b2,0xc3b3,0xc3b4,0xc3b5,0xc3b6,0xc3b7,0xc3b8,0xc3b9,
  0xc3ba,0xc3bb,0xc3bc,0xc3bd,0xc3be,0xc3bf,0xc3c1,0xc3c2,
  0xc3c3,0xc3c4,0xc3c5,0xc3c6,0xc3c7,0xc3c8,0xc3c9,0xc3ca,
  0xc3cb,0xc3cc,0xc3cd,0xc3ce,0xc3cf,0xc3d0,0xc3d1,0xc3d2,
  0xc3d3,0xc3d4,0xc3d5,0xc3d6,0xc3d7,0xc3da,
/* 0x9c00 */
  0x0000,0xc3db,0xc3dd,0xc3de,0xc3e1,0xc3e3,0xc3e4,0xc3e5,
  0xc3e6,0xc3e7,0xc3ea,0xc3eb,0xc3ec,0xc3ee,0xc3ef,0xc3f0,
  0xc3f1,0xc3f2,0xc3f3,0xc3f6,0xc3f7,0xc3f9,0xc3fa,0xc3fb,
  0xc3fc,0xc3fd,0xc3fe,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xc3ff,0xc400,0xc401,0xc402,0xc403,0xc404,0xc405,
  0xc406,0xc407,0xc409,0xc40a,0xc40b,0xc40c,0xc40d,0xc40e,
  0xc40f,0xc411,0xc412,0xc413,0xc414,0xc415,0xc416,0xc417,
  0xc418,0xc419,0xc41a,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xc41b,0xc41c,0xc41d,0xc41e,0xc41f,0xc420,0xc421,0xc422,
  0xc423,0xc425,0xc426,0xc427,0xc428,0xc429,0xc42a,0xc42b,
  0xc42d,0xc42e,0xc42f,0xc431,0xc432,0xc433,0xc435,0xc436,
  0xc437,0xc438,0xc439,0xc43a,0xc43b,0xc43e,0xc43f,0xc440,
  0xc441,0xc442,0xc443,0xc444,0xc445,0xc446,0xc447,0xc449,
  0xc44a,0xc44b,0xc44c,0xc44d,0xc44e,0xc44f,0xc450,0xc451,
  0xc452,0xc453,0xc454,0xc455,0xc456,0xc457,0xc458,0xc459,
  0xc45a,0xc45b,0xc45c,0xc45d,0xc45e,0xc45f,0xc460,0xc461,
  0xc462,0xc463,0xc466,0xc467,0xc469,0xc46a,0xc46b,0xc46d,
  0xc46e,0xc46f,0xc470,0xc471,0xc472,0xc473,0xc476,0xc477,
  0xc478,0xc47a,0xc47b,0xc47c,0xc47d,0xc47e,0xc47f,0xc481,
  0xc482,0xc483,0xc484,0xc485,0xc486,0xc487,0xc488,0xc489,
  0xc48a,0xc48b,0xc48c,0xc48d,0xc48e,0xc48f,0xc490,0xc491,
  0xc492,0xc493,0xc495,0xc496,0xc497,0xc498,0xc499,0xc49a,
  0xc49b,0xc49d,0xc49e,0xc49f,0xc4a0,0xc4a1,0xc4a2,0xc4a3,
  0xc4a4,0xc4a5,0xc4a6,0xc4a7,0xc4a8,0xc4a9,
/* 0x9d00 */
  0x0000,0xc4aa,0xc4ab,0xc4ac,0xc4ad,0xc4ae,0xc4af,0xc4b0,
  0xc4b1,0xc4b2,0xc4b3,0xc4b4,0xc4b5,0xc4b6,0xc4b7,0xc4b9,
  0xc4ba,0xc4bb,0xc4bd,0xc4be,0xc4bf,0xc4c0,0xc4c1,0xc4c2,
  0xc4c3,0xc4c4,0xc4c5,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xc4c6,0xc4c7,0xc4c8,0xc4c9,0xc4ca,0xc4cb,0xc4cc,
  0xc4cd,0xc4ce,0xc4cf,0xc4d0,0xc4d1,0xc4d2,0xc4d3,0xc4d4,
  0xc4d5,0xc4d6,0xc4d7,0xc4d8,0xc4d9,0xc4da,0xc4db,0xc4dc,
  0xc4dd,0xc4de,0xc4df,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xc4e0,0xc4e1,0xc4e2,0xc4e3,0xc4e4,0xc4e5,0xc4e6,0xc4e7,
  0xc4e8,0xc4ea,0xc4eb,0xc4ec,0xc4ed,0xc4ee,0xc4ef,0xc4f2,
  0xc4f3,0xc4f5,0xc4f6,0xc4f7,0xc4f9,0xc4fb,0xc4fc,0xc4fd,
  0xc4fe,0xc502,0xc503,0xc504,0xc505,0xc506,0xc507,0xc508,
  0xc509,0xc50a,0xc50b,0xc50d,0xc50e,0xc50f,0xc511,0xc512,
  0xc513,0xc515,0xc516,0xc517,0xc518,0xc519,0xc51a,0xc51b,
  0xc51d,0xc51e,0xc51f,0xc520,0xc521,0xc522,0xc523,0xc524,
  0xc525,0xc526,0xc527,0xc52a,0xc52b,0xc52d,0xc52e,0xc52f,
  0xc531,0xc532,0xc533,0xc534,0xc535,0xc536,0xc537,0xc53a,
  0xc53c,0xc53e,0xc53f,0xc540,0xc541,0xc542,0xc543,0xc546,
  0xc547,0xc54b,0xc54f,0xc550,0xc551,0xc552,0xc556,0xc55a,
  0xc55b,0xc55c,0xc55f,0xc562,0xc563,0xc565,0xc566,0xc567,
  0xc569,0xc56a,0xc56b,0xc56c,0xc56d,0xc56e,0xc56f,0xc572,
  0xc576,0xc577,0xc578,0xc579,0xc57a,0xc57b,0xc57e,0xc57f,
  0xc581,0xc582,0xc583,0xc585,0xc586,0xc588,0xc589,0xc58a,
  0xc58b,0xc58e,0xc590,0xc592,0xc593,0xc594,
/* 0x9e00 */
  0x0000,0xc596,0xc599,0xc59a,0xc59b,0xc59d,0xc59e,0xc59f,
  0xc5a1,0xc5a2,0xc5a3,0xc5a4,0xc5a5,0xc5a6,0xc5a7,0xc5a8,
  0xc5aa,0xc5ab,0xc5ac,0xc5ad,0xc5ae,0xc5af,0xc5b0,0xc5b1,
  0xc5b2,0xc5b3,0xc5b6,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xc5b7,0xc5ba,0xc5bf,0xc5c0,0xc5c1,0xc5c2,0xc5c3,
  0xc5cb,0xc5cd,0xc5cf,0xc5d2,0xc5d3,0xc5d5,0xc5d6,0xc5d7,
  0xc5d9,0xc5da,0xc5db,0xc5dc,0xc5dd,0xc5de,0xc5df,0xc5e2,
  0xc5e4,0xc5e6,0xc5e7,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xc5e8,0xc5e9,0xc5ea,0xc5eb,0xc5ef,0xc5f1,0xc5f2,0xc5f3,
  0xc5f5,0xc5f8,0xc5f9,0xc5fa,0xc5fb,0xc602,0xc603,0xc604,
  0xc609,0xc60a,0xc60b,0xc60d,0xc60e,0xc60f,0xc611,0xc612,
  0xc613,0xc614,0xc615,0xc616,0xc617,0xc61a,0xc61d,0xc61e,
  0xc61f,0xc620,0xc621,0xc622,0xc623,0xc626,0xc627,0xc629,
  0xc62a,0xc62b,0xc62f,0xc631,0xc632,0xc636,0xc638,0xc63a,
  0xc63c,0xc63d,0xc63e,0xc63f,0xc642,0xc643,0xc645,0xc646,
  0xc647,0xc649,0xc64a,0xc64b,0xc64c,0xc64d,0xc64e,0xc64f,
  0xc652,0xc656,0xc657,0xc658,0xc659,0xc65a,0xc65b,0xc65e,
  0xc65f,0xc661,0xc662,0xc663,0xc664,0xc665,0xc666,0xc667,
  0xc668,0xc669,0xc66a,0xc66b,0xc66d,0xc66e,0xc670,0xc672,
  0xc673,0xc674,0xc675,0xc676,0xc677,0xc67a,0xc67b,0xc67d,
  0xc67e,0xc67f,0xc681,0xc682,0xc683,0xc684,0xc685,0xc686,
  0xc687,0xc68a,0xc68c,0xc68e,0xc68f,0xc690,0xc691,0xc692,
  0xc693,0xc696,0xc697,0xc699,0xc69a,0xc69b,0xc69d,0xc69e,
  0xc69f,0xc6a0,0xc6a1,0xc6a2,0xc6a3,0xc6a6,
/* 0x9f00 */
  0x0000,0xc6a8,0xc6aa,0xc6ab,0xc6ac,0xc6ad,0xc6ae,0xc6af,
  0xc6b2,0xc6b3,0xc6b5,0xc6b6,0xc6b7,0xc6bb,0xc6bc,0xc6bd,
  0xc6be,0xc6bf,0xc6c2,0xc6c4,0xc6c6,0xc6c7,0xc6c8,0xc6c9,
  0xc6ca,0xc6cb,0xc6ce,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xc6cf,0xc6d1,0xc6d2,0xc6d3,0xc6d5,0xc6d6,0xc6d7,
  0xc6d8,0xc6d9,0xc6da,0xc6db,0xc6de,0xc6df,0xc6e2,0xc6e3,
  0xc6e4,0xc6e5,0xc6e6,0xc6e7,0xc6ea,0xc6eb,0xc6ed,0xc6ee,
  0xc6ef,0xc6f1,0xc6f2,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xc6f3,0xc6f4,0xc6f5,0xc6f6,0xc6f7,0xc6fa,0xc6fb,0xc6fc,
  0xc6fe,0xc6ff,0xc700,0xc701,0xc702,0xc703,0xc706,0xc707,
  0xc709,0xc70a,0xc70b,0xc70d,0xc70e,0xc70f,0xc710,0xc711,
  0xc712,0xc713,0xc716,0xc718,0xc71a,0xc71b,0xc71c,0xc71d,
  0xc71e,0xc71f,0xc722,0xc723,0xc725,0xc726,0xc727,0xc729,
  0xc72a,0xc72b,0xc72c,0xc72d,0xc72e,0xc72f,0xc732,0xc734,
  0xc736,0xc738,0xc739,0xc73a,0xc73b,0xc73e,0xc73f,0xc741,
  0xc742,0xc743,0xc745,0xc746,0xc747,0xc748,0xc749,0xc74b,
  0xc74e,0xc750,0xc759,0xc75a,0xc75b,0xc75d,0xc75e,0xc75f,
  0xc761,0xc762,0xc763,0xc764,0xc765,0xc766,0xc767,0xc769,
  0xc76a,0xc76c,0xc76d,0xc76e,0xc76f,0xc770,0xc771,0xc772,
  0xc773,0xc776,0xc777,0xc779,0xc77a,0xc77b,0xc77f,0xc780,
  0xc781,0xc782,0xc786,0xc78b,0xc78c,0xc78d,0xc78f,0xc792,
  0xc793,0xc795,0xc799,0xc79b,0xc79c,0xc79d,0xc79e,0xc79f,
  0xc7a2,0xc7a7,0xc7a8,0xc7a9,0xc7aa,0xc7ab,0xc7ae,0xc7af,
  0xc7b1,0xc7b2,0xc7b3,0xc7b5,0xc7b6,0xc7b7,
/* 0xa000 */
  0x0000,0xc7b8,0xc7b9,0xc7ba,0xc7bb,0xc7be,0xc7c2,0xc7c3,
  0xc7c4,0xc7c5,0xc7c6,0xc7c7,0xc7ca,0xc7cb,0xc7cd,0xc7cf,
  0xc7d1,0xc7d2,0xc7d3,0xc7d4,0xc7d5,0xc7d6,0xc7d7,0xc7d9,
  0xc7da,0xc7db,0xc7dc,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xc7de,0xc7df,0xc7e0,0xc7e1,0xc7e2,0xc7e3,0xc7e5,
  0xc7e6,0xc7e7,0xc7e9,0xc7ea,0xc7eb,0xc7ed,0xc7ee,0xc7ef,
  0xc7f0,0xc7f1,0xc7f2,0xc7f3,0xc7f4,0xc7f5,0xc7f6,0xc7f7,
  0xc7f8,0xc7f9,0xc7fa,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xc7fb,0xc7fc,0xc7fd,0xc7fe,0xc7ff,0xc802,0xc803,0xc805,
  0xc806,0xc807,0xc809,0xc80b,0xc80c,0xc80d,0xc80e,0xc80f,
  0xc812,0xc814,0xc817,0xc818,0xc819,0xc81a,0xc81b,0xc81e,
  0xc81f,0xc821,0xc822,0xc823,0xc825,0xc826,0xc827,0xc828,
  0xc829,0xc82a,0xc82b,0xc82e,0xc830,0xc832,0xc833,0xc834,
  0xc835,0xc836,0xc837,0xc839,0xc83a,0xc83b,0xc83d,0xc83e,
  0xc83f,0xc841,0xc842,0xc843,0xc844,0xc845,0xc846,0xc847,
  0xc84a,0xc84b,0xc84e,0xc84f,0xc850,0xc851,0xc852,0xc853,
  0xc855,0xc856,0xc857,0xc858,0xc859,0xc85a,0xc85b,0xc85c,
  0xc85d,0xc85e,0xc85f,0xc860,0xc861,0xc862,0xc863,0xc864,
  0xc865,0xc866,0xc867,0xc868,0xc869,0xc86a,0xc86b,0xc86c,
  0xc86d,0xc86e,0xc86f,0xc872,0xc873,0xc875,0xc876,0xc877,
  0xc879,0xc87b,0xc87c,0xc87d,0xc87e,0xc87f,0xc882,0xc884,
  0xc888,0xc889,0xc88a,0xc88e,0xc88f,0xc890,0xc891,0xc892,
  0xc893,0xc895,0xc896,0xc897,0xc898,0xc899,0xc89a,0xc89b,
  0xc89c,0xc89e,0xc8a0,0xc8a2,0xc8a3,0xc8a4,
/* 0xa100 */
  0x0000,0xc8a5,0xc8a6,0xc8a7,0xc8a9,0xc8aa,0xc8ab,0xc8ac,
  0xc8ad,0xc8ae,0xc8af,0xc8b0,0xc8b1,0xc8b2,0xc8b3,0xc8b4,
  0xc8b5,0xc8b6,0xc8b7,0xc8b8,0xc8b9,0xc8ba,0xc8bb,0xc8be,
  0xc8bf,0xc8c0,0xc8c1,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xc8c2,0xc8c3,0xc8c5,0xc8c6,0xc8c7,0xc8c9,0xc8ca,
  0xc8cb,0xc8cd,0xc8ce,0xc8cf,0xc8d0,0xc8d1,0xc8d2,0xc8d3,
  0xc8d6,0xc8d8,0xc8da,0xc8db,0xc8dc,0xc8dd,0xc8de,0xc8df,
  0xc8e2,0xc8e3,0xc8e5,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xc8e6,0xc8e7,0xc8e8,0xc8e9,0xc8ea,0xc8eb,0xc8ec,0xc8ed,
  0xc8ee,0xc8ef,0xc8f0,0xc8f1,0xc8f2,0xc8f3,0xc8f4,0xc8f6,
  0xc8f7,0xc8f8,0xc8f9,0xc8fa,0xc8fb,0xc8fe,0xc8ff,0xc901,
  0xc902,0xc903,0xc907,0xc908,0xc909,0xc90a,0xc90b,0xc90e,
  0x3000,0x3001,0x3002,0x00b7,0x2025,0x2026,0x00a8,0x3003,
  0x00ad,0x2015,0x2225,0xff3c,0x223c,0x2018,0x2019,0x201c,
  0x201d,0x3014,0x3015,0x3008,0x3009,0x300a,0x300b,0x300c,
  0x300d,0x300e,0x300f,0x3010,0x3011,0x00b1,0x00d7,0x00f7,
  0x2260,0x2264,0x2265,0x221e,0x2234,0x00b0,0x2032,0x2033,
  0x2103,0x212b,0xffe0,0xffe1,0xffe5,0x2642,0x2640,0x2220,
  0x22a5,0x2312,0x2202,0x2207,0x2261,0x2252,0x00a7,0x203b,
  0x2606,0x2605,0x25cb,0x25cf,0x25ce,0x25c7,0x25c6,0x25a1,
  0x25a0,0x25b3,0x25b2,0x25bd,0x25bc,0x2192,0x2190,0x2191,
  0x2193,0x2194,0x3013,0x226a,0x226b,0x221a,0x223d,0x221d,
  0x2235,0x222b,0x222c,0x2208,0x220b,0x2286,0x2287,0x2282,
  0x2283,0x222a,0x2229,0x2227,0x2228,0xffe2,
/* 0xa200 */
  0x0000,0xc910,0xc912,0xc913,0xc914,0xc915,0xc916,0xc917,
  0xc919,0xc91a,0xc91b,0xc91c,0xc91d,0xc91e,0xc91f,0xc920,
  0xc921,0xc922,0xc923,0xc924,0xc925,0xc926,0xc927,0xc928,
  0xc929,0xc92a,0xc92b,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xc92d,0xc92e,0xc92f,0xc930,0xc931,0xc932,0xc933,
  0xc935,0xc936,0xc937,0xc938,0xc939,0xc93a,0xc93b,0xc93c,
  0xc93d,0xc93e,0xc93f,0xc940,0xc941,0xc942,0xc943,0xc944,
  0xc945,0xc946,0xc947,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xc948,0xc949,0xc94a,0xc94b,0xc94c,0xc94d,0xc94e,0xc94f,
  0xc952,0xc953,0xc955,0xc956,0xc957,0xc959,0xc95a,0xc95b,
  0xc95c,0xc95d,0xc95e,0xc95f,0xc962,0xc964,0xc965,0xc966,
  0xc967,0xc968,0xc969,0xc96a,0xc96b,0xc96d,0xc96e,0xc96f,
  0x21d2,0x21d4,0x2200,0x2203,0x00b4,0xff5e,0x02c7,0x02d8,
  0x02dd,0x02da,0x02d9,0x00b8,0x02db,0x00a1,0x00bf,0x02d0,
  0x222e,0x2211,0x220f,0x00a4,0x2109,0x2030,0x25c1,0x25c0,
  0x25b7,0x25b6,0x2664,0x2660,0x2661,0x2665,0x2667,0x2663,
  0x2299,0x25c8,0x25a3,0x25d0,0x25d1,0x2592,0x25a4,0x25a5,
  0x25a8,0x25a7,0x25a6,0x25a9,0x2668,0x260f,0x260e,0x261c,
  0x261e,0x00b6,0x2020,0x2021,0x2195,0x2197,0x2199,0x2196,
  0x2198,0x266d,0x2669,0x266a,0x266c,0x327f,0x321c,0x2116,
  0x33c7,0x2122,0x33c2,0x33d8,0x2121,0x20ac,0x00ae,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
/* 0xa300 */
  0x0000,0xc971,0xc972,0xc973,0xc975,0xc976,0xc977,0xc978,
  0xc979,0xc97a,0xc97b,0xc97d,0xc97e,0xc97f,0xc980,0xc981,
  0xc982,0xc983,0xc984,0xc985,0xc986,0xc987,0xc98a,0xc98b,
  0xc98d,0xc98e,0xc98f,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xc991,0xc992,0xc993,0xc994,0xc995,0xc996,0xc997,
  0xc99a,0xc99c,0xc99e,0xc99f,0xc9a0,0xc9a1,0xc9a2,0xc9a3,
  0xc9a4,0xc9a5,0xc9a6,0xc9a7,0xc9a8,0xc9a9,0xc9aa,0xc9ab,
  0xc9ac,0xc9ad,0xc9ae,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xc9af,0xc9b0,0xc9b1,0xc9b2,0xc9b3,0xc9b4,0xc9b5,0xc9b6,
  0xc9b7,0xc9b8,0xc9b9,0xc9ba,0xc9bb,0xc9bc,0xc9bd,0xc9be,
  0xc9bf,0xc9c2,0xc9c3,0xc9c5,0xc9c6,0xc9c9,0xc9cb,0xc9cc,
  0xc9cd,0xc9ce,0xc9cf,0xc9d2,0xc9d4,0xc9d7,0xc9d8,0xc9db,
  0xff01,0xff02,0xff03,0xff04,0xff05,0xff06,0xff07,0xff08,
  0xff09,0xff0a,0xff0b,0xff0c,0xff0d,0xff0e,0xff0f,0xff10,
  0xff11,0xff12,0xff13,0xff14,0xff15,0xff16,0xff17,0xff18,
  0xff19,0xff1a,0xff1b,0xff1c,0xff1d,0xff1e,0xff1f,0xff20,
  0xff21,0xff22,0xff23,0xff24,0xff25,0xff26,0xff27,0xff28,
  0xff29,0xff2a,0xff2b,0xff2c,0xff2d,0xff2e,0xff2f,0xff30,
  0xff31,0xff32,0xff33,0xff34,0xff35,0xff36,0xff37,0xff38,
  0xff39,0xff3a,0xff3b,0xffe6,0xff3d,0xff3e,0xff3f,0xff40,
  0xff41,0xff42,0xff43,0xff44,0xff45,0xff46,0xff47,0xff48,
  0xff49,0xff4a,0xff4b,0xff4c,0xff4d,0xff4e,0xff4f,0xff50,
  0xff51,0xff52,0xff53,0xff54,0xff55,0xff56,0xff57,0xff58,
  0xff59,0xff5a,0xff5b,0xff5c,0xff5d,0xffe3,
/* 0xa400 */
  0x0000,0xc9de,0xc9df,0xc9e1,0xc9e3,0xc9e5,0xc9e6,0xc9e8,
  0xc9e9,0xc9ea,0xc9eb,0xc9ee,0xc9f2,0xc9f3,0xc9f4,0xc9f5,
  0xc9f6,0xc9f7,0xc9fa,0xc9fb,0xc9fd,0xc9fe,0xc9ff,0xca01,
  0xca02,0xca03,0xca04,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xca05,0xca06,0xca07,0xca0a,0xca0e,0xca0f,0xca10,
  0xca11,0xca12,0xca13,0xca15,0xca16,0xca17,0xca19,0xca1a,
  0xca1b,0xca1c,0xca1d,0xca1e,0xca1f,0xca20,0xca21,0xca22,
  0xca23,0xca24,0xca25,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xca26,0xca27,0xca28,0xca2a,0xca2b,0xca2c,0xca2d,0xca2e,
  0xca2f,0xca30,0xca31,0xca32,0xca33,0xca34,0xca35,0xca36,
  0xca37,0xca38,0xca39,0xca3a,0xca3b,0xca3c,0xca3d,0xca3e,
  0xca3f,0xca40,0xca41,0xca42,0xca43,0xca44,0xca45,0xca46,
  0xffa1,0xffa2,0xffa3,0xffa4,0xffa5,0xffa6,0xffa7,0xffa8,
  0xffa9,0xffaa,0xffab,0xffac,0xffad,0xffae,0xffaf,0xffb0,
  0xffb1,0xffb2,0xffb3,0xffb4,0xffb5,0xffb6,0xffb7,0xffb8,
  0xffb9,0xffba,0xffbb,0xffbc,0xffbd,0xffbe,0xffc2,0xffc3,
  0xffc4,0xffc5,0xffc6,0xffc7,0xffca,0xffcb,0xffcc,0xffcd,
  0xffce,0xffcf,0xffd2,0xffd3,0xffd4,0xffd5,0xffd6,0xffd7,
  0xffda,0xffdb,0xffdc,0xffa0,0x3165,0x3166,0x3167,0x3168,
  0x3169,0x316a,0x316b,0x316c,0x316d,0x316e,0x316f,0x3170,
  0x3171,0x3172,0x3173,0x3174,0x3175,0x3176,0x3177,0x3178,
  0x3179,0x317a,0x317b,0x317c,0x317d,0x317e,0x317f,0x3180,
  0x3181,0x3182,0x3183,0x3184,0x3185,0x3186,0x3187,0x3188,
  0x3189,0x318a,0x318b,0x318c,0x318d,0x318e,
/* 0xa500 */
  0x0000,0xca47,0xca48,0xca49,0xca4a,0xca4b,0xca4e,0xca4f,
  0xca51,0xca52,0xca53,0xca55,0xca56,0xca57,0xca58,0xca59,
  0xca5a,0xca5b,0xca5e,0xca62,0xca63,0xca64,0xca65,0xca66,
  0xca67,0xca69,0xca6a,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xca6b,0xca6c,0xca6d,0xca6e,0xca6f,0xca70,0xca71,
  0xca72,0xca73,0xca74,0xca75,0xca76,0xca77,0xca78,0xca79,
  0xca7a,0xca7b,0xca7c,0xca7e,0xca7f,0xca80,0xca81,0xca82,
  0xca83,0xca85,0xca86,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xca87,0xca88,0xca89,0xca8a,0xca8b,0xca8c,0xca8d,0xca8e,
  0xca8f,0xca90,0xca91,0xca92,0xca93,0xca94,0xca95,0xca96,
  0xca97,0xca99,0xca9a,0xca9b,0xca9c,0xca9d,0xca9e,0xca9f,
  0xcaa0,0xcaa1,0xcaa2,0xcaa3,0xcaa4,0xcaa5,0xcaa6,0xcaa7,
  0x2170,0x2171,0x2172,0x2173,0x2174,0x2175,0x2176,0x2177,
  0x2178,0x2179,0x0000,0x0000,0x0000,0x0000,0x0000,0x2160,
  0x2161,0x2162,0x2163,0x2164,0x2165,0x2166,0x2167,0x2168,
  0x2169,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0391,0x0392,0x0393,0x0394,0x0395,0x0396,0x0397,0x0398,
  0x0399,0x039a,0x039b,0x039c,0x039d,0x039e,0x039f,0x03a0,
  0x03a1,0x03a3,0x03a4,0x03a5,0x03a6,0x03a7,0x03a8,0x03a9,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x03b1,0x03b2,0x03b3,0x03b4,0x03b5,0x03b6,0x03b7,0x03b8,
  0x03b9,0x03ba,0x03bb,0x03bc,0x03bd,0x03be,0x03bf,0x03c0,
  0x03c1,0x03c3,0x03c4,0x03c5,0x03c6,0x03c7,0x03c8,0x03c9,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
/* 0xa600 */
  0x0000,0xcaa8,0xcaa9,0xcaaa,0xcaab,0xcaac,0xcaad,0xcaae,
  0xcaaf,0xcab0,0xcab1,0xcab2,0xcab3,0xcab4,0xcab5,0xcab6,
  0xcab7,0xcab8,0xcab9,0xcaba,0xcabb,0xcabe,0xcabf,0xcac1,
  0xcac2,0xcac3,0xcac5,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xcac6,0xcac7,0xcac8,0xcac9,0xcaca,0xcacb,0xcace,
  0xcad0,0xcad2,0xcad4,0xcad5,0xcad6,0xcad7,0xcada,0xcadb,
  0xcadc,0xcadd,0xcade,0xcadf,0xcae1,0xcae2,0xcae3,0xcae4,
  0xcae5,0xcae6,0xcae7,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xcae8,0xcae9,0xcaea,0xcaeb,0xcaed,0xcaee,0xcaef,0xcaf0,
  0xcaf1,0xcaf2,0xcaf3,0xcaf5,0xcaf6,0xcaf7,0xcaf8,0xcaf9,
  0xcafa,0xcafb,0xcafc,0xcafd,0xcafe,0xcaff,0xcb00,0xcb01,
  0xcb02,0xcb03,0xcb04,0xcb05,0xcb06,0xcb07,0xcb09,0xcb0a,
  0x2500,0x2502,0x250c,0x2510,0x2518,0x2514,0x251c,0x252c,
  0x2524,0x2534,0x253c,0x2501,0x2503,0x250f,0x2513,0x251b,
  0x2517,0x2523,0x2533,0x252b,0x253b,0x254b,0x2520,0x252f,
  0x2528,0x2537,0x253f,0x251d,0x2530,0x2525,0x2538,0x2542,
  0x2512,0x2511,0x251a,0x2519,0x2516,0x2515,0x250e,0x250d,
  0x251e,0x251f,0x2521,0x2522,0x2526,0x2527,0x2529,0x252a,
  0x252d,0x252e,0x2531,0x2532,0x2535,0x2536,0x2539,0x253a,
  0x253d,0x253e,0x2540,0x2541,0x2543,0x2544,0x2545,0x2546,
  0x2547,0x2548,0x2549,0x254a,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
/* 0xa700 */
  0x0000,0xcb0b,0xcb0c,0xcb0d,0xcb0e,0xcb0f,0xcb11,0xcb12,
  0xcb13,0xcb15,0xcb16,0xcb17,0xcb19,0xcb1a,0xcb1b,0xcb1c,
  0xcb1d,0xcb1e,0xcb1f,0xcb22,0xcb23,0xcb24,0xcb25,0xcb26,
  0xcb27,0xcb28,0xcb29,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xcb2a,0xcb2b,0xcb2c,0xcb2d,0xcb2e,0xcb2f,0xcb30,
  0xcb31,0xcb32,0xcb33,0xcb34,0xcb35,0xcb36,0xcb37,0xcb38,
  0xcb39,0xcb3a,0xcb3b,0xcb3c,0xcb3d,0xcb3e,0xcb3f,0xcb40,
  0xcb42,0xcb43,0xcb44,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xcb45,0xcb46,0xcb47,0xcb4a,0xcb4b,0xcb4d,0xcb4e,0xcb4f,
  0xcb51,0xcb52,0xcb53,0xcb54,0xcb55,0xcb56,0xcb57,0xcb5a,
  0xcb5b,0xcb5c,0xcb5e,0xcb5f,0xcb60,0xcb61,0xcb62,0xcb63,
  0xcb65,0xcb66,0xcb67,0xcb68,0xcb69,0xcb6a,0xcb6b,0xcb6c,
  0x3395,0x3396,0x3397,0x2113,0x3398,0x33c4,0x33a3,0x33a4,
  0x33a5,0x33a6,0x3399,0x339a,0x339b,0x339c,0x339d,0x339e,
  0x339f,0x33a0,0x33a1,0x33a2,0x33ca,0x338d,0x338e,0x338f,
  0x33cf,0x3388,0x3389,0x33c8,0x33a7,0x33a8,0x33b0,0x33b1,
  0x33b2,0x33b3,0x33b4,0x33b5,0x33b6,0x33b7,0x33b8,0x33b9,
  0x3380,0x3381,0x3382,0x3383,0x3384,0x33ba,0x33bb,0x33bc,
  0x33bd,0x33be,0x33bf,0x3390,0x3391,0x3392,0x3393,0x3394,
  0x2126,0x33c0,0x33c1,0x338a,0x338b,0x338c,0x33d6,0x33c5,
  0x33ad,0x33ae,0x33af,0x33db,0x33a9,0x33aa,0x33ab,0x33ac,
  0x33dd,0x33d0,0x33d3,0x33c3,0x33c9,0x33dc,0x33c6,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
/* 0xa800 */
  0x0000,0xcb6d,0xcb6e,0xcb6f,0xcb70,0xcb71,0xcb72,0xcb73,
  0xcb74,0xcb75,0xcb76,0xcb77,0xcb7a,0xcb7b,0xcb7c,0xcb7d,
  0xcb7e,0xcb7f,0xcb80,0xcb81,0xcb82,0xcb83,0xcb84,0xcb85,
  0xcb86,0xcb87,0xcb88,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xcb89,0xcb8a,0xcb8b,0xcb8c,0xcb8d,0xcb8e,0xcb8f,
  0xcb90,0xcb91,0xcb92,0xcb93,0xcb94,0xcb95,0xcb96,0xcb97,
  0xcb98,0xcb99,0xcb9a,0xcb9b,0xcb9d,0xcb9e,0xcb9f,0xcba0,
  0xcba1,0xcba2,0xcba3,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xcba4,0xcba5,0xcba6,0xcba7,0xcba8,0xcba9,0xcbaa,0xcbab,
  0xcbac,0xcbad,0xcbae,0xcbaf,0xcbb0,0xcbb1,0xcbb2,0xcbb3,
  0xcbb4,0xcbb5,0xcbb6,0xcbb7,0xcbb9,0xcbba,0xcbbb,0xcbbc,
  0xcbbd,0xcbbe,0xcbbf,0xcbc0,0xcbc1,0xcbc2,0xcbc3,0xcbc4,
  0x00c6,0x00d0,0x00aa,0x0126,0x0000,0x0132,0x0000,0x013f,
  0x0141,0x00d8,0x0152,0x00ba,0x00de,0x0166,0x014a,0x0000,
  0x3260,0x3261,0x3262,0x3263,0x3264,0x3265,0x3266,0x3267,
  0x3268,0x3269,0x326a,0x326b,0x326c,0x326d,0x326e,0x326f,
  0x3270,0x3271,0x3272,0x3273,0x3274,0x3275,0x3276,0x3277,
  0x3278,0x3279,0x327a,0x327b,0x24d0,0x24d1,0x24d2,0x24d3,
  0x24d4,0x24d5,0x24d6,0x24d7,0x24d8,0x24d9,0x24da,0x24db,
  0x24dc,0x24dd,0x24de,0x24df,0x24e0,0x24e1,0x24e2,0x24e3,
  0x24e4,0x24e5,0x24e6,0x24e7,0x24e8,0x24e9,0x2460,0x2461,
  0x2462,0x2463,0x2464,0x2465,0x2466,0x2467,0x2468,0x2469,
  0x246a,0x246b,0x246c,0x246d,0x246e,0x00bd,0x2153,0x2154,
  0x00bc,0x00be,0x215b,0x215c,0x215d,0x215e,
/* 0xa900 */
  0x0000,0xcbc5,0xcbc6,0xcbc7,0xcbc8,0xcbc9,0xcbca,0xcbcb,
  0xcbcc,0xcbcd,0xcbce,0xcbcf,0xcbd0,0xcbd1,0xcbd2,0xcbd3,
  0xcbd5,0xcbd6,0xcbd7,0xcbd8,0xcbd9,0xcbda,0xcbdb,0xcbdc,
  0xcbdd,0xcbde,0xcbdf,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xcbe0,0xcbe1,0xcbe2,0xcbe3,0xcbe5,0xcbe6,0xcbe8,
  0xcbea,0xcbeb,0xcbec,0xcbed,0xcbee,0xcbef,0xcbf0,0xcbf1,
  0xcbf2,0xcbf3,0xcbf4,0xcbf5,0xcbf6,0xcbf7,0xcbf8,0xcbf9,
  0xcbfa,0xcbfb,0xcbfc,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xcbfd,0xcbfe,0xcbff,0xcc00,0xcc01,0xcc02,0xcc03,0xcc04,
  0xcc05,0xcc06,0xcc07,0xcc08,0xcc09,0xcc0a,0xcc0b,0xcc0e,
  0xcc0f,0xcc11,0xcc12,0xcc13,0xcc15,0xcc16,0xcc17,0xcc18,
  0xcc19,0xcc1a,0xcc1b,0xcc1e,0xcc1f,0xcc20,0xcc23,0xcc24,
  0x00e6,0x0111,0x00f0,0x0127,0x0131,0x0133,0x0138,0x0140,
  0x0142,0x00f8,0x0153,0x00df,0x00fe,0x0167,0x014b,0x0149,
  0x3200,0x3201,0x3202,0x3203,0x3204,0x3205,0x3206,0x3207,
  0x3208,0x3209,0x320a,0x320b,0x320c,0x320d,0x320e,0x320f,
  0x3210,0x3211,0x3212,0x3213,0x3214,0x3215,0x3216,0x3217,
  0x3218,0x3219,0x321a,0x321b,0x249c,0x249d,0x249e,0x249f,
  0x24a0,0x24a1,0x24a2,0x24a3,0x24a4,0x24a5,0x24a6,0x24a7,
  0x24a8,0x24a9,0x24aa,0x24ab,0x24ac,0x24ad,0x24ae,0x24af,
  0x24b0,0x24b1,0x24b2,0x24b3,0x24b4,0x24b5,0x2474,0x2475,
  0x2476,0x2477,0x2478,0x2479,0x247a,0x247b,0x247c,0x247d,
  0x247e,0x247f,0x2480,0x2481,0x2482,0x00b9,0x00b2,0x00b3,
  0x2074,0x207f,0x2081,0x2082,0x2083,0x2084,
/* 0xaa00 */
  0x0000,0xcc25,0xcc26,0xcc2a,0xcc2b,0xcc2d,0xcc2f,0xcc31,
  0xcc32,0xcc33,0xcc34,0xcc35,0xcc36,0xcc37,0xcc3a,0xcc3f,
  0xcc40,0xcc41,0xcc42,0xcc43,0xcc46,0xcc47,0xcc49,0xcc4a,
  0xcc4b,0xcc4d,0xcc4e,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xcc4f,0xcc50,0xcc51,0xcc52,0xcc53,0xcc56,0xcc5a,
  0xcc5b,0xcc5c,0xcc5d,0xcc5e,0xcc5f,0xcc61,0xcc62,0xcc63,
  0xcc65,0xcc67,0xcc69,0xcc6a,0xcc6b,0xcc6c,0xcc6d,0xcc6e,
  0xcc6f,0xcc71,0xcc72,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xcc73,0xcc74,0xcc76,0xcc77,0xcc78,0xcc79,0xcc7a,0xcc7b,
  0xcc7c,0xcc7d,0xcc7e,0xcc7f,0xcc80,0xcc81,0xcc82,0xcc83,
  0xcc84,0xcc85,0xcc86,0xcc87,0xcc88,0xcc89,0xcc8a,0xcc8b,
  0xcc8c,0xcc8d,0xcc8e,0xcc8f,0xcc90,0xcc91,0xcc92,0xcc93,
  0x3041,0x3042,0x3043,0x3044,0x3045,0x3046,0x3047,0x3048,
  0x3049,0x304a,0x304b,0x304c,0x304d,0x304e,0x304f,0x3050,
  0x3051,0x3052,0x3053,0x3054,0x3055,0x3056,0x3057,0x3058,
  0x3059,0x305a,0x305b,0x305c,0x305d,0x305e,0x305f,0x3060,
  0x3061,0x3062,0x3063,0x3064,0x3065,0x3066,0x3067,0x3068,
  0x3069,0x306a,0x306b,0x306c,0x306d,0x306e,0x306f,0x3070,
  0x3071,0x3072,0x3073,0x3074,0x3075,0x3076,0x3077,0x3078,
  0x3079,0x307a,0x307b,0x307c,0x307d,0x307e,0x307f,0x3080,
  0x3081,0x3082,0x3083,0x3084,0x3085,0x3086,0x3087,0x3088,
  0x3089,0x308a,0x308b,0x308c,0x308d,0x308e,0x308f,0x3090,
  0x3091,0x3092,0x3093,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
/* 0xab00 */
  0x0000,0xcc94,0xcc95,0xcc96,0xcc97,0xcc9a,0xcc9b,0xcc9d,
  0xcc9e,0xcc9f,0xcca1,0xcca2,0xcca3,0xcca4,0xcca5,0xcca6,
  0xcca7,0xccaa,0xccae,0xccaf,0xccb0,0xccb1,0xccb2,0xccb3,
  0xccb6,0xccb7,0xccb9,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xccba,0xccbb,0xccbd,0xccbe,0xccbf,0xccc0,0xccc1,
  0xccc2,0xccc3,0xccc6,0xccc8,0xccca,0xcccb,0xcccc,0xcccd,
  0xccce,0xcccf,0xccd1,0xccd2,0xccd3,0xccd5,0xccd6,0xccd7,
  0xccd8,0xccd9,0xccda,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xccdb,0xccdc,0xccdd,0xccde,0xccdf,0xcce0,0xcce1,0xcce2,
  0xcce3,0xcce5,0xcce6,0xcce7,0xcce8,0xcce9,0xccea,0xcceb,
  0xcced,0xccee,0xccef,0xccf1,0xccf2,0xccf3,0xccf4,0xccf5,
  0xccf6,0xccf7,0xccf8,0xccf9,0xccfa,0xccfb,0xccfc,0xccfd,
  0x30a1,0x30a2,0x30a3,0x30a4,0x30a5,0x30a6,0x30a7,0x30a8,
  0x30a9,0x30aa,0x30ab,0x30ac,0x30ad,0x30ae,0x30af,0x30b0,
  0x30b1,0x30b2,0x30b3,0x30b4,0x30b5,0x30b6,0x30b7,0x30b8,
  0x30b9,0x30ba,0x30bb,0x30bc,0x30bd,0x30be,0x30bf,0x30c0,
  0x30c1,0x30c2,0x30c3,0x30c4,0x30c5,0x30c6,0x30c7,0x30c8,
  0x30c9,0x30ca,0x30cb,0x30cc,0x30cd,0x30ce,0x30cf,0x30d0,
  0x30d1,0x30d2,0x30d3,0x30d4,0x30d5,0x30d6,0x30d7,0x30d8,
  0x30d9,0x30da,0x30db,0x30dc,0x30dd,0x30de,0x30df,0x30e0,
  0x30e1,0x30e2,0x30e3,0x30e4,0x30e5,0x30e6,0x30e7,0x30e8,
  0x30e9,0x30ea,0x30eb,0x30ec,0x30ed,0x30ee,0x30ef,0x30f0,
  0x30f1,0x30f2,0x30f3,0x30f4,0x30f5,0x30f6,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
/* 0xac00 */
  0x0000,0xccfe,0xccff,0xcd00,0xcd02,0xcd03,0xcd04,0xcd05,
  0xcd06,0xcd07,0xcd0a,0xcd0b,0xcd0d,0xcd0e,0xcd0f,0xcd11,
  0xcd12,0xcd13,0xcd14,0xcd15,0xcd16,0xcd17,0xcd1a,0xcd1c,
  0xcd1e,0xcd1f,0xcd20,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xcd21,0xcd22,0xcd23,0xcd25,0xcd26,0xcd27,0xcd29,
  0xcd2a,0xcd2b,0xcd2d,0xcd2e,0xcd2f,0xcd30,0xcd31,0xcd32,
  0xcd33,0xcd34,0xcd35,0xcd36,0xcd37,0xcd38,0xcd3a,0xcd3b,
  0xcd3c,0xcd3d,0xcd3e,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xcd3f,0xcd40,0xcd41,0xcd42,0xcd43,0xcd44,0xcd45,0xcd46,
  0xcd47,0xcd48,0xcd49,0xcd4a,0xcd4b,0xcd4c,0xcd4d,0xcd4e,
  0xcd4f,0xcd50,0xcd51,0xcd52,0xcd53,0xcd54,0xcd55,0xcd56,
  0xcd57,0xcd58,0xcd59,0xcd5a,0xcd5b,0xcd5d,0xcd5e,0xcd5f,
  0x0410,0x0411,0x0412,0x0413,0x0414,0x0415,0x0401,0x0416,
  0x0417,0x0418,0x0419,0x041a,0x041b,0x041c,0x041d,0x041e,
  0x041f,0x0420,0x0421,0x0422,0x0423,0x0424,0x0425,0x0426,
  0x0427,0x0428,0x0429,0x042a,0x042b,0x042c,0x042d,0x042e,
  0x042f,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0430,0x0431,0x0432,0x0433,0x0434,0x0435,0x0451,0x0436,
  0x0437,0x0438,0x0439,0x043a,0x043b,0x043c,0x043d,0x043e,
  0x043f,0x0440,0x0441,0x0442,0x0443,0x0444,0x0445,0x0446,
  0x0447,0x0448,0x0449,0x044a,0x044b,0x044c,0x044d,0x044e,
  0x044f,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
/* 0xad00 */
  0x0000,0xcd61,0xcd62,0xcd63,0xcd65,0xcd66,0xcd67,0xcd68,
  0xcd69,0xcd6a,0xcd6b,0xcd6e,0xcd70,0xcd72,0xcd73,0xcd74,
  0xcd75,0xcd76,0xcd77,0xcd79,0xcd7a,0xcd7b,0xcd7c,0xcd7d,
  0xcd7e,0xcd7f,0xcd80,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xcd81,0xcd82,0xcd83,0xcd84,0xcd85,0xcd86,0xcd87,
  0xcd89,0xcd8a,0xcd8b,0xcd8c,0xcd8d,0xcd8e,0xcd8f,0xcd90,
  0xcd91,0xcd92,0xcd93,0xcd96,0xcd97,0xcd99,0xcd9a,0xcd9b,
  0xcd9d,0xcd9e,0xcd9f,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xcda0,0xcda1,0xcda2,0xcda3,0xcda6,0xcda8,0xcdaa,0xcdab,
  0xcdac,0xcdad,0xcdae,0xcdaf,0xcdb1,0xcdb2,0xcdb3,0xcdb4,
  0xcdb5,0xcdb6,0xcdb7,0xcdb8,0xcdb9,0xcdba,0xcdbb,0xcdbc,
  0xcdbd,0xcdbe,0xcdbf,0xcdc0,0xcdc1,0xcdc2,0xcdc3,0xcdc5,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
/* 0xae00 */
  0x0000,0xcdc6,0xcdc7,0xcdc8,0xcdc9,0xcdca,0xcdcb,0xcdcd,
  0xcdce,0xcdcf,0xcdd1,0xcdd2,0xcdd3,0xcdd4,0xcdd5,0xcdd6,
  0xcdd7,0xcdd8,0xcdd9,0xcdda,0xcddb,0xcddc,0xcddd,0xcdde,
  0xcddf,0xcde0,0xcde1,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xcde2,0xcde3,0xcde4,0xcde5,0xcde6,0xcde7,0xcde9,
  0xcdea,0xcdeb,0xcded,0xcdee,0xcdef,0xcdf1,0xcdf2,0xcdf3,
  0xcdf4,0xcdf5,0xcdf6,0xcdf7,0xcdfa,0xcdfc,0xcdfe,0xcdff,
  0xce00,0xce01,0xce02,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xce03,0xce05,0xce06,0xce07,0xce09,0xce0a,0xce0b,0xce0d,
  0xce0e,0xce0f,0xce10,0xce11,0xce12,0xce13,0xce15,0xce16,
  0xce17,0xce18,0xce1a,0xce1b,0xce1c,0xce1d,0xce1e,0xce1f,
  0xce22,0xce23,0xce25,0xce26,0xce27,0xce29,0xce2a,0xce2b,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
/* 0xaf00 */
  0x0000,0xce2c,0xce2d,0xce2e,0xce2f,0xce32,0xce34,0xce36,
  0xce37,0xce38,0xce39,0xce3a,0xce3b,0xce3c,0xce3d,0xce3e,
  0xce3f,0xce40,0xce41,0xce42,0xce43,0xce44,0xce45,0xce46,
  0xce47,0xce48,0xce49,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xce4a,0xce4b,0xce4c,0xce4d,0xce4e,0xce4f,0xce50,
  0xce51,0xce52,0xce53,0xce54,0xce55,0xce56,0xce57,0xce5a,
  0xce5b,0xce5d,0xce5e,0xce62,0xce63,0xce64,0xce65,0xce66,
  0xce67,0xce6a,0xce6c,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xce6e,0xce6f,0xce70,0xce71,0xce72,0xce73,0xce76,0xce77,
  0xce79,0xce7a,0xce7b,0xce7d,0xce7e,0xce7f,0xce80,0xce81,
  0xce82,0xce83,0xce86,0xce88,0xce8a,0xce8b,0xce8c,0xce8d,
  0xce8e,0xce8f,0xce92,0xce93,0xce95,0xce96,0xce97,0xce99,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
/* 0xb000 */
  0x0000,0xce9a,0xce9b,0xce9c,0xce9d,0xce9e,0xce9f,0xcea2,
  0xcea6,0xcea7,0xcea8,0xcea9,0xceaa,0xceab,0xceae,0xceaf,
  0xceb0,0xceb1,0xceb2,0xceb3,0xceb4,0xceb5,0xceb6,0xceb7,
  0xceb8,0xceb9,0xceba,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xcebb,0xcebc,0xcebd,0xcebe,0xcebf,0xcec0,0xcec2,
  0xcec3,0xcec4,0xcec5,0xcec6,0xcec7,0xcec8,0xcec9,0xceca,
  0xcecb,0xcecc,0xcecd,0xcece,0xcecf,0xced0,0xced1,0xced2,
  0xced3,0xced4,0xced5,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xced6,0xced7,0xced8,0xced9,0xceda,0xcedb,0xcedc,0xcedd,
  0xcede,0xcedf,0xcee0,0xcee1,0xcee2,0xcee3,0xcee6,0xcee7,
  0xcee9,0xceea,0xceed,0xceee,0xceef,0xcef0,0xcef1,0xcef2,
  0xcef3,0xcef6,0xcefa,0xcefb,0xcefc,0xcefd,0xcefe,0xceff,
  0xac00,0xac01,0xac04,0xac07,0xac08,0xac09,0xac0a,0xac10,
  0xac11,0xac12,0xac13,0xac14,0xac15,0xac16,0xac17,0xac19,
  0xac1a,0xac1b,0xac1c,0xac1d,0xac20,0xac24,0xac2c,0xac2d,
  0xac2f,0xac30,0xac31,0xac38,0xac39,0xac3c,0xac40,0xac4b,
  0xac4d,0xac54,0xac58,0xac5c,0xac70,0xac71,0xac74,0xac77,
  0xac78,0xac7a,0xac80,0xac81,0xac83,0xac84,0xac85,0xac86,
  0xac89,0xac8a,0xac8b,0xac8c,0xac90,0xac94,0xac9c,0xac9d,
  0xac9f,0xaca0,0xaca1,0xaca8,0xaca9,0xacaa,0xacac,0xacaf,
  0xacb0,0xacb8,0xacb9,0xacbb,0xacbc,0xacbd,0xacc1,0xacc4,
  0xacc8,0xaccc,0xacd5,0xacd7,0xace0,0xace1,0xace4,0xace7,
  0xace8,0xacea,0xacec,0xacef,0xacf0,0xacf1,0xacf3,0xacf5,
  0xacf6,0xacfc,0xacfd,0xad00,0xad04,0xad06,
/* 0xb100 */
  0x0000,0xcf02,0xcf03,0xcf05,0xcf06,0xcf07,0xcf09,0xcf0a,
  0xcf0b,0xcf0c,0xcf0d,0xcf0e,0xcf0f,0xcf12,0xcf14,0xcf16,
  0xcf17,0xcf18,0xcf19,0xcf1a,0xcf1b,0xcf1d,0xcf1e,0xcf1f,
  0xcf21,0xcf22,0xcf23,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xcf25,0xcf26,0xcf27,0xcf28,0xcf29,0xcf2a,0xcf2b,
  0xcf2e,0xcf32,0xcf33,0xcf34,0xcf35,0xcf36,0xcf37,0xcf39,
  0xcf3a,0xcf3b,0xcf3c,0xcf3d,0xcf3e,0xcf3f,0xcf40,0xcf41,
  0xcf42,0xcf43,0xcf44,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xcf45,0xcf46,0xcf47,0xcf48,0xcf49,0xcf4a,0xcf4b,0xcf4c,
  0xcf4d,0xcf4e,0xcf4f,0xcf50,0xcf51,0xcf52,0xcf53,0xcf56,
  0xcf57,0xcf59,0xcf5a,0xcf5b,0xcf5d,0xcf5e,0xcf5f,0xcf60,
  0xcf61,0xcf62,0xcf63,0xcf66,0xcf68,0xcf6a,0xcf6b,0xcf6c,
  0xad0c,0xad0d,0xad0f,0xad11,0xad18,0xad1c,0xad20,0xad29,
  0xad2c,0xad2d,0xad34,0xad35,0xad38,0xad3c,0xad44,0xad45,
  0xad47,0xad49,0xad50,0xad54,0xad58,0xad61,0xad63,0xad6c,
  0xad6d,0xad70,0xad73,0xad74,0xad75,0xad76,0xad7b,0xad7c,
  0xad7d,0xad7f,0xad81,0xad82,0xad88,0xad89,0xad8c,0xad90,
  0xad9c,0xad9d,0xada4,0xadb7,0xadc0,0xadc1,0xadc4,0xadc8,
  0xadd0,0xadd1,0xadd3,0xaddc,0xade0,0xade4,0xadf8,0xadf9,
  0xadfc,0xadff,0xae00,0xae01,0xae08,0xae09,0xae0b,0xae0d,
  0xae14,0xae30,0xae31,0xae34,0xae37,0xae38,0xae3a,0xae40,
  0xae41,0xae43,0xae45,0xae46,0xae4a,0xae4c,0xae4d,0xae4e,
  0xae50,0xae54,0xae56,0xae5c,0xae5d,0xae5f,0xae60,0xae61,
  0xae65,0xae68,0xae69,0xae6c,0xae70,0xae78,
/* 0xb200 */
  0x0000,0xcf6d,0xcf6e,0xcf6f,0xcf72,0xcf73,0xcf75,0xcf76,
  0xcf77,0xcf79,0xcf7a,0xcf7b,0xcf7c,0xcf7d,0xcf7e,0xcf7f,
  0xcf81,0xcf82,0xcf83,0xcf84,0xcf86,0xcf87,0xcf88,0xcf89,
  0xcf8a,0xcf8b,0xcf8d,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xcf8e,0xcf8f,0xcf90,0xcf91,0xcf92,0xcf93,0xcf94,
  0xcf95,0xcf96,0xcf97,0xcf98,0xcf99,0xcf9a,0xcf9b,0xcf9c,
  0xcf9d,0xcf9e,0xcf9f,0xcfa0,0xcfa2,0xcfa3,0xcfa4,0xcfa5,
  0xcfa6,0xcfa7,0xcfa9,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xcfaa,0xcfab,0xcfac,0xcfad,0xcfae,0xcfaf,0xcfb1,0xcfb2,
  0xcfb3,0xcfb4,0xcfb5,0xcfb6,0xcfb7,0xcfb8,0xcfb9,0xcfba,
  0xcfbb,0xcfbc,0xcfbd,0xcfbe,0xcfbf,0xcfc0,0xcfc1,0xcfc2,
  0xcfc3,0xcfc5,0xcfc6,0xcfc7,0xcfc8,0xcfc9,0xcfca,0xcfcb,
  0xae79,0xae7b,0xae7c,0xae7d,0xae84,0xae85,0xae8c,0xaebc,
  0xaebd,0xaebe,0xaec0,0xaec4,0xaecc,0xaecd,0xaecf,0xaed0,
  0xaed1,0xaed8,0xaed9,0xaedc,0xaee8,0xaeeb,0xaeed,0xaef4,
  0xaef8,0xaefc,0xaf07,0xaf08,0xaf0d,0xaf10,0xaf2c,0xaf2d,
  0xaf30,0xaf32,0xaf34,0xaf3c,0xaf3d,0xaf3f,0xaf41,0xaf42,
  0xaf43,0xaf48,0xaf49,0xaf50,0xaf5c,0xaf5d,0xaf64,0xaf65,
  0xaf79,0xaf80,0xaf84,0xaf88,0xaf90,0xaf91,0xaf95,0xaf9c,
  0xafb8,0xafb9,0xafbc,0xafc0,0xafc7,0xafc8,0xafc9,0xafcb,
  0xafcd,0xafce,0xafd4,0xafdc,0xafe8,0xafe9,0xaff0,0xaff1,
  0xaff4,0xaff8,0xb000,0xb001,0xb004,0xb00c,0xb010,0xb014,
  0xb01c,0xb01d,0xb028,0xb044,0xb045,0xb048,0xb04a,0xb04c,
  0xb04e,0xb053,0xb054,0xb055,0xb057,0xb059,
/* 0xb300 */
  0x0000,0xcfcc,0xcfcd,0xcfce,0xcfcf,0xcfd0,0xcfd1,0xcfd2,
  0xcfd3,0xcfd4,0xcfd5,0xcfd6,0xcfd7,0xcfd8,0xcfd9,0xcfda,
  0xcfdb,0xcfdc,0xcfdd,0xcfde,0xcfdf,0xcfe2,0xcfe3,0xcfe5,
  0xcfe6,0xcfe7,0xcfe9,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xcfea,0xcfeb,0xcfec,0xcfed,0xcfee,0xcfef,0xcff2,
  0xcff4,0xcff6,0xcff7,0xcff8,0xcff9,0xcffa,0xcffb,0xcffd,
  0xcffe,0xcfff,0xd001,0xd002,0xd003,0xd005,0xd006,0xd007,
  0xd008,0xd009,0xd00a,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xd00b,0xd00c,0xd00d,0xd00e,0xd00f,0xd010,0xd012,0xd013,
  0xd014,0xd015,0xd016,0xd017,0xd019,0xd01a,0xd01b,0xd01c,
  0xd01d,0xd01e,0xd01f,0xd020,0xd021,0xd022,0xd023,0xd024,
  0xd025,0xd026,0xd027,0xd028,0xd029,0xd02a,0xd02b,0xd02c,
  0xb05d,0xb07c,0xb07d,0xb080,0xb084,0xb08c,0xb08d,0xb08f,
  0xb091,0xb098,0xb099,0xb09a,0xb09c,0xb09f,0xb0a0,0xb0a1,
  0xb0a2,0xb0a8,0xb0a9,0xb0ab,0xb0ac,0xb0ad,0xb0ae,0xb0af,
  0xb0b1,0xb0b3,0xb0b4,0xb0b5,0xb0b8,0xb0bc,0xb0c4,0xb0c5,
  0xb0c7,0xb0c8,0xb0c9,0xb0d0,0xb0d1,0xb0d4,0xb0d8,0xb0e0,
  0xb0e5,0xb108,0xb109,0xb10b,0xb10c,0xb110,0xb112,0xb113,
  0xb118,0xb119,0xb11b,0xb11c,0xb11d,0xb123,0xb124,0xb125,
  0xb128,0xb12c,0xb134,0xb135,0xb137,0xb138,0xb139,0xb140,
  0xb141,0xb144,0xb148,0xb150,0xb151,0xb154,0xb155,0xb158,
  0xb15c,0xb160,0xb178,0xb179,0xb17c,0xb180,0xb182,0xb188,
  0xb189,0xb18b,0xb18d,0xb192,0xb193,0xb194,0xb198,0xb19c,
  0xb1a8,0xb1cc,0xb1d0,0xb1d4,0xb1dc,0xb1dd,
/* 0xb400 */
  0x0000,0xd02e,0xd02f,0xd030,0xd031,0xd032,0xd033,0xd036,
  0xd037,0xd039,0xd03a,0xd03b,0xd03d,0xd03e,0xd03f,0xd040,
  0xd041,0xd042,0xd043,0xd046,0xd048,0xd04a,0xd04b,0xd04c,
  0xd04d,0xd04e,0xd04f,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xd051,0xd052,0xd053,0xd055,0xd056,0xd057,0xd059,
  0xd05a,0xd05b,0xd05c,0xd05d,0xd05e,0xd05f,0xd061,0xd062,
  0xd063,0xd064,0xd065,0xd066,0xd067,0xd068,0xd069,0xd06a,
  0xd06b,0xd06e,0xd06f,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xd071,0xd072,0xd073,0xd075,0xd076,0xd077,0xd078,0xd079,
  0xd07a,0xd07b,0xd07e,0xd07f,0xd080,0xd082,0xd083,0xd084,
  0xd085,0xd086,0xd087,0xd088,0xd089,0xd08a,0xd08b,0xd08c,
  0xd08d,0xd08e,0xd08f,0xd090,0xd091,0xd092,0xd093,0xd094,
  0xb1df,0xb1e8,0xb1e9,0xb1ec,0xb1f0,0xb1f9,0xb1fb,0xb1fd,
  0xb204,0xb205,0xb208,0xb20b,0xb20c,0xb214,0xb215,0xb217,
  0xb219,0xb220,0xb234,0xb23c,0xb258,0xb25c,0xb260,0xb268,
  0xb269,0xb274,0xb275,0xb27c,0xb284,0xb285,0xb289,0xb290,
  0xb291,0xb294,0xb298,0xb299,0xb29a,0xb2a0,0xb2a1,0xb2a3,
  0xb2a5,0xb2a6,0xb2aa,0xb2ac,0xb2b0,0xb2b4,0xb2c8,0xb2c9,
  0xb2cc,0xb2d0,0xb2d2,0xb2d8,0xb2d9,0xb2db,0xb2dd,0xb2e2,
  0xb2e4,0xb2e5,0xb2e6,0xb2e8,0xb2eb,0xb2ec,0xb2ed,0xb2ee,
  0xb2ef,0xb2f3,0xb2f4,0xb2f5,0xb2f7,0xb2f8,0xb2f9,0xb2fa,
  0xb2fb,0xb2ff,0xb300,0xb301,0xb304,0xb308,0xb310,0xb311,
  0xb313,0xb314,0xb315,0xb31c,0xb354,0xb355,0xb356,0xb358,
  0xb35b,0xb35c,0xb35e,0xb35f,0xb364,0xb365,
/* 0xb500 */
  0x0000,0xd095,0xd096,0xd097,0xd098,0xd099,0xd09a,0xd09b,
  0xd09c,0xd09d,0xd09e,0xd09f,0xd0a0,0xd0a1,0xd0a2,0xd0a3,
  0xd0a6,0xd0a7,0xd0a9,0xd0aa,0xd0ab,0xd0ad,0xd0ae,0xd0af,
  0xd0b0,0xd0b1,0xd0b2,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xd0b3,0xd0b6,0xd0b8,0xd0ba,0xd0bb,0xd0bc,0xd0bd,
  0xd0be,0xd0bf,0xd0c2,0xd0c3,0xd0c5,0xd0c6,0xd0c7,0xd0ca,
  0xd0cb,0xd0cc,0xd0cd,0xd0ce,0xd0cf,0xd0d2,0xd0d6,0xd0d7,
  0xd0d8,0xd0d9,0xd0da,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xd0db,0xd0de,0xd0df,0xd0e1,0xd0e2,0xd0e3,0xd0e5,0xd0e6,
  0xd0e7,0xd0e8,0xd0e9,0xd0ea,0xd0eb,0xd0ee,0xd0f2,0xd0f3,
  0xd0f4,0xd0f5,0xd0f6,0xd0f7,0xd0f9,0xd0fa,0xd0fb,0xd0fc,
  0xd0fd,0xd0fe,0xd0ff,0xd100,0xd101,0xd102,0xd103,0xd104,
  0xb367,0xb369,0xb36b,0xb36e,0xb370,0xb371,0xb374,0xb378,
  0xb380,0xb381,0xb383,0xb384,0xb385,0xb38c,0xb390,0xb394,
  0xb3a0,0xb3a1,0xb3a8,0xb3ac,0xb3c4,0xb3c5,0xb3c8,0xb3cb,
  0xb3cc,0xb3ce,0xb3d0,0xb3d4,0xb3d5,0xb3d7,0xb3d9,0xb3db,
  0xb3dd,0xb3e0,0xb3e4,0xb3e8,0xb3fc,0xb410,0xb418,0xb41c,
  0xb420,0xb428,0xb429,0xb42b,0xb434,0xb450,0xb451,0xb454,
  0xb458,0xb460,0xb461,0xb463,0xb465,0xb46c,0xb480,0xb488,
  0xb49d,0xb4a4,0xb4a8,0xb4ac,0xb4b5,0xb4b7,0xb4b9,0xb4c0,
  0xb4c4,0xb4c8,0xb4d0,0xb4d5,0xb4dc,0xb4dd,0xb4e0,0xb4e3,
  0xb4e4,0xb4e6,0xb4ec,0xb4ed,0xb4ef,0xb4f1,0xb4f8,0xb514,
  0xb515,0xb518,0xb51b,0xb51c,0xb524,0xb525,0xb527,0xb528,
  0xb529,0xb52a,0xb530,0xb531,0xb534,0xb538,
/* 0xb600 */
  0x0000,0xd105,0xd106,0xd107,0xd108,0xd109,0xd10a,0xd10b,
  0xd10c,0xd10e,0xd10f,0xd110,0xd111,0xd112,0xd113,0xd114,
  0xd115,0xd116,0xd117,0xd118,0xd119,0xd11a,0xd11b,0xd11c,
  0xd11d,0xd11e,0xd11f,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xd120,0xd121,0xd122,0xd123,0xd124,0xd125,0xd126,
  0xd127,0xd128,0xd129,0xd12a,0xd12b,0xd12c,0xd12d,0xd12e,
  0xd12f,0xd132,0xd133,0xd135,0xd136,0xd137,0xd139,0xd13b,
  0xd13c,0xd13d,0xd13e,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xd13f,0xd142,0xd146,0xd147,0xd148,0xd149,0xd14a,0xd14b,
  0xd14e,0xd14f,0xd151,0xd152,0xd153,0xd155,0xd156,0xd157,
  0xd158,0xd159,0xd15a,0xd15b,0xd15e,0xd160,0xd162,0xd163,
  0xd164,0xd165,0xd166,0xd167,0xd169,0xd16a,0xd16b,0xd16d,
  0xb540,0xb541,0xb543,0xb544,0xb545,0xb54b,0xb54c,0xb54d,
  0xb550,0xb554,0xb55c,0xb55d,0xb55f,0xb560,0xb561,0xb5a0,
  0xb5a1,0xb5a4,0xb5a8,0xb5aa,0xb5ab,0xb5b0,0xb5b1,0xb5b3,
  0xb5b4,0xb5b5,0xb5bb,0xb5bc,0xb5bd,0xb5c0,0xb5c4,0xb5cc,
  0xb5cd,0xb5cf,0xb5d0,0xb5d1,0xb5d8,0xb5ec,0xb610,0xb611,
  0xb614,0xb618,0xb625,0xb62c,0xb634,0xb648,0xb664,0xb668,
  0xb69c,0xb69d,0xb6a0,0xb6a4,0xb6ab,0xb6ac,0xb6b1,0xb6d4,
  0xb6f0,0xb6f4,0xb6f8,0xb700,0xb701,0xb705,0xb728,0xb729,
  0xb72c,0xb72f,0xb730,0xb738,0xb739,0xb73b,0xb744,0xb748,
  0xb74c,0xb754,0xb755,0xb760,0xb764,0xb768,0xb770,0xb771,
  0xb773,0xb775,0xb77c,0xb77d,0xb780,0xb784,0xb78c,0xb78d,
  0xb78f,0xb790,0xb791,0xb792,0xb796,0xb797,
/* 0xb700 */
  0x0000,0xd16e,0xd16f,0xd170,0xd171,0xd172,0xd173,0xd174,
  0xd175,0xd176,0xd177,0xd178,0xd179,0xd17a,0xd17b,0xd17d,
  0xd17e,0xd17f,0xd180,0xd181,0xd182,0xd183,0xd185,0xd186,
  0xd187,0xd189,0xd18a,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xd18b,0xd18c,0xd18d,0xd18e,0xd18f,0xd190,0xd191,
  0xd192,0xd193,0xd194,0xd195,0xd196,0xd197,0xd198,0xd199,
  0xd19a,0xd19b,0xd19c,0xd19d,0xd19e,0xd19f,0xd1a2,0xd1a3,
  0xd1a5,0xd1a6,0xd1a7,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xd1a9,0xd1aa,0xd1ab,0xd1ac,0xd1ad,0xd1ae,0xd1af,0xd1b2,
  0xd1b4,0xd1b6,0xd1b7,0xd1b8,0xd1b9,0xd1bb,0xd1bd,0xd1be,
  0xd1bf,0xd1c1,0xd1c2,0xd1c3,0xd1c4,0xd1c5,0xd1c6,0xd1c7,
  0xd1c8,0xd1c9,0xd1ca,0xd1cb,0xd1cc,0xd1cd,0xd1ce,0xd1cf,
  0xb798,0xb799,0xb79c,0xb7a0,0xb7a8,0xb7a9,0xb7ab,0xb7ac,
  0xb7ad,0xb7b4,0xb7b5,0xb7b8,0xb7c7,0xb7c9,0xb7ec,0xb7ed,
  0xb7f0,0xb7f4,0xb7fc,0xb7fd,0xb7ff,0xb800,0xb801,0xb807,
  0xb808,0xb809,0xb80c,0xb810,0xb818,0xb819,0xb81b,0xb81d,
  0xb824,0xb825,0xb828,0xb82c,0xb834,0xb835,0xb837,0xb838,
  0xb839,0xb840,0xb844,0xb851,0xb853,0xb85c,0xb85d,0xb860,
  0xb864,0xb86c,0xb86d,0xb86f,0xb871,0xb878,0xb87c,0xb88d,
  0xb8a8,0xb8b0,0xb8b4,0xb8b8,0xb8c0,0xb8c1,0xb8c3,0xb8c5,
  0xb8cc,0xb8d0,0xb8d4,0xb8dd,0xb8df,0xb8e1,0xb8e8,0xb8e9,
  0xb8ec,0xb8f0,0xb8f8,0xb8f9,0xb8fb,0xb8fd,0xb904,0xb918,
  0xb920,0xb93c,0xb93d,0xb940,0xb944,0xb94c,0xb94f,0xb951,
  0xb958,0xb959,0xb95c,0xb960,0xb968,0xb969,
/* 0xb800 */
  0x0000,0xd1d0,0xd1d1,0xd1d2,0xd1d3,0xd1d4,0xd1d5,0xd1d6,
  0xd1d7,0xd1d9,0xd1da,0xd1db,0xd1dc,0xd1dd,0xd1de,0xd1df,
  0xd1e0,0xd1e1,0xd1e2,0xd1e3,0xd1e4,0xd1e5,0xd1e6,0xd1e7,
  0xd1e8,0xd1e9,0xd1ea,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xd1eb,0xd1ec,0xd1ed,0xd1ee,0xd1ef,0xd1f0,0xd1f1,
  0xd1f2,0xd1f3,0xd1f5,0xd1f6,0xd1f7,0xd1f9,0xd1fa,0xd1fb,
  0xd1fc,0xd1fd,0xd1fe,0xd1ff,0xd200,0xd201,0xd202,0xd203,
  0xd204,0xd205,0xd206,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xd208,0xd20a,0xd20b,0xd20c,0xd20d,0xd20e,0xd20f,0xd211,
  0xd212,0xd213,0xd214,0xd215,0xd216,0xd217,0xd218,0xd219,
  0xd21a,0xd21b,0xd21c,0xd21d,0xd21e,0xd21f,0xd220,0xd221,
  0xd222,0xd223,0xd224,0xd225,0xd226,0xd227,0xd228,0xd229,
  0xb96b,0xb96d,0xb974,0xb975,0xb978,0xb97c,0xb984,0xb985,
  0xb987,0xb989,0xb98a,0xb98d,0xb98e,0xb9ac,0xb9ad,0xb9b0,
  0xb9b4,0xb9bc,0xb9bd,0xb9bf,0xb9c1,0xb9c8,0xb9c9,0xb9cc,
  0xb9ce,0xb9cf,0xb9d0,0xb9d1,0xb9d2,0xb9d8,0xb9d9,0xb9db,
  0xb9dd,0xb9de,0xb9e1,0xb9e3,0xb9e4,0xb9e5,0xb9e8,0xb9ec,
  0xb9f4,0xb9f5,0xb9f7,0xb9f8,0xb9f9,0xb9fa,0xba00,0xba01,
  0xba08,0xba15,0xba38,0xba39,0xba3c,0xba40,0xba42,0xba48,
  0xba49,0xba4b,0xba4d,0xba4e,0xba53,0xba54,0xba55,0xba58,
  0xba5c,0xba64,0xba65,0xba67,0xba68,0xba69,0xba70,0xba71,
  0xba74,0xba78,0xba83,0xba84,0xba85,0xba87,0xba8c,0xbaa8,
  0xbaa9,0xbaab,0xbaac,0xbab0,0xbab2,0xbab8,0xbab9,0xbabb,
  0xbabd,0xbac4,0xbac8,0xbad8,0xbad9,0xbafc,
/* 0xb900 */
  0x0000,0xd22a,0xd22b,0xd22e,0xd22f,0xd231,0xd232,0xd233,
  0xd235,0xd236,0xd237,0xd238,0xd239,0xd23a,0xd23b,0xd23e,
  0xd240,0xd242,0xd243,0xd244,0xd245,0xd246,0xd247,0xd249,
  0xd24a,0xd24b,0xd24c,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xd24d,0xd24e,0xd24f,0xd250,0xd251,0xd252,0xd253,
  0xd254,0xd255,0xd256,0xd257,0xd258,0xd259,0xd25a,0xd25b,
  0xd25d,0xd25e,0xd25f,0xd260,0xd261,0xd262,0xd263,0xd265,
  0xd266,0xd267,0xd268,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xd269,0xd26a,0xd26b,0xd26c,0xd26d,0xd26e,0xd26f,0xd270,
  0xd271,0xd272,0xd273,0xd274,0xd275,0xd276,0xd277,0xd278,
  0xd279,0xd27a,0xd27b,0xd27c,0xd27d,0xd27e,0xd27f,0xd282,
  0xd283,0xd285,0xd286,0xd287,0xd289,0xd28a,0xd28b,0xd28c,
  0xbb00,0xbb04,0xbb0d,0xbb0f,0xbb11,0xbb18,0xbb1c,0xbb20,
  0xbb29,0xbb2b,0xbb34,0xbb35,0xbb36,0xbb38,0xbb3b,0xbb3c,
  0xbb3d,0xbb3e,0xbb44,0xbb45,0xbb47,0xbb49,0xbb4d,0xbb4f,
  0xbb50,0xbb54,0xbb58,0xbb61,0xbb63,0xbb6c,0xbb88,0xbb8c,
  0xbb90,0xbba4,0xbba8,0xbbac,0xbbb4,0xbbb7,0xbbc0,0xbbc4,
  0xbbc8,0xbbd0,0xbbd3,0xbbf8,0xbbf9,0xbbfc,0xbbff,0xbc00,
  0xbc02,0xbc08,0xbc09,0xbc0b,0xbc0c,0xbc0d,0xbc0f,0xbc11,
  0xbc14,0xbc15,0xbc16,0xbc17,0xbc18,0xbc1b,0xbc1c,0xbc1d,
  0xbc1e,0xbc1f,0xbc24,0xbc25,0xbc27,0xbc29,0xbc2d,0xbc30,
  0xbc31,0xbc34,0xbc38,0xbc40,0xbc41,0xbc43,0xbc44,0xbc45,
  0xbc49,0xbc4c,0xbc4d,0xbc50,0xbc5d,0xbc84,0xbc85,0xbc88,
  0xbc8b,0xbc8c,0xbc8e,0xbc94,0xbc95,0xbc97,
/* 0xba00 */
  0x0000,0xd28d,0xd28e,0xd28f,0xd292,0xd293,0xd294,0xd296,
  0xd297,0xd298,0xd299,0xd29a,0xd29b,0xd29d,0xd29e,0xd29f,
  0xd2a1,0xd2a2,0xd2a3,0xd2a5,0xd2a6,0xd2a7,0xd2a8,0xd2a9,
  0xd2aa,0xd2ab,0xd2ad,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xd2ae,0xd2af,0xd2b0,0xd2b2,0xd2b3,0xd2b4,0xd2b5,
  0xd2b6,0xd2b7,0xd2ba,0xd2bb,0xd2bd,0xd2be,0xd2c1,0xd2c3,
  0xd2c4,0xd2c5,0xd2c6,0xd2c7,0xd2ca,0xd2cc,0xd2cd,0xd2ce,
  0xd2cf,0xd2d0,0xd2d1,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xd2d2,0xd2d3,0xd2d5,0xd2d6,0xd2d7,0xd2d9,0xd2da,0xd2db,
  0xd2dd,0xd2de,0xd2df,0xd2e0,0xd2e1,0xd2e2,0xd2e3,0xd2e6,
  0xd2e7,0xd2e8,0xd2e9,0xd2ea,0xd2eb,0xd2ec,0xd2ed,0xd2ee,
  0xd2ef,0xd2f2,0xd2f3,0xd2f5,0xd2f6,0xd2f7,0xd2f9,0xd2fa,
  0xbc99,0xbc9a,0xbca0,0xbca1,0xbca4,0xbca7,0xbca8,0xbcb0,
  0xbcb1,0xbcb3,0xbcb4,0xbcb5,0xbcbc,0xbcbd,0xbcc0,0xbcc4,
  0xbccd,0xbccf,0xbcd0,0xbcd1,0xbcd5,0xbcd8,0xbcdc,0xbcf4,
  0xbcf5,0xbcf6,0xbcf8,0xbcfc,0xbd04,0xbd05,0xbd07,0xbd09,
  0xbd10,0xbd14,0xbd24,0xbd2c,0xbd40,0xbd48,0xbd49,0xbd4c,
  0xbd50,0xbd58,0xbd59,0xbd64,0xbd68,0xbd80,0xbd81,0xbd84,
  0xbd87,0xbd88,0xbd89,0xbd8a,0xbd90,0xbd91,0xbd93,0xbd95,
  0xbd99,0xbd9a,0xbd9c,0xbda4,0xbdb0,0xbdb8,0xbdd4,0xbdd5,
  0xbdd8,0xbddc,0xbde9,0xbdf0,0xbdf4,0xbdf8,0xbe00,0xbe03,
  0xbe05,0xbe0c,0xbe0d,0xbe10,0xbe14,0xbe1c,0xbe1d,0xbe1f,
  0xbe44,0xbe45,0xbe48,0xbe4c,0xbe4e,0xbe54,0xbe55,0xbe57,
  0xbe59,0xbe5a,0xbe5b,0xbe60,0xbe61,0xbe64,
/* 0xbb00 */
  0x0000,0xd2fb,0xd2fc,0xd2fd,0xd2fe,0xd2ff,0xd302,0xd304,
  0xd306,0xd307,0xd308,0xd309,0xd30a,0xd30b,0xd30f,0xd311,
  0xd312,0xd313,0xd315,0xd317,0xd318,0xd319,0xd31a,0xd31b,
  0xd31e,0xd322,0xd323,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xd324,0xd326,0xd327,0xd32a,0xd32b,0xd32d,0xd32e,
  0xd32f,0xd331,0xd332,0xd333,0xd334,0xd335,0xd336,0xd337,
  0xd33a,0xd33e,0xd33f,0xd340,0xd341,0xd342,0xd343,0xd346,
  0xd347,0xd348,0xd349,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xd34a,0xd34b,0xd34c,0xd34d,0xd34e,0xd34f,0xd350,0xd351,
  0xd352,0xd353,0xd354,0xd355,0xd356,0xd357,0xd358,0xd359,
  0xd35a,0xd35b,0xd35c,0xd35d,0xd35e,0xd35f,0xd360,0xd361,
  0xd362,0xd363,0xd364,0xd365,0xd366,0xd367,0xd368,0xd369,
  0xbe68,0xbe6a,0xbe70,0xbe71,0xbe73,0xbe74,0xbe75,0xbe7b,
  0xbe7c,0xbe7d,0xbe80,0xbe84,0xbe8c,0xbe8d,0xbe8f,0xbe90,
  0xbe91,0xbe98,0xbe99,0xbea8,0xbed0,0xbed1,0xbed4,0xbed7,
  0xbed8,0xbee0,0xbee3,0xbee4,0xbee5,0xbeec,0xbf01,0xbf08,
  0xbf09,0xbf18,0xbf19,0xbf1b,0xbf1c,0xbf1d,0xbf40,0xbf41,
  0xbf44,0xbf48,0xbf50,0xbf51,0xbf55,0xbf94,0xbfb0,0xbfc5,
  0xbfcc,0xbfcd,0xbfd0,0xbfd4,0xbfdc,0xbfdf,0xbfe1,0xc03c,
  0xc051,0xc058,0xc05c,0xc060,0xc068,0xc069,0xc090,0xc091,
  0xc094,0xc098,0xc0a0,0xc0a1,0xc0a3,0xc0a5,0xc0ac,0xc0ad,
  0xc0af,0xc0b0,0xc0b3,0xc0b4,0xc0b5,0xc0b6,0xc0bc,0xc0bd,
  0xc0bf,0xc0c0,0xc0c1,0xc0c5,0xc0c8,0xc0c9,0xc0cc,0xc0d0,
  0xc0d8,0xc0d9,0xc0db,0xc0dc,0xc0dd,0xc0e4,
/* 0xbc00 */
  0x0000,0xd36a,0xd36b,0xd36c,0xd36d,0xd36e,0xd36f,0xd370,
  0xd371,0xd372,0xd373,0xd374,0xd375,0xd376,0xd377,0xd378,
  0xd379,0xd37a,0xd37b,0xd37e,0xd37f,0xd381,0xd382,0xd383,
  0xd385,0xd386,0xd387,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xd388,0xd389,0xd38a,0xd38b,0xd38e,0xd392,0xd393,
  0xd394,0xd395,0xd396,0xd397,0xd39a,0xd39b,0xd39d,0xd39e,
  0xd39f,0xd3a1,0xd3a2,0xd3a3,0xd3a4,0xd3a5,0xd3a6,0xd3a7,
  0xd3aa,0xd3ac,0xd3ae,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xd3af,0xd3b0,0xd3b1,0xd3b2,0xd3b3,0xd3b5,0xd3b6,0xd3b7,
  0xd3b9,0xd3ba,0xd3bb,0xd3bd,0xd3be,0xd3bf,0xd3c0,0xd3c1,
  0xd3c2,0xd3c3,0xd3c6,0xd3c7,0xd3ca,0xd3cb,0xd3cc,0xd3cd,
  0xd3ce,0xd3cf,0xd3d1,0xd3d2,0xd3d3,0xd3d4,0xd3d5,0xd3d6,
  0xc0e5,0xc0e8,0xc0ec,0xc0f4,0xc0f5,0xc0f7,0xc0f9,0xc100,
  0xc104,0xc108,0xc110,0xc115,0xc11c,0xc11d,0xc11e,0xc11f,
  0xc120,0xc123,0xc124,0xc126,0xc127,0xc12c,0xc12d,0xc12f,
  0xc130,0xc131,0xc136,0xc138,0xc139,0xc13c,0xc140,0xc148,
  0xc149,0xc14b,0xc14c,0xc14d,0xc154,0xc155,0xc158,0xc15c,
  0xc164,0xc165,0xc167,0xc168,0xc169,0xc170,0xc174,0xc178,
  0xc185,0xc18c,0xc18d,0xc18e,0xc190,0xc194,0xc196,0xc19c,
  0xc19d,0xc19f,0xc1a1,0xc1a5,0xc1a8,0xc1a9,0xc1ac,0xc1b0,
  0xc1bd,0xc1c4,0xc1c8,0xc1cc,0xc1d4,0xc1d7,0xc1d8,0xc1e0,
  0xc1e4,0xc1e8,0xc1f0,0xc1f1,0xc1f3,0xc1fc,0xc1fd,0xc200,
  0xc204,0xc20c,0xc20d,0xc20f,0xc211,0xc218,0xc219,0xc21c,
  0xc21f,0xc220,0xc228,0xc229,0xc22b,0xc22d,
/* 0xbd00 */
  0x0000,0xd3d7,0xd3d9,0xd3da,0xd3db,0xd3dc,0xd3dd,0xd3de,
  0xd3df,0xd3e0,0xd3e2,0xd3e4,0xd3e5,0xd3e6,0xd3e7,0xd3e8,
  0xd3e9,0xd3ea,0xd3eb,0xd3ee,0xd3ef,0xd3f1,0xd3f2,0xd3f3,
  0xd3f5,0xd3f6,0xd3f7,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xd3f8,0xd3f9,0xd3fa,0xd3fb,0xd3fe,0xd400,0xd402,
  0xd403,0xd404,0xd405,0xd406,0xd407,0xd409,0xd40a,0xd40b,
  0xd40c,0xd40d,0xd40e,0xd40f,0xd410,0xd411,0xd412,0xd413,
  0xd414,0xd415,0xd416,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xd417,0xd418,0xd419,0xd41a,0xd41b,0xd41c,0xd41e,0xd41f,
  0xd420,0xd421,0xd422,0xd423,0xd424,0xd425,0xd426,0xd427,
  0xd428,0xd429,0xd42a,0xd42b,0xd42c,0xd42d,0xd42e,0xd42f,
  0xd430,0xd431,0xd432,0xd433,0xd434,0xd435,0xd436,0xd437,
  0xc22f,0xc231,0xc232,0xc234,0xc248,0xc250,0xc251,0xc254,
  0xc258,0xc260,0xc265,0xc26c,0xc26d,0xc270,0xc274,0xc27c,
  0xc27d,0xc27f,0xc281,0xc288,0xc289,0xc290,0xc298,0xc29b,
  0xc29d,0xc2a4,0xc2a5,0xc2a8,0xc2ac,0xc2ad,0xc2b4,0xc2b5,
  0xc2b7,0xc2b9,0xc2dc,0xc2dd,0xc2e0,0xc2e3,0xc2e4,0xc2eb,
  0xc2ec,0xc2ed,0xc2ef,0xc2f1,0xc2f6,0xc2f8,0xc2f9,0xc2fb,
  0xc2fc,0xc300,0xc308,0xc309,0xc30c,0xc30d,0xc313,0xc314,
  0xc315,0xc318,0xc31c,0xc324,0xc325,0xc328,0xc329,0xc345,
  0xc368,0xc369,0xc36c,0xc370,0xc372,0xc378,0xc379,0xc37c,
  0xc37d,0xc384,0xc388,0xc38c,0xc3c0,0xc3d8,0xc3d9,0xc3dc,
  0xc3df,0xc3e0,0xc3e2,0xc3e8,0xc3e9,0xc3ed,0xc3f4,0xc3f5,
  0xc3f8,0xc408,0xc410,0xc424,0xc42c,0xc430,
/* 0xbe00 */
  0x0000,0xd438,0xd439,0xd43a,0xd43b,0xd43c,0xd43d,0xd43e,
  0xd43f,0xd441,0xd442,0xd443,0xd445,0xd446,0xd447,0xd448,
  0xd449,0xd44a,0xd44b,0xd44c,0xd44d,0xd44e,0xd44f,0xd450,
  0xd451,0xd452,0xd453,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xd454,0xd455,0xd456,0xd457,0xd458,0xd459,0xd45a,
  0xd45b,0xd45d,0xd45e,0xd45f,0xd461,0xd462,0xd463,0xd465,
  0xd466,0xd467,0xd468,0xd469,0xd46a,0xd46b,0xd46c,0xd46e,
  0xd470,0xd471,0xd472,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xd473,0xd474,0xd475,0xd476,0xd477,0xd47a,0xd47b,0xd47d,
  0xd47e,0xd481,0xd483,0xd484,0xd485,0xd486,0xd487,0xd48a,
  0xd48c,0xd48e,0xd48f,0xd490,0xd491,0xd492,0xd493,0xd495,
  0xd496,0xd497,0xd498,0xd499,0xd49a,0xd49b,0xd49c,0xd49d,
  0xc434,0xc43c,0xc43d,0xc448,0xc464,0xc465,0xc468,0xc46c,
  0xc474,0xc475,0xc479,0xc480,0xc494,0xc49c,0xc4b8,0xc4bc,
  0xc4e9,0xc4f0,0xc4f1,0xc4f4,0xc4f8,0xc4fa,0xc4ff,0xc500,
  0xc501,0xc50c,0xc510,0xc514,0xc51c,0xc528,0xc529,0xc52c,
  0xc530,0xc538,0xc539,0xc53b,0xc53d,0xc544,0xc545,0xc548,
  0xc549,0xc54a,0xc54c,0xc54d,0xc54e,0xc553,0xc554,0xc555,
  0xc557,0xc558,0xc559,0xc55d,0xc55e,0xc560,0xc561,0xc564,
  0xc568,0xc570,0xc571,0xc573,0xc574,0xc575,0xc57c,0xc57d,
  0xc580,0xc584,0xc587,0xc58c,0xc58d,0xc58f,0xc591,0xc595,
  0xc597,0xc598,0xc59c,0xc5a0,0xc5a9,0xc5b4,0xc5b5,0xc5b8,
  0xc5b9,0xc5bb,0xc5bc,0xc5bd,0xc5be,0xc5c4,0xc5c5,0xc5c6,
  0xc5c7,0xc5c8,0xc5c9,0xc5ca,0xc5cc,0xc5ce,
/* 0xbf00 */
  0x0000,0xd49e,0xd49f,0xd4a0,0xd4a1,0xd4a2,0xd4a3,0xd4a4,
  0xd4a5,0xd4a6,0xd4a7,0xd4a8,0xd4aa,0xd4ab,0xd4ac,0xd4ad,
  0xd4ae,0xd4af,0xd4b0,0xd4b1,0xd4b2,0xd4b3,0xd4b4,0xd4b5,
  0xd4b6,0xd4b7,0xd4b8,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xd4b9,0xd4ba,0xd4bb,0xd4bc,0xd4bd,0xd4be,0xd4bf,
  0xd4c0,0xd4c1,0xd4c2,0xd4c3,0xd4c4,0xd4c5,0xd4c6,0xd4c7,
  0xd4c8,0xd4c9,0xd4ca,0xd4cb,0xd4cd,0xd4ce,0xd4cf,0xd4d1,
  0xd4d2,0xd4d3,0xd4d5,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xd4d6,0xd4d7,0xd4d8,0xd4d9,0xd4da,0xd4db,0xd4dd,0xd4de,
  0xd4e0,0xd4e1,0xd4e2,0xd4e3,0xd4e4,0xd4e5,0xd4e6,0xd4e7,
  0xd4e9,0xd4ea,0xd4eb,0xd4ed,0xd4ee,0xd4ef,0xd4f1,0xd4f2,
  0xd4f3,0xd4f4,0xd4f5,0xd4f6,0xd4f7,0xd4f9,0xd4fa,0xd4fc,
  0xc5d0,0xc5d1,0xc5d4,0xc5d8,0xc5e0,0xc5e1,0xc5e3,0xc5e5,
  0xc5ec,0xc5ed,0xc5ee,0xc5f0,0xc5f4,0xc5f6,0xc5f7,0xc5fc,
  0xc5fd,0xc5fe,0xc5ff,0xc600,0xc601,0xc605,0xc606,0xc607,
  0xc608,0xc60c,0xc610,0xc618,0xc619,0xc61b,0xc61c,0xc624,
  0xc625,0xc628,0xc62c,0xc62d,0xc62e,0xc630,0xc633,0xc634,
  0xc635,0xc637,0xc639,0xc63b,0xc640,0xc641,0xc644,0xc648,
  0xc650,0xc651,0xc653,0xc654,0xc655,0xc65c,0xc65d,0xc660,
  0xc66c,0xc66f,0xc671,0xc678,0xc679,0xc67c,0xc680,0xc688,
  0xc689,0xc68b,0xc68d,0xc694,0xc695,0xc698,0xc69c,0xc6a4,
  0xc6a5,0xc6a7,0xc6a9,0xc6b0,0xc6b1,0xc6b4,0xc6b8,0xc6b9,
  0xc6ba,0xc6c0,0xc6c1,0xc6c3,0xc6c5,0xc6cc,0xc6cd,0xc6d0,
  0xc6d4,0xc6dc,0xc6dd,0xc6e0,0xc6e1,0xc6e8,
/* 0xc000 */
  0x0000,0xd4fe,0xd4ff,0xd500,0xd501,0xd502,0xd503,0xd505,
  0xd506,0xd507,0xd509,0xd50a,0xd50b,0xd50d,0xd50e,0xd50f,
  0xd510,0xd511,0xd512,0xd513,0xd516,0xd518,0xd519,0xd51a,
  0xd51b,0xd51c,0xd51d,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xd51e,0xd51f,0xd520,0xd521,0xd522,0xd523,0xd524,
  0xd525,0xd526,0xd527,0xd528,0xd529,0xd52a,0xd52b,0xd52c,
  0xd52d,0xd52e,0xd52f,0xd530,0xd531,0xd532,0xd533,0xd534,
  0xd535,0xd536,0xd537,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xd538,0xd539,0xd53a,0xd53b,0xd53e,0xd53f,0xd541,0xd542,
  0xd543,0xd545,0xd546,0xd547,0xd548,0xd549,0xd54a,0xd54b,
  0xd54e,0xd550,0xd552,0xd553,0xd554,0xd555,0xd556,0xd557,
  0xd55a,0xd55b,0xd55d,0xd55e,0xd55f,0xd561,0xd562,0xd563,
  0xc6e9,0xc6ec,0xc6f0,0xc6f8,0xc6f9,0xc6fd,0xc704,0xc705,
  0xc708,0xc70c,0xc714,0xc715,0xc717,0xc719,0xc720,0xc721,
  0xc724,0xc728,0xc730,0xc731,0xc733,0xc735,0xc737,0xc73c,
  0xc73d,0xc740,0xc744,0xc74a,0xc74c,0xc74d,0xc74f,0xc751,
  0xc752,0xc753,0xc754,0xc755,0xc756,0xc757,0xc758,0xc75c,
  0xc760,0xc768,0xc76b,0xc774,0xc775,0xc778,0xc77c,0xc77d,
  0xc77e,0xc783,0xc784,0xc785,0xc787,0xc788,0xc789,0xc78a,
  0xc78e,0xc790,0xc791,0xc794,0xc796,0xc797,0xc798,0xc79a,
  0xc7a0,0xc7a1,0xc7a3,0xc7a4,0xc7a5,0xc7a6,0xc7ac,0xc7ad,
  0xc7b0,0xc7b4,0xc7bc,0xc7bd,0xc7bf,0xc7c0,0xc7c1,0xc7c8,
  0xc7c9,0xc7cc,0xc7ce,0xc7d0,0xc7d8,0xc7dd,0xc7e4,0xc7e8,
  0xc7ec,0xc800,0xc801,0xc804,0xc808,0xc80a,
/* 0xc100 */
  0x0000,0xd564,0xd566,0xd567,0xd56a,0xd56c,0xd56e,0xd56f,
  0xd570,0xd571,0xd572,0xd573,0xd576,0xd577,0xd579,0xd57a,
  0xd57b,0xd57d,0xd57e,0xd57f,0xd580,0xd581,0xd582,0xd583,
  0xd586,0xd58a,0xd58b,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xd58c,0xd58d,0xd58e,0xd58f,0xd591,0xd592,0xd593,
  0xd594,0xd595,0xd596,0xd597,0xd598,0xd599,0xd59a,0xd59b,
  0xd59c,0xd59d,0xd59e,0xd59f,0xd5a0,0xd5a1,0xd5a2,0xd5a3,
  0xd5a4,0xd5a6,0xd5a7,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xd5a8,0xd5a9,0xd5aa,0xd5ab,0xd5ac,0xd5ad,0xd5ae,0xd5af,
  0xd5b0,0xd5b1,0xd5b2,0xd5b3,0xd5b4,0xd5b5,0xd5b6,0xd5b7,
  0xd5b8,0xd5b9,0xd5ba,0xd5bb,0xd5bc,0xd5bd,0xd5be,0xd5bf,
  0xd5c0,0xd5c1,0xd5c2,0xd5c3,0xd5c4,0xd5c5,0xd5c6,0xd5c7,
  0xc810,0xc811,0xc813,0xc815,0xc816,0xc81c,0xc81d,0xc820,
  0xc824,0xc82c,0xc82d,0xc82f,0xc831,0xc838,0xc83c,0xc840,
  0xc848,0xc849,0xc84c,0xc84d,0xc854,0xc870,0xc871,0xc874,
  0xc878,0xc87a,0xc880,0xc881,0xc883,0xc885,0xc886,0xc887,
  0xc88b,0xc88c,0xc88d,0xc894,0xc89d,0xc89f,0xc8a1,0xc8a8,
  0xc8bc,0xc8bd,0xc8c4,0xc8c8,0xc8cc,0xc8d4,0xc8d5,0xc8d7,
  0xc8d9,0xc8e0,0xc8e1,0xc8e4,0xc8f5,0xc8fc,0xc8fd,0xc900,
  0xc904,0xc905,0xc906,0xc90c,0xc90d,0xc90f,0xc911,0xc918,
  0xc92c,0xc934,0xc950,0xc951,0xc954,0xc958,0xc960,0xc961,
  0xc963,0xc96c,0xc970,0xc974,0xc97c,0xc988,0xc989,0xc98c,
  0xc990,0xc998,0xc999,0xc99b,0xc99d,0xc9c0,0xc9c1,0xc9c4,
  0xc9c7,0xc9c8,0xc9ca,0xc9d0,0xc9d1,0xc9d3,
/* 0xc200 */
  0x0000,0xd5ca,0xd5cb,0xd5cd,0xd5ce,0xd5cf,0xd5d1,0xd5d3,
  0xd5d4,0xd5d5,0xd5d6,0xd5d7,0xd5da,0xd5dc,0xd5de,0xd5df,
  0xd5e0,0xd5e1,0xd5e2,0xd5e3,0xd5e6,0xd5e7,0xd5e9,0xd5ea,
  0xd5eb,0xd5ed,0xd5ee,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xd5ef,0xd5f0,0xd5f1,0xd5f2,0xd5f3,0xd5f6,0xd5f8,
  0xd5fa,0xd5fb,0xd5fc,0xd5fd,0xd5fe,0xd5ff,0xd602,0xd603,
  0xd605,0xd606,0xd607,0xd609,0xd60a,0xd60b,0xd60c,0xd60d,
  0xd60e,0xd60f,0xd612,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xd616,0xd617,0xd618,0xd619,0xd61a,0xd61b,0xd61d,0xd61e,
  0xd61f,0xd621,0xd622,0xd623,0xd625,0xd626,0xd627,0xd628,
  0xd629,0xd62a,0xd62b,0xd62c,0xd62e,0xd62f,0xd630,0xd631,
  0xd632,0xd633,0xd634,0xd635,0xd636,0xd637,0xd63a,0xd63b,
  0xc9d5,0xc9d6,0xc9d9,0xc9da,0xc9dc,0xc9dd,0xc9e0,0xc9e2,
  0xc9e4,0xc9e7,0xc9ec,0xc9ed,0xc9ef,0xc9f0,0xc9f1,0xc9f8,
  0xc9f9,0xc9fc,0xca00,0xca08,0xca09,0xca0b,0xca0c,0xca0d,
  0xca14,0xca18,0xca29,0xca4c,0xca4d,0xca50,0xca54,0xca5c,
  0xca5d,0xca5f,0xca60,0xca61,0xca68,0xca7d,0xca84,0xca98,
  0xcabc,0xcabd,0xcac0,0xcac4,0xcacc,0xcacd,0xcacf,0xcad1,
  0xcad3,0xcad8,0xcad9,0xcae0,0xcaec,0xcaf4,0xcb08,0xcb10,
  0xcb14,0xcb18,0xcb20,0xcb21,0xcb41,0xcb48,0xcb49,0xcb4c,
  0xcb50,0xcb58,0xcb59,0xcb5d,0xcb64,0xcb78,0xcb79,0xcb9c,
  0xcbb8,0xcbd4,0xcbe4,0xcbe7,0xcbe9,0xcc0c,0xcc0d,0xcc10,
  0xcc14,0xcc1c,0xcc1d,0xcc21,0xcc22,0xcc27,0xcc28,0xcc29,
  0xcc2c,0xcc2e,0xcc30,0xcc38,0xcc39,0xcc3b,
/* 0xc300 */
  0x0000,0xd63d,0xd63e,0xd63f,0xd641,0xd642,0xd643,0xd644,
  0xd646,0xd647,0xd64a,0xd64c,0xd64e,0xd64f,0xd650,0xd652,
  0xd653,0xd656,0xd657,0xd659,0xd65a,0xd65b,0xd65d,0xd65e,
  0xd65f,0xd660,0xd661,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xd662,0xd663,0xd664,0xd665,0xd666,0xd668,0xd66a,
  0xd66b,0xd66c,0xd66d,0xd66e,0xd66f,0xd672,0xd673,0xd675,
  0xd676,0xd677,0xd678,0xd679,0xd67a,0xd67b,0xd67c,0xd67d,
  0xd67e,0xd67f,0xd680,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xd681,0xd682,0xd684,0xd686,0xd687,0xd688,0xd689,0xd68a,
  0xd68b,0xd68e,0xd68f,0xd691,0xd692,0xd693,0xd695,0xd696,
  0xd697,0xd698,0xd699,0xd69a,0xd69b,0xd69c,0xd69e,0xd6a0,
  0xd6a2,0xd6a3,0xd6a4,0xd6a5,0xd6a6,0xd6a7,0xd6a9,0xd6aa,
  0xcc3c,0xcc3d,0xcc3e,0xcc44,0xcc45,0xcc48,0xcc4c,0xcc54,
  0xcc55,0xcc57,0xcc58,0xcc59,0xcc60,0xcc64,0xcc66,0xcc68,
  0xcc70,0xcc75,0xcc98,0xcc99,0xcc9c,0xcca0,0xcca8,0xcca9,
  0xccab,0xccac,0xccad,0xccb4,0xccb5,0xccb8,0xccbc,0xccc4,
  0xccc5,0xccc7,0xccc9,0xccd0,0xccd4,0xcce4,0xccec,0xccf0,
  0xcd01,0xcd08,0xcd09,0xcd0c,0xcd10,0xcd18,0xcd19,0xcd1b,
  0xcd1d,0xcd24,0xcd28,0xcd2c,0xcd39,0xcd5c,0xcd60,0xcd64,
  0xcd6c,0xcd6d,0xcd6f,0xcd71,0xcd78,0xcd88,0xcd94,0xcd95,
  0xcd98,0xcd9c,0xcda4,0xcda5,0xcda7,0xcda9,0xcdb0,0xcdc4,
  0xcdcc,0xcdd0,0xcde8,0xcdec,0xcdf0,0xcdf8,0xcdf9,0xcdfb,
  0xcdfd,0xce04,0xce08,0xce0c,0xce14,0xce19,0xce20,0xce21,
  0xce24,0xce28,0xce30,0xce31,0xce33,0xce35,
/* 0xc400 */
  0x0000,0xd6ab,0xd6ad,0xd6ae,0xd6af,0xd6b1,0xd6b2,0xd6b3,
  0xd6b4,0xd6b5,0xd6b6,0xd6b7,0xd6b8,0xd6ba,0xd6bc,0xd6bd,
  0xd6be,0xd6bf,0xd6c0,0xd6c1,0xd6c2,0xd6c3,0xd6c6,0xd6c7,
  0xd6c9,0xd6ca,0xd6cb,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xd6cd,0xd6ce,0xd6cf,0xd6d0,0xd6d2,0xd6d3,0xd6d5,
  0xd6d6,0xd6d8,0xd6da,0xd6db,0xd6dc,0xd6dd,0xd6de,0xd6df,
  0xd6e1,0xd6e2,0xd6e3,0xd6e5,0xd6e6,0xd6e7,0xd6e9,0xd6ea,
  0xd6eb,0xd6ec,0xd6ed,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xd6ee,0xd6ef,0xd6f1,0xd6f2,0xd6f3,0xd6f4,0xd6f6,0xd6f7,
  0xd6f8,0xd6f9,0xd6fa,0xd6fb,0xd6fe,0xd6ff,0xd701,0xd702,
  0xd703,0xd705,0xd706,0xd707,0xd708,0xd709,0xd70a,0xd70b,
  0xd70c,0xd70d,0xd70e,0xd70f,0xd710,0xd712,0xd713,0xd714,
  0xce58,0xce59,0xce5c,0xce5f,0xce60,0xce61,0xce68,0xce69,
  0xce6b,0xce6d,0xce74,0xce75,0xce78,0xce7c,0xce84,0xce85,
  0xce87,0xce89,0xce90,0xce91,0xce94,0xce98,0xcea0,0xcea1,
  0xcea3,0xcea4,0xcea5,0xceac,0xcead,0xcec1,0xcee4,0xcee5,
  0xcee8,0xceeb,0xceec,0xcef4,0xcef5,0xcef7,0xcef8,0xcef9,
  0xcf00,0xcf01,0xcf04,0xcf08,0xcf10,0xcf11,0xcf13,0xcf15,
  0xcf1c,0xcf20,0xcf24,0xcf2c,0xcf2d,0xcf2f,0xcf30,0xcf31,
  0xcf38,0xcf54,0xcf55,0xcf58,0xcf5c,0xcf64,0xcf65,0xcf67,
  0xcf69,0xcf70,0xcf71,0xcf74,0xcf78,0xcf80,0xcf85,0xcf8c,
  0xcfa1,0xcfa8,0xcfb0,0xcfc4,0xcfe0,0xcfe1,0xcfe4,0xcfe8,
  0xcff0,0xcff1,0xcff3,0xcff5,0xcffc,0xd000,0xd004,0xd011,
  0xd018,0xd02d,0xd034,0xd035,0xd038,0xd03c,
/* 0xc500 */
  0x0000,0xd715,0xd716,0xd717,0xd71a,0xd71b,0xd71d,0xd71e,
  0xd71f,0xd721,0xd722,0xd723,0xd724,0xd725,0xd726,0xd727,
  0xd72a,0xd72c,0xd72e,0xd72f,0xd730,0xd731,0xd732,0xd733,
  0xd736,0xd737,0xd739,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xd73a,0xd73b,0xd73d,0xd73e,0xd73f,0xd740,0xd741,
  0xd742,0xd743,0xd745,0xd746,0xd748,0xd74a,0xd74b,0xd74c,
  0xd74d,0xd74e,0xd74f,0xd752,0xd753,0xd755,0xd75a,0xd75b,
  0xd75c,0xd75d,0xd75e,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xd75f,0xd762,0xd764,0xd766,0xd767,0xd768,0xd76a,0xd76b,
  0xd76d,0xd76e,0xd76f,0xd771,0xd772,0xd773,0xd775,0xd776,
  0xd777,0xd778,0xd779,0xd77a,0xd77b,0xd77e,0xd77f,0xd780,
  0xd782,0xd783,0xd784,0xd785,0xd786,0xd787,0xd78a,0xd78b,
  0xd044,0xd045,0xd047,0xd049,0xd050,0xd054,0xd058,0xd060,
  0xd06c,0xd06d,0xd070,0xd074,0xd07c,0xd07d,0xd081,0xd0a4,
  0xd0a5,0xd0a8,0xd0ac,0xd0b4,0xd0b5,0xd0b7,0xd0b9,0xd0c0,
  0xd0c1,0xd0c4,0xd0c8,0xd0c9,0xd0d0,0xd0d1,0xd0d3,0xd0d4,
  0xd0d5,0xd0dc,0xd0dd,0xd0e0,0xd0e4,0xd0ec,0xd0ed,0xd0ef,
  0xd0f0,0xd0f1,0xd0f8,0xd10d,0xd130,0xd131,0xd134,0xd138,
  0xd13a,0xd140,0xd141,0xd143,0xd144,0xd145,0xd14c,0xd14d,
  0xd150,0xd154,0xd15c,0xd15d,0xd15f,0xd161,0xd168,0xd16c,
  0xd17c,0xd184,0xd188,0xd1a0,0xd1a1,0xd1a4,0xd1a8,0xd1b0,
  0xd1b1,0xd1b3,0xd1b5,0xd1ba,0xd1bc,0xd1c0,0xd1d8,0xd1f4,
  0xd1f8,0xd207,0xd209,0xd210,0xd22c,0xd22d,0xd230,0xd234,
  0xd23c,0xd23d,0xd23f,0xd241,0xd248,0xd25c,
/* 0xc600 */
  0x0000,0xd78d,0xd78e,0xd78f,0xd791,0xd792,0xd793,0xd794,
  0xd795,0xd796,0xd797,0xd79a,0xd79c,0xd79e,0xd79f,0xd7a0,
  0xd7a1,0xd7a2,0xd7a3,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xd264,0xd280,0xd281,0xd284,0xd288,0xd290,0xd291,0xd295,
  0xd29c,0xd2a0,0xd2a4,0xd2ac,0xd2b1,0xd2b8,0xd2b9,0xd2bc,
  0xd2bf,0xd2c0,0xd2c2,0xd2c8,0xd2c9,0xd2cb,0xd2d4,0xd2d8,
  0xd2dc,0xd2e4,0xd2e5,0xd2f0,0xd2f1,0xd2f4,0xd2f8,0xd300,
  0xd301,0xd303,0xd305,0xd30c,0xd30d,0xd30e,0xd310,0xd314,
  0xd316,0xd31c,0xd31d,0xd31f,0xd320,0xd321,0xd325,0xd328,
  0xd329,0xd32c,0xd330,0xd338,0xd339,0xd33b,0xd33c,0xd33d,
  0xd344,0xd345,0xd37c,0xd37d,0xd380,0xd384,0xd38c,0xd38d,
  0xd38f,0xd390,0xd391,0xd398,0xd399,0xd39c,0xd3a0,0xd3a8,
  0xd3a9,0xd3ab,0xd3ad,0xd3b4,0xd3b8,0xd3bc,0xd3c4,0xd3c5,
  0xd3c8,0xd3c9,0xd3d0,0xd3d8,0xd3e1,0xd3e3,0xd3ec,0xd3ed,
  0xd3f0,0xd3f4,0xd3fc,0xd3fd,0xd3ff,0xd401,
/* 0xc700 */
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xd408,0xd41d,0xd440,0xd444,0xd45c,0xd460,0xd464,0xd46d,
  0xd46f,0xd478,0xd479,0xd47c,0xd47f,0xd480,0xd482,0xd488,
  0xd489,0xd48b,0xd48d,0xd494,0xd4a9,0xd4cc,0xd4d0,0xd4d4,
  0xd4dc,0xd4df,0xd4e8,0xd4ec,0xd4f0,0xd4f8,0xd4fb,0xd4fd,
  0xd504,0xd508,0xd50c,0xd514,0xd515,0xd517,0xd53c,0xd53d,
  0xd540,0xd544,0xd54c,0xd54d,0xd54f,0xd551,0xd558,0xd559,
  0xd55c,0xd560,0xd565,0xd568,0xd569,0xd56b,0xd56d,0xd574,
  0xd575,0xd578,0xd57c,0xd584,0xd585,0xd587,0xd588,0xd589,
  0xd590,0xd5a5,0xd5c8,0xd5c9,0xd5cc,0xd5d0,0xd5d2,0xd5d8,
  0xd5d9,0xd5db,0xd5dd,0xd5e4,0xd5e5,0xd5e8,0xd5ec,0xd5f4,
  0xd5f5,0xd5f7,0xd5f9,0xd600,0xd601,0xd604,0xd608,0xd610,
  0xd611,0xd613,0xd614,0xd615,0xd61c,0xd620,
/* 0xc800 */
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xd624,0xd62d,0xd638,0xd639,0xd63c,0xd640,0xd645,0xd648,
  0xd649,0xd64b,0xd64d,0xd651,0xd654,0xd655,0xd658,0xd65c,
  0xd667,0xd669,0xd670,0xd671,0xd674,0xd683,0xd685,0xd68c,
  0xd68d,0xd690,0xd694,0xd69d,0xd69f,0xd6a1,0xd6a8,0xd6ac,
  0xd6b0,0xd6b9,0xd6bb,0xd6c4,0xd6c5,0xd6c8,0xd6cc,0xd6d1,
  0xd6d4,0xd6d7,0xd6d9,0xd6e0,0xd6e4,0xd6e8,0xd6f0,0xd6f5,
  0xd6fc,0xd6fd,0xd700,0xd704,0xd711,0xd718,0xd719,0xd71c,
  0xd720,0xd728,0xd729,0xd72b,0xd72d,0xd734,0xd735,0xd738,
  0xd73c,0xd744,0xd747,0xd749,0xd750,0xd751,0xd754,0xd756,
  0xd757,0xd758,0xd759,0xd760,0xd761,0xd763,0xd765,0xd769,
  0xd76c,0xd770,0xd774,0xd77c,0xd77d,0xd781,0xd788,0xd789,
  0xd78c,0xd790,0xd798,0xd799,0xd79b,0xd79d,
/* 0xc900 */
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xe000,0xe001,0xe002,0xe003,0xe004,0xe005,0xe006,0xe007,
  0xe008,0xe009,0xe00a,0xe00b,0xe00c,0xe00d,0xe00e,0xe00f,
  0xe010,0xe011,0xe012,0xe013,0xe014,0xe015,0xe016,0xe017,
  0xe018,0xe019,0xe01a,0xe01b,0xe01c,0xe01d,0xe01e,0xe01f,
  0xe020,0xe021,0xe022,0xe023,0xe024,0xe025,0xe026,0xe027,
  0xe028,0xe029,0xe02a,0xe02b,0xe02c,0xe02d,0xe02e,0xe02f,
  0xe030,0xe031,0xe032,0xe033,0xe034,0xe035,0xe036,0xe037,
  0xe038,0xe039,0xe03a,0xe03b,0xe03c,0xe03d,0xe03e,0xe03f,
  0xe040,0xe041,0xe042,0xe043,0xe044,0xe045,0xe046,0xe047,
  0xe048,0xe049,0xe04a,0xe04b,0xe04c,0xe04d,0xe04e,0xe04f,
  0xe050,0xe051,0xe052,0xe053,0xe054,0xe055,0xe056,0xe057,
  0xe058,0xe059,0xe05a,0xe05b,0xe05c,0xe05d,
/* 0xca00 */
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x4f3d,0x4f73,0x5047,0x50f9,0x52a0,0x53ef,0x5475,0x54e5,
  0x5609,0x5ac1,0x5bb6,0x6687,0x67b6,0x67b7,0x67ef,0x6b4c,
  0x73c2,0x75c2,0x7a3c,0x82db,0x8304,0x8857,0x8888,0x8a36,
  0x8cc8,0x8dcf,0x8efb,0x8fe6,0x99d5,0x523b,0x5374,0x5404,
  0x606a,0x6164,0x6bbc,0x73cf,0x811a,0x89ba,0x89d2,0x95a3,
  0x4f83,0x520a,0x58be,0x5978,0x59e6,0x5e72,0x5e79,0x61c7,
  0x63c0,0x6746,0x67ec,0x687f,0x6f97,0x764e,0x770b,0x78f5,
  0x7a08,0x7aff,0x7c21,0x809d,0x826e,0x8271,0x8aeb,0x9593,
  0x4e6b,0x559d,0x66f7,0x6e34,0x78a3,0x7aed,0x845b,0x8910,
  0x874e,0x97a8,0x52d8,0x574e,0x582a,0x5d4c,0x611f,0x61be,
  0x6221,0x6562,0x67d1,0x6a44,0x6e1b,0x7518,0x75b3,0x76e3,
  0x77b0,0x7d3a,0x90af,0x9451,0x9452,0x9f95,
/* 0xcb00 */
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x5323,0x5cac,0x7532,0x80db,0x9240,0x9598,0x525b,0x5808,
  0x59dc,0x5ca1,0x5d17,0x5eb7,0x5f3a,0x5f4a,0x6177,0x6c5f,
  0x757a,0x7586,0x7ce0,0x7d73,0x7db1,0x7f8c,0x8154,0x8221,
  0x8591,0x8941,0x8b1b,0x92fc,0x964d,0x9c47,0x4ecb,0x4ef7,
  0x500b,0x51f1,0x584f,0x6137,0x613e,0x6168,0x6539,0x69ea,
  0x6f11,0x75a5,0x7686,0x76d6,0x7b87,0x82a5,0x84cb,0xf900,
  0x93a7,0x958b,0x5580,0x5ba2,0x5751,0xf901,0x7cb3,0x7fb9,
  0x91b5,0x5028,0x53bb,0x5c45,0x5de8,0x62d2,0x636e,0x64da,
  0x64e7,0x6e20,0x70ac,0x795b,0x8ddd,0x8e1e,0xf902,0x907d,
  0x9245,0x92f8,0x4e7e,0x4ef6,0x5065,0x5dfe,0x5efa,0x6106,
  0x6957,0x8171,0x8654,0x8e47,0x9375,0x9a2b,0x4e5e,0x5091,
  0x6770,0x6840,0x5109,0x528d,0x5292,0x6aa2,
/* 0xcc00 */
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x77bc,0x9210,0x9ed4,0x52ab,0x602f,0x8ff2,0x5048,0x61a9,
  0x63ed,0x64ca,0x683c,0x6a84,0x6fc0,0x8188,0x89a1,0x9694,
  0x5805,0x727d,0x72ac,0x7504,0x7d79,0x7e6d,0x80a9,0x898b,
  0x8b74,0x9063,0x9d51,0x6289,0x6c7a,0x6f54,0x7d50,0x7f3a,
  0x8a23,0x517c,0x614a,0x7b9d,0x8b19,0x9257,0x938c,0x4eac,
  0x4fd3,0x501e,0x50be,0x5106,0x52c1,0x52cd,0x537f,0x5770,
  0x5883,0x5e9a,0x5f91,0x6176,0x61ac,0x64ce,0x656c,0x666f,
  0x66bb,0x66f4,0x6897,0x6d87,0x7085,0x70f1,0x749f,0x74a5,
  0x74ca,0x75d9,0x786c,0x78ec,0x7adf,0x7af6,0x7d45,0x7d93,
  0x8015,0x803f,0x811b,0x8396,0x8b66,0x8f15,0x9015,0x93e1,
  0x9803,0x9838,0x9a5a,0x9be8,0x4fc2,0x5553,0x583a,0x5951,
  0x5b63,0x5c46,0x60b8,0x6212,0x6842,0x68b0,
/* 0xcd00 */
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x68e8,0x6eaa,0x754c,0x7678,0x78ce,0x7a3d,0x7cfb,0x7e6b,
  0x7e7c,0x8a08,0x8aa1,0x8c3f,0x968e,0x9dc4,0x53e4,0x53e9,
  0x544a,0x5471,0x56fa,0x59d1,0x5b64,0x5c3b,0x5eab,0x62f7,
  0x6537,0x6545,0x6572,0x66a0,0x67af,0x69c1,0x6cbd,0x75fc,
  0x7690,0x777e,0x7a3f,0x7f94,0x8003,0x80a1,0x818f,0x82e6,
  0x82fd,0x83f0,0x85c1,0x8831,0x88b4,0x8aa5,0xf903,0x8f9c,
  0x932e,0x96c7,0x9867,0x9ad8,0x9f13,0x54ed,0x659b,0x66f2,
  0x688f,0x7a40,0x8c37,0x9d60,0x56f0,0x5764,0x5d11,0x6606,
  0x68b1,0x68cd,0x6efe,0x7428,0x889e,0x9be4,0x6c68,0xf904,
  0x9aa8,0x4f9b,0x516c,0x5171,0x529f,0x5b54,0x5de5,0x6050,
  0x606d,0x62f1,0x63a7,0x653b,0x73d9,0x7a7a,0x86a3,0x8ca2,
  0x978f,0x4e32,0x5be1,0x6208,0x679c,0x74dc,
/* 0xce00 */
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x79d1,0x83d3,0x8a87,0x8ab2,0x8de8,0x904e,0x934b,0x9846,
  0x5ed3,0x69e8,0x85ff,0x90ed,0xf905,0x51a0,0x5b98,0x5bec,
  0x6163,0x68fa,0x6b3e,0x704c,0x742f,0x74d8,0x7ba1,0x7f50,
  0x83c5,0x89c0,0x8cab,0x95dc,0xfa2c,0x522e,0x605d,0x62ec,
  0x9002,0x4f8a,0x5149,0x5321,0x58d9,0x5ee3,0x66e0,0x6d38,
  0x709a,0x72c2,0x73d6,0x7b50,0x80f1,0x945b,0x5366,0x639b,
  0x7f6b,0x4e56,0x5080,0x584a,0x58de,0x602a,0x6127,0x62d0,
  0x69d0,0x9b41,0x5b8f,0x7d18,0x80b1,0x8f5f,0x4ea4,0x50d1,
  0x54ac,0x55ac,0x5b0c,0x5da0,0x5de7,0x652a,0x654e,0x6821,
  0x6a4b,0x72e1,0x768e,0x77ef,0x7d5e,0x7ff9,0x81a0,0x854e,
  0x86df,0x8f03,0x8f4e,0x90ca,0x9903,0x9a55,0x9bab,0x4e18,
  0x4e45,0x4e5d,0x4ec7,0x4ff1,0x5177,0x52fe,
/* 0xcf00 */
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x5340,0x53e3,0x53e5,0x548e,0x5614,0x5775,0x57a2,0x5bc7,
  0x5d87,0x5ed0,0x61fc,0x62d8,0x6551,0x67b8,0x67e9,0x69cb,
  0x6b50,0x6bc6,0x6bec,0x6c42,0x6e9d,0x7078,0x72d7,0x7396,
  0x7403,0x77bf,0x77e9,0x7a76,0x7d7f,0x8009,0x81fc,0x8205,
  0x820a,0x82df,0x8862,0x8b33,0x8cfc,0x8ec0,0x9011,0x90b1,
  0x9264,0x92b6,0x99d2,0x9a45,0x9ce9,0x9dd7,0x9f9c,0x570b,
  0x5c40,0x83ca,0x97a0,0x97ab,0x9eb4,0x541b,0x7a98,0x7fa4,
  0x88d9,0x8ecd,0x90e1,0x5800,0x5c48,0x6398,0x7a9f,0x5bae,
  0x5f13,0x7a79,0x7aae,0x828e,0x8eac,0x5026,0x5238,0x52f8,
  0x5377,0x5708,0x62f3,0x6372,0x6b0a,0x6dc3,0x7737,0x53a5,
  0x7357,0x8568,0x8e76,0x95d5,0x673a,0x6ac3,0x6f70,0x8a6d,
  0x8ecc,0x994b,0xf906,0x6677,0x6b78,0x8cb4,
/* 0xd000 */
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x9b3c,0xf907,0x53eb,0x572d,0x594e,0x63c6,0x69fb,0x73ea,
  0x7845,0x7aba,0x7ac5,0x7cfe,0x8475,0x898f,0x8d73,0x9035,
  0x95a8,0x52fb,0x5747,0x7547,0x7b60,0x83cc,0x921e,0xf908,
  0x6a58,0x514b,0x524b,0x5287,0x621f,0x68d8,0x6975,0x9699,
  0x50c5,0x52a4,0x52e4,0x61c3,0x65a4,0x6839,0x69ff,0x747e,
  0x7b4b,0x82b9,0x83eb,0x89b2,0x8b39,0x8fd1,0x9949,0xf909,
  0x4eca,0x5997,0x64d2,0x6611,0x6a8e,0x7434,0x7981,0x79bd,
  0x82a9,0x887e,0x887f,0x895f,0xf90a,0x9326,0x4f0b,0x53ca,
  0x6025,0x6271,0x6c72,0x7d1a,0x7d66,0x4e98,0x5162,0x77dc,
  0x80af,0x4f01,0x4f0e,0x5176,0x5180,0x55dc,0x5668,0x573b,
  0x57fa,0x57fc,0x5914,0x5947,0x5993,0x5bc4,0x5c90,0x5d0e,
  0x5df1,0x5e7e,0x5fcc,0x6280,0x65d7,0x65e3,
/* 0xd100 */
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x671e,0x671f,0x675e,0x68cb,0x68c4,0x6a5f,0x6b3a,0x6c23,
  0x6c7d,0x6c82,0x6dc7,0x7398,0x7426,0x742a,0x7482,0x74a3,
  0x7578,0x757f,0x7881,0x78ef,0x7941,0x7947,0x7948,0x797a,
  0x7b95,0x7d00,0x7dba,0x7f88,0x8006,0x802d,0x808c,0x8a18,
  0x8b4f,0x8c48,0x8d77,0x9321,0x9324,0x98e2,0x9951,0x9a0e,
  0x9a0f,0x9a65,0x9e92,0x7dca,0x4f76,0x5409,0x62ee,0x6854,
  0x91d1,0x55ab,0x513a,0xf90b,0xf90c,0x5a1c,0x61e6,0xf90d,
  0x62cf,0x62ff,0xf90e,0xf90f,0xf910,0xf911,0xf912,0xf913,
  0x90a3,0xf914,0xf915,0xf916,0xf917,0xf918,0x8afe,0xf919,
  0xf91a,0xf91b,0xf91c,0x6696,0xf91d,0x7156,0xf91e,0xf91f,
  0x96e3,0xf920,0x634f,0x637a,0x5357,0xf921,0x678f,0x6960,
  0x6e73,0xf922,0x7537,0xf923,0xf924,0xf925,
/* 0xd200 */
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x7d0d,0xf926,0xf927,0x8872,0x56ca,0x5a18,0xf928,0xf929,
  0xf92a,0xf92b,0xf92c,0x4e43,0xf92d,0x5167,0x5948,0x67f0,
  0x8010,0xf92e,0x5973,0x5e74,0x649a,0x79ca,0x5ff5,0x606c,
  0x62c8,0x637b,0x5be7,0x5bd7,0x52aa,0xf92f,0x5974,0x5f29,
  0x6012,0xf930,0xf931,0xf932,0x7459,0xf933,0xf934,0xf935,
  0xf936,0xf937,0xf938,0x99d1,0xf939,0xf93a,0xf93b,0xf93c,
  0xf93d,0xf93e,0xf93f,0xf940,0xf941,0xf942,0xf943,0x6fc3,
  0xf944,0xf945,0x81bf,0x8fb2,0x60f1,0xf946,0xf947,0x8166,
  0xf948,0xf949,0x5c3f,0xf94a,0xf94b,0xf94c,0xf94d,0xf94e,
  0xf94f,0xf950,0xf951,0x5ae9,0x8a25,0x677b,0x7d10,0xf952,
  0xf953,0xf954,0xf955,0xf956,0xf957,0x80fd,0xf958,0xf959,
  0x5c3c,0x6ce5,0x533f,0x6eba,0x591a,0x8336,
/* 0xd300 */
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x4e39,0x4eb6,0x4f46,0x55ae,0x5718,0x58c7,0x5f56,0x65b7,
  0x65e6,0x6a80,0x6bb5,0x6e4d,0x77ed,0x7aef,0x7c1e,0x7dde,
  0x86cb,0x8892,0x9132,0x935b,0x64bb,0x6fbe,0x737a,0x75b8,
  0x9054,0x5556,0x574d,0x61ba,0x64d4,0x66c7,0x6de1,0x6e5b,
  0x6f6d,0x6fb9,0x75f0,0x8043,0x81bd,0x8541,0x8983,0x8ac7,
  0x8b5a,0x931f,0x6c93,0x7553,0x7b54,0x8e0f,0x905d,0x5510,
  0x5802,0x5858,0x5e62,0x6207,0x649e,0x68e0,0x7576,0x7cd6,
  0x87b3,0x9ee8,0x4ee3,0x5788,0x576e,0x5927,0x5c0d,0x5cb1,
  0x5e36,0x5f85,0x6234,0x64e1,0x73b3,0x81fa,0x888b,0x8cb8,
  0x968a,0x9edb,0x5b85,0x5fb7,0x60b3,0x5012,0x5200,0x5230,
  0x5716,0x5835,0x5857,0x5c0e,0x5c60,0x5cf6,0x5d8b,0x5ea6,
  0x5f92,0x60bc,0x6311,0x6389,0x6417,0x6843,
/* 0xd400 */
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x68f9,0x6ac2,0x6dd8,0x6e21,0x6ed4,0x6fe4,0x71fe,0x76dc,
  0x7779,0x79b1,0x7a3b,0x8404,0x89a9,0x8ced,0x8df3,0x8e48,
  0x9003,0x9014,0x9053,0xfa26,0x934d,0x9676,0x97dc,0x6bd2,
  0x7006,0x7258,0x72a2,0x7368,0x7763,0x79bf,0x7be4,0x7e9b,
  0x8b80,0x58a9,0x60c7,0x6566,0x65fd,0x66be,0x6c8c,0x711e,
  0x71c9,0x8c5a,0x9813,0x4e6d,0x7a81,0x4edd,0x51ac,0x51cd,
  0x52d5,0x540c,0x61a7,0x6771,0x6850,0x68df,0x6d1e,0x6f7c,
  0x75bc,0x77b3,0x7ae5,0x80f4,0x8463,0x9285,0x515c,0x6597,
  0x675c,0x6793,0x75d8,0x7ac7,0x8373,0xf95a,0x8c46,0x9017,
  0x982d,0x5c6f,0x81c0,0x829a,0x9041,0x906f,0x920d,0x5f97,
  0x5d9d,0x6a59,0x71c8,0x767b,0x7b49,0x85e4,0x8b04,0x9127,
  0x9a30,0x5587,0x61f6,0xf95b,0x7669,0x7f85,
/* 0xd500 */
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x863f,0x87ba,0x88f8,0x908f,0xf95c,0x6d1b,0x70d9,0x73de,
  0x7d61,0x843d,0xf95d,0x916a,0x99f1,0xf95e,0x4e82,0x5375,
  0x6b04,0x6b12,0x703e,0x721b,0x862d,0x9e1e,0x524c,0x8fa3,
  0x5d50,0x64e5,0x652c,0x6b16,0x6feb,0x7c43,0x7e9c,0x85cd,
  0x8964,0x89bd,0x62c9,0x81d8,0x881f,0x5eca,0x6717,0x6d6a,
  0x72fc,0x7405,0x746f,0x8782,0x90de,0x4f86,0x5d0d,0x5fa0,
  0x840a,0x51b7,0x63a0,0x7565,0x4eae,0x5006,0x5169,0x51c9,
  0x6881,0x6a11,0x7cae,0x7cb1,0x7ce7,0x826f,0x8ad2,0x8f1b,
  0x91cf,0x4fb6,0x5137,0x52f5,0x5442,0x5eec,0x616e,0x623e,
  0x65c5,0x6ada,0x6ffe,0x792a,0x85dc,0x8823,0x95ad,0x9a62,
  0x9a6a,0x9e97,0x9ece,0x529b,0x66c6,0x6b77,0x701d,0x792b,
  0x8f62,0x9742,0x6190,0x6200,0x6523,0x6f23,
/* 0xd600 */
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x7149,0x7489,0x7df4,0x806f,0x84ee,0x8f26,0x9023,0x934a,
  0x51bd,0x5217,0x52a3,0x6d0c,0x70c8,0x88c2,0x5ec9,0x6582,
  0x6bae,0x6fc2,0x7c3e,0x7375,0x4ee4,0x4f36,0x56f9,0xf95f,
  0x5cba,0x5dba,0x601c,0x73b2,0x7b2d,0x7f9a,0x7fce,0x8046,
  0x901e,0x9234,0x96f6,0x9748,0x9818,0x9f61,0x4f8b,0x6fa7,
  0x79ae,0x91b4,0x96b7,0x52de,0xf960,0x6488,0x64c4,0x6ad3,
  0x6f5e,0x7018,0x7210,0x76e7,0x8001,0x8606,0x865c,0x8def,
  0x8f05,0x9732,0x9b6f,0x9dfa,0x9e75,0x788c,0x797f,0x7da0,
  0x83c9,0x9304,0x9e7f,0x9e93,0x8ad6,0x58df,0x5f04,0x6727,
  0x7027,0x74cf,0x7c60,0x807e,0x5121,0x7028,0x7262,0x78ca,
  0x8cc2,0x8cda,0x8cf4,0x96f7,0x4e86,0x50da,0x5bee,0x5ed6,
  0x6599,0x71ce,0x7642,0x77ad,0x804a,0x84fc,
/* 0xd700 */
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x907c,0x9b27,0x9f8d,0x58d8,0x5a41,0x5c62,0x6a13,0x6dda,
  0x6f0f,0x763b,0x7d2f,0x7e37,0x851e,0x8938,0x93e4,0x964b,
  0x5289,0x65d2,0x67f3,0x69b4,0x6d41,0x6e9c,0x700f,0x7409,
  0x7460,0x7559,0x7624,0x786b,0x8b2c,0x985e,0x516d,0x622e,
  0x9678,0x4f96,0x502b,0x5d19,0x6dea,0x7db8,0x8f2a,0x5f8b,
  0x6144,0x6817,0xf961,0x9686,0x52d2,0x808b,0x51dc,0x51cc,
  0x695e,0x7a1c,0x7dbe,0x83f1,0x9675,0x4fda,0x5229,0x5398,
  0x540f,0x550e,0x5c65,0x60a7,0x674e,0x68a8,0x6d6c,0x7281,
  0x72f8,0x7406,0x7483,0xf962,0x75e2,0x7c6c,0x7f79,0x7fb8,
  0x8389,0x88cf,0x88e1,0x91cc,0x91d0,0x96e2,0x9bc9,0x541d,
  0x6f7e,0x71d0,0x7498,0x85fa,0x8eaa,0x96a3,0x9c57,0x9e9f,
  0x6797,0x6dcb,0x7433,0x81e8,0x9716,0x782c,
/* 0xd800 */
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x7acb,0x7b20,0x7c92,0x6469,0x746a,0x75f2,0x78bc,0x78e8,
  0x99ac,0x9b54,0x9ebb,0x5bde,0x5e55,0x6f20,0x819c,0x83ab,
  0x9088,0x4e07,0x534d,0x5a29,0x5dd2,0x5f4e,0x6162,0x633d,
  0x6669,0x66fc,0x6eff,0x6f2b,0x7063,0x779e,0x842c,0x8513,
  0x883b,0x8f13,0x9945,0x9c3b,0x551c,0x62b9,0x672b,0x6cab,
  0x8309,0x896a,0x977a,0x4ea1,0x5984,0x5fd8,0x5fd9,0x671b,
  0x7db2,0x7f54,0x8292,0x832b,0x83bd,0x8f1e,0x9099,0x57cb,
  0x59b9,0x5a92,0x5bd0,0x6627,0x679a,0x6885,0x6bcf,0x7164,
  0x7f75,0x8cb7,0x8ce3,0x9081,0x9b45,0x8108,0x8c8a,0x964c,
  0x9a40,0x9ea5,0x5b5f,0x6c13,0x731b,0x76f2,0x76df,0x840c,
  0x51aa,0x8993,0x514d,0x5195,0x52c9,0x68c9,0x6c94,0x7704,
  0x7720,0x7dbf,0x7dec,0x9762,0x9eb5,0x6ec5,
/* 0xd900 */
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x8511,0x51a5,0x540d,0x547d,0x660e,0x669d,0x6927,0x6e9f,
  0x76bf,0x7791,0x8317,0x84c2,0x879f,0x9169,0x9298,0x9cf4,
  0x8882,0x4fae,0x5192,0x52df,0x59c6,0x5e3d,0x6155,0x6478,
  0x6479,0x66ae,0x67d0,0x6a21,0x6bcd,0x6bdb,0x725f,0x7261,
  0x7441,0x7738,0x77db,0x8017,0x82bc,0x8305,0x8b00,0x8b28,
  0x8c8c,0x6728,0x6c90,0x7267,0x76ee,0x7766,0x7a46,0x9da9,
  0x6b7f,0x6c92,0x5922,0x6726,0x8499,0x536f,0x5893,0x5999,
  0x5edf,0x63cf,0x6634,0x6773,0x6e3a,0x732b,0x7ad7,0x82d7,
  0x9328,0x52d9,0x5deb,0x61ae,0x61cb,0x620a,0x62c7,0x64ab,
  0x65e0,0x6959,0x6b66,0x6bcb,0x7121,0x73f7,0x755d,0x7e46,
  0x821e,0x8302,0x856a,0x8aa3,0x8cbf,0x9727,0x9d61,0x58a8,
  0x9ed8,0x5011,0x520e,0x543b,0x554f,0x6587,
/* 0xda00 */
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x6c76,0x7d0a,0x7d0b,0x805e,0x868a,0x9580,0x96ef,0x52ff,
  0x6c95,0x7269,0x5473,0x5a9a,0x5c3e,0x5d4b,0x5f4c,0x5fae,
  0x672a,0x68b6,0x6963,0x6e3c,0x6e44,0x7709,0x7c73,0x7f8e,
  0x8587,0x8b0e,0x8ff7,0x9761,0x9ef4,0x5cb7,0x60b6,0x610d,
  0x61ab,0x654f,0x65fb,0x65fc,0x6c11,0x6cef,0x739f,0x73c9,
  0x7de1,0x9594,0x5bc6,0x871c,0x8b10,0x525d,0x535a,0x62cd,
  0x640f,0x64b2,0x6734,0x6a38,0x6cca,0x73c0,0x749e,0x7b94,
  0x7c95,0x7e1b,0x818a,0x8236,0x8584,0x8feb,0x96f9,0x99c1,
  0x4f34,0x534a,0x53cd,0x53db,0x62cc,0x642c,0x6500,0x6591,
  0x69c3,0x6cee,0x6f58,0x73ed,0x7554,0x7622,0x76e4,0x76fc,
  0x78d0,0x78fb,0x792c,0x7d46,0x822c,0x87e0,0x8fd4,0x9812,
  0xfa2a,0x52c3,0x62d4,0x64a5,0x6e24,0x6f51,
/* 0xdb00 */
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x767c,0x8dcb,0x91b1,0x9262,0x9aee,0x9b43,0x5023,0x508d,
  0x574a,0x59a8,0x5c28,0x5e47,0x5f77,0x623f,0x653e,0x65b9,
  0x65c1,0x6609,0x678b,0x699c,0x6ec2,0x78c5,0x7d21,0x80aa,
  0x8180,0x822b,0x82b3,0x84a1,0x868c,0x8a2a,0x8b17,0x90a6,
  0x9632,0x9f90,0x500d,0x4ff3,0xf963,0x57f9,0x5f98,0x62dc,
  0x6392,0x676f,0x6e43,0x7119,0x76c3,0x80cc,0x80da,0x88f4,
  0x88f5,0x8919,0x8ce0,0x8f29,0x914d,0x966a,0x4f2f,0x4f70,
  0x5e1b,0x67cf,0x6822,0x767d,0x767e,0x9b44,0x5e61,0x6a0a,
  0x7169,0x71d4,0x756a,0xf964,0x7e41,0x8543,0x85e9,0x98dc,
  0x4f10,0x7b4f,0x7f70,0x95a5,0x51e1,0x5e06,0x68b5,0x6c3e,
  0x6c4e,0x6cdb,0x72af,0x7bc4,0x8303,0x6cd5,0x743a,0x50fb,
  0x5288,0x58c1,0x64d8,0x6a97,0x74a7,0x7656,
/* 0xdc00 */
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x78a7,0x8617,0x95e2,0x9739,0xf965,0x535e,0x5f01,0x8b8a,
  0x8fa8,0x8faf,0x908a,0x5225,0x77a5,0x9c49,0x9f08,0x4e19,
  0x5002,0x5175,0x5c5b,0x5e77,0x661e,0x663a,0x67c4,0x68c5,
  0x70b3,0x7501,0x75c5,0x79c9,0x7add,0x8f27,0x9920,0x9a08,
  0x4fdd,0x5821,0x5831,0x5bf6,0x666e,0x6b65,0x6d11,0x6e7a,
  0x6f7d,0x73e4,0x752b,0x83e9,0x88dc,0x8913,0x8b5c,0x8f14,
  0x4f0f,0x50d5,0x5310,0x535c,0x5b93,0x5fa9,0x670d,0xfa1b,
  0x8179,0x832f,0x8514,0x8907,0x8986,0x8f39,0x8f3b,0x99a5,
  0x9c12,0x672c,0x4e76,0x4ff8,0x5949,0x5c01,0x5cef,0x5cf0,
  0x6367,0x68d2,0x70fd,0x71a2,0x742b,0x7e2b,0x84ec,0x8702,
  0x9022,0x92d2,0x9cf3,0x4e0d,0x4ed8,0x4fef,0x5085,0x5256,
  0x526f,0x5426,0x5490,0x57e0,0x592b,0x5a66,
/* 0xdd00 */
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x5b5a,0x5b75,0x5bcc,0x5e9c,0xf966,0x6276,0x6577,0x65a7,
  0x6d6e,0x6ea5,0x7236,0x7b26,0x7c3f,0x7f36,0x8150,0x8151,
  0x819a,0x8240,0x8299,0x83a9,0x8a03,0x8ca0,0x8ce6,0x8cfb,
  0x8d74,0x8dba,0x90e8,0x91dc,0x961c,0x9644,0x99d9,0x9ce7,
  0x5317,0x5206,0x5429,0x5674,0x58b3,0x5954,0x596e,0x5fff,
  0x61a4,0x626e,0x6610,0x6c7e,0x711a,0x76c6,0x7c89,0x7cde,
  0x7d1b,0x82ac,0x8cc1,0x96f0,0xf967,0x4f5b,0x5f17,0x5f7f,
  0x62c2,0x5d29,0x670b,0x68da,0x787c,0x7e43,0x9d6c,0x4e15,
  0x5099,0x5315,0x532a,0x5351,0x5983,0x5a62,0x5e87,0x60b2,
  0x618a,0x6249,0x6279,0x6590,0x6787,0x69a7,0x6bd4,0x6bd6,
  0x6bd7,0x6bd8,0x6cb8,0xf968,0x7435,0x75fa,0x7812,0x7891,
  0x79d5,0x79d8,0x7c83,0x7dcb,0x7fe1,0x80a5,
/* 0xde00 */
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x813e,0x81c2,0x83f2,0x871a,0x88e8,0x8ab9,0x8b6c,0x8cbb,
  0x9119,0x975e,0x98db,0x9f3b,0x56ac,0x5b2a,0x5f6c,0x658c,
  0x6ab3,0x6baf,0x6d5c,0x6ff1,0x7015,0x725d,0x73ad,0x8ca7,
  0x8cd3,0x983b,0x6191,0x6c37,0x8058,0x9a01,0x4e4d,0x4e8b,
  0x4e9b,0x4ed5,0x4f3a,0x4f3c,0x4f7f,0x4fdf,0x50ff,0x53f2,
  0x53f8,0x5506,0x55e3,0x56db,0x58eb,0x5962,0x5a11,0x5beb,
  0x5bfa,0x5c04,0x5df3,0x5e2b,0x5f99,0x601d,0x6368,0x659c,
  0x65af,0x67f6,0x67fb,0x68ad,0x6b7b,0x6c99,0x6cd7,0x6e23,
  0x7009,0x7345,0x7802,0x793e,0x7940,0x7960,0x79c1,0x7be9,
  0x7d17,0x7d72,0x8086,0x820d,0x838e,0x84d1,0x86c7,0x88df,
  0x8a50,0x8a5e,0x8b1d,0x8cdc,0x8d66,0x8fad,0x90aa,0xfa2b,
  0x99df,0x9e9d,0x524a,0xf969,0x6714,0xf96a,
/* 0xdf00 */
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x5098,0x522a,0x5c71,0x6563,0x6c55,0x73ca,0x7523,0x759d,
  0x7b97,0x849c,0x9178,0x9730,0x4e77,0x6492,0x6bba,0x715e,
  0x85a9,0x4e09,0xf96b,0x6749,0x68ee,0x6e17,0x829f,0x8518,
  0x886b,0x63f7,0x6f81,0x9212,0x98af,0x4e0a,0x50b7,0x50cf,
  0x511f,0x5546,0x55aa,0x5617,0x5b40,0x5c19,0x5ce0,0x5e38,
  0x5e8a,0x5ea0,0x5ec2,0x60f3,0x6851,0x6a61,0x6e58,0x723d,
  0x7240,0x72c0,0x76f8,0xfa1a,0x7bb1,0x7fd4,0x88f3,0x89f4,
  0x8a73,0x8c61,0x8cde,0x971c,0x585e,0x74bd,0x8cfd,0x55c7,
  0xf96c,0x7a61,0x7d22,0x8272,0x7272,0x751f,0x7525,0xf96d,
  0x7b19,0x5885,0x58fb,0x5dbc,0x5e8f,0x5eb6,0x5f90,0x6055,
  0x6292,0x637f,0x654d,0x6691,0x66d9,0x66f8,0x6816,0x68f2,
  0x7280,0x745e,0x7b6e,0x7d6e,0x7dd6,0x7f72,
/* 0xe000 */
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x80e5,0x8212,0x85af,0x897f,0x8a93,0x901d,0x92e4,0x9ecd,
  0x9f20,0x5915,0x596d,0x5e2d,0x60dc,0x6614,0x6673,0x6790,
  0x6c50,0x6dc5,0x6f5f,0x77f3,0x78a9,0x84c6,0x91cb,0x932b,
  0x4ed9,0x50ca,0x5148,0x5584,0x5b0b,0x5ba3,0x6247,0x657e,
  0x65cb,0x6e32,0x717d,0x7401,0x7444,0x7487,0x74bf,0x766c,
  0x79aa,0x7dda,0x7e55,0x7fa8,0x817a,0x81b3,0x8239,0x861a,
  0x87ec,0x8a75,0x8de3,0x9078,0x9291,0x9425,0x994d,0x9bae,
  0x5368,0x5c51,0x6954,0x6cc4,0x6d29,0x6e2b,0x820c,0x859b,
  0x893b,0x8a2d,0x8aaa,0x96ea,0x9f67,0x5261,0x66b9,0x6bb2,
  0x7e96,0x87fe,0x8d0d,0x9583,0x965d,0x651d,0x6d89,0x71ee,
  0xf96e,0x57ce,0x59d3,0x5bac,0x6027,0x60fa,0x6210,0x661f,
  0x665f,0x7329,0x73f9,0x76db,0x7701,0x7b6c,
/* 0xe100 */
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x8056,0x8072,0x8165,0x8aa0,0x9192,0x4e16,0x52e2,0x6b72,
  0x6d17,0x7a05,0x7b39,0x7d30,0xf96f,0x8cb0,0x53ec,0x562f,
  0x5851,0x5bb5,0x5c0f,0x5c11,0x5de2,0x6240,0x6383,0x6414,
  0x662d,0x68b3,0x6cbc,0x6d88,0x6eaf,0x701f,0x70a4,0x71d2,
  0x7526,0x758f,0x758e,0x7619,0x7b11,0x7be0,0x7c2b,0x7d20,
  0x7d39,0x852c,0x856d,0x8607,0x8a34,0x900d,0x9061,0x90b5,
  0x92b7,0x97f6,0x9a37,0x4fd7,0x5c6c,0x675f,0x6d91,0x7c9f,
  0x7e8c,0x8b16,0x8d16,0x901f,0x5b6b,0x5dfd,0x640d,0x84c0,
  0x905c,0x98e1,0x7387,0x5b8b,0x609a,0x677e,0x6dde,0x8a1f,
  0x8aa6,0x9001,0x980c,0x5237,0xf970,0x7051,0x788e,0x9396,
  0x8870,0x91d7,0x4fee,0x53d7,0x55fd,0x56da,0x5782,0x58fd,
  0x5ac2,0x5b88,0x5cab,0x5cc0,0x5e25,0x6101,
/* 0xe200 */
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x620d,0x624b,0x6388,0x641c,0x6536,0x6578,0x6a39,0x6b8a,
  0x6c34,0x6d19,0x6f31,0x71e7,0x72e9,0x7378,0x7407,0x74b2,
  0x7626,0x7761,0x79c0,0x7a57,0x7aea,0x7cb9,0x7d8f,0x7dac,
  0x7e61,0x7f9e,0x8129,0x8331,0x8490,0x84da,0x85ea,0x8896,
  0x8ab0,0x8b90,0x8f38,0x9042,0x9083,0x916c,0x9296,0x92b9,
  0x968b,0x96a7,0x96a8,0x96d6,0x9700,0x9808,0x9996,0x9ad3,
  0x9b1a,0x53d4,0x587e,0x5919,0x5b70,0x5bbf,0x6dd1,0x6f5a,
  0x719f,0x7421,0x74b9,0x8085,0x83fd,0x5de1,0x5f87,0x5faa,
  0x6042,0x65ec,0x6812,0x696f,0x6a53,0x6b89,0x6d35,0x6df3,
  0x73e3,0x76fe,0x77ac,0x7b4d,0x7d14,0x8123,0x821c,0x8340,
  0x84f4,0x8563,0x8a62,0x8ac4,0x9187,0x931e,0x9806,0x99b4,
  0x620c,0x8853,0x8ff0,0x9265,0x5d07,0x5d27,
/* 0xe300 */
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x5d69,0x745f,0x819d,0x8768,0x6fd5,0x62fe,0x7fd2,0x8936,
  0x8972,0x4e1e,0x4e58,0x50e7,0x52dd,0x5347,0x627f,0x6607,
  0x7e69,0x8805,0x965e,0x4f8d,0x5319,0x5636,0x59cb,0x5aa4,
  0x5c38,0x5c4e,0x5c4d,0x5e02,0x5f11,0x6043,0x65bd,0x662f,
  0x6642,0x67be,0x67f4,0x731c,0x77e2,0x793a,0x7fc5,0x8494,
  0x84cd,0x8996,0x8a66,0x8a69,0x8ae1,0x8c55,0x8c7a,0x57f4,
  0x5bd4,0x5f0f,0x606f,0x62ed,0x690d,0x6b96,0x6e5c,0x7184,
  0x7bd2,0x8755,0x8b58,0x8efe,0x98df,0x98fe,0x4f38,0x4f81,
  0x4fe1,0x547b,0x5a20,0x5bb8,0x613c,0x65b0,0x6668,0x71fc,
  0x7533,0xfa19,0x7d33,0x814e,0x81e3,0x8398,0x85aa,0x85ce,
  0x8703,0x8a0a,0x8eab,0x8f9b,0xf971,0x8fc5,0x5931,0x5ba4,
  0x5be6,0x6089,0x5be9,0x5c0b,0x5fc3,0x6c81,
/* 0xe400 */
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xf972,0x6df1,0x700b,0x751a,0x82af,0x8af6,0x4ec0,0x5341,
  0xf973,0x96d9,0x6c0f,0x4e9e,0x4fc4,0x5152,0x555e,0x5a25,
  0x5ce8,0x6211,0x7259,0x82bd,0x83aa,0x86fe,0x8859,0x8a1d,
  0x963f,0x96c5,0x9913,0x9d09,0x9d5d,0x580a,0x5cb3,0x5dbd,
  0x5e44,0x60e1,0x6115,0x63e1,0x6a02,0x6e25,0x9102,0x9354,
  0x984e,0x9c10,0x9f77,0x5b89,0x5cb8,0x6309,0x664f,0x6848,
  0x773c,0x96c1,0x978d,0x9854,0x9b9f,0x65a1,0x8b01,0x8ecb,
  0x95bc,0x5535,0x5ca9,0x5dd6,0x5eb5,0x6697,0x764c,0x83f4,
  0x95c7,0x58d3,0x62bc,0x72ce,0x9d28,0x4ef0,0x592e,0x600f,
  0x663b,0x6b83,0x79e7,0x9d26,0x5393,0x54c0,0x57c3,0x5d16,
  0x611b,0x66d6,0x6daf,0x788d,0x827e,0x9698,0x9744,0x5384,
  0x627c,0x6396,0x6db2,0x7e0a,0x814b,0x984d,
/* 0xe500 */
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x6afb,0x7f4c,0x9daf,0x9e1a,0x4e5f,0x503b,0x51b6,0x591c,
  0x60f9,0x63f6,0x6930,0x723a,0x8036,0xf974,0x91ce,0x5f31,
  0xf975,0xf976,0x7d04,0x82e5,0x846f,0x84bb,0x85e5,0x8e8d,
  0xf977,0x4f6f,0xf978,0xf979,0x58e4,0x5b43,0x6059,0x63da,
  0x6518,0x656d,0x6698,0xf97a,0x694a,0x6a23,0x6d0b,0x7001,
  0x716c,0x75d2,0x760d,0x79b3,0x7a70,0xf97b,0x7f8a,0xf97c,
  0x8944,0xf97d,0x8b93,0x91c0,0x967d,0xf97e,0x990a,0x5704,
  0x5fa1,0x65bc,0x6f01,0x7600,0x79a6,0x8a9e,0x99ad,0x9b5a,
  0x9f6c,0x5104,0x61b6,0x6291,0x6a8d,0x81c6,0x5043,0x5830,
  0x5f66,0x7109,0x8a00,0x8afa,0x5b7c,0x8616,0x4ffa,0x513c,
  0x56b4,0x5944,0x63a9,0x6df9,0x5daa,0x696d,0x5186,0x4e88,
  0x4f59,0xf97f,0xf980,0xf981,0x5982,0xf982,
/* 0xe600 */
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xf983,0x6b5f,0x6c5d,0xf984,0x74b5,0x7916,0xf985,0x8207,
  0x8245,0x8339,0x8f3f,0x8f5d,0xf986,0x9918,0xf987,0xf988,
  0xf989,0x4ea6,0xf98a,0x57df,0x5f79,0x6613,0xf98b,0xf98c,
  0x75ab,0x7e79,0x8b6f,0xf98d,0x9006,0x9a5b,0x56a5,0x5827,
  0x59f8,0x5a1f,0x5bb4,0xf98e,0x5ef6,0xf98f,0xf990,0x6350,
  0x633b,0xf991,0x693d,0x6c87,0x6cbf,0x6d8e,0x6d93,0x6df5,
  0x6f14,0xf992,0x70df,0x7136,0x7159,0xf993,0x71c3,0x71d5,
  0xf994,0x784f,0x786f,0xf995,0x7b75,0x7de3,0xf996,0x7e2f,
  0xf997,0x884d,0x8edf,0xf998,0xf999,0xf99a,0x925b,0xf99b,
  0x9cf6,0xf99c,0xf99d,0xf99e,0x6085,0x6d85,0xf99f,0x71b1,
  0xf9a0,0xf9a1,0x95b1,0x53ad,0xf9a2,0xf9a3,0xf9a4,0x67d3,
  0xf9a5,0x708e,0x7130,0x7430,0x8276,0x82d2,
/* 0xe700 */
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xf9a6,0x95bb,0x9ae5,0x9e7d,0x66c4,0xf9a7,0x71c1,0x8449,
  0xf9a8,0xf9a9,0x584b,0xf9aa,0xf9ab,0x5db8,0x5f71,0xf9ac,
  0x6620,0x668e,0x6979,0x69ae,0x6c38,0x6cf3,0x6e36,0x6f41,
  0x6fda,0x701b,0x702f,0x7150,0x71df,0x7370,0xf9ad,0x745b,
  0xf9ae,0x74d4,0x76c8,0x7a4e,0x7e93,0xf9af,0xf9b0,0x82f1,
  0x8a60,0x8fce,0xf9b1,0x9348,0xf9b2,0x9719,0xf9b3,0xf9b4,
  0x4e42,0x502a,0xf9b5,0x5208,0x53e1,0x66f3,0x6c6d,0x6fca,
  0x730a,0x777f,0x7a62,0x82ae,0x85dd,0x8602,0xf9b6,0x88d4,
  0x8a63,0x8b7d,0x8c6b,0xf9b7,0x92b3,0xf9b8,0x9713,0x9810,
  0x4e94,0x4f0d,0x4fc9,0x50b2,0x5348,0x543e,0x5433,0x55da,
  0x5862,0x58ba,0x5967,0x5a1b,0x5be4,0x609f,0xf9b9,0x61ca,
  0x6556,0x65ff,0x6664,0x68a7,0x6c5a,0x6fb3,
/* 0xe800 */
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x70cf,0x71ac,0x7352,0x7b7d,0x8708,0x8aa4,0x9c32,0x9f07,
  0x5c4b,0x6c83,0x7344,0x7389,0x923a,0x6eab,0x7465,0x761f,
  0x7a69,0x7e15,0x860a,0xfa0c,0x58c5,0x64c1,0x74ee,0x7515,
  0x7670,0x7fc1,0x9095,0x96cd,0x9954,0x6e26,0x74e6,0x7aa9,
  0x7aaa,0x81e5,0x86d9,0x8778,0x8a1b,0x5a49,0x5b8c,0x5b9b,
  0x68a1,0x6900,0x6d63,0x73a9,0x7413,0x742c,0x7897,0x7de9,
  0x7feb,0x8118,0x8155,0x839e,0x8c4c,0x962e,0x9811,0x66f0,
  0x5f80,0x65fa,0x6789,0x6c6a,0x738b,0x502d,0x5a03,0x6b6a,
  0x77ee,0x5916,0x5d6c,0x5dcd,0x7325,0x754f,0xf9ba,0xf9bb,
  0x50e5,0x51f9,0x582f,0x592d,0x5996,0x59da,0x5be5,0xf9bc,
  0xf9bd,0x5da2,0x62d7,0x6416,0x6493,0x64fe,0xf9be,0x66dc,
  0xf9bf,0x6a48,0xf9c0,0x71ff,0x7464,0xf9c1,
/* 0xe900 */
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x7a88,0x7aaf,0x7e47,0x7e5e,0x8000,0x8170,0xf9c2,0x87ef,
  0x8981,0x8b20,0x9059,0xf9c3,0x9080,0x9952,0x617e,0x6b32,
  0x6d74,0x7e1f,0x8925,0x8fb1,0x4fd1,0x50ad,0x5197,0x52c7,
  0x57c7,0x5889,0x5bb9,0x5eb8,0x6142,0x6995,0x6d8c,0x6e67,
  0x6eb6,0x7194,0x7462,0x7528,0x752c,0x8073,0x8338,0x84c9,
  0x8e0a,0x9394,0x93de,0xf9c4,0x4e8e,0x4f51,0x5076,0x512a,
  0x53c8,0x53cb,0x53f3,0x5b87,0x5bd3,0x5c24,0x611a,0x6182,
  0x65f4,0x725b,0x7397,0x7440,0x76c2,0x7950,0x7991,0x79b9,
  0x7d06,0xfa1e,0x828b,0x85d5,0x865e,0x8fc2,0x9047,0x90f5,
  0x91ea,0x9685,0x96e8,0x96e9,0x52d6,0x5f67,0x65ed,0x6631,
  0x682f,0x715c,0x7a36,0x90c1,0x980a,0x4e91,0xf9c5,0x6a52,
  0x6b9e,0x6f90,0x7189,0x8018,0x82b8,0x8553,
/* 0xea00 */
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x904b,0x9695,0x96f2,0x97fb,0x851a,0x9b31,0x4e90,0x718a,
  0x96c4,0x5143,0x539f,0x54e1,0x5713,0x5712,0x57a3,0x5a9b,
  0x5ac4,0x5bc3,0x6028,0x613f,0x63f4,0x6c85,0x6d39,0x6e72,
  0x6e90,0x7230,0x733f,0x7457,0x82d1,0x8881,0x8f45,0x9060,
  0xf9c6,0x9662,0x9858,0x9d1b,0x6708,0x8d8a,0x925e,0x4f4d,
  0x5049,0x50de,0x5371,0x570d,0x59d4,0x5a01,0x5c09,0x6170,
  0x6690,0x6e2d,0x7232,0x744b,0x7def,0x80c3,0x840e,0x8466,
  0x853f,0x875f,0x885b,0x8918,0x8b02,0x9055,0x97cb,0x9b4f,
  0x4e73,0x4f91,0x5112,0x516a,0xf9c7,0x552f,0x55a9,0x5b7a,
  0x5ba5,0x5e7c,0x5e7d,0x5ebe,0x60a0,0x60df,0x6108,0x6109,
  0x63c4,0x6538,0x6709,0xf9c8,0x67d4,0x67da,0xf9c9,0x6961,
  0x6962,0x6cb9,0x6d27,0xf9ca,0x6e38,0xf9cb,
/* 0xeb00 */
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x6fe1,0x7336,0x7337,0xf9cc,0x745c,0x7531,0xf9cd,0x7652,
  0xf9ce,0xf9cf,0x7dad,0x81fe,0x8438,0x88d5,0x8a98,0x8adb,
  0x8aed,0x8e30,0x8e42,0x904a,0x903e,0x907a,0x9149,0x91c9,
  0x936e,0xf9d0,0xf9d1,0x5809,0xf9d2,0x6bd3,0x8089,0x80b2,
  0xf9d3,0xf9d4,0x5141,0x596b,0x5c39,0xf9d5,0xf9d6,0x6f64,
  0x73a7,0x80e4,0x8d07,0xf9d7,0x9217,0x958f,0xf9d8,0xf9d9,
  0xf9da,0xf9db,0x807f,0x620e,0x701c,0x7d68,0x878d,0xf9dc,
  0x57a0,0x6069,0x6147,0x6bb7,0x8abe,0x9280,0x96b1,0x4e59,
  0x541f,0x6deb,0x852d,0x9670,0x97f3,0x98ee,0x63d6,0x6ce3,
  0x9091,0x51dd,0x61c9,0x81ba,0x9df9,0x4f9d,0x501a,0x5100,
  0x5b9c,0x610f,0x61ff,0x64ec,0x6905,0x6bc5,0x7591,0x77e3,
  0x7fa9,0x8264,0x858f,0x87fb,0x8863,0x8abc,
/* 0xec00 */
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x8b70,0x91ab,0x4e8c,0x4ee5,0x4f0a,0xf9dd,0xf9de,0x5937,
  0x59e8,0xf9df,0x5df2,0x5f1b,0x5f5b,0x6021,0xf9e0,0xf9e1,
  0xf9e2,0xf9e3,0x723e,0x73e5,0xf9e4,0x7570,0x75cd,0xf9e5,
  0x79fb,0xf9e6,0x800c,0x8033,0x8084,0x82e1,0x8351,0xf9e7,
  0xf9e8,0x8cbd,0x8cb3,0x9087,0xf9e9,0xf9ea,0x98f4,0x990c,
  0xf9eb,0xf9ec,0x7037,0xfa17,0x7fca,0x7fcc,0x7ffc,0x8b1a,
  0x4eba,0x4ec1,0x5203,0x5370,0xf9ed,0x54bd,0x56e0,0x59fb,
  0x5bc5,0x5f15,0x5fcd,0x6e6e,0xf9ee,0xf9ef,0x7d6a,0x8335,
  0xf9f0,0x8693,0x8a8d,0xf9f1,0x976d,0x9777,0xf9f2,0xf9f3,
  0x4e00,0x4f5a,0x4f7e,0x58f9,0x65e5,0x6ea2,0xfa25,0x93b0,
  0x99b9,0x4efb,0x58ec,0x598a,0x59d9,0x6041,0xf9f4,0xf9f5,
  0x7a14,0xf9f6,0x834f,0x8cc3,0x5165,0x5344,
/* 0xed00 */
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xf9f7,0xf9f8,0xf9f9,0x4ecd,0x5269,0x5b55,0x82bf,0x4ed4,
  0x523a,0x54a8,0x59c9,0x59ff,0x5b50,0x5b57,0x5b5c,0x6063,
  0x6148,0x6ecb,0x7099,0x716e,0x7386,0x74f7,0x75b5,0x78c1,
  0x7d2b,0x8005,0x81ea,0x8328,0x8517,0x85c9,0x8aee,0x8cc7,
  0x96cc,0x4f5c,0x52fa,0x56bc,0x65ab,0x6628,0x707c,0x70b8,
  0x7235,0x7dbd,0x828d,0x914c,0x96c0,0x9d72,0x5b71,0x68e7,
  0x6b98,0x6f7a,0x76de,0x5c91,0x66ab,0x6f5b,0x7bb4,0x7c2a,
  0x8836,0x96dc,0x4e08,0x4ed7,0x5320,0x5834,0x58bb,0x58ef,
  0x596c,0x5c07,0x5e33,0x5e84,0x5f35,0x638c,0x66b2,0x6756,
  0x6a1f,0x6aa3,0x6b0c,0x6f3f,0x7246,0xf9fa,0x7350,0x748b,
  0x7ae0,0x7ca7,0x8178,0x81df,0x81e7,0x838a,0x846c,0x8523,
  0x8594,0x85cf,0x88dd,0x8d13,0x91ac,0x9577,
/* 0xee00 */
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x969c,0x518d,0x54c9,0x5728,0x5bb0,0x624d,0x6750,0x683d,
  0x6893,0x6e3d,0x6ed3,0x707d,0x7e21,0x88c1,0x8ca1,0x8f09,
  0x9f4b,0x9f4e,0x722d,0x7b8f,0x8acd,0x931a,0x4f47,0x4f4e,
  0x5132,0x5480,0x59d0,0x5e95,0x62b5,0x6775,0x696e,0x6a17,
  0x6cae,0x6e1a,0x72d9,0x732a,0x75bd,0x7bb8,0x7d35,0x82e7,
  0x83f9,0x8457,0x85f7,0x8a5b,0x8caf,0x8e87,0x9019,0x90b8,
  0x96ce,0x9f5f,0x52e3,0x540a,0x5ae1,0x5bc2,0x6458,0x6575,
  0x6ef4,0x72c4,0xf9fb,0x7684,0x7a4d,0x7b1b,0x7c4d,0x7e3e,
  0x7fdf,0x837b,0x8b2b,0x8cca,0x8d64,0x8de1,0x8e5f,0x8fea,
  0x8ff9,0x9069,0x93d1,0x4f43,0x4f7a,0x50b3,0x5168,0x5178,
  0x524d,0x526a,0x5861,0x587c,0x5960,0x5c08,0x5c55,0x5edb,
  0x609b,0x6230,0x6813,0x6bbf,0x6c08,0x6fb1,
/* 0xef00 */
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x714e,0x7420,0x7530,0x7538,0x7551,0x7672,0x7b4c,0x7b8b,
  0x7bad,0x7bc6,0x7e8f,0x8a6e,0x8f3e,0x8f49,0x923f,0x9293,
  0x9322,0x942b,0x96fb,0x985a,0x986b,0x991e,0x5207,0x622a,
  0x6298,0x6d59,0x7664,0x7aca,0x7bc0,0x7d76,0x5360,0x5cbe,
  0x5e97,0x6f38,0x70b9,0x7c98,0x9711,0x9b8e,0x9ede,0x63a5,
  0x647a,0x8776,0x4e01,0x4e95,0x4ead,0x505c,0x5075,0x5448,
  0x59c3,0x5b9a,0x5e40,0x5ead,0x5ef7,0x5f81,0x60c5,0x633a,
  0x653f,0x6574,0x65cc,0x6676,0x6678,0x67fe,0x6968,0x6a89,
  0x6b63,0x6c40,0x6dc0,0x6de8,0x6e1f,0x6e5e,0x701e,0x70a1,
  0x738e,0x73fd,0x753a,0x775b,0x7887,0x798e,0x7a0b,0x7a7d,
  0xfa1d,0x7d8e,0x8247,0x8a02,0x8aea,0x8c9e,0x912d,0x914a,
  0x91d8,0x9266,0x92cc,0x9320,0x9706,0xfa1c,
/* 0xf000 */
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x975c,0x9802,0x9f0e,0x5236,0x5291,0x557c,0x5824,0x5e1d,
  0x5f1f,0x608c,0x63d0,0x68af,0x6fdf,0x796d,0x7b2c,0x81cd,
  0x85ba,0x88fd,0xfa22,0x8e44,0x918d,0x9664,0x969b,0x973d,
  0x984c,0x9f4a,0x4fce,0x5146,0x51cb,0x52a9,0x5632,0x5f14,
  0x5f6b,0x63aa,0x64cd,0x65e9,0x6641,0x66fa,0x66f9,0x671d,
  0x689d,0x68d7,0x69fd,0x6f15,0x6f6e,0x7167,0x71e5,0x722a,
  0x74aa,0x773a,0x7956,0x795a,0x79df,0x7a20,0x7a95,0x7c97,
  0x7cdf,0x7d44,0x7e70,0x8087,0x85fb,0x86a4,0x8a54,0x8abf,
  0x8d99,0x8e81,0x9020,0x906d,0x91e3,0x963b,0x96d5,0x9ce5,
  0x65cf,0x7c07,0x8db3,0x93c3,0x5b58,0x5c0a,0x5352,0x62d9,
  0x731d,0x5027,0x5b97,0x5f9e,0x60b0,0x616b,0x68d5,0x6dd9,
  0x742e,0x7a2e,0x7d42,0x7d9c,0x7e31,0x816b,
/* 0xf100 */
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x8e2a,0x8e35,0x937e,0x9418,0x4f50,0x5750,0x5de6,0x5ea7,
  0x632b,0x7f6a,0x4e3b,0x4f4f,0x4f8f,0x505a,0x59dd,0x80c4,
  0x546a,0x5468,0x55fe,0x594f,0x5b99,0x5dde,0x5eda,0x665d,
  0x6731,0x67f1,0x682a,0x6ce8,0x6d32,0x6e4a,0x6f8d,0x70b7,
  0x73e0,0x7587,0x7c4c,0x7d02,0x7d2c,0x7da2,0x821f,0x86db,
  0x8a3b,0x8a85,0x8d70,0x8e8a,0x8f33,0x9031,0x914e,0x9152,
  0x9444,0x99d0,0x7af9,0x7ca5,0x4fca,0x5101,0x51c6,0x57c8,
  0x5bef,0x5cfb,0x6659,0x6a3d,0x6d5a,0x6e96,0x6fec,0x710c,
  0x756f,0x7ae3,0x8822,0x9021,0x9075,0x96cb,0x99ff,0x8301,
  0x4e2d,0x4ef2,0x8846,0x91cd,0x537d,0x6adb,0x696b,0x6c41,
  0x847a,0x589e,0x618e,0x66fe,0x62ef,0x70dd,0x7511,0x75c7,
  0x7e52,0x84b8,0x8b49,0x8d08,0x4e4b,0x53ea,
/* 0xf200 */
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x54ab,0x5730,0x5740,0x5fd7,0x6301,0x6307,0x646f,0x652f,
  0x65e8,0x667a,0x679d,0x67b3,0x6b62,0x6c60,0x6c9a,0x6f2c,
  0x77e5,0x7825,0x7949,0x7957,0x7d19,0x80a2,0x8102,0x81f3,
  0x829d,0x82b7,0x8718,0x8a8c,0xf9fc,0x8d04,0x8dbe,0x9072,
  0x76f4,0x7a19,0x7a37,0x7e54,0x8077,0x5507,0x55d4,0x5875,
  0x632f,0x6422,0x6649,0x664b,0x686d,0x699b,0x6b84,0x6d25,
  0x6eb1,0x73cd,0x7468,0x74a1,0x755b,0x75b9,0x76e1,0x771e,
  0x778b,0x79e6,0x7e09,0x7e1d,0x81fb,0x852f,0x8897,0x8a3a,
  0x8cd1,0x8eeb,0x8fb0,0x9032,0x93ad,0x9663,0x9673,0x9707,
  0x4f84,0x53f1,0x59ea,0x5ac9,0x5e19,0x684e,0x74c6,0x75be,
  0x79e9,0x7a92,0x81a3,0x86ed,0x8cea,0x8dcc,0x8fed,0x659f,
  0x6715,0xf9fd,0x57f7,0x6f57,0x7ddd,0x8f2f,
/* 0xf300 */
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x93f6,0x96c6,0x5fb5,0x61f2,0x6f84,0x4e14,0x4f98,0x501f,
  0x53c9,0x55df,0x5d6f,0x5dee,0x6b21,0x6b64,0x78cb,0x7b9a,
  0xf9fe,0x8e49,0x8eca,0x906e,0x6349,0x643e,0x7740,0x7a84,
  0x932f,0x947f,0x9f6a,0x64b0,0x6faf,0x71e6,0x74a8,0x74da,
  0x7ac4,0x7c12,0x7e82,0x7cb2,0x7e98,0x8b9a,0x8d0a,0x947d,
  0x9910,0x994c,0x5239,0x5bdf,0x64e6,0x672d,0x7d2e,0x50ed,
  0x53c3,0x5879,0x6158,0x6159,0x61fa,0x65ac,0x7ad9,0x8b92,
  0x8b96,0x5009,0x5021,0x5275,0x5531,0x5a3c,0x5ee0,0x5f70,
  0x6134,0x655e,0x660c,0x6636,0x66a2,0x69cd,0x6ec4,0x6f32,
  0x7316,0x7621,0x7a93,0x8139,0x8259,0x83d6,0x84bc,0x50b5,
  0x57f0,0x5bc0,0x5be8,0x5f69,0x63a1,0x7826,0x7db5,0x83dc,
  0x8521,0x91c7,0x91f5,0x518a,0x67f5,0x7b56,
/* 0xf400 */
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x8cac,0x51c4,0x59bb,0x60bd,0x8655,0x501c,0xf9ff,0x5254,
  0x5c3a,0x617d,0x621a,0x62d3,0x64f2,0x65a5,0x6ecc,0x7620,
  0x810a,0x8e60,0x965f,0x96bb,0x4edf,0x5343,0x5598,0x5929,
  0x5ddd,0x64c5,0x6cc9,0x6dfa,0x7394,0x7a7f,0x821b,0x85a6,
  0x8ce4,0x8e10,0x9077,0x91e7,0x95e1,0x9621,0x97c6,0x51f8,
  0x54f2,0x5586,0x5fb9,0x64a4,0x6f88,0x7db4,0x8f1f,0x8f4d,
  0x9435,0x50c9,0x5c16,0x6cbe,0x6dfb,0x751b,0x77bb,0x7c3d,
  0x7c64,0x8a79,0x8ac2,0x581e,0x59be,0x5e16,0x6377,0x7252,
  0x758a,0x776b,0x8adc,0x8cbc,0x8f12,0x5ef3,0xfa12,0x6df8,
  0x807d,0x83c1,0x8acb,0x9751,0x9bd6,0xfa00,0x5243,0x66ff,
  0x6d95,0x6eef,0x7de0,0x8ae6,0x902e,0x905e,0x9ad4,0x521d,
  0x527f,0x54e8,0x6194,0x6284,0x62db,0x68a2,
/* 0xf500 */
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x6912,0x695a,0x6a35,0x7092,0x7126,0x785d,0x7901,0x790e,
  0x79d2,0x7a0d,0x8096,0x8278,0x82d5,0x8349,0x8549,0x8c82,
  0x8d85,0x9162,0x918b,0x91ae,0x4fc3,0x56d1,0x71ed,0x77d7,
  0x8700,0x89f8,0x5bf8,0x5fd6,0x6751,0x90a8,0x53e2,0xfa10,
  0x5bf5,0x60a4,0x6181,0x6460,0x7e3d,0x8070,0x8525,0x9283,
  0x64ae,0x50ac,0x5d14,0x6700,0x589c,0x62bd,0x63a8,0x690e,
  0x6978,0x6a1e,0x6e6b,0x76ba,0x79cb,0x82bb,0x8429,0x8acf,
  0x8da8,0x8ffd,0x9112,0x914b,0x919c,0x9310,0x9318,0x939a,
  0x96db,0x9a36,0x9c0d,0x4e11,0x755c,0x795d,0x7afa,0x7b51,
  0x7bc9,0x7e2e,0x84c4,0x8e59,0x8e74,0x8ef8,0x9010,0x6625,
  0x693f,0x7443,0x51fa,0x672e,0x9edc,0x5145,0x5fe0,0x6c96,
  0x87f2,0x885d,0x8877,0x60b4,0x81b5,0x8403,
/* 0xf600 */
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x8d05,0x53d6,0x5439,0x5634,0x5a36,0x5c31,0x708a,0x7fe0,
  0x805a,0x8106,0x81ed,0x8da3,0x9189,0x9a5f,0x9df2,0x5074,
  0x4ec4,0x53a0,0x60fb,0x6e2c,0x5c64,0x4f88,0x5024,0x55e4,
  0x5cd9,0x5e5f,0x6065,0x6894,0x6cbb,0x6dc4,0x71be,0x75d4,
  0x75f4,0x7661,0x7a1a,0x7a49,0x7dc7,0x7dfb,0x7f6e,0x81f4,
  0x86a9,0x8f1c,0x96c9,0x99b3,0x9f52,0x5247,0x52c5,0x98ed,
  0x89aa,0x4e03,0x67d2,0x6f06,0x4fb5,0x5be2,0x6795,0x6c88,
  0x6d78,0x741b,0x7827,0x91dd,0x937c,0x87c4,0x79e4,0x7a31,
  0x5feb,0x4ed6,0x54a4,0x553e,0x58ae,0x59a5,0x60f0,0x6253,
  0x62d6,0x6736,0x6955,0x8235,0x9640,0x99b1,0x99dd,0x502c,
  0x5353,0x5544,0x577c,0xfa01,0x6258,0xfa02,0x64e2,0x666b,
  0x67dd,0x6fc1,0x6fef,0x7422,0x7438,0x8a17,
/* 0xf700 */
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x9438,0x5451,0x5606,0x5766,0x5f48,0x619a,0x6b4e,0x7058,
  0x70ad,0x7dbb,0x8a95,0x596a,0x812b,0x63a2,0x7708,0x803d,
  0x8caa,0x5854,0x642d,0x69bb,0x5b95,0x5e11,0x6e6f,0xfa03,
  0x8569,0x514c,0x53f0,0x592a,0x6020,0x614b,0x6b86,0x6c70,
  0x6cf0,0x7b1e,0x80ce,0x82d4,0x8dc6,0x90b0,0x98b1,0xfa04,
  0x64c7,0x6fa4,0x6491,0x6504,0x514e,0x5410,0x571f,0x8a0e,
  0x615f,0x6876,0xfa05,0x75db,0x7b52,0x7d71,0x901a,0x5806,
  0x69cc,0x817f,0x892a,0x9000,0x9839,0x5078,0x5957,0x59ac,
  0x6295,0x900f,0x9b2a,0x615d,0x7279,0x95d6,0x5761,0x5a46,
  0x5df4,0x628a,0x64ad,0x64fa,0x6777,0x6ce2,0x6d3e,0x722c,
  0x7436,0x7834,0x7f77,0x82ad,0x8ddb,0x9817,0x5224,0x5742,
  0x677f,0x7248,0x74e3,0x8ca9,0x8fa6,0x9211,
/* 0xf800 */
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x962a,0x516b,0x53ed,0x634c,0x4f69,0x5504,0x6096,0x6557,
  0x6c9b,0x6d7f,0x724c,0x72fd,0x7a17,0x8987,0x8c9d,0x5f6d,
  0x6f8e,0x70f9,0x81a8,0x610e,0x4fbf,0x504f,0x6241,0x7247,
  0x7bc7,0x7de8,0x7fe9,0x904d,0x97ad,0x9a19,0x8cb6,0x576a,
  0x5e73,0x67b0,0x840d,0x8a55,0x5420,0x5b16,0x5e63,0x5ee2,
  0x5f0a,0x6583,0x80ba,0x853d,0x9589,0x965b,0x4f48,0x5305,
  0x530d,0x530f,0x5486,0x54fa,0x5703,0x5e03,0x6016,0x629b,
  0x62b1,0x6355,0xfa06,0x6ce1,0x6d66,0x75b1,0x7832,0x80de,
  0x812f,0x82de,0x8461,0x84b2,0x888d,0x8912,0x900b,0x92ea,
  0x98fd,0x9b91,0x5e45,0x66b4,0x66dd,0x7011,0x7206,0xfa07,
  0x4ff5,0x527d,0x5f6a,0x6153,0x6753,0x6a19,0x6f02,0x74e2,
  0x7968,0x8868,0x8c79,0x98c7,0x98c4,0x9a43,
/* 0xf900 */
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x54c1,0x7a1f,0x6953,0x8af7,0x8c4a,0x98a8,0x99ae,0x5f7c,
  0x62ab,0x75b2,0x76ae,0x88ab,0x907f,0x9642,0x5339,0x5f3c,
  0x5fc5,0x6ccc,0x73cc,0x7562,0x758b,0x7b46,0x82fe,0x999d,
  0x4e4f,0x903c,0x4e0b,0x4f55,0x53a6,0x590f,0x5ec8,0x6630,
  0x6cb3,0x7455,0x8377,0x8766,0x8cc0,0x9050,0x971e,0x9c15,
  0x58d1,0x5b78,0x8650,0x8b14,0xfa2d,0x5bd2,0x6068,0x608d,
  0x65f1,0x6c57,0x6f22,0x6fa3,0x701a,0x7f55,0x7ff0,0x9591,
  0x9592,0x9650,0x97d3,0x5272,0x8f44,0x51fd,0x542b,0x54b8,
  0x5563,0x558a,0x6abb,0x6db5,0x7dd8,0x8266,0x929c,0x9677,
  0x9e79,0x5408,0x54c8,0x76d2,0x86e4,0x95a4,0x95d4,0x965c,
  0x4ea2,0x4f09,0x59ee,0x5ae6,0x5df7,0x6052,0x6297,0x676d,
  0x6841,0x6c86,0x6e2f,0x7f38,0x809b,0x822a,
/* 0xfa00 */
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xfa08,0xfa09,0x9805,0x4ea5,0x5055,0x54b3,0x5793,0x595a,
  0x5b69,0x5bb3,0x61c8,0x6977,0x6d77,0x7023,0x87f9,0x89e3,
  0x8a72,0x8ae7,0x9082,0x99ed,0x9ab8,0x52be,0x6838,0x5016,
  0x5e78,0x674f,0x8347,0x884c,0x4eab,0x5411,0x56ae,0x73e6,
  0x9115,0x97ff,0x9909,0x9957,0x9999,0x5653,0x589f,0x865b,
  0x8a31,0x61b2,0x6af6,0x737b,0x8ed2,0x6b47,0x96aa,0x9a57,
  0x5955,0x7200,0x8d6b,0x9769,0x4fd4,0x5cf4,0x5f26,0x61f8,
  0x665b,0x6ceb,0x70ab,0x7384,0x73b9,0x73fe,0x7729,0x774d,
  0x7d43,0x7d62,0x7e23,0x8237,0x8852,0xfa0a,0x8ce2,0x9249,
  0x986f,0x5b51,0x7a74,0x8840,0x9801,0x5acc,0x4fe0,0x5354,
  0x593e,0x5cfd,0x633e,0x6d79,0x72f9,0x8105,0x8107,0x83a2,
  0x92cf,0x9830,0x4ea8,0x5144,0x5211,0x578b,
/* 0xfb00 */
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x5f62,0x6cc2,0x6ece,0x7005,0x7050,0x70af,0x7192,0x73e9,
  0x7469,0x834a,0x87a2,0x8861,0x9008,0x90a2,0x93a3,0x99a8,
  0x516e,0x5f57,0x60e0,0x6167,0x66b3,0x8559,0x8e4a,0x91af,
  0x978b,0x4e4e,0x4e92,0x547c,0x58d5,0x58fa,0x597d,0x5cb5,
  0x5f27,0x6236,0x6248,0x660a,0x6667,0x6beb,0x6d69,0x6dcf,
  0x6e56,0x6ef8,0x6f94,0x6fe0,0x6fe9,0x705d,0x72d0,0x7425,
  0x745a,0x74e0,0x7693,0x795c,0x7cca,0x7e1e,0x80e1,0x82a6,
  0x846b,0x84bf,0x864e,0x865f,0x8774,0x8b77,0x8c6a,0x93ac,
  0x9800,0x9865,0x60d1,0x6216,0x9177,0x5a5a,0x660f,0x6df7,
  0x6e3e,0x743f,0x9b42,0x5ffd,0x60da,0x7b0f,0x54c4,0x5f18,
  0x6c5e,0x6cd3,0x6d2a,0x70d8,0x7d05,0x8679,0x8a0c,0x9d3b,
  0x5316,0x548c,0x5b05,0x6a3a,0x706b,0x7575,
/* 0xfc00 */
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x798d,0x79be,0x82b1,0x83ef,0x8a71,0x8b41,0x8ca8,0x9774,
  0xfa0b,0x64f4,0x652b,0x78ba,0x78bb,0x7a6b,0x4e38,0x559a,
  0x5950,0x5ba6,0x5e7b,0x60a3,0x63db,0x6b61,0x6665,0x6853,
  0x6e19,0x7165,0x74b0,0x7d08,0x9084,0x9a69,0x9c25,0x6d3b,
  0x6ed1,0x733e,0x8c41,0x95ca,0x51f0,0x5e4c,0x5fa8,0x604d,
  0x60f6,0x6130,0x614c,0x6643,0x6644,0x69a5,0x6cc1,0x6e5f,
  0x6ec9,0x6f62,0x714c,0x749c,0x7687,0x7bc1,0x7c27,0x8352,
  0x8757,0x9051,0x968d,0x9ec3,0x532f,0x56de,0x5efb,0x5f8a,
  0x6062,0x6094,0x61f7,0x6666,0x6703,0x6a9c,0x6dee,0x6fae,
  0x7070,0x736a,0x7e6a,0x81be,0x8334,0x86d4,0x8aa8,0x8cc4,
  0x5283,0x7372,0x5b96,0x6a6b,0x9404,0x54ee,0x5686,0x5b5d,
  0x6548,0x6585,0x66c9,0x689f,0x6d8d,0x6dc6,
/* 0xfd00 */
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x723b,0x80b4,0x9175,0x9a4d,0x4faf,0x5019,0x539a,0x540e,
  0x543c,0x5589,0x55c5,0x5e3f,0x5f8c,0x673d,0x7166,0x73dd,
  0x9005,0x52db,0x52f3,0x5864,0x58ce,0x7104,0x718f,0x71fb,
  0x85b0,0x8a13,0x6688,0x85a8,0x55a7,0x6684,0x714a,0x8431,
  0x5349,0x5599,0x6bc1,0x5f59,0x5fbd,0x63ee,0x6689,0x7147,
  0x8af1,0x8f1d,0x9ebe,0x4f11,0x643a,0x70cb,0x7566,0x8667,
  0x6064,0x8b4e,0x9df8,0x5147,0x51f6,0x5308,0x6d36,0x80f8,
  0x9ed1,0x6615,0x6b23,0x7098,0x75d5,0x5403,0x5c79,0x7d07,
  0x8a16,0x6b20,0x6b3d,0x6b46,0x5438,0x6070,0x6d3d,0x7fd5,
  0x8208,0x50d6,0xfa15,0x559c,0x566b,0x56cd,0x59ec,0x5b09,
  0x5e0c,0x6199,0x6198,0x6231,0x665e,0x66e6,0x7199,0x71b9,
  0x71ba,0x72a7,0x79a7,0x7a00,0x7fb2,0x8a70,
/* 0xfe00 */
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0xe05e,0xe05f,0xe060,0xe061,0xe062,0xe063,0xe064,0xe065,
  0xe066,0xe067,0xe068,0xe069,0xe06a,0xe06b,0xe06c,0xe06d,
  0xe06e,0xe06f,0xe070,0xe071,0xe072,0xe073,0xe074,0xe075,
  0xe076,0xe077,0xe078,0xe079,0xe07a,0xe07b,0xe07c,0xe07d,
  0xe07e,0xe07f,0xe080,0xe081,0xe082,0xe083,0xe084,0xe085,
  0xe086,0xe087,0xe088,0xe089,0xe08a,0xe08b,0xe08c,0xe08d,
  0xe08e,0xe08f,0xe090,0xe091,0xe092,0xe093,0xe094,0xe095,
  0xe096,0xe097,0xe098,0xe099,0xe09a,0xe09b,0xe09c,0xe09d,
  0xe09e,0xe09f,0xe0a0,0xe0a1,0xe0a2,0xe0a3,0xe0a4,0xe0a5,
  0xe0a6,0xe0a7,0xe0a8,0xe0a9,0xe0aa,0xe0ab,0xe0ac,0xe0ad,
  0xe0ae,0xe0af,0xe0b0,0xe0b1,0xe0b2,0xe0b3,0xe0b4,0xe0b5,
  0xe0b6,0xe0b7,0xe0b8,0xe0b9,0xe0ba,0xe0bb
};

unsigned short gb12345_uni_byte[GB12345_TBL_LEN] = {
  0x3000,0x3001,0x3002,0x30fb, 0x02c9,0x02c7,0x00a8,0x3003,
  0x3005,0x2015,0xff5e,0x2225, 0x2026,0x2018,0x2019,0x201c,
  0x201d,0x3014,0x3015,0x3008, 0x3009,0x300a,0x300b,0x300c,
  0x300d,0x300e,0x300f,0x3016, 0x3017,0x3010,0x3011,0x00b1,
  0x00d7,0x00f7,0x2236,0x2227, 0x2228,0x2211,0x220f,0x222a,
  0x2229,0x2208,0x2237,0x221a, 0x22a5,0x2225,0x2220,0x2312,
  0x2299,0x222b,0x222e,0x2261, 0x224c,0x2248,0x223d,0x221d,
  0x2260,0x226e,0x226f,0x2264, 0x2265,0x221e,0x2235,0x2234,
  0x2642,0x2640,0x00b0,0x2032, 0x2033,0x2103,0xff04,0x00a4,
  0xffe0,0xffe1,0x2030,0x00a7, 0x2116,0x2606,0x2605,0x25cb,
  0x25cf,0x25ce,0x25c7,0x25c6, 0x25a1,0x25a0,0x25b3,0x25b2,
  0x203b,0x2192,0x2190,0x2191, 0x2193,0x3013,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x2488,0x2489,
  0x248a,0x248b,0x248c,0x248d, 0x248e,0x248f,0x2490,0x2491,
  0x2492,0x2493,0x2494,0x2495, 0x2496,0x2497,0x2498,0x2499,
  0x249a,0x249b,0x2474,0x2475, 0x2476,0x2477,0x2478,0x2479,
  0x247a,0x247b,0x247c,0x247d, 0x247e,0x247f,0x2480,0x2481,
  0x2482,0x2483,0x2484,0x2485, 0x2486,0x2487,0x2460,0x2461,
  0x2462,0x2463,0x2464,0x2465, 0x2466,0x2467,0x2468,0x2469,
  0x0000,0x0000,0x3220,0x3221, 0x3222,0x3223,0x3224,0x3225,
  0x3226,0x3227,0x3228,0x3229, 0x0000,0x0000,0x2160,0x2161,
  0x2162,0x2163,0x2164,0x2165, 0x2166,0x2167,0x2168,0x2169,
  0x216a,0x216b,0x0000,0x0000, 0xff01,0xff02,0xff03,0xffe5,
  0xff05,0xff06,0xff07,0xff08, 0xff09,0xff0a,0xff0b,0xff0c,
  0xff0d,0xff0e,0xff0f,0xff10, 0xff11,0xff12,0xff13,0xff14,
  0xff15,0xff16,0xff17,0xff18, 0xff19,0xff1a,0xff1b,0xff1c,
  0xff1d,0xff1e,0xff1f,0xff20, 0xff21,0xff22,0xff23,0xff24,
  0xff25,0xff26,0xff27,0xff28, 0xff29,0xff2a,0xff2b,0xff2c,
  0xff2d,0xff2e,0xff2f,0xff30, 0xff31,0xff32,0xff33,0xff34,
  0xff35,0xff36,0xff37,0xff38, 0xff39,0xff3a,0xff3b,0xff3c,
  0xff3d,0xff3e,0xff3f,0xff40, 0xff41,0xff42,0xff43,0xff44,
  0xff45,0xff46,0xff47,0xff48, 0xff49,0xff4a,0xff4b,0xff4c,
  0xff4d,0xff4e,0xff4f,0xff50, 0xff51,0xff52,0xff53,0xff54,
  0xff55,0xff56,0xff57,0xff58, 0xff59,0xff5a,0xff5b,0xff5c,
  0xff5d,0xffe3,0x3041,0x3042, 0x3043,0x3044,0x3045,0x3046,
  0x3047,0x3048,0x3049,0x304a, 0x304b,0x304c,0x304d,0x304e,
  0x304f,0x3050,0x3051,0x3052, 0x3053,0x3054,0x3055,0x3056,
  0x3057,0x3058,0x3059,0x305a, 0x305b,0x305c,0x305d,0x305e,
  0x305f,0x3060,0x3061,0x3062, 0x3063,0x3064,0x3065,0x3066,
  0x3067,0x3068,0x3069,0x306a, 0x306b,0x306c,0x306d,0x306e,
  0x306f,0x3070,0x3071,0x3072, 0x3073,0x3074,0x3075,0x3076,
  0x3077,0x3078,0x3079,0x307a, 0x307b,0x307c,0x307d,0x307e,
  0x307f,0x3080,0x3081,0x3082, 0x3083,0x3084,0x3085,0x3086,
  0x3087,0x3088,0x3089,0x308a, 0x308b,0x308c,0x308d,0x308e,
  0x308f,0x3090,0x3091,0x3092, 0x3093,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x30a1,0x30a2,0x30a3,0x30a4, 0x30a5,0x30a6,0x30a7,0x30a8,
  0x30a9,0x30aa,0x30ab,0x30ac, 0x30ad,0x30ae,0x30af,0x30b0,
  0x30b1,0x30b2,0x30b3,0x30b4, 0x30b5,0x30b6,0x30b7,0x30b8,
  0x30b9,0x30ba,0x30bb,0x30bc, 0x30bd,0x30be,0x30bf,0x30c0,
  0x30c1,0x30c2,0x30c3,0x30c4, 0x30c5,0x30c6,0x30c7,0x30c8,
  0x30c9,0x30ca,0x30cb,0x30cc, 0x30cd,0x30ce,0x30cf,0x30d0,
  0x30d1,0x30d2,0x30d3,0x30d4, 0x30d5,0x30d6,0x30d7,0x30d8,
  0x30d9,0x30da,0x30db,0x30dc, 0x30dd,0x30de,0x30df,0x30e0,
  0x30e1,0x30e2,0x30e3,0x30e4, 0x30e5,0x30e6,0x30e7,0x30e8,
  0x30e9,0x30ea,0x30eb,0x30ec, 0x30ed,0x30ee,0x30ef,0x30f0,
  0x30f1,0x30f2,0x30f3,0x30f4, 0x30f5,0x30f6,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0391,0x0392,
  0x0393,0x0394,0x0395,0x0396, 0x0397,0x0398,0x0399,0x039a,
  0x039b,0x039c,0x039d,0x039e, 0x039f,0x03a0,0x03a1,0x03a3,
  0x03a4,0x03a5,0x03a6,0x03a7, 0x03a8,0x03a9,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x03b1,0x03b2,
  0x03b3,0x03b4,0x03b5,0x03b6, 0x03b7,0x03b8,0x03b9,0x03ba,
  0x03bb,0x03bc,0x03bd,0x03be, 0x03bf,0x03c0,0x03c1,0x03c3,
  0x03c4,0x03c5,0x03c6,0x03c7, 0x03c8,0x03c9,0xe87d,0xe87e,
  0xe87f,0xfe30,0xe791,0xe792, 0xe793,0xfe35,0xfe36,0xfe39,
  0xfe3a,0xfe3f,0xfe40,0xfe3d, 0xfe3e,0xfe41,0xfe42,0xfe43,
  0xfe44,0xe794,0xe795,0xfe3b, 0xfe3c,0xfe37,0xfe38,0xfe31,
  0xe796,0xfe33,0xfe34,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0410,0x0411,0x0412,0x0413,
  0x0414,0x0415,0x0401,0x0416, 0x0417,0x0418,0x0419,0x041a,
  0x041b,0x041c,0x041d,0x041e, 0x041f,0x0420,0x0421,0x0422,
  0x0423,0x0424,0x0425,0x0426, 0x0427,0x0428,0x0429,0x042a,
  0x042b,0x042c,0x042d,0x042e, 0x042f,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0430,0x0431,0x0432,0x0433,
  0x0434,0x0435,0x0451,0x0436, 0x0437,0x0438,0x0439,0x043a,
  0x043b,0x043c,0x043d,0x043e, 0x043f,0x0440,0x0441,0x0442,
  0x0443,0x0444,0x0445,0x0446, 0x0447,0x0448,0x0449,0x044a,
  0x044b,0x044c,0x044d,0x044e, 0x044f,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0101,0x00e1, 0x01ce,0x00e0,0x0113,0x00e9,
  0x011b,0x00e8,0x012b,0x00ed, 0x01d0,0x00ec,0x014d,0x00f3,
  0x01d2,0x00f2,0x016b,0x00fa, 0x01d4,0x00f9,0x01d6,0x01d8,
  0x01da,0x01dc,0x00fc,0x00ea, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x3105,0x3106,
  0x3107,0x3108,0x3109,0x310a, 0x310b,0x310c,0x310d,0x310e,
  0x310f,0x3110,0x3111,0x3112, 0x3113,0x3114,0x3115,0x3116,
  0x3117,0x3118,0x3119,0x311a, 0x311b,0x311c,0x311d,0x311e,
  0x311f,0x3120,0x3121,0x3122, 0x3123,0x3124,0x3125,0x3126,
  0x3127,0x3128,0x3129,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x2500, 0x2501,0x2502,0x2503,0x2504,
  0x2505,0x2506,0x2507,0x2508, 0x2509,0x250a,0x250b,0x250c,
  0x250d,0x250e,0x250f,0x2510, 0x2511,0x2512,0x2513,0x2514,
  0x2515,0x2516,0x2517,0x2518, 0x2519,0x251a,0x251b,0x251c,
  0x251d,0x251e,0x251f,0x2520, 0x2521,0x2522,0x2523,0x2524,
  0x2525,0x2526,0x2527,0x2528, 0x2529,0x252a,0x252b,0x252c,
  0x252d,0x252e,0x252f,0x2530, 0x2531,0x2532,0x2533,0x2534,
  0x2535,0x2536,0x2537,0x2538, 0x2539,0x253a,0x253b,0x253c,
  0x253d,0x253e,0x253f,0x2540, 0x2541,0x2542,0x2543,0x2544,
  0x2545,0x2546,0x2547,0x2548, 0x2549,0x254a,0x254b,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,
  0x0000,0x0021,0x0022,0x0023, 0x0024,0x0025,0x0026,0x0027,
  0x0028,0x0029,0x002a,0x002b, 0x002c,0x002d,0x002e,0x002f,
  0x0030,0x0031,0x0032,0x0033, 0x0034,0x0035,0x0036,0x0037,
  0x0038,0x0039,0x003a,0x003b, 0x003c,0x003d,0x003e,0x003f,
  0x0040,0x0041,0x0042,0x0043, 0x0044,0x0045,0x0046,0x0047,
  0x0048,0x0049,0x004a,0x004b, 0x004c,0x004d,0x004e,0x004f,
  0x0050,0x0051,0x0052,0x0053, 0x0054,0x0055,0x0056,0x0057,
  0x0058,0x0059,0x005a,0x005b, 0x005c,0x005d,0x005e,0x005f,
  0x0060,0x0061,0x0062,0x0063, 0x0064,0x0065,0x0066,0x0067,
  0x0068,0x0069,0x006a,0x006b, 0x006c,0x006d,0x006e,0x006f,
  0x0070,0x0071,0x0072,0x0073, 0x0074,0x0075,0x0076,0x0077,
  0x0078,0x0079,0x007a,0x007b, 0x007c,0x007d,0x007e,
  0x0101,0x00e1,0x01ce,0x00e0, 0x0113,0x00e9,0x011b,0x00e8,
  0x012b,0x00ed,0x01d0,0x00ec, 0x014d,0x00f3,0x01d2,0x00f2,
  0x016b,0x00fa,0x01d4,0x00f9, 0x01d6,0x01d8,0x01da,0x01dc,
  0x00fc,0x00ea,0x0251,0x1e3f, 0x0144,0x0148,0x01f9,0x0261,
  0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x554a,0x963f, 0x57c3,0x6328,0x54ce,0x5509,
  0x54c0,0x769a,0x764c,0x85f9, 0x77ee,0x827e,0x7919,0x611b,
  0x9698,0x978d,0x6c28,0x5b89, 0x4ffa,0x6309,0x6697,0x5cb8,
  0x80fa,0x6848,0x9aaf,0x6602, 0x76ce,0x51f9,0x6556,0x71ac,
  0x7ff1,0x8956,0x50b2,0x5965, 0x61ca,0x6fb3,0x82ad,0x634c,
  0x6252,0x53ed,0x5427,0x7b06, 0x516b,0x75a4,0x5df4,0x62d4,
  0x8dcb,0x9776,0x628a,0x8019, 0x58e9,0x9738,0x7f77,0x7238,
  0x767d,0x67cf,0x767e,0x64fa, 0x4f70,0x6557,0x62dc,0x7a17,
  0x6591,0x73ed,0x642c,0x6273, 0x822c,0x9812,0x677f,0x7248,
  0x626e,0x62cc,0x4f34,0x74e3, 0x534a,0x8fa6,0x7d46,0x90a6,
  0x5e6b,0x6886,0x699c,0x8180, 0x7d81,0x68d2,0x78c5,0x868c,
  0x938a,0x508d,0x8b17,0x82de, 0x80de,0x5305,0x8912,0x5265,
  0x8584,0x96f9,0x4fdd,0x5821, 0x98fd,0x5bf6,0x62b1,0x5831,
  0x66b4,0x8c79,0x9b91,0x7206, 0x676f,0x7891,0x60b2,0x5351,
  0x5317,0x8f29,0x80cc,0x8c9d, 0x92c7,0x500d,0x72fd,0x5099,
  0x618a,0x7119,0x88ab,0x5954, 0x82ef,0x672c,0x7b28,0x5d29,
  0x7db3,0x752d,0x6cf5,0x8e66, 0x8ff8,0x903c,0x9f3b,0x6bd4,
  0x9119,0x7b46,0x5f7c,0x78a7, 0x84d6,0x853d,0x7562,0x6583,
  0x6bd6,0x5e63,0x5e87,0x75f9, 0x9589,0x655d,0x5f0a,0x5fc5,
  0x8f9f,0x58c1,0x81c2,0x907f, 0x965b,0x97ad,0x908a,0x7de8,
  0x8cb6,0x6241,0x4fbf,0x8b8a, 0x535e,0x8fa8,0x8faf,0x8fae,
  0x904d,0x6a19,0x5f6a,0x8198, 0x8868,0x9c49,0x618b,0x522b,
  0x765f,0x5f6c,0x658c,0x7015, 0x6ff1,0x8cd3,0x64ef,0x5175,
  0x51b0,0x67c4,0x4e19,0x79c9, 0x9905,0x70b3,0x75c5,0x5e76,
  0x73bb,0x83e0,0x64ad,0x64a5, 0x9262,0x6ce2,0x535a,0x52c3,
  0x640f,0x9251,0x7b94,0x4f2f, 0x5e1b,0x8236,0x8116,0x818a,
  0x6e24,0x6cca,0x99c1,0x6355, 0x535c,0x54fa,0x88dc,0x57e0,
  0x4e0d,0x5e03,0x6b65,0x7c3f, 0x90e8,0x6016,0x64e6,0x731c,
  0x88c1,0x6750,0x624d,0x8ca1, 0x776c,0x8e29,0x91c7,0x5f69,
  0x83dc,0x8521,0x9910,0x53c3, 0x8836,0x6b98,0x615a,0x6158,
  0x71e6,0x84bc,0x8259,0x5009, 0x6ec4,0x85cf,0x64cd,0x7cd9,
  0x69fd,0x66f9,0x8349,0x53a0, 0x7b56,0x5074,0x518c,0x6e2c,
  0x5c64,0x8e6d,0x63d2,0x53c9, 0x832c,0x8336,0x67e5,0x78b4,
  0x643d,0x5bdf,0x5c94,0x5dee, 0x8a6b,0x62c6,0x67f4,0x8c7a,
  0x6519,0x647b,0x87ec,0x995e, 0x8b92,0x7e8f,0x93df,0x7523,
  0x95e1,0x986b,0x660c,0x7316, 0x5834,0x5617,0x5e38,0x9577,
  0x511f,0x8178,0x5ee0,0x655e, 0x66a2,0x5531,0x5021,0x8d85,
  0x6284,0x9214,0x671d,0x5632, 0x6f6e,0x5de2,0x5435,0x7092,
  0x8eca,0x626f,0x64a4,0x63a3, 0x5fb9,0x6f88,0x90f4,0x81e3,
  0x8fb0,0x5875,0x6668,0x5ff1, 0x6c89,0x9673,0x8d81,0x896f,
  0x6491,0x7a31,0x57ce,0x6a59, 0x6210,0x5448,0x4e58,0x7a0b,
  0x61f2,0x6f84,0x8aa0,0x627f, 0x901e,0x9a01,0x79e4,0x5403,
  0x75f4,0x6301,0x5319,0x6c60, 0x9072,0x5f1b,0x99b3,0x803b,
  0x9f52,0x4f88,0x5c3a,0x8d64, 0x7fc5,0x65a5,0x71be,0x5145,
  0x885d,0x87f2,0x5d07,0x5bf5, 0x62bd,0x916c,0x7587,0x8e8a,
  0x7a20,0x6101,0x7c4c,0x4ec7, 0x7da2,0x7785,0x919c,0x81ed,
  0x521d,0x51fa,0x6a71,0x53a8, 0x8e87,0x92e4,0x96db,0x6ec1,
  0x9664,0x695a,0x790e,0x5132, 0x77d7,0x6410,0x89f8,0x8655,
  0x63e3,0x5ddd,0x7a7f,0x693d, 0x50b3,0x8239,0x5598,0x4e32,
  0x7621,0x7a97,0x5e62,0x5e8a, 0x95d6,0x5275,0x5439,0x708a,
  0x6376,0x9318,0x5782,0x6625, 0x693f,0x9187,0x5507,0x6df3,
  0x7d14,0x8822,0x6233,0x7dbd, 0x75b5,0x8328,0x78c1,0x96cc,
  0x8fad,0x6148,0x74f7,0x8a5e, 0x6b64,0x523a,0x8cdc,0x6b21,
  0x8070,0x8471,0x56f1,0x5306, 0x5f9e,0x53e2,0x51d1,0x7c97,
  0x918b,0x7c07,0x4fc3,0x8ea5, 0x7be1,0x7ac4,0x6467,0x5d14,
  0x50ac,0x8106,0x7601,0x7cb9, 0x6dec,0x7fe0,0x6751,0x5b58,
  0x5bf8,0x78cb,0x64ae,0x6413, 0x63aa,0x632b,0x932f,0x642d,
  0x9054,0x7b54,0x7629,0x6253, 0x5927,0x5446,0x6b79,0x50a3,
  0x6234,0x5e36,0x6b86,0x4ee3, 0x8cb8,0x888b,0x5f85,0x902e,
  0x6020,0x803d,0x64d4,0x4e39, 0x55ae,0x9132,0x64a3,0x81bd,
  0x65e6,0x6c2e,0x4f46,0x619a, 0x6de1,0x8a95,0x5f48,0x86cb,
  0x7576,0x64cb,0x9ee8,0x8569, 0x6a94,0x5200,0x6417,0x8e48,
  0x5012,0x5cf6,0x79b1,0x5c0e, 0x5230,0x7a3b,0x60bc,0x9053,
  0x76d7,0x5fb7,0x5f97,0x7684, 0x8e6c,0x71c8,0x767b,0x7b49,
  0x77aa,0x51f3,0x9127,0x5824, 0x4f4e,0x6ef4,0x8fea,0x6575,
  0x7b1b,0x72c4,0x6ecc,0x7fdf, 0x5ae1,0x62b5,0x5e95,0x5730,
  0x8482,0x7b2c,0x5e1d,0x5f1f, 0x905e,0x7de0,0x985b,0x6382,
  0x6ec7,0x7898,0x9ede,0x5178, 0x975b,0x588a,0x96fb,0x4f43,
  0x7538,0x5e97,0x60e6,0x5960, 0x6fb1,0x6bbf,0x7889,0x53fc,
  0x96d5,0x51cb,0x5201,0x6389, 0x540a,0x91e3,0x8abf,0x8dcc,
  0x7239,0x789f,0x8776,0x8fed, 0x8adc,0x758a,0x4e01,0x76ef,
  0x53ee,0x91d8,0x9802,0x9f0e, 0x9320,0x5b9a,0x8a02,0x4e22,
  0x6771,0x51ac,0x8463,0x61c2, 0x52d5,0x68df,0x4f97,0x606b,
  0x51cd,0x6d1e,0x515c,0x6296, 0x9b25,0x9661,0x8c46,0x9017,
  0x75d8,0x90fd,0x7763,0x6bd2, 0x72a2,0x7368,0x8b80,0x5835,
  0x7779,0x8ced,0x675c,0x934d, 0x809a,0x5ea6,0x6e21,0x5992,
  0x7aef,0x77ed,0x935b,0x6bb5, 0x65b7,0x7dde,0x5806,0x5151,
  0x968a,0x5c0d,0x58a9,0x5678, 0x8e72,0x6566,0x9813,0x56e4,
  0x920d,0x76fe,0x9041,0x6387, 0x54c6,0x591a,0x596a,0x579b,
  0x8eb2,0x6735,0x8dfa,0x8235, 0x5241,0x60f0,0x58ae,0x86fe,
  0x5ce8,0x9d5d,0x4fc4,0x984d, 0x8a1b,0x5a25,0x60e1,0x5384,
  0x627c,0x904f,0x9102,0x9913, 0x6069,0x800c,0x5152,0x8033,
  0x723e,0x990c,0x6d31,0x4e8c, 0x8cb3,0x767c,0x7f70,0x7b4f,
  0x4f10,0x4e4f,0x95a5,0x6cd5, 0x73d0,0x85e9,0x5e06,0x756a,
  0x7ffb,0x6a0a,0x792c,0x91e9, 0x7e41,0x51e1,0x7169,0x53cd,
  0x8fd4,0x7bc4,0x8ca9,0x72af, 0x98ef,0x6cdb,0x574a,0x82b3,
  0x65b9,0x80aa,0x623f,0x9632, 0x59a8,0x4eff,0x8a2a,0x7d21,
  0x653e,0x83f2,0x975e,0x5561, 0x98db,0x80a5,0x532a,0x8ab9,
  0x5420,0x80ba,0x5ee2,0x6cb8, 0x8cbb,0x82ac,0x915a,0x5429,
  0x6c1b,0x5206,0x7d1b,0x58b3, 0x711a,0x6c7e,0x7c89,0x596e,
  0x4efd,0x5fff,0x61a4,0x7cde, 0x8c50,0x5c01,0x6953,0x8702,
  0x5cf0,0x92d2,0x98a8,0x760b, 0x70fd,0x9022,0x99ae,0x7e2b,
  0x8af7,0x5949,0x9cf3,0x4f5b, 0x5426,0x592b,0x6577,0x819a,
  0x5b75,0x6276,0x62c2,0x8f3b, 0x5e45,0x6c1f,0x7b26,0x4f0f,
  0x4fd8,0x670d,0x6d6e,0x6daa, 0x798f,0x88b1,0x5f17,0x752b,
  0x64ab,0x8f14,0x4fef,0x91dc, 0x65a7,0x812f,0x8151,0x5e9c,
  0x8150,0x8d74,0x526f,0x8986, 0x8ce6,0x5fa9,0x5085,0x4ed8,
  0x961c,0x7236,0x8179,0x8ca0, 0x5bcc,0x8a03,0x9644,0x5a66,
  0x7e1b,0x5490,0x5676,0x560e, 0x8a72,0x6539,0x6982,0x9223,
  0x84cb,0x6e89,0x5e79,0x7518, 0x6746,0x67d1,0x7aff,0x809d,
  0x8d95,0x611f,0x79c6,0x6562, 0x8d1b,0x5ca1,0x525b,0x92fc,
  0x7f38,0x809b,0x7db1,0x5d17, 0x6e2f,0x6760,0x7bd9,0x768b,
  0x9ad8,0x818f,0x7f94,0x7cd5, 0x641e,0x93ac,0x7a3f,0x544a,
  0x54e5,0x6b4c,0x64f1,0x6208, 0x9d3f,0x80f3,0x7599,0x5272,
  0x9769,0x845b,0x683c,0x86e4, 0x95a3,0x9694,0x927b,0x500b,
  0x5404,0x7d66,0x6839,0x8ddf, 0x8015,0x66f4,0x5e9a,0x7fb9,
  0x57c2,0x803f,0x6897,0x5de5, 0x653b,0x529f,0x606d,0x9f94,
  0x4f9b,0x8eac,0x516c,0x5bab, 0x5f13,0x978f,0x6c5e,0x62f1,
  0x8ca2,0x5171,0x920e,0x52fe, 0x6e9d,0x82df,0x72d7,0x57a2,
  0x69cb,0x8cfc,0x591f,0x8f9c, 0x83c7,0x5495,0x7b8d,0x4f30,
  0x6cbd,0x5b64,0x59d1,0x9f13, 0x53e4,0x8831,0x9aa8,0x8c37,
  0x80a1,0x6545,0x9867,0x56fa, 0x96c7,0x522e,0x74dc,0x526e,
  0x5be1,0x6302,0x8902,0x4e56, 0x62d0,0x602a,0x68fa,0x95dc,
  0x5b98,0x51a0,0x89c0,0x7ba1, 0x9928,0x7f50,0x6163,0x704c,
  0x8cab,0x5149,0x5ee3,0x901b, 0x7470,0x898f,0x572d,0x7845,
  0x6b78,0x9f9c,0x95a8,0x8ecc, 0x9b3c,0x8a6d,0x7678,0x6842,
  0x6ac3,0x8dea,0x8cb4,0x528a, 0x8f25,0x6eda,0x68cd,0x934b,
  0x90ed,0x570b,0x679c,0x88f9, 0x904e,0x54c8,0x9ab8,0x5b69,
  0x6d77,0x6c26,0x4ea5,0x5bb3, 0x99ed,0x9163,0x61a8,0x90af,
  0x97d3,0x542b,0x6db5,0x5bd2, 0x51fd,0x558a,0x7f55,0x7ff0,
  0x64bc,0x634d,0x65f1,0x61be, 0x608d,0x710a,0x6c57,0x6f22,
  0x592f,0x676d,0x822a,0x58d5, 0x568e,0x8c6a,0x6beb,0x90dd,
  0x597d,0x8017,0x865f,0x6d69, 0x5475,0x559d,0x8377,0x83cf,
  0x6838,0x79be,0x548c,0x4f55, 0x5408,0x76d2,0x8c89,0x95a1,
  0x6cb3,0x6db8,0x8d6b,0x8910, 0x9db4,0x8cc0,0x563f,0x9ed1,
  0x75d5,0x5f88,0x72e0,0x6068, 0x54fc,0x4ea8,0x6a2a,0x8861,
  0x6052,0x8f5f,0x54c4,0x70d8, 0x8679,0x9d3b,0x6d2a,0x5b8f,
  0x5f18,0x7d05,0x5589,0x4faf, 0x7334,0x543c,0x539a,0x5019,
  0x5f8c,0x547c,0x4e4e,0x5ffd, 0x745a,0x58fa,0x846b,0x80e1,
  0x8774,0x72d0,0x7cca,0x6e56, 0x5f27,0x864e,0x552c,0x8b77,
  0x4e92,0x6eec,0x6237,0x82b1, 0x5629,0x83ef,0x733e,0x6ed1,
  0x756b,0x5283,0x5316,0x8a71, 0x69d0,0x5f8a,0x61f7,0x6dee,
  0x58de,0x6b61,0x74b0,0x6853, 0x9084,0x7de9,0x63db,0x60a3,
  0x559a,0x7613,0x8c62,0x7165, 0x6e19,0x5ba6,0x5e7b,0x8352,
  0x614c,0x9ec4,0x78fa,0x8757, 0x7c27,0x7687,0x51f0,0x60f6,
  0x714c,0x6643,0x5e4c,0x604d, 0x8b0a,0x7070,0x63ee,0x8f1d,
  0x5fbd,0x6062,0x86d4,0x56de, 0x6bc1,0x6094,0x6167,0x5349,
  0x60e0,0x6666,0x8cc4,0x7a62, 0x6703,0x71f4,0x532f,0x8af1,
  0x8aa8,0x7e6a,0x8477,0x660f, 0x5a5a,0x9b42,0x6e3e,0x6df7,
  0x8c41,0x6d3b,0x4f19,0x706b, 0x7372,0x6216,0x60d1,0x970d,
  0x8ca8,0x798d,0x64ca,0x573e, 0x57fa,0x6a5f,0x7578,0x7a3d,
  0x7a4d,0x7b95,0x808c,0x9951, 0x8ff9,0x6fc0,0x8b4f,0x9dc4,
  0x59ec,0x7e3e,0x7ddd,0x5409, 0x6975,0x68d8,0x8f2f,0x7c4d,
  0x96c6,0x53ca,0x6025,0x75be, 0x6c72,0x5373,0x5ac9,0x7d1a,
  0x64e0,0x5e7e,0x810a,0x5df1, 0x858a,0x6280,0x5180,0x5b63,
  0x4f0e,0x796d,0x5291,0x60b8, 0x6fdf,0x5bc4,0x5bc2,0x8a08,
  0x8a18,0x65e2,0x5fcc,0x969b, 0x5993,0x7e7c,0x7d00,0x5609,
  0x67b7,0x593e,0x4f73,0x5bb6, 0x52a0,0x83a2,0x9830,0x8cc8,
  0x7532,0x9240,0x5047,0x7a3c, 0x50f9,0x67b6,0x99d5,0x5ac1,
  0x6bb2,0x76e3,0x5805,0x5c16, 0x7b8b,0x9593,0x714e,0x517c,
  0x80a9,0x8271,0x5978,0x7dd8, 0x7e6d,0x6aa2,0x67ec,0x78b1,
  0x9e7c,0x63c0,0x64bf,0x7c21, 0x5109,0x526a,0x51cf,0x85a6,
  0x6abb,0x9452,0x8e10,0x8ce4, 0x898b,0x9375,0x7bad,0x4ef6,
  0x5065,0x8266,0x528d,0x991e, 0x6f38,0x6ffa,0x6f97,0x5efa,
  0x50f5,0x59dc,0x5c07,0x6f3f, 0x6c5f,0x7586,0x8523,0x69f3,
  0x596c,0x8b1b,0x5320,0x91ac, 0x964d,0x8549,0x6912,0x7901,
  0x7126,0x81a0,0x4ea4,0x90ca, 0x6f86,0x9a55,0x5b0c,0x56bc,
  0x652a,0x9278,0x77ef,0x50e5, 0x811a,0x72e1,0x89d2,0x9903,
  0x7e73,0x7d5e,0x527f,0x6559, 0x9175,0x8f4e,0x8f03,0x53eb,
  0x7a96,0x63ed,0x63a5,0x7686, 0x79f8,0x8857,0x968e,0x622a,
  0x52ab,0x7bc0,0x6854,0x6770, 0x6377,0x776b,0x7aed,0x6f54,
  0x7d50,0x89e3,0x59d0,0x6212, 0x85c9,0x82a5,0x754c,0x501f,
  0x4ecb,0x75a5,0x8aa1,0x5c4a, 0x5dfe,0x7b4b,0x65a4,0x91d1,
  0x4eca,0x6d25,0x895f,0x7dca, 0x9326,0x50c5,0x8b39,0x9032,
  0x9773,0x6649,0x7981,0x8fd1, 0x71fc,0x6d78,0x76e1,0x52c1,
  0x8346,0x5162,0x8396,0x775b, 0x6676,0x9be8,0x4eac,0x9a5a,
  0x7cbe,0x7cb3,0x7d93,0x4e95, 0x8b66,0x666f,0x9838,0x975c,
  0x5883,0x656c,0x93e1,0x5f91, 0x75d9,0x9756,0x7adf,0x7af6,
  0x51c8,0x70af,0x7a98,0x63ea, 0x7a76,0x7cfe,0x7396,0x97ed,
  0x4e45,0x7078,0x4e5d,0x9152, 0x53a9,0x6551,0x820a,0x81fc,
  0x8205,0x548e,0x5c31,0x759a, 0x97a0,0x62d8,0x72d9,0x75bd,
  0x5c45,0x99d2,0x83ca,0x5c40, 0x5480,0x77e9,0x8209,0x6cae,
  0x805a,0x62d2,0x64da,0x5de8, 0x5177,0x8ddd,0x8e1e,0x92f8,
  0x4ff1,0x53e5,0x61fc,0x70ac, 0x5287,0x6350,0x9d51,0x5a1f,
  0x5026,0x7737,0x5377,0x7d79, 0x6485,0x652b,0x6289,0x6398,
  0x5014,0x7235,0x89ba,0x51b3, 0x8a23,0x7d76,0x5747,0x83cc,
  0x921e,0x8ecd,0x541b,0x5cfb, 0x4fca,0x7ae3,0x6d5a,0x90e1,
  0x99ff,0x5580,0x5496,0x5361, 0x54af,0x958b,0x63e9,0x6977,
  0x51f1,0x6168,0x520a,0x582a, 0x52d8,0x574e,0x780d,0x770b,
  0x5eb7,0x6177,0x7ce0,0x625b, 0x6297,0x4ea2,0x7095,0x8003,
  0x62f7,0x70e4,0x9760,0x5777, 0x82db,0x67ef,0x68f5,0x78d5,
  0x9846,0x79d1,0x6bbb,0x54b3, 0x53ef,0x6e34,0x514b,0x523b,
  0x5ba2,0x8ab2,0x80af,0x5543, 0x58be,0x61c7,0x5751,0x542d,
  0x7a7a,0x6050,0x5b54,0x63a7, 0x6473,0x53e3,0x6263,0x5bc7,
  0x67af,0x54ed,0x7a9f,0x82e6, 0x9177,0x5eab,0x8932,0x8a87,
  0x57ae,0x630e,0x8de8,0x80ef, 0x584a,0x7b77,0x5108,0x5feb,
  0x5bec,0x6b3e,0x5321,0x7b50, 0x72c2,0x6846,0x7926,0x7736,
  0x66e0,0x51b5,0x8667,0x76d4, 0x5dcb,0x7aba,0x8475,0x594e,
  0x9b41,0x5080,0x994b,0x6127, 0x6f70,0x5764,0x6606,0x6346,
  0x56f0,0x62ec,0x64f4,0x5ed3, 0x95ca,0x5783,0x62c9,0x5587,
  0x881f,0x81d8,0x8fa3,0x5566, 0x840a,0x4f86,0x8cf4,0x85cd,
  0x5a6a,0x6b04,0x6514,0x7c43, 0x95cc,0x862d,0x703e,0x8b95,
  0x652c,0x89bd,0x61f6,0x7e9c, 0x721b,0x6feb,0x7405,0x6994,
  0x72fc,0x5eca,0x90ce,0x6717, 0x6d6a,0x6488,0x52de,0x7262,
  0x8001,0x4f6c,0x59e5,0x916a, 0x70d9,0x6f87,0x52d2,0x6a02,
  0x96f7,0x9433,0x857e,0x78ca, 0x7d2f,0x5121,0x58d8,0x64c2,
  0x808b,0x985e,0x6cea,0x68f1, 0x695e,0x51b7,0x5398,0x68a8,
  0x7281,0x9ece,0x7c6c,0x72f8, 0x96e2,0x7055,0x7406,0x674e,
  0x88cf,0x9bc9,0x79ae,0x8389, 0x8354,0x540f,0x6817,0x9e97,
  0x53b2,0x52f5,0x792b,0x6b77, 0x5229,0x5088,0x4f8b,0x4fd0,
  0x75e2,0x7acb,0x7c92,0x701d, 0x96b8,0x529b,0x7483,0x54e9,
  0x5006,0x806f,0x84ee,0x9023, 0x942e,0x5ec9,0x6190,0x6f23,
  0x7c3e,0x6582,0x81c9,0x93c8, 0x6200,0x7149,0x7df4,0x7ce7,
  0x51c9,0x6881,0x7cb1,0x826f, 0x5169,0x8f1b,0x91cf,0x667e,
  0x4eae,0x8ad2,0x64a9,0x804a, 0x50da,0x7642,0x71ce,0x5be5,
  0x907c,0x6f66,0x4e86,0x6482, 0x9410,0x5ed6,0x6599,0x5217,
  0x88c2,0x70c8,0x52a3,0x7375, 0x7433,0x6797,0x78f7,0x9716,
  0x81e8,0x9130,0x9c57,0x6dcb, 0x51db,0x8cc3,0x541d,0x62ce,
  0x73b2,0x83f1,0x96f6,0x9f61, 0x9234,0x4f36,0x7f9a,0x51cc,
  0x9748,0x9675,0x5dba,0x9818, 0x53e6,0x4ee4,0x6e9c,0x7409,
  0x69b4,0x786b,0x993e,0x7559, 0x5289,0x7624,0x6d41,0x67f3,
  0x516d,0x9f8d,0x807e,0x56a8, 0x7c60,0x7abf,0x9686,0x58df,
  0x650f,0x96b4,0x6a13,0x5a41, 0x645f,0x7c0d,0x6f0f,0x964b,
  0x8606,0x76e7,0x9871,0x5eec, 0x7210,0x64c4,0x6ef7,0x865c,
  0x9b6f,0x9e93,0x788c,0x9732, 0x8def,0x8cc2,0x9e7f,0x6f5e,
  0x7984,0x9332,0x9678,0x622e, 0x9a62,0x5415,0x92c1,0x4fa3,
  0x65c5,0x5c65,0x5c62,0x7e37, 0x616e,0x6c2f,0x5f8b,0x7387,
  0x6ffe,0x7dd1,0x5dd2,0x6523, 0x5b7f,0x7064,0x5375,0x4e82,
  0x63a0,0x7565,0x6384,0x8f2a, 0x502b,0x4f96,0x6dea,0x7db8,
  0x8ad6,0x863f,0x87ba,0x7f85, 0x908f,0x947c,0x7c6e,0x9a3e,
  0x88f8,0x843d,0x6d1b,0x99f1, 0x7d61,0x5abd,0x9ebb,0x746a,
  0x78bc,0x879e,0x99ac,0x99e1, 0x561b,0x55ce,0x57cb,0x8cb7,
  0x9ea5,0x8ce3,0x9081,0x8109, 0x779e,0x9945,0x883b,0x6eff,
  0x8513,0x66fc,0x6162,0x6f2b, 0x8b3e,0x8292,0x832b,0x76f2,
  0x6c13,0x5fd9,0x83bd,0x732b, 0x8305,0x9328,0x6bdb,0x77db,
  0x925a,0x536f,0x8302,0x5192, 0x5e3d,0x8c8c,0x8cbf,0x9ebd,
  0x73ab,0x679a,0x6885,0x9176, 0x9709,0x7164,0x6ca1,0x7709,
  0x5a92,0x9382,0x6bcf,0x7f8e, 0x6627,0x5bd0,0x59b9,0x5a9a,
  0x9580,0x60b6,0x5011,0x840c, 0x8499,0x6aac,0x76df,0x9333,
  0x731b,0x5922,0x5b5f,0x772f, 0x919a,0x9761,0x7cdc,0x8ff7,
  0x8b0e,0x5f4c,0x7c73,0x79d8, 0x8993,0x6ccc,0x871c,0x5bc6,
  0x5e42,0x68c9,0x7720,0x7dbf, 0x5195,0x514d,0x52c9,0x5a29,
  0x7dec,0x9762,0x82d7,0x63cf, 0x7784,0x85d0,0x79d2,0x6e3a,
  0x5edf,0x5999,0x8511,0x6ec5, 0x6c11,0x62bf,0x76bf,0x654f,
  0x61ab,0x95a9,0x660e,0x879f, 0x9cf4,0x9298,0x540d,0x547d,
  0x8b2c,0x6478,0x6479,0x8611, 0x6a21,0x819c,0x78e8,0x6469,
  0x9b54,0x62b9,0x672b,0x83ab, 0x58a8,0x9ed8,0x6cab,0x6f20,
  0x5bde,0x964c,0x8b00,0x725f, 0x67d0,0x62c7,0x7261,0x755d,
  0x59c6,0x6bcd,0x5893,0x66ae, 0x5e55,0x52df,0x6155,0x6728,
  0x76ee,0x7766,0x7267,0x7a46, 0x62ff,0x54ea,0x5450,0x9209,
  0x90a3,0x5a1c,0x7d0d,0x6c16, 0x4e43,0x5976,0x8010,0x5948,
  0x5357,0x7537,0x96e3,0x56ca, 0x6493,0x8166,0x60f1,0x9b27,
  0x6dd6,0x5462,0x9912,0x5185, 0x5ae9,0x80fd,0x59ae,0x9713,
  0x502a,0x6ce5,0x5c3c,0x64ec, 0x4f60,0x533f,0x81a9,0x9006,
  0x6eba,0x852b,0x62c8,0x5e74, 0x78be,0x6506,0x637b,0x5ff5,
  0x5a18,0x91c0,0x9ce5,0x5c3f, 0x634f,0x8076,0x5b7d,0x5699,
  0x9477,0x93b3,0x6d85,0x60a8, 0x6ab8,0x7370,0x51dd,0x5be7,
  0x64f0,0x6fd8,0x725b,0x626d, 0x9215,0x7d10,0x81bf,0x6fc3,
  0x8fb2,0x5f04,0x5974,0x52aa, 0x6012,0x5973,0x6696,0x8650,
  0x7627,0x632a,0x61e6,0x7cef, 0x8afe,0x54e6,0x6b50,0x9dd7,
  0x6bc6,0x85d5,0x5614,0x5076, 0x6f1a,0x556a,0x8db4,0x722c,
  0x5e15,0x6015,0x7436,0x62cd, 0x6392,0x724c,0x5f98,0x6e43,
  0x6d3e,0x6500,0x6f58,0x76e4, 0x78d0,0x76fc,0x7554,0x5224,
  0x53db,0x4e53,0x9f90,0x65c1, 0x802a,0x80d6,0x629b,0x5486,
  0x5228,0x70ae,0x888d,0x8dd1, 0x6ce1,0x5478,0x80da,0x57f9,
  0x88f4,0x8ce0,0x966a,0x914d, 0x4f69,0x6c9b,0x5674,0x76c6,
  0x7830,0x62a8,0x70f9,0x6f8e, 0x5f6d,0x84ec,0x68da,0x787c,
  0x7bf7,0x81a8,0x670b,0x9d6c, 0x6367,0x78b0,0x576f,0x7812,
  0x9739,0x6279,0x62ab,0x5288, 0x7435,0x6bd7,0x5564,0x813e,
  0x75b2,0x76ae,0x5339,0x75de, 0x50fb,0x5c41,0x8b6c,0x7bc7,
  0x504f,0x7247,0x9a19,0x98c4, 0x6f02,0x74e2,0x7968,0x6487,
  0x77a5,0x62fc,0x983b,0x8ca7, 0x54c1,0x8058,0x4e52,0x576a,
  0x860b,0x840d,0x5e73,0x6191, 0x74f6,0x8a55,0x5c4f,0x5761,
  0x6f51,0x9817,0x5a46,0x7834, 0x9b44,0x8feb,0x7c95,0x5256,
  0x64b2,0x92ea,0x50d5,0x8386, 0x8461,0x83e9,0x84b2,0x57d4,
  0x6a38,0x5703,0x666e,0x6d66, 0x8b5c,0x66dd,0x7011,0x671f,
  0x6b3a,0x68f2,0x621a,0x59bb, 0x4e03,0x51c4,0x6f06,0x67d2,
  0x6c8f,0x5176,0x68cb,0x5947, 0x6b67,0x7566,0x5d0e,0x81cd,
  0x9f4a,0x65d7,0x7948,0x7941, 0x9a0e,0x8d77,0x8c48,0x4e5e,
  0x4f01,0x5553,0x5951,0x780c, 0x5668,0x6c23,0x8fc4,0x68c4,
  0x6c7d,0x6ce3,0x8a16,0x6390, 0x6070,0x6d3d,0x727d,0x6266,
  0x91fa,0x925b,0x5343,0x9077, 0x7c3d,0x4edf,0x8b19,0x4e7e,
  0x9ed4,0x9322,0x9257,0x524d, 0x6f5b,0x9063,0x6dfa,0x8b74,
  0x5879,0x5d4c,0x6b20,0x6b49, 0x69cd,0x55c6,0x8154,0x7f8c,
  0x58bb,0x8594,0x5f3a,0x6436, 0x6a47,0x936c,0x6572,0x6084,
  0x6a4b,0x77a7,0x55ac,0x50d1, 0x5de7,0x9798,0x64ac,0x7ff9,
  0x5ced,0x4fcf,0x7ac5,0x5207, 0x8304,0x4e14,0x602f,0x7aca,
  0x6b3d,0x4fb5,0x89aa,0x79e6, 0x7434,0x52e4,0x82b9,0x64d2,
  0x79bd,0x5be2,0x6c81,0x9752, 0x8f15,0x6c2b,0x50be,0x537f,
  0x6e05,0x64ce,0x6674,0x6c30, 0x60c5,0x9803,0x8acb,0x6176,
  0x74ca,0x7aae,0x79cb,0x4e18, 0x90b1,0x7403,0x6c42,0x56da,
  0x914b,0x6cc5,0x8da8,0x5340, 0x86c6,0x66f2,0x8ec0,0x5c48,
  0x9a45,0x6e20,0x53d6,0x5a36, 0x9f72,0x8da3,0x53bb,0x5708,
  0x9874,0x6b0a,0x919b,0x6cc9, 0x5168,0x75ca,0x62f3,0x72ac,
  0x5238,0x52f8,0x7f3a,0x7094, 0x7638,0x5374,0x9d72,0x69b7,
  0x78ba,0x96c0,0x88d9,0x7fa4, 0x7136,0x71c3,0x5189,0x67d3,
  0x74e4,0x58e4,0x6518,0x56b7, 0x8b93,0x9952,0x64fe,0x7e5e,
  0x60f9,0x71b1,0x58ec,0x4ec1, 0x4eba,0x5fcd,0x97cc,0x4efb,
  0x8a8d,0x5203,0x598a,0x7d09, 0x6254,0x4ecd,0x65e5,0x620e,
  0x8338,0x84c9,0x69ae,0x878d, 0x7194,0x6eb6,0x5bb9,0x7d68,
  0x5197,0x63c9,0x67d4,0x8089, 0x8339,0x8815,0x5112,0x5b7a,
  0x5982,0x8fb1,0x4e73,0x6c5d, 0x5165,0x8925,0x8edf,0x962e,
  0x854a,0x745e,0x92ed,0x958f, 0x6f64,0x82e5,0x5f31,0x6492,
  0x7051,0x85a9,0x816e,0x9c13, 0x585e,0x8cfd,0x4e09,0x53c1,
  0x5098,0x6563,0x6851,0x55d3, 0x55aa,0x6414,0x9a37,0x6383,
  0x5ac2,0x745f,0x8272,0x6f80, 0x68ee,0x50e7,0x838e,0x7802,
  0x6bba,0x5239,0x6c99,0x7d17, 0x50bb,0x5565,0x715e,0x7be9,
  0x66ec,0x73ca,0x82eb,0x6749, 0x5c71,0x5220,0x717d,0x886b,
  0x9583,0x965d,0x64c5,0x8d0d, 0x81b3,0x5584,0x6c55,0x6247,
  0x7e55,0x5892,0x50b7,0x5546, 0x8cde,0x664c,0x4e0a,0x5c1a,
  0x88f3,0x68a2,0x634e,0x7a0d, 0x71d2,0x828d,0x52fa,0x97f6,
  0x5c11,0x54e8,0x90b5,0x7d39, 0x5962,0x8cd2,0x86c7,0x820c,
  0x6368,0x8d66,0x651d,0x5c04, 0x61fe,0x6d89,0x793e,0x8a2d,
  0x7837,0x7533,0x547b,0x4f38, 0x8eab,0x6df1,0x5a20,0x7d33,
  0x795e,0x6c88,0x5be9,0x5b38, 0x751a,0x814e,0x614e,0x6ef2,
  0x8072,0x751f,0x7525,0x7272, 0x5347,0x7e69,0x7701,0x76db,
  0x5269,0x52dd,0x8056,0x5e2b, 0x5931,0x7345,0x65bd,0x6fd5,
  0x8a69,0x5c38,0x8671,0x5341, 0x77f3,0x62fe,0x6642,0x4ec0,
  0x98df,0x8755,0x5be6,0x8b58, 0x53f2,0x77e2,0x4f7f,0x5c4e,
  0x99db,0x59cb,0x5f0f,0x793a, 0x58eb,0x4e16,0x67ff,0x4e8b,
  0x62ed,0x8a93,0x901d,0x52e2, 0x662f,0x55dc,0x566c,0x9069,
  0x4ed5,0x4f8d,0x91cb,0x98fe, 0x6c0f,0x5e02,0x6043,0x5ba4,
  0x8996,0x8a66,0x6536,0x624b, 0x9996,0x5b88,0x58fd,0x6388,
  0x552e,0x53d7,0x7626,0x7378, 0x852c,0x6a1e,0x68b3,0x6b8a,
  0x6292,0x8f38,0x53d4,0x8212, 0x6dd1,0x758f,0x66f8,0x8d16,
  0x5b70,0x719f,0x85af,0x6691, 0x66d9,0x7f72,0x8700,0x9ecd,
  0x9f20,0x5c6c,0x8853,0x8ff0, 0x6a39,0x675f,0x620d,0x7aea,
  0x5885,0x5eb6,0x6578,0x6f31, 0x6055,0x5237,0x800d,0x6454,
  0x8870,0x7529,0x5e25,0x6813, 0x62f4,0x971c,0x96d9,0x723d,
  0x8ab0,0x6c34,0x7761,0x7a0e, 0x542e,0x77ac,0x9806,0x821c,
  0x8aac,0x78a9,0x6714,0x720d, 0x65af,0x6495,0x5636,0x601d,
  0x79c1,0x53f8,0x7d72,0x6b7b, 0x8086,0x5bfa,0x55e3,0x56db,
  0x4f3a,0x4f3c,0x98fc,0x5df3, 0x9b06,0x8073,0x616b,0x980c,
  0x9001,0x5b8b,0x8a1f,0x8aa6, 0x641c,0x8258,0x64fb,0x55fd,
  0x8607,0x9165,0x4fd7,0x7d20, 0x901f,0x7c9f,0x50f3,0x5851,
  0x6eaf,0x5bbf,0x8a34,0x8085, 0x9178,0x849c,0x7b97,0x96d6,
  0x968b,0x96a8,0x7d8f,0x9ad3, 0x788e,0x6b72,0x7a57,0x9042,
  0x96a7,0x795f,0x5b6b,0x640d, 0x7b0b,0x84d1,0x68ad,0x5506,
  0x7e2e,0x7463,0x7d22,0x9396, 0x6240,0x584c,0x4ed6,0x5b83,
  0x5979,0x5854,0x737a,0x64bb, 0x8e4b,0x8e0f,0x80ce,0x82d4,
  0x62ac,0x81fa,0x6cf0,0x915e, 0x592a,0x614b,0x6c70,0x574d,
  0x6524,0x8caa,0x7671,0x7058, 0x58c7,0x6a80,0x75f0,0x6f6d,
  0x8b5a,0x8ac7,0x5766,0x6bef, 0x8892,0x78b3,0x63a2,0x5606,
  0x70ad,0x6e6f,0x5858,0x642a, 0x5802,0x68e0,0x819b,0x5510,
  0x7cd6,0x5018,0x8eba,0x6dcc, 0x8d9f,0x71d9,0x638f,0x6fe4,
  0x6ed4,0x7e27,0x8404,0x6843, 0x9003,0x6dd8,0x9676,0x8a0e,
  0x5957,0x7279,0x85e4,0x9a30, 0x75bc,0x8b04,0x68af,0x5254,
  0x8e22,0x92bb,0x63d0,0x984c, 0x8e44,0x557c,0x9ad4,0x66ff,
  0x568f,0x60d5,0x6d95,0x5243, 0x5c49,0x5929,0x6dfb,0x586b,
  0x7530,0x751c,0x606c,0x8214, 0x8146,0x6311,0x689d,0x8fe2,
  0x773a,0x8df3,0x8cbc,0x9435, 0x5e16,0x5ef3,0x807d,0x70f4,
  0x6c40,0x5ef7,0x505c,0x4ead, 0x5ead,0x633a,0x8247,0x901a,
  0x6850,0x916e,0x77b3,0x540c, 0x9285,0x5f64,0x7ae5,0x6876,
  0x6345,0x7b52,0x7d71,0x75db, 0x5077,0x6295,0x982d,0x900f,
  0x51f8,0x79c3,0x7a81,0x5716, 0x5f92,0x9014,0x5857,0x5c60,
  0x571f,0x5410,0x5154,0x6e4d, 0x5718,0x63a8,0x983d,0x817f,
  0x8715,0x892a,0x9000,0x541e, 0x5c6f,0x81c0,0x62d6,0x6258,
  0x8131,0x9d15,0x9640,0x99b1, 0x99dd,0x6a62,0x59a5,0x62d3,
  0x553e,0x6316,0x54c7,0x86d9, 0x7aaa,0x5a03,0x74e6,0x896a,
  0x6b6a,0x5916,0x8c4c,0x5f4e, 0x7063,0x73a9,0x9811,0x4e38,
  0x70f7,0x5b8c,0x7897,0x633d, 0x665a,0x7696,0x60cb,0x5b9b,
  0x5a49,0x842c,0x8155,0x6c6a, 0x738b,0x4ea1,0x6789,0x7db2,
  0x5f80,0x65fa,0x671b,0x5fd8, 0x5984,0x5a01,0x5dcd,0x5fae,
  0x5371,0x97cb,0x9055,0x6845, 0x570d,0x552f,0x60df,0x7232,
  0x6ff0,0x7dad,0x8466,0x840e, 0x59d4,0x5049,0x50de,0x5c3e,
  0x7def,0x672a,0x851a,0x5473, 0x754f,0x80c3,0x5582,0x9b4f,
  0x4f4d,0x6e2d,0x8b02,0x5c09, 0x6170,0x885b,0x761f,0x6e29,
  0x868a,0x6587,0x805e,0x7d0b, 0x543b,0x7a69,0x7d0a,0x554f,
  0x55e1,0x7fc1,0x74ee,0x64be, 0x8778,0x6e26,0x7aa9,0x6211,
  0x65a1,0x5367,0x63e1,0x6c83, 0x5deb,0x55da,0x93a2,0x70cf,
  0x6c61,0x8aa3,0x5c4b,0x7121, 0x856a,0x68a7,0x543e,0x5434,
  0x6bcb,0x6b66,0x4e94,0x6342, 0x5348,0x821e,0x4f0d,0x4fae,
  0x5862,0x620a,0x9727,0x6664, 0x7269,0x52ff,0x52d9,0x609f,
  0x8aa4,0x6614,0x7199,0x6790, 0x897f,0x7852,0x77fd,0x6670,
  0x563b,0x5438,0x932b,0x72a7, 0x7a00,0x606f,0x5e0c,0x6089,
  0x819d,0x5915,0x60dc,0x7184, 0x70ef,0x6eaa,0x6c50,0x7280,
  0x6a84,0x8972,0x5e2d,0x7fd2, 0x5ab3,0x559c,0x9291,0x6d17,
  0x7cfb,0x9699,0x6232,0x7d30, 0x778e,0x8766,0x5323,0x971e,
  0x8f44,0x6687,0x5cfd,0x4fe0, 0x72f9,0x4e0b,0x53a6,0x590f,
  0x5687,0x6380,0x9341,0x5148, 0x4ed9,0x9bae,0x7e96,0x54b8,
  0x8ce2,0x929c,0x8237,0x9591, 0x6d8e,0x5f26,0x5acc,0x986f,
  0x96aa,0x73fe,0x737b,0x7e23, 0x817a,0x9921,0x7fa1,0x61b2,
  0x9677,0x9650,0x7dab,0x76f8, 0x53a2,0x9472,0x9999,0x7bb1,
  0x8944,0x6e58,0x9109,0x7fd4, 0x7965,0x8a73,0x60f3,0x97ff,
  0x4eab,0x9805,0x5df7,0x6a61, 0x50cf,0x5411,0x8c61,0x856d,
  0x785d,0x9704,0x524a,0x54ee, 0x56c2,0x92b7,0x6d88,0x5bb5,
  0x6dc6,0x66c9,0x5c0f,0x5b5d, 0x6821,0x8096,0x562f,0x7b11,
  0x6548,0x6954,0x4e9b,0x6b47, 0x874e,0x978b,0x5354,0x633e,
  0x643a,0x90aa,0x659c,0x8105, 0x8ae7,0x5beb,0x68b0,0x5378,
  0x87f9,0x61c8,0x6cc4,0x7009, 0x8b1d,0x5c51,0x85aa,0x82af,
  0x92c5,0x6b23,0x8f9b,0x65b0, 0x5ffb,0x5fc3,0x4fe1,0x91c1,
  0x661f,0x8165,0x7329,0x60fa, 0x8208,0x5211,0x578b,0x5f62,
  0x90a2,0x884c,0x9192,0x5e78, 0x674f,0x6027,0x59d3,0x5144,
  0x51f6,0x80f8,0x5308,0x6c79, 0x96c4,0x718a,0x4f11,0x4fee,
  0x7f9e,0x673d,0x55c5,0x92b9, 0x79c0,0x8896,0x7d89,0x589f,
  0x620c,0x9700,0x865a,0x5618, 0x9808,0x5f90,0x8a31,0x84c4,
  0x9157,0x53d9,0x65ed,0x5e8f, 0x755c,0x6064,0x7d6e,0x5a7f,
  0x7dd2,0x7e8c,0x8ed2,0x55a7, 0x5ba3,0x61f8,0x65cb,0x7384,
  0x9078,0x766c,0x7729,0x7d62, 0x9774,0x859b,0x5b78,0x7a74,
  0x96ea,0x8840,0x52db,0x718f, 0x5faa,0x65ec,0x8a62,0x5c0b,
  0x99b4,0x5de1,0x6b89,0x6c5b, 0x8a13,0x8a0a,0x905c,0x8fc5,
  0x58d3,0x62bc,0x9d09,0x9d28, 0x5440,0x4e2b,0x82bd,0x7259,
  0x869c,0x5d16,0x8859,0x6daf, 0x96c5,0x555e,0x4e9e,0x8a1d,
  0x7109,0x54bd,0x95b9,0x70df, 0x6df9,0x9e7d,0x56b4,0x7814,
  0x8712,0x5ca9,0x5ef6,0x8a00, 0x9854,0x95bb,0x708e,0x6cbf,
  0x5944,0x63a9,0x773c,0x884d, 0x6f14,0x8277,0x5830,0x71d5,
  0x53ad,0x786f,0x96c1,0x5501, 0x5f66,0x7130,0x5bb4,0x8afa,
  0x9a57,0x6b83,0x592e,0x9d26, 0x79e7,0x694a,0x63da,0x4f6f,
  0x760d,0x7f8a,0x6d0b,0x967d, 0x6c27,0x4ef0,0x7662,0x990a,
  0x6a23,0x6f3e,0x9080,0x8170, 0x5996,0x7476,0x6447,0x582f,
  0x9065,0x7a91,0x8b21,0x59da, 0x54ac,0x8200,0x85e5,0x8981,
  0x8000,0x6930,0x564e,0x8036, 0x723a,0x91ce,0x51b6,0x4e5f,
  0x9801,0x6396,0x696d,0x8449, 0x66f3,0x814b,0x591c,0x6db2,
  0x4e00,0x58f9,0x91ab,0x63d6, 0x92a5,0x4f9d,0x4f0a,0x8863,
  0x9824,0x5937,0x907a,0x79fb, 0x5100,0x80f0,0x7591,0x6c82,
  0x5b9c,0x59e8,0x5f5d,0x6905, 0x87fb,0x501a,0x5df2,0x4e59,
  0x77e3,0x4ee5,0x85dd,0x6291, 0x6613,0x9091,0x5c79,0x5104,
  0x5f79,0x81c6,0x9038,0x8084, 0x75ab,0x4ea6,0x88d4,0x610f,
  0x6bc5,0x61b6,0x7fa9,0x76ca, 0x6ea2,0x8a63,0x8b70,0x8abc,
  0x8b6f,0x5f02,0x7ffc,0x7fcc, 0x7e79,0x8335,0x852d,0x56e0,
  0x6bb7,0x97f3,0x9670,0x59fb, 0x541f,0x9280,0x6deb,0x5bc5,
  0x98f2,0x5c39,0x5f15,0x96b1, 0x5370,0x82f1,0x6afb,0x5b30,
  0x9df9,0x61c9,0x7e93,0x7469, 0x87a2,0x71df,0x7192,0x8805,
  0x8fce,0x8d0f,0x76c8,0x5f71, 0x7a4e,0x786c,0x6620,0x55b2,
  0x64c1,0x50ad,0x81c3,0x7670, 0x5eb8,0x96cd,0x8e34,0x86f9,
  0x548f,0x6cf3,0x6d8c,0x6c38, 0x607f,0x52c7,0x7528,0x5e7d,
  0x512a,0x60a0,0x6182,0x5c24, 0x7531,0x90f5,0x923e,0x7336,
  0x6cb9,0x6e38,0x9149,0x6709, 0x53cb,0x53f3,0x4f51,0x91c9,
  0x8a98,0x53c8,0x5e7c,0x8fc2, 0x6de4,0x4e8e,0x76c2,0x6986,
  0x865e,0x611a,0x8f3f,0x9918, 0x4fde,0x903e,0x9b5a,0x6109,
  0x6e1d,0x6f01,0x9685,0x4e88, 0x5a31,0x96e8,0x8207,0x5dbc,
  0x79b9,0x5b87,0x8a9e,0x7fbd, 0x7389,0x57df,0x828b,0x9b31,
  0x5401,0x9047,0x55bb,0x5cea, 0x5fa1,0x6108,0x6b32,0x7344,
  0x80b2,0x8b7d,0x6d74,0x5bd3, 0x88d5,0x9810,0x8c6b,0x99ad,
  0x9d1b,0x6df5,0x51a4,0x5143, 0x57a3,0x8881,0x539f,0x63f4,
  0x8f45,0x5712,0x54e1,0x5713, 0x733f,0x6e90,0x7de3,0x9060,
  0x82d1,0x9858,0x6028,0x9662, 0x66f0,0x7d04,0x8d8a,0x8e8d,
  0x9470,0x5cb3,0x7ca4,0x6708, 0x60a6,0x95b2,0x8018,0x96f2,
  0x9116,0x5300,0x9695,0x5141, 0x904b,0x85f4,0x9196,0x6688,
  0x97f5,0x5b55,0x531d,0x7838, 0x96dc,0x683d,0x54c9,0x707e,
  0x5bb0,0x8f09,0x518d,0x5728, 0x54b1,0x6522,0x66ab,0x8d0a,
  0x8d1c,0x81df,0x846c,0x906d, 0x7cdf,0x947f,0x85fb,0x68d7,
  0x65e9,0x6fa1,0x86a4,0x8e81, 0x566a,0x9020,0x7682,0x7ac8,
  0x71e5,0x8cac,0x64c7,0x5247, 0x6fa4,0x8cca,0x600e,0x589e,
  0x618e,0x66fe,0x8d08,0x624e, 0x55b3,0x6e23,0x672d,0x8ecb,
  0x9358,0x9598,0x7728,0x6805, 0x69a8,0x548b,0x4e4d,0x70b8,
  0x8a50,0x6458,0x9f4b,0x5b85, 0x7a84,0x50b5,0x5be8,0x77bb,
  0x6c08,0x8a79,0x7c98,0x6cbe, 0x76de,0x65ac,0x8f3e,0x5d84,
  0x5c55,0x8638,0x68e7,0x5360, 0x6230,0x7ad9,0x6e5b,0x7dbb,
  0x6a1f,0x7ae0,0x5f70,0x6f33, 0x5f35,0x638c,0x6f32,0x6756,
  0x4e08,0x5e33,0x8cec,0x4ed7, 0x8139,0x7634,0x969c,0x62db,
  0x662d,0x627e,0x6cbc,0x8d99, 0x7167,0x7f69,0x5146,0x8087,
  0x53ec,0x906e,0x6298,0x54f2, 0x87c4,0x8f4d,0x8005,0x937a,
  0x8517,0x9019,0x6d59,0x73cd, 0x659f,0x771f,0x7504,0x7827,
  0x81fb,0x8c9e,0x91dd,0x5075, 0x6795,0x75b9,0x8a3a,0x9707,
  0x632f,0x93ae,0x9663,0x84b8, 0x6399,0x775c,0x5f81,0x7319,
  0x722d,0x6014,0x6574,0x62ef, 0x6b63,0x653f,0x5e40,0x7665,
  0x912d,0x8b49,0x829d,0x679d, 0x652f,0x5431,0x8718,0x77e5,
  0x80a2,0x8102,0x6c41,0x4e4b, 0x7e54,0x8077,0x76f4,0x690d,
  0x6b96,0x57f7,0x503c,0x4f84, 0x5740,0x6307,0x6b62,0x8dbe,
  0x8879,0x65e8,0x7d19,0x5fd7, 0x646f,0x64f2,0x81f3,0x81f4,
  0x7f6e,0x5e5f,0x5cd9,0x5236, 0x667a,0x79e9,0x7a1a,0x8cea,
  0x7099,0x75d4,0x6eef,0x6cbb, 0x7a92,0x4e2d,0x76c5,0x5fe0,
  0x9418,0x8877,0x7d42,0x7a2e, 0x816b,0x91cd,0x4ef2,0x8846,
  0x821f,0x5468,0x5dde,0x6d32, 0x8b05,0x7ca5,0x8ef8,0x8098,
  0x5e1a,0x5492,0x76ba,0x5b99, 0x665d,0x9a5f,0x73e0,0x682a,
  0x86db,0x6731,0x732a,0x8af8, 0x8a85,0x9010,0x7af9,0x71ed,
  0x716e,0x62c4,0x77da,0x56d1, 0x4e3b,0x8457,0x67f1,0x52a9,
  0x86c0,0x8caf,0x9444,0x7bc9, 0x4f4f,0x6ce8,0x795d,0x99d0,
  0x6293,0x722a,0x62fd,0x5c08, 0x78da,0x8f49,0x64b0,0x8cfa,
  0x7bc6,0x6a01,0x838a,0x88dd, 0x599d,0x649e,0x58ef,0x72c0,
  0x690e,0x9310,0x8ffd,0x8d05, 0x589c,0x7db4,0x8ac4,0x6e96,
  0x6349,0x62d9,0x5353,0x684c, 0x7422,0x8301,0x914c,0x5544,
  0x7740,0x707c,0x6fc1,0x5179, 0x54a8,0x8cc7,0x59ff,0x6ecb,
  0x6dc4,0x5b5c,0x7d2b,0x4ed4, 0x7c7d,0x6ed3,0x5b50,0x81ea,
  0x6f2c,0x5b57,0x9b03,0x68d5, 0x8e2a,0x5b97,0x7d9c,0x7e3d,
  0x7e31,0x9112,0x8d70,0x594f, 0x63cd,0x79df,0x8db3,0x5352,
  0x65cf,0x7956,0x8a5b,0x963b, 0x7d44,0x947d,0x7e82,0x5634,
  0x9189,0x6700,0x7f6a,0x5c0a, 0x9075,0x6628,0x5de6,0x4f50,
  0x67de,0x505a,0x4f5c,0x5750, 0x5ea7,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x4e8d,0x4e0c, 0x5140,0x4e10,0x5eff,0x5345,
  0x4e15,0x4e98,0x4e1e,0x9b32, 0x5b6c,0x5669,0x4e28,0x79ba,
  0x4e3f,0x5315,0x4e47,0x592d, 0x723b,0x536e,0x6c10,0x56df,
  0x80e4,0x9997,0x6bd3,0x777e, 0x9f17,0x4e36,0x4e9f,0x9f10,
  0x4e5c,0x4e69,0x4e93,0x8288, 0x5b5b,0x55c7,0x560f,0x4ec4,
  0x5399,0x539d,0x53b4,0x53a5, 0x53ae,0x9768,0x8d0b,0x531a,
  0x53f5,0x532d,0x5331,0x533e, 0x8cfe,0x5366,0x5363,0x5202,
  0x5208,0x520e,0x5244,0x5233, 0x528c,0x5274,0x524c,0x525e,
  0x5261,0x525c,0x84af,0x527d, 0x5282,0x5281,0x5290,0x5293,
  0x5182,0x7f54,0x4ebb,0x4ec3, 0x4ec9,0x4ec2,0x4ee8,0x4ee1,
  0x4eeb,0x4ede,0x50b4,0x4ef3, 0x4f22,0x4f64,0x4ef5,0x5000,
  0x5096,0x4f09,0x4f47,0x4f5e, 0x4f67,0x6538,0x4f5a,0x4f5d,
  0x4f5f,0x4f57,0x4f32,0x4f3d, 0x4f76,0x4f74,0x4f91,0x4f89,
  0x4f83,0x4f8f,0x4f7e,0x4f7b, 0x5115,0x4f7c,0x5102,0x4f94,
  0x5114,0x513c,0x5137,0x4fc5, 0x4fda,0x4fe3,0x4fdc,0x4fd1,
  0x4fdf,0x4ff8,0x5029,0x504c, 0x4ff3,0x502c,0x500f,0x502e,
  0x502d,0x4ffe,0x501c,0x500c, 0x5025,0x5028,0x50e8,0x5043,
  0x5055,0x5048,0x504e,0x506c, 0x50c2,0x513b,0x5110,0x513a,
  0x50ba,0x50d6,0x5106,0x50ed, 0x50ec,0x50e6,0x50ee,0x5107,
  0x510b,0x4edd,0x6c3d,0x4f58, 0x50c9,0x4fce,0x9fa0,0x6c46,
  0x7cf4,0x516e,0x5dfd,0x9ecc, 0x9998,0x56c5,0x5914,0x52f9,
  0x530d,0x8a07,0x5310,0x9cec, 0x5919,0x5155,0x4ea0,0x5156,
  0x4eb3,0x886e,0x88a4,0x893b, 0x81e0,0x88d2,0x7980,0x5b34,
  0x8803,0x7fb8,0x51ab,0x51b1, 0x51bd,0x51bc,0x51c7,0x5196,
  0x51a2,0x51a5,0x8a01,0x8a10, 0x8a0c,0x8a15,0x8b33,0x8a4e,
  0x8a25,0x8a41,0x8a36,0x8a46, 0x8a54,0x8a58,0x8a52,0x8a86,
  0x8a84,0x8a7f,0x8a70,0x8a7c, 0x8a75,0x8a6c,0x8a6e,0x8acd,
  0x8ae2,0x8a61,0x8a9a,0x8aa5, 0x8a91,0x8a92,0x8acf,0x8ad1,
  0x8ac9,0x8adb,0x8ad7,0x8ac2, 0x8ab6,0x8af6,0x8aeb,0x8b14,
  0x8b01,0x8ae4,0x8aed,0x8afc, 0x8af3,0x8ae6,0x8aee,0x8ade,
  0x8b28,0x8b9c,0x8b16,0x8b1a, 0x8b10,0x8b2b,0x8b2d,0x8b56,
  0x8b59,0x8b4e,0x8b9e,0x8b6b, 0x8b96,0x5369,0x537a,0x961d,
  0x9622,0x9621,0x9631,0x962a, 0x963d,0x963c,0x9642,0x9658,
  0x9654,0x965f,0x9689,0x966c, 0x9672,0x9674,0x9688,0x968d,
  0x9697,0x96b0,0x9097,0x909b, 0x913a,0x9099,0x9114,0x90a1,
  0x90b4,0x90b3,0x90b6,0x9134, 0x90b8,0x90b0,0x90df,0x90c5,
  0x90be,0x9136,0x90c4,0x90c7, 0x9106,0x9148,0x90e2,0x90dc,
  0x90d7,0x90db,0x90eb,0x90ef, 0x90fe,0x9104,0x9122,0x911e,
  0x9123,0x9131,0x912f,0x9139, 0x9143,0x9146,0x82bb,0x5950,
  0x52f1,0x52ac,0x52ad,0x52be, 0x54ff,0x52d0,0x52d6,0x52f0,
  0x53df,0x71ee,0x77cd,0x5ef4, 0x51f5,0x51fc,0x9b2f,0x53b6,
  0x5f01,0x755a,0x5df0,0x574c, 0x580a,0x57a1,0x587e,0x58bc,
  0x58c5,0x58d1,0x5729,0x572c, 0x572a,0x5733,0x58d9,0x572e,
  0x572f,0x58e2,0x573b,0x5742, 0x5769,0x58e0,0x576b,0x58da,
  0x577c,0x577b,0x5768,0x576d, 0x5776,0x5773,0x57e1,0x57a4,
  0x578c,0x584f,0x57cf,0x57a7, 0x5816,0x5793,0x57a0,0x57d5,
  0x5852,0x581d,0x5864,0x57d2, 0x57b8,0x57f4,0x57ef,0x57f8,
  0x57e4,0x57dd,0x580b,0x580d, 0x57fd,0x57ed,0x5800,0x581e,
  0x5819,0x5844,0x5820,0x5865, 0x586c,0x5881,0x5889,0x589a,
  0x5880,0x99a8,0x9f19,0x61ff, 0x8279,0x827d,0x827f,0x828f,
  0x828a,0x82a8,0x8284,0x828e, 0x8291,0x858c,0x8299,0x82ab,
  0x8553,0x82be,0x82b0,0x85f6, 0x82ca,0x82e3,0x8298,0x82b7,
  0x82ae,0x83a7,0x8407,0x84ef, 0x82a9,0x82b4,0x82a1,0x82aa,
  0x829f,0x82c4,0x82e7,0x82a4, 0x82e1,0x8309,0x82f7,0x82e4,
  0x8622,0x8307,0x82dc,0x82f4, 0x82d2,0x82d8,0x830c,0x82fb,
  0x82d3,0x8526,0x831a,0x8306, 0x584b,0x7162,0x82e0,0x82d5,
  0x831c,0x8351,0x8558,0x84fd, 0x8308,0x8392,0x833c,0x8334,
  0x8331,0x839b,0x854e,0x832f, 0x834f,0x8347,0x8343,0x8588,
  0x8340,0x8317,0x85ba,0x832d, 0x833a,0x8333,0x7296,0x6ece,
  0x8541,0x831b,0x85ce,0x8552, 0x84c0,0x8452,0x8464,0x83b0,
  0x8378,0x8494,0x8435,0x83a0, 0x83aa,0x8393,0x839c,0x8385,
  0x837c,0x859f,0x83a9,0x837d, 0x8555,0x837b,0x8398,0x839e,
  0x83a8,0x9daf,0x8493,0x83c1, 0x8401,0x83e5,0x83d8,0x5807,
  0x8418,0x840b,0x83dd,0x83fd, 0x83d6,0x841c,0x8438,0x8411,
  0x8406,0x83d4,0x83df,0x840f, 0x8403,0x83f8,0x83f9,0x83ea,
  0x83c5,0x83c0,0x7e08,0x83f0, 0x83e1,0x845c,0x8451,0x845a,
  0x8459,0x8473,0x8546,0x8488, 0x847a,0x8562,0x8478,0x843c,
  0x8446,0x8469,0x8476,0x851e, 0x848e,0x8431,0x846d,0x84c1,
  0x84cd,0x84d0,0x9a40,0x84bd, 0x84d3,0x84ca,0x84bf,0x84ba,
  0x863a,0x84a1,0x84b9,0x84b4, 0x8497,0x93a3,0x8577,0x850c,
  0x750d,0x8538,0x84f0,0x861e, 0x851f,0x85fa,0x8556,0x853b,
  0x84ff,0x84fc,0x8559,0x8548, 0x8568,0x8564,0x855e,0x857a,
  0x77a2,0x8543,0x8604,0x857b, 0x85a4,0x85a8,0x8587,0x858f,
  0x8579,0x85ea,0x859c,0x8585, 0x85b9,0x85b7,0x85b0,0x861a,
  0x85c1,0x85dc,0x85ff,0x8627, 0x8605,0x8629,0x8616,0x863c,
  0x5efe,0x5f08,0x593c,0x5969, 0x8037,0x5955,0x595a,0x5958,
  0x530f,0x5c22,0x5c25,0x5c2c, 0x5c37,0x624c,0x636b,0x6476,
  0x62bb,0x62ca,0x62da,0x62d7, 0x62ee,0x649f,0x62f6,0x6339,
  0x634b,0x6343,0x63ad,0x63f6, 0x6371,0x637a,0x638e,0x6451,
  0x636d,0x63ac,0x638a,0x6369, 0x63ae,0x645c,0x63f2,0x63f8,
  0x63e0,0x64b3,0x63c4,0x63de, 0x63ce,0x6452,0x63c6,0x63be,
  0x6504,0x6441,0x640b,0x641b, 0x6420,0x640c,0x6426,0x6421,
  0x645e,0x6516,0x646d,0x6496, 0x647a,0x64f7,0x64fc,0x6499,
  0x651b,0x64c0,0x64d0,0x64d7, 0x64e4,0x64e2,0x6509,0x6525,
  0x652e,0x5f0b,0x5fd2,0x7519, 0x5f11,0x535f,0x53f1,0x5630,
  0x53e9,0x53e8,0x53fb,0x5412, 0x5416,0x5406,0x544b,0x5638,
  0x56c8,0x5454,0x56a6,0x5443, 0x5421,0x5504,0x54bc,0x5423,
  0x5432,0x5482,0x5494,0x5477, 0x5471,0x5464,0x549a,0x5680,
  0x5484,0x5476,0x5466,0x565d, 0x54d0,0x54ad,0x54c2,0x54b4,
  0x5660,0x54a7,0x54a6,0x5635, 0x55f6,0x5472,0x54a3,0x5666,
  0x54bb,0x54bf,0x54cc,0x5672, 0x54da,0x568c,0x54a9,0x54aa,
  0x54a4,0x5665,0x54cf,0x54de, 0x561c,0x54e7,0x562e,0x54fd,
  0x5514,0x54f3,0x55e9,0x5523, 0x550f,0x5511,0x5527,0x552a,
  0x5616,0x558f,0x55b5,0x5549, 0x56c0,0x5541,0x5555,0x553f,
  0x5550,0x553c,0x5537,0x5556, 0x5575,0x5576,0x5577,0x5533,
  0x5530,0x555c,0x558b,0x55d2, 0x5583,0x55b1,0x55b9,0x5588,
  0x5581,0x559f,0x557e,0x55d6, 0x5591,0x557b,0x55df,0x560d,
  0x56b3,0x5594,0x5599,0x55ea, 0x55f7,0x55c9,0x561f,0x55d1,
  0x56c1,0x55ec,0x55d4,0x55e6, 0x55dd,0x55c4,0x55ef,0x55e5,
  0x55f2,0x566f,0x55cc,0x55cd, 0x55e8,0x55f5,0x55e4,0x8f61,
  0x561e,0x5608,0x560c,0x5601, 0x56b6,0x5623,0x55fe,0x5600,
  0x5627,0x562d,0x5658,0x5639, 0x5657,0x562c,0x564d,0x5662,
  0x5659,0x5695,0x564c,0x5654, 0x5686,0x5664,0x5671,0x566b,
  0x567b,0x567c,0x5685,0x5693, 0x56af,0x56d4,0x56d7,0x56dd,
  0x56e1,0x5707,0x56eb,0x56f9, 0x56ff,0x5704,0x570a,0x5709,
  0x571c,0x5e43,0x5e19,0x5e14, 0x5e11,0x5e6c,0x5e58,0x5e57,
  0x5e37,0x5e44,0x5e54,0x5e5b, 0x5e5e,0x5e61,0x5c8c,0x5c7a,
  0x5c8d,0x5c90,0x5d87,0x5c88, 0x5cf4,0x5c99,0x5c91,0x5d50,
  0x5c9c,0x5cb5,0x5ca2,0x5d2c, 0x5cac,0x5cab,0x5cb1,0x5ca3,
  0x5cc1,0x5cb7,0x5da7,0x5cd2, 0x5da0,0x5ccb,0x5d22,0x5d97,
  0x5d0d,0x5d27,0x5d26,0x5d2e, 0x5d24,0x5d1e,0x5d06,0x5d1b,
  0x5db8,0x5d3e,0x5d34,0x5d3d, 0x5d6c,0x5d5b,0x5d6f,0x5d81,
  0x5d6b,0x5d4b,0x5d4a,0x5d69, 0x5d74,0x5d82,0x5d99,0x5d9d,
  0x8c73,0x5db7,0x5dd4,0x5f73, 0x5f77,0x5f82,0x5f87,0x5f89,
  0x540e,0x5fa0,0x5f99,0x5f9c, 0x5fa8,0x5fad,0x5fb5,0x5fbc,
  0x8862,0x5f61,0x72ad,0x72b0, 0x72b4,0x7377,0x7341,0x72c3,
  0x72c1,0x72ce,0x72cd,0x72d2, 0x72e8,0x736a,0x72e9,0x733b,
  0x72f4,0x72f7,0x7301,0x72f3, 0x736b,0x72fa,0x72fb,0x7317,
  0x7313,0x7380,0x730a,0x731e, 0x731d,0x737c,0x7322,0x7339,
  0x7325,0x732c,0x7338,0x7331, 0x7350,0x734d,0x7357,0x7360,
  0x736c,0x736f,0x737e,0x821b, 0x5925,0x98e7,0x5924,0x5902,
  0x98e0,0x9933,0x98e9,0x993c, 0x98ea,0x98eb,0x98ed,0x98f4,
  0x9909,0x9911,0x4f59,0x991b, 0x9937,0x993f,0x9943,0x9948,
  0x9949,0x994a,0x994c,0x9962, 0x5e80,0x5ee1,0x5e8b,0x5e96,
  0x5ea5,0x5ea0,0x5eb9,0x5eb5, 0x5ebe,0x5eb3,0x8ce1,0x5ed2,
  0x5ed1,0x5edb,0x5ee8,0x5eea, 0x81ba,0x5fc4,0x5fc9,0x5fd6,
  0x61fa,0x61ae,0x5fee,0x616a, 0x5fe1,0x5fe4,0x613e,0x60b5,
  0x6134,0x5fea,0x5fed,0x5ff8, 0x6019,0x6035,0x6026,0x601b,
  0x600f,0x600d,0x6029,0x602b, 0x600a,0x61cc,0x6021,0x615f,
  0x61e8,0x60fb,0x6137,0x6042, 0x606a,0x60f2,0x6096,0x609a,
  0x6173,0x609d,0x6083,0x6092, 0x608c,0x609b,0x611c,0x60bb,
  0x60b1,0x60dd,0x60d8,0x60c6, 0x60da,0x60b4,0x6120,0x6192,
  0x6115,0x6123,0x60f4,0x6100, 0x610e,0x612b,0x614a,0x6175,
  0x61ac,0x6194,0x61a7,0x61b7, 0x61d4,0x61f5,0x5fdd,0x96b3,
  0x9582,0x9586,0x95c8,0x958e, 0x9594,0x958c,0x95e5,0x95ad,
  0x95ab,0x9b2e,0x95ac,0x95be, 0x95b6,0x9b29,0x95bf,0x95bd,
  0x95bc,0x95c3,0x95cb,0x95d4, 0x95d0,0x95d5,0x95de,0x4e2c,
  0x723f,0x6215,0x6c35,0x6c54, 0x6c5c,0x6c4a,0x7043,0x6c85,
  0x6c90,0x6c94,0x6c8c,0x6c68, 0x6c69,0x6c74,0x6c76,0x6c86,
  0x6f59,0x6cd0,0x6cd4,0x6cad, 0x7027,0x7018,0x6cf1,0x6cd7,
  0x6cb2,0x6ce0,0x6cd6,0x6ffc, 0x6ceb,0x6cee,0x6cb1,0x6cd3,
  0x6cef,0x6d87,0x6d39,0x6d27, 0x6d0c,0x6d79,0x6e5e,0x6d07,
  0x6d04,0x6d19,0x6d0e,0x6d2b, 0x6fae,0x6d2e,0x6d35,0x6d1a,
  0x700f,0x6ef8,0x6f6f,0x6d33, 0x6d91,0x6d6f,0x6df6,0x6f7f,
  0x6d5e,0x6d93,0x6d94,0x6d5c, 0x6d60,0x6d7c,0x6d63,0x6e1a,
  0x6dc7,0x6dc5,0x6dde,0x7006, 0x6dbf,0x6de0,0x6fa0,0x6de6,
  0x6ddd,0x6dd9,0x700b,0x6dab, 0x6e0c,0x6dae,0x6e2b,0x6e6e,
  0x6e4e,0x6e6b,0x6eb2,0x6e5f, 0x6e86,0x6e53,0x6e54,0x6e32,
  0x6e25,0x6e44,0x7067,0x6eb1, 0x6e98,0x7044,0x6f2d,0x7005,
  0x6ea5,0x6ea7,0x6ebd,0x6ebb, 0x6eb7,0x6f77,0x6eb4,0x6ecf,
  0x6e8f,0x6ec2,0x6e9f,0x6f62, 0x7020,0x701f,0x6f24,0x6f15,
  0x6ef9,0x6f2f,0x6f36,0x7032, 0x6f74,0x6f2a,0x6f09,0x6f29,
  0x6f89,0x6f8d,0x6f8c,0x6f78, 0x6f72,0x6f7c,0x6f7a,0x7028,
  0x6fc9,0x6fa7,0x6fb9,0x6fb6, 0x6fc2,0x6fe1,0x6fee,0x6fde,
  0x6fe0,0x6fef,0x701a,0x7023, 0x701b,0x7039,0x7035,0x705d,
  0x705e,0x5b80,0x5b84,0x5b95, 0x5b93,0x5ba5,0x5bb8,0x752f,
  0x9a2b,0x6434,0x5be4,0x5bee, 0x8930,0x5bf0,0x8e47,0x8b07,
  0x8fb6,0x8fd3,0x8fd5,0x8fe5, 0x8fee,0x8fe4,0x9087,0x8fe6,
  0x9015,0x8fe8,0x9005,0x9004, 0x900b,0x9090,0x9011,0x900d,
  0x9016,0x9021,0x9035,0x9036, 0x902d,0x902f,0x9044,0x9051,
  0x9052,0x9050,0x9068,0x9058, 0x9062,0x905b,0x66b9,0x9074,
  0x907d,0x9082,0x9088,0x9083, 0x908b,0x5f50,0x5f57,0x5f56,
  0x5f58,0x5c3b,0x54ab,0x5c50, 0x5c59,0x5b71,0x5c63,0x5c68,
  0x7fbc,0x5f33,0x5f29,0x5f2d, 0x8274,0x5f3c,0x9b3b,0x5c6e,
  0x5981,0x5983,0x598d,0x5af5, 0x5ad7,0x59a3,0x5997,0x59ca,
  0x5b00,0x599e,0x59a4,0x59d2, 0x59b2,0x59af,0x59d7,0x59be,
  0x5a6d,0x5b08,0x59dd,0x5b4c, 0x59e3,0x59d8,0x59f9,0x5a0c,
  0x5a09,0x5aa7,0x5afb,0x5a11, 0x5a23,0x5a13,0x5a40,0x5a67,
  0x5a4a,0x5a55,0x5a3c,0x5a62, 0x5b0b,0x80ec,0x5aaa,0x5a9b,
  0x5a77,0x5a7a,0x5abe,0x5aeb, 0x5ab2,0x5b21,0x5b2a,0x5ab8,
  0x5ae0,0x5ae3,0x5b19,0x5ad6, 0x5ae6,0x5ad8,0x5adc,0x5b09,
  0x5b17,0x5b16,0x5b32,0x5b37, 0x5b40,0x5c15,0x5c1c,0x5b5a,
  0x5b65,0x5b73,0x5b51,0x5b53, 0x5b62,0x99d4,0x99df,0x99d9,
  0x9a36,0x9a5b,0x99d1,0x99d8, 0x9a4d,0x9a4a,0x99e2,0x9a6a,
  0x9a0f,0x9a0d,0x9a05,0x9a42, 0x9a2d,0x9a16,0x9a41,0x9a2e,
  0x9a38,0x9a43,0x9a44,0x9a4f, 0x9a65,0x9a64,0x7cf9,0x7d06,
  0x7d02,0x7d07,0x7d08,0x7e8a, 0x7d1c,0x7d15,0x7d13,0x7d3a,
  0x7d32,0x7d31,0x7e10,0x7d3c, 0x7d40,0x7d3f,0x7d5d,0x7d4e,
  0x7d73,0x7d86,0x7d83,0x7d88, 0x7dbe,0x7dba,0x7dcb,0x7dd4,
  0x7dc4,0x7d9e,0x7dac,0x7db9, 0x7da3,0x7db0,0x7dc7,0x7dd9,
  0x7dd7,0x7df9,0x7df2,0x7e62, 0x7de6,0x7df6,0x7df1,0x7e0b,
  0x7de1,0x7e09,0x7e1d,0x7e1f, 0x7e1e,0x7e2d,0x7e0a,0x7e11,
  0x7e7d,0x7e39,0x7e35,0x7e32, 0x7e46,0x7e45,0x7e88,0x7e5a,
  0x7e52,0x7e6e,0x7e7e,0x7e70, 0x7e6f,0x7e98,0x5e7a,0x757f,
  0x5ddb,0x753e,0x9095,0x738e, 0x74a3,0x744b,0x73a2,0x739f,
  0x73cf,0x73c2,0x74cf,0x73b7, 0x73b3,0x73c0,0x73c9,0x73c8,
  0x73e5,0x73d9,0x980a,0x740a, 0x73e9,0x73e7,0x73de,0x74bd,
  0x743f,0x7489,0x742a,0x745b, 0x7426,0x7425,0x7428,0x7430,
  0x742e,0x742c,0x741b,0x741a, 0x7441,0x745c,0x7457,0x7455,
  0x7459,0x74a6,0x746d,0x747e, 0x749c,0x74d4,0x7480,0x7481,
  0x7487,0x748b,0x749e,0x74a8, 0x74a9,0x7490,0x74a7,0x74da,
  0x74ba,0x97d9,0x97de,0x97dc, 0x674c,0x6753,0x675e,0x6748,
  0x69aa,0x6aea,0x6787,0x676a, 0x6773,0x6798,0x6898,0x6775,
  0x68d6,0x6a05,0x689f,0x678b, 0x6777,0x677c,0x67f0,0x6adb,
  0x67d8,0x6af3,0x67e9,0x67b0, 0x6ae8,0x67d9,0x67b5,0x67da,
  0x67b3,0x67dd,0x6800,0x67c3, 0x67b8,0x67e2,0x6adf,0x67c1,
  0x6a89,0x6832,0x6833,0x690f, 0x6a48,0x684e,0x6968,0x6844,
  0x69bf,0x6883,0x681d,0x6855, 0x6a3a,0x6841,0x6a9c,0x6840,
  0x6b12,0x684a,0x6849,0x6829, 0x68b5,0x688f,0x6874,0x6877,
  0x6893,0x686b,0x6b1e,0x696e, 0x68fc,0x6add,0x69e7,0x68f9,
  0x6b0f,0x68f0,0x690b,0x6901, 0x6957,0x68e3,0x6910,0x6971,
  0x6939,0x6960,0x6942,0x695d, 0x6b16,0x696b,0x6980,0x6998,
  0x6978,0x6934,0x69cc,0x6aec, 0x6ada,0x69ce,0x6af8,0x6966,
  0x6963,0x6979,0x699b,0x69a7, 0x69bb,0x69ab,0x69ad,0x69d4,
  0x69b1,0x69c1,0x69ca,0x6ab3, 0x6995,0x6ae7,0x698d,0x69ff,
  0x6aa3,0x69ed,0x6a17,0x6a18, 0x6a65,0x69f2,0x6a44,0x6a3e,
  0x6aa0,0x6a50,0x6a5b,0x6a35, 0x6a8e,0x6ad3,0x6a3d,0x6a28,
  0x6a58,0x6ade,0x6a91,0x6a90, 0x6aa9,0x6a97,0x6aab,0x7337,
  0x7352,0x6b81,0x6b82,0x6ba4, 0x6b84,0x6b9e,0x6bae,0x6b8d,
  0x6bab,0x6b9b,0x6baf,0x6baa, 0x8ed4,0x8edb,0x8ef2,0x8efb,
  0x8f64,0x8ef9,0x8efc,0x8eeb, 0x8ee4,0x8f62,0x8efa,0x8efe,
  0x8f0a,0x8f07,0x8f05,0x8f12, 0x8f26,0x8f1e,0x8f1f,0x8f1c,
  0x8f33,0x8f46,0x8f54,0x8ece, 0x6214,0x6227,0x621b,0x621f,
  0x6222,0x6221,0x6225,0x6224, 0x6229,0x81e7,0x750c,0x74f4,
  0x74ff,0x750f,0x7511,0x7513, 0x6534,0x65ee,0x65ef,0x65f0,
  0x660a,0x66c7,0x6772,0x6603, 0x6615,0x6600,0x7085,0x66f7,
  0x661d,0x6634,0x6631,0x6636, 0x6635,0x8006,0x665f,0x66c4,
  0x6641,0x664f,0x6689,0x6661, 0x6657,0x6677,0x6684,0x668c,
  0x66d6,0x669d,0x66be,0x66db, 0x66dc,0x66e6,0x66e9,0x8cc1,
  0x8cb0,0x8cba,0x8cbd,0x8d04, 0x8cb2,0x8cc5,0x8d10,0x8cd1,
  0x8cda,0x8cd5,0x8ceb,0x8ce7, 0x8cfb,0x8998,0x89ac,0x89a1,
  0x89bf,0x89a6,0x89af,0x89b2, 0x89b7,0x726e,0x729f,0x725d,
  0x7266,0x726f,0x727e,0x727f, 0x7284,0x728b,0x728d,0x728f,
  0x7292,0x6308,0x6332,0x63b0, 0x643f,0x64d8,0x8004,0x6bea,
  0x6bf3,0x6bfd,0x6bff,0x6bf9, 0x6c05,0x6c0c,0x6c06,0x6c0d,
  0x6c15,0x6c18,0x6c19,0x6c1a, 0x6c21,0x6c2c,0x6c24,0x6c2a,
  0x6c32,0x6535,0x6555,0x656b, 0x7258,0x7252,0x7256,0x7230,
  0x8662,0x5216,0x809f,0x809c, 0x8093,0x80bc,0x670a,0x80bd,
  0x80b1,0x80ab,0x80ad,0x80b4, 0x80b7,0x6727,0x8156,0x80e9,
  0x81da,0x80db,0x80c2,0x80c4, 0x80d9,0x80cd,0x80d7,0x6710,
  0x80dd,0x811b,0x80f1,0x80f4, 0x80ed,0x81be,0x810e,0x80f2,
  0x80fc,0x6715,0x8112,0x8c5a, 0x8161,0x811e,0x812c,0x8118,
  0x8132,0x8148,0x814c,0x8153, 0x8174,0x8159,0x815a,0x8171,
  0x8160,0x8169,0x817c,0x817d, 0x816d,0x8167,0x584d,0x5ab5,
  0x8188,0x8182,0x81cf,0x6ed5, 0x81a3,0x81aa,0x81cc,0x6726,
  0x81ca,0x81bb,0x81c1,0x81a6, 0x6b5f,0x6b37,0x6b39,0x6b43,
  0x6b46,0x6b59,0x98ae,0x98af, 0x98b6,0x98bc,0x98c6,0x98c8,
  0x6bb3,0x5f40,0x8f42,0x89f3, 0x6590,0x9f4f,0x6595,0x65bc,
  0x65c6,0x65c4,0x65c3,0x65cc, 0x65ce,0x65d2,0x65d6,0x716c,
  0x7152,0x7096,0x7197,0x70bb, 0x70c0,0x70b7,0x70ab,0x70b1,
  0x71c1,0x70ca,0x7110,0x7113, 0x71dc,0x712f,0x7131,0x7173,
  0x715c,0x7168,0x7145,0x7172, 0x714a,0x7178,0x717a,0x7198,
  0x71b3,0x71b5,0x71a8,0x71a0, 0x71e0,0x71d4,0x71e7,0x71f9,
  0x721d,0x7228,0x706c,0x71fe, 0x7166,0x71b9,0x623e,0x623d,
  0x6243,0x6248,0x6249,0x793b, 0x7940,0x7946,0x7949,0x795b,
  0x795c,0x7953,0x795a,0x79b0, 0x7957,0x7960,0x798e,0x7967,
  0x797a,0x79aa,0x798a,0x799a, 0x79a7,0x79b3,0x5fd1,0x5fd0,
  0x61df,0x605d,0x605a,0x6067, 0x6041,0x6059,0x6063,0x6164,
  0x6106,0x610d,0x615d,0x61a9, 0x619d,0x61cb,0x61e3,0x6207,
  0x8080,0x807f,0x6c93,0x6fa9, 0x6dfc,0x78ef,0x77f8,0x78ad,
  0x7809,0x7868,0x7818,0x7811, 0x65ab,0x782d,0x78b8,0x781d,
  0x7839,0x792a,0x7931,0x781f, 0x783c,0x7825,0x782c,0x7823,
  0x7829,0x784e,0x786d,0x7864, 0x78fd,0x7826,0x7850,0x7847,
  0x784c,0x786a,0x78e7,0x7893, 0x789a,0x7887,0x78e3,0x78a1,
  0x78a3,0x78b2,0x78b9,0x78a5, 0x78d4,0x78d9,0x78c9,0x78ec,
  0x78f2,0x7905,0x78f4,0x7913, 0x7924,0x791e,0x7934,0x9f95,
  0x9ef9,0x9efb,0x9efc,0x76f1, 0x7704,0x7798,0x76f9,0x7707,
  0x7708,0x771a,0x7722,0x7719, 0x772d,0x7726,0x7735,0x7738,
  0x775e,0x77bc,0x7747,0x7743, 0x775a,0x7768,0x7762,0x7765,
  0x777f,0x778d,0x777d,0x7780, 0x778c,0x7791,0x779f,0x77a0,
  0x77b0,0x77b5,0x77bd,0x753a, 0x7540,0x754e,0x754b,0x7548,
  0x755b,0x7572,0x7579,0x7583, 0x7f58,0x7f61,0x7f5f,0x8a48,
  0x7f68,0x7f86,0x7f71,0x7f79, 0x7f88,0x7f7e,0x76cd,0x76e5,
  0x8832,0x91d2,0x91d3,0x91d4, 0x91d9,0x91d7,0x91d5,0x91f7,
  0x91e7,0x91e4,0x9346,0x91f5, 0x91f9,0x9208,0x9226,0x9245,
  0x9211,0x9210,0x9201,0x9227, 0x9204,0x9225,0x9200,0x923a,
  0x9266,0x9237,0x9233,0x9255, 0x923d,0x9238,0x925e,0x926c,
  0x926d,0x923f,0x9460,0x9230, 0x9249,0x9248,0x924d,0x922e,
  0x9239,0x9438,0x92ac,0x92a0, 0x927a,0x92aa,0x92ee,0x92cf,
  0x9403,0x92e3,0x943a,0x92b1, 0x92a6,0x93a7,0x9296,0x92cc,
  0x92a9,0x93f5,0x9293,0x927f, 0x93a9,0x929a,0x931a,0x92ab,
  0x9283,0x940b,0x92a8,0x92a3, 0x9412,0x9338,0x92f1,0x93d7,
  0x92e5,0x92f0,0x92ef,0x92e8, 0x92bc,0x92dd,0x92f6,0x9426,
  0x9427,0x92c3,0x92df,0x92e6, 0x9312,0x9306,0x9369,0x931b,
  0x9340,0x9301,0x9315,0x932e, 0x9343,0x9307,0x9308,0x931f,
  0x9319,0x9365,0x9347,0x9376, 0x9354,0x9364,0x93aa,0x9370,
  0x9384,0x93e4,0x93d8,0x9428, 0x9387,0x93cc,0x9398,0x93b8,
  0x93bf,0x93a6,0x93b0,0x93b5, 0x944c,0x93e2,0x93dc,0x93dd,
  0x93cd,0x93de,0x93c3,0x93c7, 0x93d1,0x9414,0x941d,0x93f7,
  0x9465,0x9413,0x946d,0x9420, 0x9479,0x93f9,0x9419,0x944a,
  0x9432,0x943f,0x9454,0x9463, 0x937e,0x77e7,0x77ec,0x96c9,
  0x79d5,0x79ed,0x79e3,0x79eb, 0x7a06,0x5d47,0x7a03,0x7a02,
  0x7a1e,0x7a14,0x7a39,0x7a37, 0x7a61,0x9ecf,0x99a5,0x7a70,
  0x7688,0x768e,0x7693,0x7699, 0x76a4,0x74de,0x74e0,0x752c,
  0x9ce9,0x9cf6,0x9d07,0x9d06, 0x9d23,0x9d87,0x9e15,0x9d1d,
  0x9d1f,0x9de5,0x9d2f,0x9dd9, 0x9d30,0x9d42,0x9e1e,0x9d53,
  0x9e1d,0x9d60,0x9d52,0x9df3, 0x9d5c,0x9d61,0x9d93,0x9d6a,
  0x9d6f,0x9d89,0x9d98,0x9d9a, 0x9dc0,0x9da5,0x9da9,0x9dc2,
  0x9dbc,0x9e1a,0x9dd3,0x9dda, 0x9def,0x9de6,0x9df2,0x9df8,
  0x9e0c,0x9dfa,0x9e1b,0x7592, 0x7594,0x7664,0x7658,0x759d,
  0x7667,0x75a3,0x75b3,0x75b4, 0x75b8,0x75c4,0x75b1,0x75b0,
  0x75c3,0x75c2,0x7602,0x75cd, 0x75e3,0x7646,0x75e6,0x75e4,
  0x7647,0x75e7,0x7603,0x75f1, 0x75fc,0x75ff,0x7610,0x7600,
  0x7649,0x760c,0x761e,0x760a, 0x7625,0x763b,0x7615,0x7619,
  0x761b,0x763c,0x7622,0x7620, 0x7640,0x762d,0x7630,0x766d,
  0x7635,0x7643,0x766e,0x7633, 0x764d,0x7669,0x7654,0x765c,
  0x7656,0x7672,0x766f,0x7fca, 0x7ae6,0x7a78,0x7a79,0x7a80,
  0x7a86,0x7a88,0x7a95,0x7ac7, 0x7aa0,0x7aac,0x7aa8,0x7ab6,
  0x7ab3,0x8864,0x8869,0x8872, 0x887d,0x887f,0x8882,0x88a2,
  0x8960,0x88b7,0x88bc,0x88c9, 0x8933,0x88ce,0x895d,0x8947,
  0x88f1,0x891a,0x88fc,0x88e8, 0x88fe,0x88f0,0x8921,0x8919,
  0x8913,0x8938,0x890a,0x8964, 0x892b,0x8936,0x8941,0x8966,
  0x897b,0x758b,0x80e5,0x76b8, 0x76b4,0x77dc,0x8012,0x8014,
  0x8016,0x801c,0x8020,0x802e, 0x8025,0x8026,0x802c,0x8029,
  0x8028,0x8031,0x800b,0x8035, 0x8043,0x8046,0x8079,0x8052,
  0x8075,0x8071,0x8983,0x9807, 0x980e,0x980f,0x9821,0x981c,
  0x6f41,0x9826,0x9837,0x984e, 0x9853,0x9873,0x9862,0x9859,
  0x9865,0x986c,0x9870,0x864d, 0x8654,0x866c,0x87e3,0x8806,
  0x867a,0x867c,0x867b,0x86a8, 0x868d,0x868b,0x8706,0x869d,
  0x86a7,0x86a3,0x86aa,0x8693, 0x86a9,0x86b6,0x86c4,0x86b5,
  0x8823,0x86b0,0x86ba,0x86b1, 0x86af,0x86c9,0x87f6,0x86b4,
  0x86e9,0x86fa,0x87ef,0x86ed, 0x8784,0x86d0,0x8713,0x86de,
  0x8810,0x86df,0x86d8,0x86d1, 0x8703,0x8707,0x86f8,0x8708,
  0x870a,0x870d,0x8709,0x8723, 0x873b,0x871e,0x8725,0x872e,
  0x871a,0x873e,0x87c8,0x8734, 0x8731,0x8729,0x8737,0x873f,
  0x8782,0x8722,0x877d,0x8811, 0x877b,0x8760,0x8770,0x874c,
  0x876e,0x878b,0x8753,0x8763, 0x87bb,0x8764,0x8759,0x8765,
  0x8793,0x87af,0x87ce,0x87d2, 0x87c6,0x8788,0x8785,0x87ad,
  0x8797,0x8783,0x87ab,0x87e5, 0x87ac,0x87b5,0x87b3,0x87cb,
  0x87d3,0x87bd,0x87d1,0x87c0, 0x87ca,0x87db,0x87ea,0x87e0,
  0x87ee,0x8816,0x8813,0x87fe, 0x880a,0x881b,0x8821,0x8839,
  0x883c,0x7f36,0x7f4c,0x7f44, 0x7f45,0x8210,0x7afa,0x7afd,
  0x7b08,0x7be4,0x7b04,0x7b67, 0x7b0a,0x7b2b,0x7b0f,0x7b47,
  0x7b38,0x7b2a,0x7b19,0x7b2e, 0x7b31,0x7b20,0x7b25,0x7b24,
  0x7b33,0x7c69,0x7b1e,0x7b58, 0x7bf3,0x7b45,0x7b75,0x7b4c,
  0x7b8f,0x7b60,0x7b6e,0x7b7b, 0x7b62,0x7b72,0x7b71,0x7b90,
  0x7c00,0x7bcb,0x7bb8,0x7bac, 0x7b9d,0x7c5c,0x7b85,0x7c1e,
  0x7b9c,0x7ba2,0x7c2b,0x7bb4, 0x7c23,0x7bc1,0x7bcc,0x7bdd,
  0x7bda,0x7be5,0x7be6,0x7bea, 0x7c0c,0x7bfe,0x7bfc,0x7c0f,
  0x7c6a,0x7c0b,0x7c1f,0x7c2a, 0x7c26,0x7c38,0x7c5f,0x7c40,
  0x81fe,0x8201,0x8202,0x8204, 0x81ec,0x8844,0x8221,0x8222,
  0x8264,0x822d,0x822f,0x8228, 0x822b,0x8238,0x826b,0x8233,
  0x8234,0x823e,0x8244,0x8249, 0x824b,0x824f,0x825a,0x825f,
  0x8268,0x887e,0x88ca,0x8888, 0x88d8,0x88df,0x895e,0x7f9d,
  0x7fa5,0x7fa7,0x7faf,0x7fb0, 0x7fb2,0x7c7c,0x6549,0x7c91,
  0x7cf2,0x7cf6,0x7c9e,0x7ca2, 0x7cb2,0x7cbc,0x7cbd,0x7cdd,
  0x7cc7,0x7ccc,0x7ccd,0x7cc8, 0x7cc5,0x7cd7,0x7ce8,0x826e,
  0x66a8,0x7fbf,0x7fce,0x7fd5, 0x7fe5,0x7fe1,0x7fe6,0x7fe9,
  0x7fee,0x7ff3,0x7cf8,0x7e36, 0x7da6,0x7dae,0x7e47,0x7e9b,
  0x9ea9,0x9eb4,0x8d73,0x8d84, 0x8d94,0x8d91,0x8db2,0x8d67,
  0x8d6d,0x8c47,0x8c49,0x914a, 0x9150,0x914e,0x914f,0x9164,
  0x9162,0x9161,0x9170,0x9169, 0x916f,0x91c5,0x91c3,0x9172,
  0x9174,0x9179,0x918c,0x9185, 0x9190,0x918d,0x9191,0x91a2,
  0x91a3,0x91aa,0x91ad,0x91ae, 0x91af,0x91b5,0x91b4,0x91ba,
  0x8c55,0x9e7a,0x8e89,0x8deb, 0x8e05,0x8e59,0x8e69,0x8db5,
  0x8dbf,0x8dbc,0x8dba,0x8e4c, 0x8dd6,0x8dd7,0x8dda,0x8e92,
  0x8dce,0x8dcf,0x8ddb,0x8dc6, 0x8dec,0x8e7a,0x8e55,0x8de3,
  0x8e9a,0x8e8b,0x8de4,0x8e09, 0x8dfd,0x8e14,0x8e1d,0x8e1f,
  0x8e93,0x8e2e,0x8e23,0x8e91, 0x8e3a,0x8e40,0x8e39,0x8e35,
  0x8e3d,0x8e31,0x8e49,0x8e41, 0x8e42,0x8ea1,0x8e63,0x8e4a,
  0x8e70,0x8e76,0x8e7c,0x8e6f, 0x8e74,0x8e85,0x8eaa,0x8e94,
  0x8e90,0x8ea6,0x8e9e,0x8c78, 0x8c82,0x8c8a,0x8c85,0x8c98,
  0x8c94,0x659b,0x89d6,0x89f4, 0x89da,0x89dc,0x89e5,0x89eb,
  0x89f6,0x8a3e,0x8b26,0x975a, 0x96e9,0x9742,0x96ef,0x9706,
  0x973d,0x9708,0x970f,0x970e, 0x972a,0x9744,0x9730,0x973e,
  0x9f54,0x9f5f,0x9f59,0x9f60, 0x9f5c,0x9f66,0x9f6c,0x9f6a,
  0x9f77,0x9efd,0x9eff,0x9f09, 0x96b9,0x96bc,0x96bd,0x96ce,
  0x96d2,0x77bf,0x8b8e,0x928e, 0x947e,0x92c8,0x93e8,0x936a,
  0x93ca,0x938f,0x943e,0x946b, 0x9b77,0x9b74,0x9b81,0x9b83,
  0x9b8e,0x9c78,0x7a4c,0x9b92, 0x9c5f,0x9b90,0x9bad,0x9b9a,
  0x9baa,0x9b9e,0x9c6d,0x9bab, 0x9b9d,0x9c58,0x9bc1,0x9c7a,
  0x9c31,0x9c39,0x9c23,0x9c37, 0x9bc0,0x9bca,0x9bc7,0x9bfd,
  0x9bd6,0x9bea,0x9beb,0x9be1, 0x9be4,0x9be7,0x9bdd,0x9be2,
  0x9bf0,0x9bdb,0x9bf4,0x9bd4, 0x9c5d,0x9c08,0x9c10,0x9c0d,
  0x9c12,0x9c09,0x9bff,0x9c20, 0x9c32,0x9c2d,0x9c28,0x9c25,
  0x9c29,0x9c33,0x9c3e,0x9c48, 0x9c3b,0x9c35,0x9c45,0x9c56,
  0x9c54,0x9c52,0x9c67,0x977c, 0x9785,0x97c3,0x97bd,0x9794,
  0x97c9,0x97ab,0x97a3,0x97b2, 0x97b4,0x9ab1,0x9ab0,0x9ab7,
  0x9dbb,0x9ab6,0x9aba,0x9abc, 0x9ac1,0x9ac0,0x9acf,0x9ac2,
  0x9ad6,0x9ad5,0x9ad1,0x9b45, 0x9b43,0x9b58,0x9b4e,0x9b48,
  0x9b4d,0x9b51,0x9957,0x995c, 0x992e,0x9955,0x9954,0x9adf,
  0x9ae1,0x9ae6,0x9aef,0x9aeb, 0x9afb,0x9aed,0x9af9,0x9b08,
  0x9b0f,0x9b22,0x9b1f,0x9b23, 0x4e48,0x9ebe,0x7e3b,0x9e82,
  0x9e87,0x9e88,0x9e8b,0x9e92, 0x93d6,0x9e9d,0x9e9f,0x9edb,
  0x9edc,0x9edd,0x9ee0,0x9edf, 0x9ee2,0x9ef7,0x9ee7,0x9ee5,
  0x9ef2,0x9eef,0x9f22,0x9f2c, 0x9f2f,0x9f39,0x9f37,0x9f3d,
  0x9f3e,0x9f44,0x896c,0x95c6, 0x9336,0x5f46,0x8514,0x7e94,
  0x5382,0x51b2,0x4e11,0x9f63, 0x5679,0x515a,0x6dc0,0x9f15,
  0x6597,0x5641,0x9aee,0x8303, 0x4e30,0x8907,0x5e72,0x7a40,
  0x98b3,0x5e7f,0x95a4,0x9b0d, 0x5212,0x8ff4,0x5f59,0x7a6b,
  0x98e2,0x51e0,0x50a2,0x4ef7, 0x8350,0x8591,0x5118,0x636e,
  0x6372,0x524b,0x5938,0x774f, 0x8721,0x814a,0x7e8d,0x91cc,
  0x66c6,0x5e18,0x77ad,0x9e75, 0x56c9,0x9ef4,0x6fdb,0x61de,
  0x77c7,0x7030,0x9eb5,0x884a, 0x95e2,0x82f9,0x51ed,0x6251,
  0x4ec6,0x6734,0x97c6,0x7c64, 0x7e34,0x97a6,0x9eaf,0x786e,
  0x820d,0x672f,0x677e,0x56cc, 0x53f0,0x98b1,0x6aaf,0x7f4e,
  0x6d82,0x7cf0,0x4e07,0x4fc2, 0x7e6b,0x9e79,0x56ae,0x9b1a,
  0x846f,0x53f6,0x90c1,0x79a6, 0x7c72,0x613f,0x4e91,0x9ad2,
  0x75c7,0x96bb,0x53ea,0x7dfb, 0x88fd,0x79cd,0x7843,0x7b51,
  0x51c6,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000
};

/* codelimit: 16732 */
/* Note that this table represents BIG5, not BIG5 plus */
unsigned short big5_uni_byte[BIG5_TBL_LEN] = {
/* a100 */
  0x3000,0xff0c,0x3001,0x3002, 0xff0e,0x2022,0xff1b,0xff1a,
  0xff1f,0xff01,0xfe30,0x2026, 0x2025,0xfe50,0xff64,0xfe52,
  0x00b7,0xfe54,0xfe55,0xfe56, 0xfe57,0xff5c,0x2013,0xfe31,
  0x2014,0xfe33,0x2015,0xfe34, 0xfe4f,0xff08,0xff09,0xfe35,
  0xfe36,0xff5b,0xff5d,0xfe37, 0xfe38,0x3014,0x3015,0xfe39,
  0xfe3a,0x3010,0x3011,0xfe3b, 0xfe3c,0x300a,0x300b,0xfe3d,
  0xfe3e,0x3008,0x3009,0xfe3f, 0xfe40,0x300c,0x300d,0xfe41,
  0xfe42,0x300e,0x300f,0xfe43, 0xfe44,0xfe59,0xfe5a,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xfe5b,0xfe5c,0xfe5d,0xfe5e, 0x2018,0x2019,0x201c,0x201d,
  0x301d,0x301e,0x2035,0x2032, 0xff03,0xff06,0xff0a,0x203b,
  0x00a7,0x3003,0x25cb,0x25cf, 0x25b3,0x25b2,0x25ce,0x2606,
  0x2605,0x25c7,0x25c6,0x25a1, 0x25a0,0x25bd,0x25bc,0x32a3,
  0x2105,0x203e,0xffe3,0xff3f, 0x02cd,0xfe49,0xfe4a,0xfe4d,
  0xfe4e,0xfe4b,0xfe4c,0xfe5f, 0xfe60,0xfe61,0xff0b,0xff0d,
  0x00d7,0x00f7,0x00b1,0x221a, 0xff1c,0xff1e,0xff1d,0x2266,
  0x2267,0x2260,0x221e,0x2252, 0x2261,0xfe62,0xfe63,0xfe64,
  0xfe65,0xfe66,0x223c,0x2229, 0x222a,0x22a5,0x2220,0x221f,
  0x22bf,0x33d2,0x33d1,0x222b, 0x222e,0x2235,0x2234,0x2640,
  0x2642,0x2641,0x2609,0x2191, 0x2193,0x2190,0x2192,0x2196,
  0x2197,0x2199,0x2198,0x2225, 0x2223,0x2215,
/* a200 */
  0x2216,0xff0f,0xff3c,0xff04, 0xffe5,0x3012,0xffe0,0xffe1,
  0xff05,0xff20,0x2103,0x2109, 0xfe69,0xfe6a,0xfe6b,0x33d5,
  0x339c,0x339d,0x339e,0x33ce, 0x33a1,0x338e,0x338f,0x33c4,
  0x00b0,0x5159,0x515b,0x515e, 0x515d,0x5161,0x5163,0x55e7,
  0x74e9,0x7cce,0x2581,0x2582, 0x2583,0x2584,0x2585,0x2586,
  0x2587,0x2588,0x258f,0x258e, 0x258d,0x258c,0x258b,0x258a,
  0x2589,0x253c,0x2534,0x252c, 0x2524,0x251c,0x2594,0x2500,
  0x2502,0x2595,0x250c,0x2510, 0x2514,0x2518,0x256d,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x256e,0x2570,0x256f,0x2550, 0x255e,0x256a,0x2561,0x25e2,
  0x25e3,0x25e5,0x25e4,0x2571, 0x2572,0x2573,0xff10,0xff11,
  0xff12,0xff13,0xff14,0xff15, 0xff16,0xff17,0xff18,0xff19,
  0x2160,0x2161,0x2162,0x2163, 0x2164,0x2165,0x2166,0x2167,
  0x2168,0x2169,0x3021,0x3022, 0x3023,0x3024,0x3025,0x3026,
  0x3027,0x3028,0x3029,0x3038, 0x5344,0x303a,0xff21,0xff22,
  0xff23,0xff24,0xff25,0xff26, 0xff27,0xff28,0xff29,0xff2a,
  0xff2b,0xff2c,0xff2d,0xff2e, 0xff2f,0xff30,0xff31,0xff32,
  0xff33,0xff34,0xff35,0xff36, 0xff37,0xff38,0xff39,0xff3a,
  0xff41,0xff42,0xff43,0xff44, 0xff45,0xff46,0xff47,0xff48,
  0xff49,0xff4a,0xff4b,0xff4c, 0xff4d,0xff4e,0xff4f,0xff50,
  0xff51,0xff52,0xff53,0xff54, 0xff55,0xff56,
/* a300 */
  0xff57,0xff58,0xff59,0xff5a, 0x0391,0x0392,0x0393,0x0394,
  0x0395,0x0396,0x0397,0x0398, 0x0399,0x039a,0x039b,0x039c,
  0x039d,0x039e,0x039f,0x03a0, 0x03a1,0x03a3,0x03a4,0x03a5,
  0x03a6,0x03a7,0x03a8,0x03a9, 0x03b1,0x03b2,0x03b3,0x03b4,
  0x03b5,0x03b6,0x03b7,0x03b8, 0x03b9,0x03ba,0x03bb,0x03bc,
  0x03bd,0x03be,0x03bf,0x03c0, 0x03c1,0x03c3,0x03c4,0x03c5,
  0x03c6,0x03c7,0x03c8,0x03c9, 0x3105,0x3106,0x3107,0x3108,
  0x3109,0x310a,0x310b,0x310c, 0x310d,0x310e,0x310f,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x3110,0x3111,0x3112,0x3113, 0x3114,0x3115,0x3116,0x3117,
  0x3118,0x3119,0x311a,0x311b, 0x311c,0x311d,0x311e,0x311f,
  0x3120,0x3121,0x3122,0x3123, 0x3124,0x3125,0x3126,0x3127,
  0x3128,0x3129,0x02d9,0x02c9, 0x02ca,0x02c7,0x02cb,0x2400,
  0x2401,0x2402,0x2403,0x2404, 0x2405,0x2406,0x2407,0x2408,
  0x2409,0x240a,0x240b,0x240c, 0x240d,0x240e,0x240f,0x2410,
  0x2411,0x2412,0x2413,0x2414, 0x2415,0x2416,0x2417,0x2418,
  0x2419,0x241a,0x241b,0x241c, 0x241d,0x241e,0x241f,0x2421,
  0x20ac,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* a400 */
  0x4e00,0x4e59,0x4e01,0x4e03, 0x4e43,0x4e5d,0x4e86,0x4e8c,
  0x4eba,0x513f,0x5165,0x516b, 0x51e0,0x5200,0x5201,0x529b,
  0x5315,0x5341,0x535c,0x53c8, 0x4e09,0x4e0b,0x4e08,0x4e0a,
  0x4e2b,0x4e38,0x51e1,0x4e45, 0x4e48,0x4e5f,0x4e5e,0x4e8e,
  0x4ea1,0x5140,0x5203,0x52fa, 0x5343,0x53c9,0x53e3,0x571f,
  0x58eb,0x5915,0x5927,0x5973, 0x5b50,0x5b51,0x5b53,0x5bf8,
  0x5c0f,0x5c22,0x5c38,0x5c71, 0x5ddd,0x5de5,0x5df1,0x5df2,
  0x5df3,0x5dfe,0x5e72,0x5efe, 0x5f0b,0x5f13,0x624d,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x4e11,0x4e10,0x4e0d,0x4e2d, 0x4e30,0x4e39,0x4e4b,0x5c39,
  0x4e88,0x4e91,0x4e95,0x4e92, 0x4e94,0x4ea2,0x4ec1,0x4ec0,
  0x4ec3,0x4ec6,0x4ec7,0x4ecd, 0x4eca,0x4ecb,0x4ec4,0x5143,
  0x5141,0x5167,0x516d,0x516e, 0x516c,0x5197,0x51f6,0x5206,
  0x5207,0x5208,0x52fb,0x52fe, 0x52ff,0x5316,0x5339,0x5348,
  0x5347,0x5345,0x535e,0x5384, 0x53cb,0x53ca,0x53cd,0x58ec,
  0x5929,0x592b,0x592a,0x592d, 0x5b54,0x5c11,0x5c24,0x5c3a,
  0x5c6f,0x5df4,0x5e7b,0x5eff, 0x5f14,0x5f15,0x5fc3,0x6208,
  0x6236,0x624b,0x624e,0x652f, 0x6587,0x6597,0x65a4,0x65b9,
  0x65e5,0x66f0,0x6708,0x6728, 0x6b20,0x6b62,0x6b79,0x6bcb,
  0x6bd4,0x6bdb,0x6c0f,0x6c34, 0x706b,0x722a,0x7236,0x723b,
  0x7247,0x7259,0x725b,0x72ac, 0x738b,0x4e19,
/* a500 */
  0x4e16,0x4e15,0x4e14,0x4e18, 0x4e3b,0x4e4d,0x4e4f,0x4e4e,
  0x4ee5,0x4ed8,0x4ed4,0x4ed5, 0x4ed6,0x4ed7,0x4ee3,0x4ee4,
  0x4ed9,0x4ede,0x5145,0x5144, 0x5189,0x518a,0x51ac,0x51f9,
  0x51fa,0x51f8,0x520a,0x52a0, 0x529f,0x5305,0x5306,0x5317,
  0x531d,0x4edf,0x534a,0x5349, 0x5361,0x5360,0x536f,0x536e,
  0x53bb,0x53ef,0x53e4,0x53f3, 0x53ec,0x53ee,0x53e9,0x53e8,
  0x53fc,0x53f8,0x53f5,0x53eb, 0x53e6,0x53ea,0x53f2,0x53f1,
  0x53f0,0x53e5,0x53ed,0x53fb, 0x56db,0x56da,0x5916,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x592e,0x5931,0x5974,0x5976, 0x5b55,0x5b83,0x5c3c,0x5de8,
  0x5de7,0x5de6,0x5e02,0x5e03, 0x5e73,0x5e7c,0x5f01,0x5f18,
  0x5f17,0x5fc5,0x620a,0x6253, 0x6254,0x6252,0x6251,0x65a5,
  0x65e6,0x672e,0x672c,0x672a, 0x672b,0x672d,0x6b63,0x6bcd,
  0x6c11,0x6c10,0x6c38,0x6c41, 0x6c40,0x6c3e,0x72af,0x7384,
  0x7389,0x74dc,0x74e6,0x7518, 0x751f,0x7528,0x7529,0x7530,
  0x7531,0x7532,0x7533,0x758b, 0x767d,0x76ae,0x76bf,0x76ee,
  0x77db,0x77e2,0x77f3,0x793a, 0x79be,0x7a74,0x7acb,0x4e1e,
  0x4e1f,0x4e52,0x4e53,0x4e69, 0x4e99,0x4ea4,0x4ea6,0x4ea5,
  0x4eff,0x4f09,0x4f19,0x4f0a, 0x4f15,0x4f0d,0x4f10,0x4f11,
  0x4f0f,0x4ef2,0x4ef6,0x4efb, 0x4ef0,0x4ef3,0x4efd,0x4f01,
  0x4f0b,0x5149,0x5147,0x5146, 0x5148,0x5168,
/* a600 */
  0x5171,0x518d,0x51b0,0x5217, 0x5211,0x5212,0x520e,0x5216,
  0x52a3,0x5308,0x5321,0x5320, 0x5370,0x5371,0x5409,0x540f,
  0x540c,0x540a,0x5410,0x5401, 0x540b,0x5404,0x5411,0x540d,
  0x5408,0x5403,0x540e,0x5406, 0x5412,0x56e0,0x56de,0x56dd,
  0x5733,0x5730,0x5728,0x572d, 0x572c,0x572f,0x5729,0x5919,
  0x591a,0x5937,0x5938,0x5984, 0x5978,0x5983,0x597d,0x5979,
  0x5982,0x5981,0x5b57,0x5b58, 0x5b87,0x5b88,0x5b85,0x5b89,
  0x5bfa,0x5c16,0x5c79,0x5dde, 0x5e06,0x5e76,0x5e74,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x5f0f,0x5f1b,0x5fd9,0x5fd6, 0x620e,0x620c,0x620d,0x6210,
  0x6263,0x625b,0x6258,0x6536, 0x65e9,0x65e8,0x65ec,0x65ed,
  0x66f2,0x66f3,0x6709,0x673d, 0x6734,0x6731,0x6735,0x6b21,
  0x6b64,0x6b7b,0x6c16,0x6c5d, 0x6c57,0x6c59,0x6c5f,0x6c60,
  0x6c50,0x6c55,0x6c61,0x6c5b, 0x6c4d,0x6c4e,0x7070,0x725f,
  0x725d,0x767e,0x7af9,0x7c73, 0x7cf8,0x7f36,0x7f8a,0x7fbd,
  0x8001,0x8003,0x800c,0x8012, 0x8033,0x807f,0x8089,0x808b,
  0x808c,0x81e3,0x81ea,0x81f3, 0x81fc,0x820c,0x821b,0x821f,
  0x826e,0x8272,0x827e,0x866b, 0x8840,0x884c,0x8863,0x897f,
  0x9621,0x4e32,0x4ea8,0x4f4d, 0x4f4f,0x4f47,0x4f57,0x4f5e,
  0x4f34,0x4f5b,0x4f55,0x4f30, 0x4f50,0x4f51,0x4f3d,0x4f3a,
  0x4f38,0x4f43,0x4f54,0x4f3c, 0x4f46,0x4f63,
/* a700 */
  0x4f5c,0x4f60,0x4f2f,0x4f4e, 0x4f36,0x4f59,0x4f5d,0x4f48,
  0x4f5a,0x514c,0x514b,0x514d, 0x5175,0x51b6,0x51b7,0x5225,
  0x5224,0x5229,0x522a,0x5228, 0x52ab,0x52a9,0x52aa,0x52ac,
  0x5323,0x5373,0x5375,0x541d, 0x542d,0x541e,0x543e,0x5426,
  0x544e,0x5427,0x5446,0x5443, 0x5433,0x5448,0x5442,0x541b,
  0x5429,0x544a,0x5439,0x543b, 0x5438,0x542e,0x5435,0x5436,
  0x5420,0x543c,0x5440,0x5431, 0x542b,0x541f,0x542c,0x56ea,
  0x56f0,0x56e4,0x56eb,0x574a, 0x5751,0x5740,0x574d,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x5747,0x574e,0x573e,0x5750, 0x574f,0x573b,0x58ef,0x593e,
  0x599d,0x5992,0x59a8,0x599e, 0x59a3,0x5999,0x5996,0x598d,
  0x59a4,0x5993,0x598a,0x59a5, 0x5b5d,0x5b5c,0x5b5a,0x5b5b,
  0x5b8c,0x5b8b,0x5b8f,0x5c2c, 0x5c40,0x5c41,0x5c3f,0x5c3e,
  0x5c90,0x5c91,0x5c94,0x5c8c, 0x5deb,0x5e0c,0x5e8f,0x5e87,
  0x5e8a,0x5ef7,0x5f04,0x5f1f, 0x5f64,0x5f62,0x5f77,0x5f79,
  0x5fd8,0x5fcc,0x5fd7,0x5fcd, 0x5ff1,0x5feb,0x5ff8,0x5fea,
  0x6212,0x6211,0x6284,0x6297, 0x6296,0x6280,0x6276,0x6289,
  0x626d,0x628a,0x627c,0x627e, 0x6279,0x6273,0x6292,0x626f,
  0x6298,0x626e,0x6295,0x6293, 0x6291,0x6286,0x6539,0x653b,
  0x6538,0x65f1,0x66f4,0x675f, 0x674e,0x674f,0x6750,0x6751,
  0x675c,0x6756,0x675e,0x6749, 0x6746,0x6760,
/* a800 */
  0x6753,0x6757,0x6b65,0x6bcf, 0x6c42,0x6c5e,0x6c99,0x6c81,
  0x6c88,0x6c89,0x6c85,0x6c9b, 0x6c6a,0x6c7a,0x6c90,0x6c70,
  0x6c8c,0x6c68,0x6c96,0x6c92, 0x6c7d,0x6c83,0x6c72,0x6c7e,
  0x6c74,0x6c86,0x6c76,0x6c8d, 0x6c94,0x6c98,0x6c82,0x7076,
  0x707c,0x707d,0x7078,0x7262, 0x7261,0x7260,0x72c4,0x72c2,
  0x7396,0x752c,0x752b,0x7537, 0x7538,0x7682,0x76ef,0x77e3,
  0x79c1,0x79c0,0x79bf,0x7a76, 0x7cfb,0x7f55,0x8096,0x8093,
  0x809d,0x8098,0x809b,0x809a, 0x80b2,0x826f,0x8292,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x828b,0x828d,0x898b,0x89d2, 0x8a00,0x8c37,0x8c46,0x8c55,
  0x8c9d,0x8d64,0x8d70,0x8db3, 0x8eab,0x8eca,0x8f9b,0x8fb0,
  0x8fc2,0x8fc6,0x8fc5,0x8fc4, 0x5de1,0x9091,0x90a2,0x90aa,
  0x90a6,0x90a3,0x9149,0x91c6, 0x91cc,0x9632,0x962e,0x9631,
  0x962a,0x962c,0x4e26,0x4e56, 0x4e73,0x4e8b,0x4e9b,0x4e9e,
  0x4eab,0x4eac,0x4f6f,0x4f9d, 0x4f8d,0x4f73,0x4f7f,0x4f6c,
  0x4f9b,0x4f8b,0x4f86,0x4f83, 0x4f70,0x4f75,0x4f88,0x4f69,
  0x4f7b,0x4f96,0x4f7e,0x4f8f, 0x4f91,0x4f7a,0x5154,0x5152,
  0x5155,0x5169,0x5177,0x5176, 0x5178,0x51bd,0x51fd,0x523b,
  0x5238,0x5237,0x523a,0x5230, 0x522e,0x5236,0x5241,0x52be,
  0x52bb,0x5352,0x5354,0x5353, 0x5351,0x5366,0x5377,0x5378,
  0x5379,0x53d6,0x53d4,0x53d7, 0x5473,0x5475,
/* a900 */
  0x5496,0x5478,0x5495,0x5480, 0x547b,0x5477,0x5484,0x5492,
  0x5486,0x547c,0x5490,0x5471, 0x5476,0x548c,0x549a,0x5462,
  0x5468,0x548b,0x547d,0x548e, 0x56fa,0x5783,0x5777,0x576a,
  0x5769,0x5761,0x5766,0x5764, 0x577c,0x591c,0x5949,0x5947,
  0x5948,0x5944,0x5954,0x59be, 0x59bb,0x59d4,0x59b9,0x59ae,
  0x59d1,0x59c6,0x59d0,0x59cd, 0x59cb,0x59d3,0x59ca,0x59af,
  0x59b3,0x59d2,0x59c5,0x5b5f, 0x5b64,0x5b63,0x5b97,0x5b9a,
  0x5b98,0x5b9c,0x5b99,0x5b9b, 0x5c1a,0x5c48,0x5c45,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x5c46,0x5cb7,0x5ca1,0x5cb8, 0x5ca9,0x5cab,0x5cb1,0x5cb3,
  0x5e18,0x5e1a,0x5e16,0x5e15, 0x5e1b,0x5e11,0x5e78,0x5e9a,
  0x5e97,0x5e9c,0x5e95,0x5e96, 0x5ef6,0x5f26,0x5f27,0x5f29,
  0x5f80,0x5f81,0x5f7f,0x5f7c, 0x5fdd,0x5fe0,0x5ffd,0x5ff5,
  0x5fff,0x600f,0x6014,0x602f, 0x6035,0x6016,0x602a,0x6015,
  0x6021,0x6027,0x6029,0x602b, 0x601b,0x6216,0x6215,0x623f,
  0x623e,0x6240,0x627f,0x62c9, 0x62cc,0x62c4,0x62bf,0x62c2,
  0x62b9,0x62d2,0x62db,0x62ab, 0x62d3,0x62d4,0x62cb,0x62c8,
  0x62a8,0x62bd,0x62bc,0x62d0, 0x62d9,0x62c7,0x62cd,0x62b5,
  0x62da,0x62b1,0x62d8,0x62d6, 0x62d7,0x62c6,0x62ac,0x62ce,
  0x653e,0x65a7,0x65bc,0x65fa, 0x6614,0x6613,0x660c,0x6606,
  0x6602,0x660e,0x6600,0x660f, 0x6615,0x660a,
/* aa00 */
  0x6607,0x670d,0x670b,0x676d, 0x678b,0x6795,0x6771,0x679c,
  0x6773,0x6777,0x6787,0x679d, 0x6797,0x676f,0x6770,0x677f,
  0x6789,0x677e,0x6790,0x6775, 0x679a,0x6793,0x677c,0x676a,
  0x6772,0x6b23,0x6b66,0x6b67, 0x6b7f,0x6c13,0x6c1b,0x6ce3,
  0x6ce8,0x6cf3,0x6cb1,0x6ccc, 0x6ce5,0x6cb3,0x6cbd,0x6cbe,
  0x6cbc,0x6ce2,0x6cab,0x6cd5, 0x6cd3,0x6cb8,0x6cc4,0x6cb9,
  0x6cc1,0x6cae,0x6cd7,0x6cc5, 0x6cf1,0x6cbf,0x6cbb,0x6ce1,
  0x6cdb,0x6cca,0x6cac,0x6cef, 0x6cdc,0x6cd6,0x6ce0,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x7095,0x708e,0x7092,0x708a, 0x7099,0x722c,0x722d,0x7238,
  0x7248,0x7267,0x7269,0x72c0, 0x72ce,0x72d9,0x72d7,0x72d0,
  0x73a9,0x73a8,0x739f,0x73ab, 0x73a5,0x753d,0x759d,0x7599,
  0x759a,0x7684,0x76c2,0x76f2, 0x76f4,0x77e5,0x77fd,0x793e,
  0x7940,0x7941,0x79c9,0x79c8, 0x7a7a,0x7a79,0x7afa,0x7cfe,
  0x7f54,0x7f8c,0x7f8b,0x8005, 0x80ba,0x80a5,0x80a2,0x80b1,
  0x80a1,0x80ab,0x80a9,0x80b4, 0x80aa,0x80af,0x81e5,0x81fe,
  0x820d,0x82b3,0x829d,0x8299, 0x82ad,0x82bd,0x829f,0x82b9,
  0x82b1,0x82ac,0x82a5,0x82af, 0x82b8,0x82a3,0x82b0,0x82be,
  0x82b7,0x864e,0x8671,0x521d, 0x8868,0x8ecb,0x8fce,0x8fd4,
  0x8fd1,0x90b5,0x90b8,0x90b1, 0x90b6,0x91c7,0x91d1,0x9577,
  0x9580,0x961c,0x9640,0x963f, 0x963b,0x9644,
/* ab00 */
  0x9642,0x96b9,0x96e8,0x9752, 0x975e,0x4e9f,0x4ead,0x4eae,
  0x4fe1,0x4fb5,0x4faf,0x4fbf, 0x4fe0,0x4fd1,0x4fcf,0x4fdd,
  0x4fc3,0x4fb6,0x4fd8,0x4fdf, 0x4fca,0x4fd7,0x4fae,0x4fd0,
  0x4fc4,0x4fc2,0x4fda,0x4fce, 0x4fde,0x4fb7,0x5157,0x5192,
  0x5191,0x51a0,0x524e,0x5243, 0x524a,0x524d,0x524c,0x524b,
  0x5247,0x52c7,0x52c9,0x52c3, 0x52c1,0x530d,0x5357,0x537b,
  0x539a,0x53db,0x54ac,0x54c0, 0x54a8,0x54ce,0x54c9,0x54b8,
  0x54a6,0x54b3,0x54c7,0x54c2, 0x54bd,0x54aa,0x54c1,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x54c4,0x54c8,0x54af,0x54ab, 0x54b1,0x54bb,0x54a9,0x54a7,
  0x54bf,0x56ff,0x5782,0x578b, 0x57a0,0x57a3,0x57a2,0x57ce,
  0x57ae,0x5793,0x5955,0x5951, 0x594f,0x594e,0x5950,0x59dc,
  0x59d8,0x59ff,0x59e3,0x59e8, 0x5a03,0x59e5,0x59ea,0x59da,
  0x59e6,0x5a01,0x59fb,0x5b69, 0x5ba3,0x5ba6,0x5ba4,0x5ba2,
  0x5ba5,0x5c01,0x5c4e,0x5c4f, 0x5c4d,0x5c4b,0x5cd9,0x5cd2,
  0x5df7,0x5e1d,0x5e25,0x5e1f, 0x5e7d,0x5ea0,0x5ea6,0x5efa,
  0x5f08,0x5f2d,0x5f65,0x5f88, 0x5f85,0x5f8a,0x5f8b,0x5f87,
  0x5f8c,0x5f89,0x6012,0x601d, 0x6020,0x6025,0x600e,0x6028,
  0x604d,0x6070,0x6068,0x6062, 0x6046,0x6043,0x606c,0x606b,
  0x606a,0x6064,0x6241,0x62dc, 0x6316,0x6309,0x62fc,0x62ed,
  0x6301,0x62ee,0x62fd,0x6307, 0x62f1,0x62f7,
/* ac00 */
  0x62ef,0x62ec,0x62fe,0x62f4, 0x6311,0x6302,0x653f,0x6545,
  0x65ab,0x65bd,0x65e2,0x6625, 0x662d,0x6620,0x6627,0x662f,
  0x661f,0x6628,0x6631,0x6624, 0x66f7,0x67ff,0x67d3,0x67f1,
  0x67d4,0x67d0,0x67ec,0x67b6, 0x67af,0x67f5,0x67e9,0x67ef,
  0x67c4,0x67d1,0x67b4,0x67da, 0x67e5,0x67b8,0x67cf,0x67de,
  0x67f3,0x67b0,0x67d9,0x67e2, 0x67dd,0x67d2,0x6b6a,0x6b83,
  0x6b86,0x6bb5,0x6bd2,0x6bd7, 0x6c1f,0x6cc9,0x6d0b,0x6d32,
  0x6d2a,0x6d41,0x6d25,0x6d0c, 0x6d31,0x6d1e,0x6d17,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x6d3b,0x6d3d,0x6d3e,0x6d36, 0x6d1b,0x6cf5,0x6d39,0x6d27,
  0x6d38,0x6d29,0x6d2e,0x6d35, 0x6d0e,0x6d2b,0x70ab,0x70ba,
  0x70b3,0x70ac,0x70af,0x70ad, 0x70b8,0x70ae,0x70a4,0x7230,
  0x7272,0x726f,0x7274,0x72e9, 0x72e0,0x72e1,0x73b7,0x73ca,
  0x73bb,0x73b2,0x73cd,0x73c0, 0x73b3,0x751a,0x752d,0x754f,
  0x754c,0x754e,0x754b,0x75ab, 0x75a4,0x75a5,0x75a2,0x75a3,
  0x7678,0x7686,0x7687,0x7688, 0x76c8,0x76c6,0x76c3,0x76c5,
  0x7701,0x76f9,0x76f8,0x7709, 0x770b,0x76fe,0x76fc,0x7707,
  0x77dc,0x7802,0x7814,0x780c, 0x780d,0x7946,0x7949,0x7948,
  0x7947,0x79b9,0x79ba,0x79d1, 0x79d2,0x79cb,0x7a7f,0x7a81,
  0x7aff,0x7afd,0x7c7d,0x7d02, 0x7d05,0x7d00,0x7d09,0x7d07,
  0x7d04,0x7d06,0x7f38,0x7f8e, 0x7fbf,0x8004,
/* ad00 */
  0x8010,0x800d,0x8011,0x8036, 0x80d6,0x80e5,0x80da,0x80c3,
  0x80c4,0x80cc,0x80e1,0x80db, 0x80ce,0x80de,0x80e4,0x80dd,
  0x81f4,0x8222,0x82e7,0x8303, 0x8305,0x82e3,0x82db,0x82e6,
  0x8304,0x82e5,0x8302,0x8309, 0x82d2,0x82d7,0x82f1,0x8301,
  0x82dc,0x82d4,0x82d1,0x82de, 0x82d3,0x82df,0x82ef,0x8306,
  0x8650,0x8679,0x867b,0x867a, 0x884d,0x886b,0x8981,0x89d4,
  0x8a08,0x8a02,0x8a03,0x8c9e, 0x8ca0,0x8d74,0x8d73,0x8db4,
  0x8ecd,0x8ecc,0x8ff0,0x8fe6, 0x8fe2,0x8fea,0x8fe5,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x8fed,0x8feb,0x8fe4,0x8fe8, 0x90ca,0x90ce,0x90c1,0x90c3,
  0x914b,0x914a,0x91cd,0x9582, 0x9650,0x964b,0x964c,0x964d,
  0x9762,0x9769,0x97cb,0x97ed, 0x97f3,0x9801,0x98a8,0x98db,
  0x98df,0x9996,0x9999,0x4e58, 0x4eb3,0x500c,0x500d,0x5023,
  0x4fef,0x5026,0x5025,0x4ff8, 0x5029,0x5016,0x5006,0x503c,
  0x501f,0x501a,0x5012,0x5011, 0x4ffa,0x5000,0x5014,0x5028,
  0x4ff1,0x5021,0x500b,0x5019, 0x5018,0x4ff3,0x4fee,0x502d,
  0x502a,0x4ffe,0x502b,0x5009, 0x517c,0x51a4,0x51a5,0x51a2,
  0x51cd,0x51cc,0x51c6,0x51cb, 0x5256,0x525c,0x5254,0x525b,
  0x525d,0x532a,0x537f,0x539f, 0x539d,0x53df,0x54e8,0x5510,
  0x5501,0x5537,0x54fc,0x54e5, 0x54f2,0x5506,0x54fa,0x5514,
  0x54e9,0x54ed,0x54e1,0x5509, 0x54ee,0x54ea,
/* ae00 */
  0x54e6,0x5527,0x5507,0x54fd, 0x550f,0x5703,0x5704,0x57c2,
  0x57d4,0x57cb,0x57c3,0x5809, 0x590f,0x5957,0x5958,0x595a,
  0x5a11,0x5a18,0x5a1c,0x5a1f, 0x5a1b,0x5a13,0x59ec,0x5a20,
  0x5a23,0x5a29,0x5a25,0x5a0c, 0x5a09,0x5b6b,0x5c58,0x5bb0,
  0x5bb3,0x5bb6,0x5bb4,0x5bae, 0x5bb5,0x5bb9,0x5bb8,0x5c04,
  0x5c51,0x5c55,0x5c50,0x5ced, 0x5cfd,0x5cfb,0x5cea,0x5ce8,
  0x5cf0,0x5cf6,0x5d01,0x5cf4, 0x5dee,0x5e2d,0x5e2b,0x5eab,
  0x5ead,0x5ea7,0x5f31,0x5f92, 0x5f91,0x5f90,0x6059,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x6063,0x6065,0x6050,0x6055, 0x606d,0x6069,0x606f,0x6084,
  0x609f,0x609a,0x608d,0x6094, 0x608c,0x6085,0x6096,0x6247,
  0x62f3,0x6308,0x62ff,0x634e, 0x633e,0x632f,0x6355,0x6342,
  0x6346,0x634f,0x6349,0x633a, 0x6350,0x633d,0x632a,0x632b,
  0x6328,0x634d,0x634c,0x6548, 0x6549,0x6599,0x65c1,0x65c5,
  0x6642,0x6649,0x664f,0x6643, 0x6652,0x664c,0x6645,0x6641,
  0x66f8,0x6714,0x6715,0x6717, 0x6821,0x6838,0x6848,0x6846,
  0x6853,0x6839,0x6842,0x6854, 0x6829,0x68b3,0x6817,0x684c,
  0x6851,0x683d,0x67f4,0x6850, 0x6840,0x683c,0x6843,0x682a,
  0x6845,0x6813,0x6818,0x6841, 0x6b8a,0x6b89,0x6bb7,0x6c23,
  0x6c27,0x6c28,0x6c26,0x6c24, 0x6cf0,0x6d6a,0x6d95,0x6d88,
  0x6d87,0x6d66,0x6d78,0x6d77, 0x6d59,0x6d93,
/* af00 */
  0x6d6c,0x6d89,0x6d6e,0x6d5a, 0x6d74,0x6d69,0x6d8c,0x6d8a,
  0x6d79,0x6d85,0x6d65,0x6d94, 0x70ca,0x70d8,0x70e4,0x70d9,
  0x70c8,0x70cf,0x7239,0x7279, 0x72fc,0x72f9,0x72fd,0x72f8,
  0x72f7,0x7386,0x73ed,0x7409, 0x73ee,0x73e0,0x73ea,0x73de,
  0x7554,0x755d,0x755c,0x755a, 0x7559,0x75be,0x75c5,0x75c7,
  0x75b2,0x75b3,0x75bd,0x75bc, 0x75b9,0x75c2,0x75b8,0x768b,
  0x76b0,0x76ca,0x76cd,0x76ce, 0x7729,0x771f,0x7720,0x7728,
  0x77e9,0x7830,0x7827,0x7838, 0x781d,0x7834,0x7837,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x7825,0x782d,0x7820,0x781f, 0x7832,0x7955,0x7950,0x7960,
  0x795f,0x7956,0x795e,0x795d, 0x7957,0x795a,0x79e4,0x79e3,
  0x79e7,0x79df,0x79e6,0x79e9, 0x79d8,0x7a84,0x7a88,0x7ad9,
  0x7b06,0x7b11,0x7c89,0x7d21, 0x7d17,0x7d0b,0x7d0a,0x7d20,
  0x7d22,0x7d14,0x7d10,0x7d15, 0x7d1a,0x7d1c,0x7d0d,0x7d19,
  0x7d1b,0x7f3a,0x7f5f,0x7f94, 0x7fc5,0x7fc1,0x8006,0x8018,
  0x8015,0x8019,0x8017,0x803d, 0x803f,0x80f1,0x8102,0x80f0,
  0x8105,0x80ed,0x80f4,0x8106, 0x80f8,0x80f3,0x8108,0x80fd,
  0x810a,0x80fc,0x80ef,0x81ed, 0x81ec,0x8200,0x8210,0x822a,
  0x822b,0x8228,0x822c,0x82bb, 0x832b,0x8352,0x8354,0x834a,
  0x8338,0x8350,0x8349,0x8335, 0x8334,0x834f,0x8332,0x8339,
  0x8336,0x8317,0x8340,0x8331, 0x8328,0x8343,
/* b000 */
  0x8654,0x868a,0x86aa,0x8693, 0x86a4,0x86a9,0x868c,0x86a3,
  0x869c,0x8870,0x8877,0x8881, 0x8882,0x887d,0x8879,0x8a18,
  0x8a10,0x8a0e,0x8a0c,0x8a15, 0x8a0a,0x8a17,0x8a13,0x8a16,
  0x8a0f,0x8a11,0x8c48,0x8c7a, 0x8c79,0x8ca1,0x8ca2,0x8d77,
  0x8eac,0x8ed2,0x8ed4,0x8ecf, 0x8fb1,0x9001,0x9006,0x8ff7,
  0x9000,0x8ffa,0x8ff4,0x9003, 0x8ffd,0x9005,0x8ff8,0x9095,
  0x90e1,0x90dd,0x90e2,0x9152, 0x914d,0x914c,0x91d8,0x91dd,
  0x91d7,0x91dc,0x91d9,0x9583, 0x9662,0x9663,0x9661,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x965b,0x965d,0x9664,0x9658, 0x965e,0x96bb,0x98e2,0x99ac,
  0x9aa8,0x9ad8,0x9b25,0x9b32, 0x9b3c,0x4e7e,0x507a,0x507d,
  0x505c,0x5047,0x5043,0x504c, 0x505a,0x5049,0x5065,0x5076,
  0x504e,0x5055,0x5075,0x5074, 0x5077,0x504f,0x500f,0x506f,
  0x506d,0x515c,0x5195,0x51f0, 0x526a,0x526f,0x52d2,0x52d9,
  0x52d8,0x52d5,0x5310,0x530f, 0x5319,0x533f,0x5340,0x533e,
  0x53c3,0x66fc,0x5546,0x556a, 0x5566,0x5544,0x555e,0x5561,
  0x5543,0x554a,0x5531,0x5556, 0x554f,0x5555,0x552f,0x5564,
  0x5538,0x552e,0x555c,0x552c, 0x5563,0x5533,0x5541,0x5557,
  0x5708,0x570b,0x5709,0x57df, 0x5805,0x580a,0x5806,0x57e0,
  0x57e4,0x57fa,0x5802,0x5835, 0x57f7,0x57f9,0x5920,0x5962,
  0x5a36,0x5a41,0x5a49,0x5a66, 0x5a6a,0x5a40,
/* b100 */
  0x5a3c,0x5a62,0x5a5a,0x5a46, 0x5a4a,0x5b70,0x5bc7,0x5bc5,
  0x5bc4,0x5bc2,0x5bbf,0x5bc6, 0x5c09,0x5c08,0x5c07,0x5c60,
  0x5c5c,0x5c5d,0x5d07,0x5d06, 0x5d0e,0x5d1b,0x5d16,0x5d22,
  0x5d11,0x5d29,0x5d14,0x5d19, 0x5d24,0x5d27,0x5d17,0x5de2,
  0x5e38,0x5e36,0x5e33,0x5e37, 0x5eb7,0x5eb8,0x5eb6,0x5eb5,
  0x5ebe,0x5f35,0x5f37,0x5f57, 0x5f6c,0x5f69,0x5f6b,0x5f97,
  0x5f99,0x5f9e,0x5f98,0x5fa1, 0x5fa0,0x5f9c,0x607f,0x60a3,
  0x6089,0x60a0,0x60a8,0x60cb, 0x60b4,0x60e6,0x60bd,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x60c5,0x60bb,0x60b5,0x60dc, 0x60bc,0x60d8,0x60d5,0x60c6,
  0x60df,0x60b8,0x60da,0x60c7, 0x621a,0x621b,0x6248,0x63a0,
  0x63a7,0x6372,0x6396,0x63a2, 0x63a5,0x6377,0x6367,0x6398,
  0x63aa,0x6371,0x63a9,0x6389, 0x6383,0x639b,0x636b,0x63a8,
  0x6384,0x6388,0x6399,0x63a1, 0x63ac,0x6392,0x638f,0x6380,
  0x637b,0x6369,0x6368,0x637a, 0x655d,0x6556,0x6551,0x6559,
  0x6557,0x555f,0x654f,0x6558, 0x6555,0x6554,0x659c,0x659b,
  0x65ac,0x65cf,0x65cb,0x65cc, 0x65ce,0x665d,0x665a,0x6664,
  0x6668,0x6666,0x665e,0x66f9, 0x52d7,0x671b,0x6881,0x68af,
  0x68a2,0x6893,0x68b5,0x687f, 0x6876,0x68b1,0x68a7,0x6897,
  0x68b0,0x6883,0x68c4,0x68ad, 0x6886,0x6885,0x6894,0x689d,
  0x68a8,0x689f,0x68a1,0x6882, 0x6b32,0x6bba,
/* b200 */
  0x6beb,0x6bec,0x6c2b,0x6d8e, 0x6dbc,0x6df3,0x6dd9,0x6db2,
  0x6de1,0x6dcc,0x6de4,0x6dfb, 0x6dfa,0x6e05,0x6dc7,0x6dcb,
  0x6daf,0x6dd1,0x6dae,0x6dde, 0x6df9,0x6db8,0x6df7,0x6df5,
  0x6dc5,0x6dd2,0x6e1a,0x6db5, 0x6dda,0x6deb,0x6dd8,0x6dea,
  0x6df1,0x6dee,0x6de8,0x6dc6, 0x6dc4,0x6daa,0x6dec,0x6dbf,
  0x6de6,0x70f9,0x7109,0x710a, 0x70fd,0x70ef,0x723d,0x727d,
  0x7281,0x731c,0x731b,0x7316, 0x7313,0x7319,0x7387,0x7405,
  0x740a,0x7403,0x7406,0x73fe, 0x740d,0x74e0,0x74f6,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x74f7,0x751c,0x7522,0x7565, 0x7566,0x7562,0x7570,0x758f,
  0x75d4,0x75d5,0x75b5,0x75ca, 0x75cd,0x768e,0x76d4,0x76d2,
  0x76db,0x7737,0x773e,0x773c, 0x7736,0x7738,0x773a,0x786b,
  0x7843,0x784e,0x7965,0x7968, 0x796d,0x79fb,0x7a92,0x7a95,
  0x7b20,0x7b28,0x7b1b,0x7b2c, 0x7b26,0x7b19,0x7b1e,0x7b2e,
  0x7c92,0x7c97,0x7c95,0x7d46, 0x7d43,0x7d71,0x7d2e,0x7d39,
  0x7d3c,0x7d40,0x7d30,0x7d33, 0x7d44,0x7d2f,0x7d42,0x7d32,
  0x7d31,0x7f3d,0x7f9e,0x7f9a, 0x7fcc,0x7fce,0x7fd2,0x801c,
  0x804a,0x8046,0x812f,0x8116, 0x8123,0x812b,0x8129,0x8130,
  0x8124,0x8202,0x8235,0x8237, 0x8236,0x8239,0x838e,0x839e,
  0x8398,0x8378,0x83a2,0x8396, 0x83bd,0x83ab,0x8392,0x838a,
  0x8393,0x8389,0x83a0,0x8377, 0x837b,0x837c,
/* b300 */
  0x8386,0x83a7,0x8655,0x5f6a, 0x86c7,0x86c0,0x86b6,0x86c4,
  0x86b5,0x86c6,0x86cb,0x86b1, 0x86af,0x86c9,0x8853,0x889e,
  0x8888,0x88ab,0x8892,0x8896, 0x888d,0x888b,0x8993,0x898f,
  0x8a2a,0x8a1d,0x8a23,0x8a25, 0x8a31,0x8a2d,0x8a1f,0x8a1b,
  0x8a22,0x8c49,0x8c5a,0x8ca9, 0x8cac,0x8cab,0x8ca8,0x8caa,
  0x8ca7,0x8d67,0x8d66,0x8dbe, 0x8dba,0x8edb,0x8edf,0x9019,
  0x900d,0x901a,0x9017,0x9023, 0x901f,0x901d,0x9010,0x9015,
  0x901e,0x9020,0x900f,0x9022, 0x9016,0x901b,0x9014,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x90e8,0x90ed,0x90fd,0x9157, 0x91ce,0x91f5,0x91e6,0x91e3,
  0x91e7,0x91ed,0x91e9,0x9589, 0x966a,0x9675,0x9673,0x9678,
  0x9670,0x9674,0x9676,0x9677, 0x966c,0x96c0,0x96ea,0x96e9,
  0x7ae0,0x7adf,0x9802,0x9803, 0x9b5a,0x9ce5,0x9e75,0x9e7f,
  0x9ea5,0x9ebb,0x50a2,0x508d, 0x5085,0x5099,0x5091,0x5080,
  0x5096,0x5098,0x509a,0x6700, 0x51f1,0x5272,0x5274,0x5275,
  0x5269,0x52de,0x52dd,0x52db, 0x535a,0x53a5,0x557b,0x5580,
  0x55a7,0x557c,0x558a,0x559d, 0x5598,0x5582,0x559c,0x55aa,
  0x5594,0x5587,0x558b,0x5583, 0x55b3,0x55ae,0x559f,0x553e,
  0x55b2,0x559a,0x55bb,0x55ac, 0x55b1,0x557e,0x5589,0x55ab,
  0x5599,0x570d,0x582f,0x582a, 0x5834,0x5824,0x5830,0x5831,
  0x5821,0x581d,0x5820,0x58f9, 0x58fa,0x5960,
/* b400 */
  0x5a77,0x5a9a,0x5a7f,0x5a92, 0x5a9b,0x5aa7,0x5b73,0x5b71,
  0x5bd2,0x5bcc,0x5bd3,0x5bd0, 0x5c0a,0x5c0b,0x5c31,0x5d4c,
  0x5d50,0x5d34,0x5d47,0x5dfd, 0x5e45,0x5e3d,0x5e40,0x5e43,
  0x5e7e,0x5eca,0x5ec1,0x5ec2, 0x5ec4,0x5f3c,0x5f6d,0x5fa9,
  0x5faa,0x5fa8,0x60d1,0x60e1, 0x60b2,0x60b6,0x60e0,0x611c,
  0x6123,0x60fa,0x6115,0x60f0, 0x60fb,0x60f4,0x6168,0x60f1,
  0x610e,0x60f6,0x6109,0x6100, 0x6112,0x621f,0x6249,0x63a3,
  0x638c,0x63cf,0x63c0,0x63e9, 0x63c9,0x63c6,0x63cd,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x63d2,0x63e3,0x63d0,0x63e1, 0x63d6,0x63ed,0x63ee,0x6376,
  0x63f4,0x63ea,0x63db,0x6452, 0x63da,0x63f9,0x655e,0x6566,
  0x6562,0x6563,0x6591,0x6590, 0x65af,0x666e,0x6670,0x6674,
  0x6676,0x666f,0x6691,0x667a, 0x667e,0x6677,0x66fe,0x66ff,
  0x671f,0x671d,0x68fa,0x68d5, 0x68e0,0x68d8,0x68d7,0x6905,
  0x68df,0x68f5,0x68ee,0x68e7, 0x68f9,0x68d2,0x68f2,0x68e3,
  0x68cb,0x68cd,0x690d,0x6912, 0x690e,0x68c9,0x68da,0x696e,
  0x68fb,0x6b3e,0x6b3a,0x6b3d, 0x6b98,0x6b96,0x6bbc,0x6bef,
  0x6c2e,0x6c2f,0x6c2c,0x6e2f, 0x6e38,0x6e54,0x6e21,0x6e32,
  0x6e67,0x6e4a,0x6e20,0x6e25, 0x6e23,0x6e1b,0x6e5b,0x6e58,
  0x6e24,0x6e56,0x6e6e,0x6e2d, 0x6e26,0x6e6f,0x6e34,0x6e4d,
  0x6e3a,0x6e2c,0x6e43,0x6e1d, 0x6e3e,0x6ecb,
/* b500 */
  0x6e89,0x6e19,0x6e4e,0x6e63, 0x6e44,0x6e72,0x6e69,0x6e5f,
  0x7119,0x711a,0x7126,0x7130, 0x7121,0x7136,0x716e,0x711c,
  0x724c,0x7284,0x7280,0x7336, 0x7325,0x7334,0x7329,0x743a,
  0x742a,0x7433,0x7422,0x7425, 0x7435,0x7436,0x7434,0x742f,
  0x741b,0x7426,0x7428,0x7525, 0x7526,0x756b,0x756a,0x75e2,
  0x75db,0x75e3,0x75d9,0x75d8, 0x75de,0x75e0,0x767b,0x767c,
  0x7696,0x7693,0x76b4,0x76dc, 0x774f,0x77ed,0x785d,0x786c,
  0x786f,0x7a0d,0x7a08,0x7a0b, 0x7a05,0x7a00,0x7a98,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x7a97,0x7a96,0x7ae5,0x7ae3, 0x7b49,0x7b56,0x7b46,0x7b50,
  0x7b52,0x7b54,0x7b4d,0x7b4b, 0x7b4f,0x7b51,0x7c9f,0x7ca5,
  0x7d5e,0x7d50,0x7d68,0x7d55, 0x7d2b,0x7d6e,0x7d72,0x7d61,
  0x7d66,0x7d62,0x7d70,0x7d73, 0x5584,0x7fd4,0x7fd5,0x800b,
  0x8052,0x8085,0x8155,0x8154, 0x814b,0x8151,0x814e,0x8139,
  0x8146,0x813e,0x814c,0x8153, 0x8174,0x8212,0x821c,0x83e9,
  0x8403,0x83f8,0x840d,0x83e0, 0x83c5,0x840b,0x83c1,0x83ef,
  0x83f1,0x83f4,0x8457,0x840a, 0x83f0,0x840c,0x83cc,0x83fd,
  0x83f2,0x83ca,0x8438,0x840e, 0x8404,0x83dc,0x8407,0x83d4,
  0x83df,0x865b,0x86df,0x86d9, 0x86ed,0x86d4,0x86db,0x86e4,
  0x86d0,0x86de,0x8857,0x88c1, 0x88c2,0x88b1,0x8983,0x8996,
  0x8a3b,0x8a60,0x8a55,0x8a5e, 0x8a3c,0x8a41,
/* b600 */
  0x8a54,0x8a5b,0x8a50,0x8a46, 0x8a34,0x8a3a,0x8a36,0x8a56,
  0x8c61,0x8c82,0x8caf,0x8cbc, 0x8cb3,0x8cbd,0x8cc1,0x8cbb,
  0x8cc0,0x8cb4,0x8cb7,0x8cb6, 0x8cbf,0x8cb8,0x8d8a,0x8d85,
  0x8d81,0x8dce,0x8ddd,0x8dcb, 0x8dda,0x8dd1,0x8dcc,0x8ddb,
  0x8dc6,0x8efb,0x8ef8,0x8efc, 0x8f9c,0x902e,0x9035,0x9031,
  0x9038,0x9032,0x9036,0x9102, 0x90f5,0x9109,0x90fe,0x9163,
  0x9165,0x91cf,0x9214,0x9215, 0x9223,0x9209,0x921e,0x920d,
  0x9210,0x9207,0x9211,0x9594, 0x958f,0x958b,0x9591,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x9593,0x9592,0x958e,0x968a, 0x968e,0x968b,0x967d,0x9685,
  0x9686,0x968d,0x9672,0x9684, 0x96c1,0x96c5,0x96c4,0x96c6,
  0x96c7,0x96ef,0x96f2,0x97cc, 0x9805,0x9806,0x9808,0x98e7,
  0x98ea,0x98ef,0x98e9,0x98f2, 0x98ed,0x99ae,0x99ad,0x9ec3,
  0x9ecd,0x9ed1,0x4e82,0x50ad, 0x50b5,0x50b2,0x50b3,0x50c5,
  0x50be,0x50ac,0x50b7,0x50bb, 0x50af,0x50c7,0x527f,0x5277,
  0x527d,0x52df,0x52e6,0x52e4, 0x52e2,0x52e3,0x532f,0x55df,
  0x55e8,0x55d3,0x55e6,0x55ce, 0x55dc,0x55c7,0x55d1,0x55e3,
  0x55e4,0x55ef,0x55da,0x55e1, 0x55c5,0x55c6,0x55e5,0x55c9,
  0x5712,0x5713,0x585e,0x5851, 0x5858,0x5857,0x585a,0x5854,
  0x586b,0x584c,0x586d,0x584a, 0x5862,0x5852,0x584b,0x5967,
  0x5ac1,0x5ac9,0x5acc,0x5abe, 0x5abd,0x5abc,
/* b700 */
  0x5ab3,0x5ac2,0x5ab2,0x5d69, 0x5d6f,0x5e4c,0x5e79,0x5ec9,
  0x5ec8,0x5f12,0x5f59,0x5fac, 0x5fae,0x611a,0x610f,0x6148,
  0x611f,0x60f3,0x611b,0x60f9, 0x6101,0x6108,0x614e,0x614c,
  0x6144,0x614d,0x613e,0x6134, 0x6127,0x610d,0x6106,0x6137,
  0x6221,0x6222,0x6413,0x643e, 0x641e,0x642a,0x642d,0x643d,
  0x642c,0x640f,0x641c,0x6414, 0x640d,0x6436,0x6416,0x6417,
  0x6406,0x656c,0x659f,0x65b0, 0x6697,0x6689,0x6687,0x6688,
  0x6696,0x6684,0x6698,0x668d, 0x6703,0x6994,0x696d,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x695a,0x6977,0x6960,0x6954, 0x6975,0x6930,0x6982,0x694a,
  0x6968,0x696b,0x695e,0x6953, 0x6979,0x6986,0x695d,0x6963,
  0x695b,0x6b47,0x6b72,0x6bc0, 0x6bbf,0x6bd3,0x6bfd,0x6ea2,
  0x6eaf,0x6ed3,0x6eb6,0x6ec2, 0x6e90,0x6e9d,0x6ec7,0x6ec5,
  0x6ea5,0x6e98,0x6ebc,0x6eba, 0x6eab,0x6ed1,0x6e96,0x6e9c,
  0x6ec4,0x6ed4,0x6eaa,0x6ea7, 0x6eb4,0x714e,0x7159,0x7169,
  0x7164,0x7149,0x7167,0x715c, 0x716c,0x7166,0x714c,0x7165,
  0x715e,0x7146,0x7168,0x7156, 0x723a,0x7252,0x7337,0x7345,
  0x733f,0x733e,0x746f,0x745a, 0x7455,0x745f,0x745e,0x7441,
  0x743f,0x7459,0x745b,0x745c, 0x7576,0x7578,0x7600,0x75f0,
  0x7601,0x75f2,0x75f1,0x75fa, 0x75ff,0x75f4,0x75f3,0x76de,
  0x76df,0x775b,0x776b,0x7766, 0x775e,0x7763,
/* b800 */
  0x7779,0x776a,0x776c,0x775c, 0x7765,0x7768,0x7762,0x77ee,
  0x788e,0x78b0,0x7897,0x7898, 0x788c,0x7889,0x787c,0x7891,
  0x7893,0x787f,0x797a,0x797f, 0x7981,0x842c,0x79bd,0x7a1c,
  0x7a1a,0x7a20,0x7a14,0x7a1f, 0x7a1e,0x7a9f,0x7aa0,0x7b77,
  0x7bc0,0x7b60,0x7b6e,0x7b67, 0x7cb1,0x7cb3,0x7cb5,0x7d93,
  0x7d79,0x7d91,0x7d81,0x7d8f, 0x7d5b,0x7f6e,0x7f69,0x7f6a,
  0x7f72,0x7fa9,0x7fa8,0x7fa4, 0x8056,0x8058,0x8086,0x8084,
  0x8171,0x8170,0x8178,0x8165, 0x816e,0x8173,0x816b,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x8179,0x817a,0x8166,0x8205, 0x8247,0x8482,0x8477,0x843d,
  0x8431,0x8475,0x8466,0x846b, 0x8449,0x846c,0x845b,0x843c,
  0x8435,0x8461,0x8463,0x8469, 0x846d,0x8446,0x865e,0x865c,
  0x865f,0x86f9,0x8713,0x8708, 0x8707,0x8700,0x86fe,0x86fb,
  0x8702,0x8703,0x8706,0x870a, 0x8859,0x88df,0x88d4,0x88d9,
  0x88dc,0x88d8,0x88dd,0x88e1, 0x88ca,0x88d5,0x88d2,0x899c,
  0x89e3,0x8a6b,0x8a72,0x8a73, 0x8a66,0x8a69,0x8a70,0x8a87,
  0x8a7c,0x8a63,0x8aa0,0x8a71, 0x8a85,0x8a6d,0x8a62,0x8a6e,
  0x8a6c,0x8a79,0x8a7b,0x8a3e, 0x8a68,0x8c62,0x8c8a,0x8c89,
  0x8cca,0x8cc7,0x8cc8,0x8cc4, 0x8cb2,0x8cc3,0x8cc2,0x8cc5,
  0x8de1,0x8ddf,0x8de8,0x8def, 0x8df3,0x8dfa,0x8dea,0x8de4,
  0x8de6,0x8eb2,0x8f03,0x8f09, 0x8efe,0x8f0a,
/* b900 */
  0x8f9f,0x8fb2,0x904b,0x904a, 0x9053,0x9042,0x9054,0x903c,
  0x9055,0x9050,0x9047,0x904f, 0x904e,0x904d,0x9051,0x903e,
  0x9041,0x9112,0x9117,0x916c, 0x916a,0x9169,0x91c9,0x9237,
  0x9257,0x9238,0x923d,0x9240, 0x923e,0x925b,0x924b,0x9264,
  0x9251,0x9234,0x9249,0x924d, 0x9245,0x9239,0x923f,0x925a,
  0x9598,0x9698,0x9694,0x9695, 0x96cd,0x96cb,0x96c9,0x96ca,
  0x96f7,0x96fb,0x96f9,0x96f6, 0x9756,0x9774,0x9776,0x9810,
  0x9811,0x9813,0x980a,0x9812, 0x980c,0x98fc,0x98f4,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x98fd,0x98fe,0x99b3,0x99b1, 0x99b4,0x9ae1,0x9ce9,0x9e82,
  0x9f0e,0x9f13,0x9f20,0x50e7, 0x50ee,0x50e5,0x50d6,0x50ed,
  0x50da,0x50d5,0x50cf,0x50d1, 0x50f1,0x50ce,0x50e9,0x5162,
  0x51f3,0x5283,0x5282,0x5331, 0x53ad,0x55fe,0x5600,0x561b,
  0x5617,0x55fd,0x5614,0x5606, 0x5609,0x560d,0x560e,0x55f7,
  0x5616,0x561f,0x5608,0x5610, 0x55f6,0x5718,0x5716,0x5875,
  0x587e,0x5883,0x5893,0x588a, 0x5879,0x5885,0x587d,0x58fd,
  0x5925,0x5922,0x5924,0x596a, 0x5969,0x5ae1,0x5ae6,0x5ae9,
  0x5ad7,0x5ad6,0x5ad8,0x5ae3, 0x5b75,0x5bde,0x5be7,0x5be1,
  0x5be5,0x5be6,0x5be8,0x5be2, 0x5be4,0x5bdf,0x5c0d,0x5c62,
  0x5d84,0x5d87,0x5e5b,0x5e63, 0x5e55,0x5e57,0x5e54,0x5ed3,
  0x5ed6,0x5f0a,0x5f46,0x5f70, 0x5fb9,0x6147,
/* ba00 */
  0x613f,0x614b,0x6177,0x6162, 0x6163,0x615f,0x615a,0x6158,
  0x6175,0x622a,0x6487,0x6458, 0x6454,0x64a4,0x6478,0x645f,
  0x647a,0x6451,0x6467,0x6434, 0x646d,0x647b,0x6572,0x65a1,
  0x65d7,0x65d6,0x66a2,0x66a8, 0x669d,0x699c,0x69a8,0x6995,
  0x69c1,0x69ae,0x69d3,0x69cb, 0x699b,0x69b7,0x69bb,0x69ab,
  0x69b4,0x69d0,0x69cd,0x69ad, 0x69cc,0x69a6,0x69c3,0x69a3,
  0x6b49,0x6b4c,0x6c33,0x6f33, 0x6f14,0x6efe,0x6f13,0x6ef4,
  0x6f29,0x6f3e,0x6f20,0x6f2c, 0x6f0f,0x6f02,0x6f22,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x6eff,0x6eef,0x6f06,0x6f31, 0x6f38,0x6f32,0x6f23,0x6f15,
  0x6f2b,0x6f2f,0x6f88,0x6f2a, 0x6eec,0x6f01,0x6ef2,0x6ecc,
  0x6ef7,0x7194,0x7199,0x717d, 0x718a,0x7184,0x7192,0x723e,
  0x7292,0x7296,0x7344,0x7350, 0x7464,0x7463,0x746a,0x7470,
  0x746d,0x7504,0x7591,0x7627, 0x760d,0x760b,0x7609,0x7613,
  0x76e1,0x76e3,0x7784,0x777d, 0x777f,0x7761,0x78c1,0x789f,
  0x78a7,0x78b3,0x78a9,0x78a3, 0x798e,0x798f,0x798d,0x7a2e,
  0x7a31,0x7aaa,0x7aa9,0x7aed, 0x7aef,0x7ba1,0x7b95,0x7b8b,
  0x7b75,0x7b97,0x7b9d,0x7b94, 0x7b8f,0x7bb8,0x7b87,0x7b84,
  0x7cb9,0x7cbd,0x7cbe,0x7dbb, 0x7db0,0x7d9c,0x7dbd,0x7dbe,
  0x7da0,0x7dca,0x7db4,0x7db2, 0x7db1,0x7dba,0x7da2,0x7dbf,
  0x7db5,0x7db8,0x7dad,0x7dd2, 0x7dc7,0x7dac,
/* bb00 */
  0x7f70,0x7fe0,0x7fe1,0x7fdf, 0x805e,0x805a,0x8087,0x8150,
  0x8180,0x818f,0x8188,0x818a, 0x817f,0x8182,0x81e7,0x81fa,
  0x8207,0x8214,0x821e,0x824b, 0x84c9,0x84bf,0x84c6,0x84c4,
  0x8499,0x849e,0x84b2,0x849c, 0x84cb,0x84b8,0x84c0,0x84d3,
  0x8490,0x84bc,0x84d1,0x84ca, 0x873f,0x871c,0x873b,0x8722,
  0x8725,0x8734,0x8718,0x8755, 0x8737,0x8729,0x88f3,0x8902,
  0x88f4,0x88f9,0x88f8,0x88fd, 0x88e8,0x891a,0x88ef,0x8aa6,
  0x8a8c,0x8a9e,0x8aa3,0x8a8d, 0x8aa1,0x8a93,0x8aa4,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x8aaa,0x8aa5,0x8aa8,0x8a98, 0x8a91,0x8a9a,0x8aa7,0x8c6a,
  0x8c8d,0x8c8c,0x8cd3,0x8cd1, 0x8cd2,0x8d6b,0x8d99,0x8d95,
  0x8dfc,0x8f14,0x8f12,0x8f15, 0x8f13,0x8fa3,0x9060,0x9058,
  0x905c,0x9063,0x9059,0x905e, 0x9062,0x905d,0x905b,0x9119,
  0x9118,0x911e,0x9175,0x9178, 0x9177,0x9174,0x9278,0x9280,
  0x9285,0x9298,0x9296,0x927b, 0x9293,0x929c,0x92a8,0x927c,
  0x9291,0x95a1,0x95a8,0x95a9, 0x95a3,0x95a5,0x95a4,0x9699,
  0x969c,0x969b,0x96cc,0x96d2, 0x9700,0x977c,0x9785,0x97f6,
  0x9817,0x9818,0x98af,0x98b1, 0x9903,0x9905,0x990c,0x9909,
  0x99c1,0x9aaf,0x9ab0,0x9ae6, 0x9b41,0x9b42,0x9cf4,0x9cf6,
  0x9cf3,0x9ebc,0x9f3b,0x9f4a, 0x5104,0x5100,0x50fb,0x50f5,
  0x50f9,0x5102,0x5108,0x5109, 0x5105,0x51dc,
/* bc00 */
  0x5287,0x5288,0x5289,0x528d, 0x528a,0x52f0,0x53b2,0x562e,
  0x563b,0x5639,0x5632,0x563f, 0x5634,0x5629,0x5653,0x564e,
  0x5657,0x5674,0x5636,0x562f, 0x5630,0x5880,0x589f,0x589e,
  0x58b3,0x589c,0x58ae,0x58a9, 0x58a6,0x596d,0x5b09,0x5afb,
  0x5b0b,0x5af5,0x5b0c,0x5b08, 0x5bee,0x5bec,0x5be9,0x5beb,
  0x5c64,0x5c65,0x5d9d,0x5d94, 0x5e62,0x5e5f,0x5e61,0x5ee2,
  0x5eda,0x5edf,0x5edd,0x5ee3, 0x5ee0,0x5f48,0x5f71,0x5fb7,
  0x5fb5,0x6176,0x6167,0x616e, 0x615d,0x6155,0x6182,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x617c,0x6170,0x616b,0x617e, 0x61a7,0x6190,0x61ab,0x618e,
  0x61ac,0x619a,0x61a4,0x6194, 0x61ae,0x622e,0x6469,0x646f,
  0x6479,0x649e,0x64b2,0x6488, 0x6490,0x64b0,0x64a5,0x6493,
  0x6495,0x64a9,0x6492,0x64ae, 0x64ad,0x64ab,0x649a,0x64ac,
  0x6499,0x64a2,0x64b3,0x6575, 0x6577,0x6578,0x66ae,0x66ab,
  0x66b4,0x66b1,0x6a23,0x6a1f, 0x69e8,0x6a01,0x6a1e,0x6a19,
  0x69fd,0x6a21,0x6a13,0x6a0a, 0x69f3,0x6a02,0x6a05,0x69ed,
  0x6a11,0x6b50,0x6b4e,0x6ba4, 0x6bc5,0x6bc6,0x6f3f,0x6f7c,
  0x6f84,0x6f51,0x6f66,0x6f54, 0x6f86,0x6f6d,0x6f5b,0x6f78,
  0x6f6e,0x6f8e,0x6f7a,0x6f70, 0x6f64,0x6f97,0x6f58,0x6ed5,
  0x6f6f,0x6f60,0x6f5f,0x719f, 0x71ac,0x71b1,0x71a8,0x7256,
  0x729b,0x734e,0x7357,0x7469, 0x748b,0x7483,
/* bd00 */
  0x747e,0x7480,0x757f,0x7620, 0x7629,0x761f,0x7624,0x7626,
  0x7621,0x7622,0x769a,0x76ba, 0x76e4,0x778e,0x7787,0x778c,
  0x7791,0x778b,0x78cb,0x78c5, 0x78ba,0x78ca,0x78be,0x78d5,
  0x78bc,0x78d0,0x7a3f,0x7a3c, 0x7a40,0x7a3d,0x7a37,0x7a3b,
  0x7aaf,0x7aae,0x7bad,0x7bb1, 0x7bc4,0x7bb4,0x7bc6,0x7bc7,
  0x7bc1,0x7ba0,0x7bcc,0x7cca, 0x7de0,0x7df4,0x7def,0x7dfb,
  0x7dd8,0x7dec,0x7ddd,0x7de8, 0x7de3,0x7dda,0x7dde,0x7de9,
  0x7d9e,0x7dd9,0x7df2,0x7df9, 0x7f75,0x7f77,0x7faf,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x7fe9,0x8026,0x819b,0x819c, 0x819d,0x81a0,0x819a,0x8198,
  0x8517,0x853d,0x851a,0x84ee, 0x852c,0x852d,0x8513,0x8511,
  0x8523,0x8521,0x8514,0x84ec, 0x8525,0x84ff,0x8506,0x8782,
  0x8774,0x8776,0x8760,0x8766, 0x8778,0x8768,0x8759,0x8757,
  0x874c,0x8753,0x885b,0x885d, 0x8910,0x8907,0x8912,0x8913,
  0x8915,0x890a,0x8abc,0x8ad2, 0x8ac7,0x8ac4,0x8a95,0x8acb,
  0x8af8,0x8ab2,0x8ac9,0x8ac2, 0x8abf,0x8ab0,0x8ad6,0x8acd,
  0x8ab6,0x8ab9,0x8adb,0x8c4c, 0x8c4e,0x8c6c,0x8ce0,0x8cde,
  0x8ce6,0x8ce4,0x8cec,0x8ced, 0x8ce2,0x8ce3,0x8cdc,0x8cea,
  0x8ce1,0x8d6d,0x8d9f,0x8da3, 0x8e2b,0x8e10,0x8e1d,0x8e22,
  0x8e0f,0x8e29,0x8e1f,0x8e21, 0x8e1e,0x8eba,0x8f1d,0x8f1b,
  0x8f1f,0x8f29,0x8f26,0x8f2a, 0x8f1c,0x8f1e,
/* be00 */
  0x8f25,0x9069,0x906e,0x9068, 0x906d,0x9077,0x9130,0x912d,
  0x9127,0x9131,0x9187,0x9189, 0x918b,0x9183,0x92c5,0x92bb,
  0x92b7,0x92ea,0x92ac,0x92e4, 0x92c1,0x92b3,0x92bc,0x92d2,
  0x92c7,0x92f0,0x92b2,0x95ad, 0x95b1,0x9704,0x9706,0x9707,
  0x9709,0x9760,0x978d,0x978b, 0x978f,0x9821,0x982b,0x981c,
  0x98b3,0x990a,0x9913,0x9912, 0x9918,0x99dd,0x99d0,0x99df,
  0x99db,0x99d1,0x99d5,0x99d2, 0x99d9,0x9ab7,0x9aee,0x9aef,
  0x9b27,0x9b45,0x9b44,0x9b77, 0x9b6f,0x9d06,0x9d09,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x9d03,0x9ea9,0x9ebe,0x9ece, 0x58a8,0x9f52,0x5112,0x5118,
  0x5114,0x5110,0x5115,0x5180, 0x51aa,0x51dd,0x5291,0x5293,
  0x52f3,0x5659,0x566b,0x5679, 0x5669,0x5664,0x5678,0x566a,
  0x5668,0x5665,0x5671,0x566f, 0x566c,0x5662,0x5676,0x58c1,
  0x58be,0x58c7,0x58c5,0x596e, 0x5b1d,0x5b34,0x5b78,0x5bf0,
  0x5c0e,0x5f4a,0x61b2,0x6191, 0x61a9,0x618a,0x61cd,0x61b6,
  0x61be,0x61ca,0x61c8,0x6230, 0x64c5,0x64c1,0x64cb,0x64bb,
  0x64bc,0x64da,0x64c4,0x64c7, 0x64c2,0x64cd,0x64bf,0x64d2,
  0x64d4,0x64be,0x6574,0x66c6, 0x66c9,0x66b9,0x66c4,0x66c7,
  0x66b8,0x6a3d,0x6a38,0x6a3a, 0x6a59,0x6a6b,0x6a58,0x6a39,
  0x6a44,0x6a62,0x6a61,0x6a4b, 0x6a47,0x6a35,0x6a5f,0x6a48,
  0x6b59,0x6b77,0x6c05,0x6fc2, 0x6fb1,0x6fa1,
/* bf00 */
  0x6fc3,0x6fa4,0x6fc1,0x6fa7, 0x6fb3,0x6fc0,0x6fb9,0x6fb6,
  0x6fa6,0x6fa0,0x6fb4,0x71be, 0x71c9,0x71d0,0x71d2,0x71c8,
  0x71d5,0x71b9,0x71ce,0x71d9, 0x71dc,0x71c3,0x71c4,0x7368,
  0x749c,0x74a3,0x7498,0x749f, 0x749e,0x74e2,0x750c,0x750d,
  0x7634,0x7638,0x763a,0x76e7, 0x76e5,0x77a0,0x779e,0x779f,
  0x77a5,0x78e8,0x78da,0x78ec, 0x78e7,0x79a6,0x7a4d,0x7a4e,
  0x7a46,0x7a4c,0x7a4b,0x7aba, 0x7bd9,0x7c11,0x7bc9,0x7be4,
  0x7bdb,0x7be1,0x7be9,0x7be6, 0x7cd5,0x7cd6,0x7e0a,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x7e11,0x7e08,0x7e1b,0x7e23, 0x7e1e,0x7e1d,0x7e09,0x7e10,
  0x7f79,0x7fb2,0x7ff0,0x7ff1, 0x7fee,0x8028,0x81b3,0x81a9,
  0x81a8,0x81fb,0x8208,0x8258, 0x8259,0x854a,0x8559,0x8548,
  0x8568,0x8569,0x8543,0x8549, 0x856d,0x856a,0x855e,0x8783,
  0x879f,0x879e,0x87a2,0x878d, 0x8861,0x892a,0x8932,0x8925,
  0x892b,0x8921,0x89aa,0x89a6, 0x8ae6,0x8afa,0x8aeb,0x8af1,
  0x8b00,0x8adc,0x8ae7,0x8aee, 0x8afe,0x8b01,0x8b02,0x8af7,
  0x8aed,0x8af3,0x8af6,0x8afc, 0x8c6b,0x8c6d,0x8c93,0x8cf4,
  0x8e44,0x8e31,0x8e34,0x8e42, 0x8e39,0x8e35,0x8f3b,0x8f2f,
  0x8f38,0x8f33,0x8fa8,0x8fa6, 0x9075,0x9074,0x9078,0x9072,
  0x907c,0x907a,0x9134,0x9192, 0x9320,0x9336,0x92f8,0x9333,
  0x932f,0x9322,0x92fc,0x932b, 0x9304,0x931a,
/* c000 */
  0x9310,0x9326,0x9321,0x9315, 0x932e,0x9319,0x95bb,0x96a7,
  0x96a8,0x96aa,0x96d5,0x970e, 0x9711,0x9716,0x970d,0x9713,
  0x970f,0x975b,0x975c,0x9766, 0x9798,0x9830,0x9838,0x983b,
  0x9837,0x982d,0x9839,0x9824, 0x9910,0x9928,0x991e,0x991b,
  0x9921,0x991a,0x99ed,0x99e2, 0x99f1,0x9ab8,0x9abc,0x9afb,
  0x9aed,0x9b28,0x9b91,0x9d15, 0x9d23,0x9d26,0x9d28,0x9d12,
  0x9d1b,0x9ed8,0x9ed4,0x9f8d, 0x9f9c,0x512a,0x511f,0x5121,
  0x5132,0x52f5,0x568e,0x5680, 0x5690,0x5685,0x5687,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x568f,0x58d5,0x58d3,0x58d1, 0x58ce,0x5b30,0x5b2a,0x5b24,
  0x5b7a,0x5c37,0x5c68,0x5dbc, 0x5dba,0x5dbd,0x5db8,0x5e6b,
  0x5f4c,0x5fbd,0x61c9,0x61c2, 0x61c7,0x61e6,0x61cb,0x6232,
  0x6234,0x64ce,0x64ca,0x64d8, 0x64e0,0x64f0,0x64e6,0x64ec,
  0x64f1,0x64e2,0x64ed,0x6582, 0x6583,0x66d9,0x66d6,0x6a80,
  0x6a94,0x6a84,0x6aa2,0x6a9c, 0x6adb,0x6aa3,0x6a7e,0x6a97,
  0x6a90,0x6aa0,0x6b5c,0x6bae, 0x6bda,0x6c08,0x6fd8,0x6ff1,
  0x6fdf,0x6fe0,0x6fdb,0x6fe4, 0x6feb,0x6fef,0x6f80,0x6fec,
  0x6fe1,0x6fe9,0x6fd5,0x6fee, 0x6ff0,0x71e7,0x71df,0x71ee,
  0x71e6,0x71e5,0x71ed,0x71ec, 0x71f4,0x71e0,0x7235,0x7246,
  0x7370,0x7372,0x74a9,0x74b0, 0x74a6,0x74a8,0x7646,0x7642,
  0x764c,0x76ea,0x77b3,0x77aa, 0x77b0,0x77ac,
/* c100 */
  0x77a7,0x77ad,0x77ef,0x78f7, 0x78fa,0x78f4,0x78ef,0x7901,
  0x79a7,0x79aa,0x7a57,0x7abf, 0x7c07,0x7c0d,0x7bfe,0x7bf7,
  0x7c0c,0x7be0,0x7ce0,0x7cdc, 0x7cde,0x7ce2,0x7cdf,0x7cd9,
  0x7cdd,0x7e2e,0x7e3e,0x7e46, 0x7e37,0x7e32,0x7e43,0x7e2b,
  0x7e3d,0x7e31,0x7e45,0x7e41, 0x7e34,0x7e39,0x7e48,0x7e35,
  0x7e3f,0x7e2f,0x7f44,0x7ff3, 0x7ffc,0x8071,0x8072,0x8070,
  0x806f,0x8073,0x81c6,0x81c3, 0x81ba,0x81c2,0x81c0,0x81bf,
  0x81bd,0x81c9,0x81be,0x81e8, 0x8209,0x8271,0x85aa,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x8584,0x857e,0x859c,0x8591, 0x8594,0x85af,0x859b,0x8587,
  0x85a8,0x858a,0x8667,0x87c0, 0x87d1,0x87b3,0x87d2,0x87c6,
  0x87ab,0x87bb,0x87ba,0x87c8, 0x87cb,0x893b,0x8936,0x8944,
  0x8938,0x893d,0x89ac,0x8b0e, 0x8b17,0x8b19,0x8b1b,0x8b0a,
  0x8b20,0x8b1d,0x8b04,0x8b10, 0x8c41,0x8c3f,0x8c73,0x8cfa,
  0x8cfd,0x8cfc,0x8cf8,0x8cfb, 0x8da8,0x8e49,0x8e4b,0x8e48,
  0x8e4a,0x8f44,0x8f3e,0x8f42, 0x8f45,0x8f3f,0x907f,0x907d,
  0x9084,0x9081,0x9082,0x9080, 0x9139,0x91a3,0x919e,0x919c,
  0x934d,0x9382,0x9328,0x9375, 0x934a,0x9365,0x934b,0x9318,
  0x937e,0x936c,0x935b,0x9370, 0x935a,0x9354,0x95ca,0x95cb,
  0x95cc,0x95c8,0x95c6,0x96b1, 0x96b8,0x96d6,0x971c,0x971e,
  0x97a0,0x97d3,0x9846,0x98b6, 0x9935,0x9a01,
/* c200 */
  0x99ff,0x9bae,0x9bab,0x9baa, 0x9bad,0x9d3b,0x9d3f,0x9e8b,
  0x9ecf,0x9ede,0x9edc,0x9edd, 0x9edb,0x9f3e,0x9f4b,0x53e2,
  0x5695,0x56ae,0x58d9,0x58d8, 0x5b38,0x5f5e,0x61e3,0x6233,
  0x64f4,0x64f2,0x64fe,0x6506, 0x64fa,0x64fb,0x64f7,0x65b7,
  0x66dc,0x6726,0x6ab3,0x6aac, 0x6ac3,0x6abb,0x6ab8,0x6ac2,
  0x6aae,0x6aaf,0x6b5f,0x6b78, 0x6baf,0x7009,0x700b,0x6ffe,
  0x7006,0x6ffa,0x7011,0x700f, 0x71fb,0x71fc,0x71fe,0x71f8,
  0x7377,0x7375,0x74a7,0x74bf, 0x7515,0x7656,0x7658,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x7652,0x77bd,0x77bf,0x77bb, 0x77bc,0x790e,0x79ae,0x7a61,
  0x7a62,0x7a60,0x7ac4,0x7ac5, 0x7c2b,0x7c27,0x7c2a,0x7c1e,
  0x7c23,0x7c21,0x7ce7,0x7e54, 0x7e55,0x7e5e,0x7e5a,0x7e61,
  0x7e52,0x7e59,0x7f48,0x7ff9, 0x7ffb,0x8077,0x8076,0x81cd,
  0x81cf,0x820a,0x85cf,0x85a9, 0x85cd,0x85d0,0x85c9,0x85b0,
  0x85ba,0x85b9,0x85a6,0x87ef, 0x87ec,0x87f2,0x87e0,0x8986,
  0x89b2,0x89f4,0x8b28,0x8b39, 0x8b2c,0x8b2b,0x8c50,0x8d05,
  0x8e59,0x8e63,0x8e66,0x8e64, 0x8e5f,0x8e55,0x8ec0,0x8f49,
  0x8f4d,0x9087,0x9083,0x9088, 0x91ab,0x91ac,0x91d0,0x9394,
  0x938a,0x9396,0x93a2,0x93b3, 0x93ae,0x93ac,0x93b0,0x9398,
  0x939a,0x9397,0x95d4,0x95d6, 0x95d0,0x95d5,0x96e2,0x96dc,
  0x96d9,0x96db,0x96de,0x9724, 0x97a3,0x97a6,
/* c300 */
  0x97ad,0x97f9,0x984d,0x984f, 0x984c,0x984e,0x9853,0x98ba,
  0x993e,0x993f,0x993d,0x992e, 0x99a5,0x9a0e,0x9ac1,0x9b03,
  0x9b06,0x9b4f,0x9b4e,0x9b4d, 0x9bca,0x9bc9,0x9bfd,0x9bc8,
  0x9bc0,0x9d51,0x9d5d,0x9d60, 0x9ee0,0x9f15,0x9f2c,0x5133,
  0x56a5,0x58de,0x58df,0x58e2, 0x5bf5,0x9f90,0x5eec,0x61f2,
  0x61f7,0x61f6,0x61f5,0x6500, 0x650f,0x66e0,0x66dd,0x6ae5,
  0x6add,0x6ada,0x6ad3,0x701b, 0x701f,0x7028,0x701a,0x701d,
  0x7015,0x7018,0x7206,0x720d, 0x7258,0x72a2,0x7378,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x737a,0x74bd,0x74ca,0x74e3, 0x7587,0x7586,0x765f,0x7661,
  0x77c7,0x7919,0x79b1,0x7a6b, 0x7a69,0x7c3e,0x7c3f,0x7c38,
  0x7c3d,0x7c37,0x7c40,0x7e6b, 0x7e6d,0x7e79,0x7e69,0x7e6a,
  0x7f85,0x7e73,0x7fb6,0x7fb9, 0x7fb8,0x81d8,0x85e9,0x85dd,
  0x85ea,0x85d5,0x85e4,0x85e5, 0x85f7,0x87fb,0x8805,0x880d,
  0x87f9,0x87fe,0x8960,0x895f, 0x8956,0x895e,0x8b41,0x8b5c,
  0x8b58,0x8b49,0x8b5a,0x8b4e, 0x8b4f,0x8b46,0x8b59,0x8d08,
  0x8d0a,0x8e7c,0x8e72,0x8e87, 0x8e76,0x8e6c,0x8e7a,0x8e74,
  0x8f54,0x8f4e,0x8fad,0x908a, 0x908b,0x91b1,0x91ae,0x93e1,
  0x93d1,0x93df,0x93c3,0x93c8, 0x93dc,0x93dd,0x93d6,0x93e2,
  0x93cd,0x93d8,0x93e4,0x93d7, 0x93e8,0x95dc,0x96b4,0x96e3,
  0x972a,0x9727,0x9761,0x97dc, 0x97fb,0x985e,
/* c400 */
  0x9858,0x985b,0x98bc,0x9945, 0x9949,0x9a16,0x9a19,0x9b0d,
  0x9be8,0x9be7,0x9bd6,0x9bdb, 0x9d89,0x9d61,0x9d72,0x9d6a,
  0x9d6c,0x9e92,0x9e97,0x9e93, 0x9eb4,0x52f8,0x56a8,0x56b7,
  0x56b6,0x56b4,0x56bc,0x58e4, 0x5b40,0x5b43,0x5b7d,0x5bf6,
  0x5dc9,0x61f8,0x61fa,0x6518, 0x6514,0x6519,0x66e6,0x6727,
  0x6aec,0x703e,0x7030,0x7032, 0x7210,0x737b,0x74cf,0x7662,
  0x7665,0x7926,0x792a,0x792c, 0x792b,0x7ac7,0x7af6,0x7c4c,
  0x7c43,0x7c4d,0x7cef,0x7cf0, 0x8fae,0x7e7d,0x7e7c,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x7e82,0x7f4c,0x8000,0x81da, 0x8266,0x85fb,0x85f9,0x8611,
  0x85fa,0x8606,0x860b,0x8607, 0x860a,0x8814,0x8815,0x8964,
  0x89ba,0x89f8,0x8b70,0x8b6c, 0x8b66,0x8b6f,0x8b5f,0x8b6b,
  0x8d0f,0x8d0d,0x8e89,0x8e81, 0x8e85,0x8e82,0x91b4,0x91cb,
  0x9418,0x9403,0x93fd,0x95e1, 0x9730,0x98c4,0x9952,0x9951,
  0x99a8,0x9a2b,0x9a30,0x9a37, 0x9a35,0x9c13,0x9c0d,0x9e79,
  0x9eb5,0x9ee8,0x9f2f,0x9f5f, 0x9f63,0x9f61,0x5137,0x5138,
  0x56c1,0x56c0,0x56c2,0x5914, 0x5c6c,0x5dcd,0x61fc,0x61fe,
  0x651d,0x651c,0x6595,0x66e9, 0x6afb,0x6b04,0x6afa,0x6bb2,
  0x704c,0x721b,0x72a7,0x74d6, 0x74d4,0x7669,0x77d3,0x7c50,
  0x7e8f,0x7e8c,0x7fbc,0x8617, 0x862d,0x861a,0x8823,0x8822,
  0x8821,0x881f,0x896a,0x896c, 0x89bd,0x8b74,
/* c500 */
  0x8b77,0x8b7d,0x8d13,0x8e8a, 0x8e8d,0x8e8b,0x8f5f,0x8faf,
  0x91ba,0x942e,0x9433,0x9435, 0x943a,0x9438,0x9432,0x942b,
  0x95e2,0x9738,0x9739,0x9732, 0x97ff,0x9867,0x9865,0x9957,
  0x9a45,0x9a43,0x9a40,0x9a3e, 0x9acf,0x9b54,0x9b51,0x9c2d,
  0x9c25,0x9daf,0x9db4,0x9dc2, 0x9db8,0x9e9d,0x9eef,0x9f19,
  0x9f5c,0x9f66,0x9f67,0x513c, 0x513b,0x56c8,0x56ca,0x56c9,
  0x5b7f,0x5dd4,0x5dd2,0x5f4e, 0x61ff,0x6524,0x6b0a,0x6b61,
  0x7051,0x7058,0x7380,0x74e4, 0x758a,0x766e,0x766c,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x79b3,0x7c60,0x7c5f,0x807e, 0x807d,0x81df,0x8972,0x896f,
  0x89fc,0x8b80,0x8d16,0x8d17, 0x8e91,0x8e93,0x8f61,0x9148,
  0x9444,0x9451,0x9452,0x973d, 0x973e,0x97c3,0x97c1,0x986b,
  0x9955,0x9a55,0x9a4d,0x9ad2, 0x9b1a,0x9c49,0x9c31,0x9c3e,
  0x9c3b,0x9dd3,0x9dd7,0x9f34, 0x9f6c,0x9f6a,0x9f94,0x56cc,
  0x5dd6,0x6200,0x6523,0x652b, 0x652a,0x66ec,0x6b10,0x74da,
  0x7aca,0x7c64,0x7c63,0x7c65, 0x7e93,0x7e96,0x7e94,0x81e2,
  0x8638,0x863f,0x8831,0x8b8a, 0x9090,0x908f,0x9463,0x9460,
  0x9464,0x9768,0x986f,0x995c, 0x9a5a,0x9a5b,0x9a57,0x9ad3,
  0x9ad4,0x9ad1,0x9c54,0x9c57, 0x9c56,0x9de5,0x9e9f,0x9ef4,
  0x56d1,0x58e9,0x652c,0x705e, 0x7671,0x7672,0x77d7,0x7f50,
  0x7f88,0x8836,0x8839,0x8862, 0x8b93,0x8b92,
/* c600 */
  0x8b96,0x8277,0x8d1b,0x91c0, 0x946a,0x9742,0x9748,0x9744,
  0x97c6,0x9870,0x9a5f,0x9b22, 0x9b58,0x9c5f,0x9df9,0x9dfa,
  0x9e7c,0x9e7d,0x9f07,0x9f77, 0x9f72,0x5ef3,0x6b16,0x7063,
  0x7c6c,0x7c6e,0x883b,0x89c0, 0x8ea1,0x91c1,0x9472,0x9470,
  0x9871,0x995e,0x9ad6,0x9b23, 0x9ecc,0x7064,0x77da,0x8b9a,
  0x9477,0x97c9,0x9a62,0x9a65, 0x7e9c,0x8b9c,0x8eaa,0x91c5,
  0x947d,0x947e,0x947c,0x9c77, 0x9c78,0x9ef7,0x8c54,0x947f,
  0x9e1a,0x7228,0x9a6a,0x9b31, 0x9e1b,0x9e1e,0x7c72,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x2460,0x2461,0x2462,0x2463, 0x2464,0x2465,0x2466,0x2467,
  0x2468,0x2469,0x2474,0x2475, 0x2476,0x2477,0x2478,0x2479,
  0x247a,0x247b,0x247c,0x247d, 0x2170,0x2171,0x2172,0x2173,
  0x2174,0x2175,0x2176,0x2177, 0x2178,0x2179,0x2f02,0x2f03,
  0x2f04,0x2f07,0x2f0c,0x2f0d, 0x2f0e,0x2f13,0x2f16,0x2f19,
  0x2f1b,0x2f22,0x2f27,0x2f2e, 0x2f33,0x2f34,0x2f35,0x2f39,
  0x2f3a,0x2f41,0x2f46,0x2f67, 0x2f68,0x2fa1,0x2faa,0x00a8,
  0x02c6,0x30fd,0x30fe,0x309d, 0x309e,0x309b,0x4edd,0x3005,
  0x3006,0x3007,0x30fc,0xff3b, 0xff3d,0x273d,0x3041,0x3042,
  0x3043,0x3044,0x3045,0x3046, 0x3047,0x3048,0x3049,0x304a,
  0x304b,0x304c,0x304d,0x304e, 0x304f,0x3050,0x3051,0x3052,
  0x3053,0x3054,0x3055,0x3056, 0x3057,0x3058,
/* c700 */
  0x3059,0x305a,0x305b,0x305c, 0x305d,0x305e,0x305f,0x3060,
  0x3061,0x3062,0x3063,0x3064, 0x3065,0x3066,0x3067,0x3068,
  0x3069,0x306a,0x306b,0x306c, 0x306d,0x306e,0x306f,0x3070,
  0x3071,0x3072,0x3073,0x3074, 0x3075,0x3076,0x3077,0x3078,
  0x3079,0x307a,0x307b,0x307c, 0x307d,0x307e,0x307f,0x3080,
  0x3081,0x3082,0x3083,0x3084, 0x3085,0x3086,0x3087,0x3088,
  0x3089,0x308a,0x308b,0x308c, 0x308d,0x308e,0x308f,0x3090,
  0x3091,0x3092,0x3093,0x30a1, 0x30a2,0x30a3,0x30a4,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x30a5,0x30a6,0x30a7,0x30a8, 0x30a9,0x30aa,0x30ab,0x30ac,
  0x30ad,0x30ae,0x30af,0x30b0, 0x30b1,0x30b2,0x30b3,0x30b4,
  0x30b5,0x30b6,0x30b7,0x30b8, 0x30b9,0x30ba,0x30bb,0x30bc,
  0x30bd,0x30be,0x30bf,0x30c0, 0x30c1,0x30c2,0x30c3,0x30c4,
  0x30c5,0x30c6,0x30c7,0x30c8, 0x30c9,0x30ca,0x30cb,0x30cc,
  0x30cd,0x30ce,0x30cf,0x30d0, 0x30d1,0x30d2,0x30d3,0x30d4,
  0x30d5,0x30d6,0x30d7,0x30d8, 0x30d9,0x30da,0x30db,0x30dc,
  0x30dd,0x30de,0x30df,0x30e0, 0x30e1,0x30e2,0x30e3,0x30e4,
  0x30e5,0x30e6,0x30e7,0x30e8, 0x30e9,0x30ea,0x30eb,0x30ec,
  0x30ed,0x30ee,0x30ef,0x30f0, 0x30f1,0x30f2,0x30f3,0x30f4,
  0x30f5,0x30f6,0x0410,0x0411, 0x0412,0x0413,0x0414,0x0415,
  0x0401,0x0416,0x0417,0x0418, 0x0419,0x041a,
/* c800 */
  0x041b,0x041c,0x041d,0x041e, 0x041f,0x0420,0x0421,0x0422,
  0x0423,0x0424,0x0425,0x0426, 0x0427,0x0428,0x0429,0x042a,
  0x042b,0x042c,0x042d,0x042e, 0x042f,0x0430,0x0431,0x0432,
  0x0433,0x0434,0x0435,0x0451, 0x0436,0x0437,0x0438,0x0439,
  0x043a,0x043b,0x043c,0x043d, 0x043e,0x043f,0x0440,0x0441,
  0x0442,0x0443,0x0444,0x0445, 0x0446,0x0447,0x0448,0x0449,
  0x044a,0x044b,0x044c,0x044d, 0x044e,0x044f,0x21e7,0x21b8,
  0x21b9,0xf7e5,0xf7e6,0x4e5a, 0xf7e8,0x5202,0xf7ea,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xf7eb,0x5188,0xf7ed,0xf7ee, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0xffe2,0xffe4,0xff07,0xff02,
  0x3231,0x2116,0x2121,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* c900 */
  0x4e42,0x4e5c,0x51f5,0x531a, 0x5382,0x4e07,0x4e0c,0x4e47,
  0x4e8d,0x56d7,0xfa0c,0x5c6e, 0x5f73,0x4e0f,0x5187,0x4e0e,
  0x4e2e,0x4e93,0x4ec2,0x4ec9, 0x4ec8,0x5198,0x52fc,0x536c,
  0x53b9,0x5720,0x5903,0x592c, 0x5c10,0x5dff,0x65e1,0x6bb3,
  0x6bcc,0x6c14,0x723f,0x4e31, 0x4e3c,0x4ee8,0x4edc,0x4ee9,
  0x4ee1,0x4edd,0x4eda,0x520c, 0x531c,0x534c,0x5722,0x5723,
  0x5917,0x592f,0x5b81,0x5b84, 0x5c12,0x5c3b,0x5c74,0x5c73,
  0x5e04,0x5e80,0x5e82,0x5fc9, 0x6209,0x6250,0x6c15,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x6c36,0x6c43,0x6c3f,0x6c3b, 0x72ae,0x72b0,0x738a,0x79b8,
  0x808a,0x961e,0x4f0e,0x4f18, 0x4f2c,0x4ef5,0x4f14,0x4ef1,
  0x4f00,0x4ef7,0x4f08,0x4f1d, 0x4f02,0x4f05,0x4f22,0x4f13,
  0x4f04,0x4ef4,0x4f12,0x51b1, 0x5213,0x5209,0x5210,0x52a6,
  0x5322,0x531f,0x534d,0x538a, 0x5407,0x56e1,0x56df,0x572e,
  0x572a,0x5734,0x593c,0x5980, 0x597c,0x5985,0x597b,0x597e,
  0x5977,0x597f,0x5b56,0x5c15, 0x5c25,0x5c7c,0x5c7a,0x5c7b,
  0x5c7e,0x5ddf,0x5e75,0x5e84, 0x5f02,0x5f1a,0x5f74,0x5fd5,
  0x5fd4,0x5fcf,0x625c,0x625e, 0x6264,0x6261,0x6266,0x6262,
  0x6259,0x6260,0x625a,0x6265, 0x65ef,0x65ee,0x673e,0x6739,
  0x6738,0x673b,0x673a,0x673f, 0x673c,0x6733,0x6c18,0x6c46,
  0x6c52,0x6c5c,0x6c4f,0x6c4a, 0x6c54,0x6c4b,
/* ca00 */
  0x6c4c,0x7071,0x725e,0x72b4, 0x72b5,0x738e,0x752a,0x767f,
  0x7a75,0x7f51,0x8278,0x827c, 0x8280,0x827d,0x827f,0x864d,
  0x897e,0x9099,0x9097,0x9098, 0x909b,0x9094,0x9622,0x9624,
  0x9620,0x9623,0x4f56,0x4f3b, 0x4f62,0x4f49,0x4f53,0x4f64,
  0x4f3e,0x4f67,0x4f52,0x4f5f, 0x4f41,0x4f58,0x4f2d,0x4f33,
  0x4f3f,0x4f61,0x518f,0x51b9, 0x521c,0x521e,0x5221,0x52ad,
  0x52ae,0x5309,0x5363,0x5372, 0x538e,0x538f,0x5430,0x5437,
  0x542a,0x5454,0x5445,0x5419, 0x541c,0x5425,0x5418,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x543d,0x544f,0x5441,0x5428, 0x5424,0x5447,0x56ee,0x56e7,
  0x56e5,0x5741,0x5745,0x574c, 0x5749,0x574b,0x5752,0x5906,
  0x5940,0x59a6,0x5998,0x59a0, 0x5997,0x598e,0x59a2,0x5990,
  0x598f,0x59a7,0x59a1,0x5b8e, 0x5b92,0x5c28,0x5c2a,0x5c8d,
  0x5c8f,0x5c88,0x5c8b,0x5c89, 0x5c92,0x5c8a,0x5c86,0x5c93,
  0x5c95,0x5de0,0x5e0a,0x5e0e, 0x5e8b,0x5e89,0x5e8c,0x5e88,
  0x5e8d,0x5f05,0x5f1d,0x5f78, 0x5f76,0x5fd2,0x5fd1,0x5fd0,
  0x5fed,0x5fe8,0x5fee,0x5ff3, 0x5fe1,0x5fe4,0x5fe3,0x5ffa,
  0x5fef,0x5ff7,0x5ffb,0x6000, 0x5ff4,0x623a,0x6283,0x628c,
  0x628e,0x628f,0x6294,0x6287, 0x6271,0x627b,0x627a,0x6270,
  0x6281,0x6288,0x6277,0x627d, 0x6272,0x6274,0x6537,0x65f0,
  0x65f4,0x65f3,0x65f2,0x65f5, 0x6745,0x6747,
/* cb00 */
  0x6759,0x6755,0x674c,0x6748, 0x675d,0x674d,0x675a,0x674b,
  0x6bd0,0x6c19,0x6c1a,0x6c78, 0x6c67,0x6c6b,0x6c84,0x6c8b,
  0x6c8f,0x6c71,0x6c6f,0x6c69, 0x6c9a,0x6c6d,0x6c87,0x6c95,
  0x6c9c,0x6c66,0x6c73,0x6c65, 0x6c7b,0x6c8e,0x7074,0x707a,
  0x7263,0x72bf,0x72bd,0x72c3, 0x72c6,0x72c1,0x72ba,0x72c5,
  0x7395,0x7397,0x7393,0x7394, 0x7392,0x753a,0x7539,0x7594,
  0x7595,0x7681,0x793d,0x8034, 0x8095,0x8099,0x8090,0x8092,
  0x809c,0x8290,0x828f,0x8285, 0x828e,0x8291,0x8293,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x828a,0x8283,0x8284,0x8c78, 0x8fc9,0x8fbf,0x909f,0x90a1,
  0x90a5,0x909e,0x90a7,0x90a0, 0x9630,0x9628,0x962f,0x962d,
  0x4e33,0x4f98,0x4f7c,0x4f85, 0x4f7d,0x4f80,0x4f87,0x4f76,
  0x4f74,0x4f89,0x4f84,0x4f77, 0x4f4c,0x4f97,0x4f6a,0x4f9a,
  0x4f79,0x4f81,0x4f78,0x4f90, 0x4f9c,0x4f94,0x4f9e,0x4f92,
  0x4f82,0x4f95,0x4f6b,0x4f6e, 0x519e,0x51bc,0x51be,0x5235,
  0x5232,0x5233,0x5246,0x5231, 0x52bc,0x530a,0x530b,0x533c,
  0x5392,0x5394,0x5487,0x547f, 0x5481,0x5491,0x5482,0x5488,
  0x546b,0x547a,0x547e,0x5465, 0x546c,0x5474,0x5466,0x548d,
  0x546f,0x5461,0x5460,0x5498, 0x5463,0x5467,0x5464,0x56f7,
  0x56f9,0x576f,0x5772,0x576d, 0x576b,0x5771,0x5770,0x5776,
  0x5780,0x5775,0x577b,0x5773, 0x5774,0x5762,
/* cc00 */
  0x5768,0x577d,0x590c,0x5945, 0x59b5,0x59ba,0x59cf,0x59ce,
  0x59b2,0x59cc,0x59c1,0x59b6, 0x59bc,0x59c3,0x59d6,0x59b1,
  0x59bd,0x59c0,0x59c8,0x59b4, 0x59c7,0x5b62,0x5b65,0x5b93,
  0x5b95,0x5c44,0x5c47,0x5cae, 0x5ca4,0x5ca0,0x5cb5,0x5caf,
  0x5ca8,0x5cac,0x5c9f,0x5ca3, 0x5cad,0x5ca2,0x5caa,0x5ca7,
  0x5c9d,0x5ca5,0x5cb6,0x5cb0, 0x5ca6,0x5e17,0x5e14,0x5e19,
  0x5f28,0x5f22,0x5f23,0x5f24, 0x5f54,0x5f82,0x5f7e,0x5f7d,
  0x5fde,0x5fe5,0x602d,0x6026, 0x6019,0x6032,0x600b,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x6034,0x600a,0x6017,0x6033, 0x601a,0x601e,0x602c,0x6022,
  0x600d,0x6010,0x602e,0x6013, 0x6011,0x600c,0x6009,0x601c,
  0x6214,0x623d,0x62ad,0x62b4, 0x62d1,0x62be,0x62aa,0x62b6,
  0x62ca,0x62ae,0x62b3,0x62af, 0x62bb,0x62a9,0x62b0,0x62b8,
  0x653d,0x65a8,0x65bb,0x6609, 0x65fc,0x6604,0x6612,0x6608,
  0x65fb,0x6603,0x660b,0x660d, 0x6605,0x65fd,0x6611,0x6610,
  0x66f6,0x670a,0x6785,0x676c, 0x678e,0x6792,0x6776,0x677b,
  0x6798,0x6786,0x6784,0x6774, 0x678d,0x678c,0x677a,0x679f,
  0x6791,0x6799,0x6783,0x677d, 0x6781,0x6778,0x6779,0x6794,
  0x6b25,0x6b80,0x6b7e,0x6bde, 0x6c1d,0x6c93,0x6cec,0x6ceb,
  0x6cee,0x6cd9,0x6cb6,0x6cd4, 0x6cad,0x6ce7,0x6cb7,0x6cd0,
  0x6cc2,0x6cba,0x6cc3,0x6cc6, 0x6ced,0x6cf2,
/* cd00 */
  0x6cd2,0x6cdd,0x6cb4,0x6c8a, 0x6c9d,0x6c80,0x6cde,0x6cc0,
  0x6d30,0x6ccd,0x6cc7,0x6cb0, 0x6cf9,0x6ccf,0x6ce9,0x6cd1,
  0x7094,0x7098,0x7085,0x7093, 0x7086,0x7084,0x7091,0x7096,
  0x7082,0x709a,0x7083,0x726a, 0x72d6,0x72cb,0x72d8,0x72c9,
  0x72dc,0x72d2,0x72d4,0x72da, 0x72cc,0x72d1,0x73a4,0x73a1,
  0x73ad,0x73a6,0x73a2,0x73a0, 0x73ac,0x739d,0x74dd,0x74e8,
  0x753f,0x7540,0x753e,0x758c, 0x7598,0x76af,0x76f3,0x76f1,
  0x76f0,0x76f5,0x77f8,0x77fc, 0x77f9,0x77fb,0x77fa,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x77f7,0x7942,0x793f,0x79c5, 0x7a78,0x7a7b,0x7afb,0x7c75,
  0x7cfd,0x8035,0x808f,0x80ae, 0x80a3,0x80b8,0x80b5,0x80ad,
  0x8220,0x82a0,0x82c0,0x82ab, 0x829a,0x8298,0x829b,0x82b5,
  0x82a7,0x82ae,0x82bc,0x829e, 0x82ba,0x82b4,0x82a8,0x82a1,
  0x82a9,0x82c2,0x82a4,0x82c3, 0x82b6,0x82a2,0x8670,0x866f,
  0x866d,0x866e,0x8c56,0x8fd2, 0x8fcb,0x8fd3,0x8fcd,0x8fd6,
  0x8fd5,0x8fd7,0x90b2,0x90b4, 0x90af,0x90b3,0x90b0,0x9639,
  0x963d,0x963c,0x963a,0x9643, 0x4fcd,0x4fc5,0x4fd3,0x4fb2,
  0x4fc9,0x4fcb,0x4fc1,0x4fd4, 0x4fdc,0x4fd9,0x4fbb,0x4fb3,
  0x4fdb,0x4fc7,0x4fd6,0x4fba, 0x4fc0,0x4fb9,0x4fec,0x5244,
  0x5249,0x52c0,0x52c2,0x533d, 0x537c,0x5397,0x5396,0x5399,
  0x5398,0x54ba,0x54a1,0x54ad, 0x54a5,0x54cf,
/* ce00 */
  0x54c3,0x830d,0x54b7,0x54ae, 0x54d6,0x54b6,0x54c5,0x54c6,
  0x54a0,0x5470,0x54bc,0x54a2, 0x54be,0x5472,0x54de,0x54b0,
  0x57b5,0x579e,0x579f,0x57a4, 0x578c,0x5797,0x579d,0x579b,
  0x5794,0x5798,0x578f,0x5799, 0x57a5,0x579a,0x5795,0x58f4,
  0x590d,0x5953,0x59e1,0x59de, 0x59ee,0x5a00,0x59f1,0x59dd,
  0x59fa,0x59fd,0x59fc,0x59f6, 0x59e4,0x59f2,0x59f7,0x59db,
  0x59e9,0x59f3,0x59f5,0x59e0, 0x59fe,0x59f4,0x59ed,0x5ba8,
  0x5c4c,0x5cd0,0x5cd8,0x5ccc, 0x5cd7,0x5ccb,0x5cdb,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x5cde,0x5cda,0x5cc9,0x5cc7, 0x5cca,0x5cd6,0x5cd3,0x5cd4,
  0x5ccf,0x5cc8,0x5cc6,0x5cce, 0x5cdf,0x5cf8,0x5df9,0x5e21,
  0x5e22,0x5e23,0x5e20,0x5e24, 0x5eb0,0x5ea4,0x5ea2,0x5e9b,
  0x5ea3,0x5ea5,0x5f07,0x5f2e, 0x5f56,0x5f86,0x6037,0x6039,
  0x6054,0x6072,0x605e,0x6045, 0x6053,0x6047,0x6049,0x605b,
  0x604c,0x6040,0x6042,0x605f, 0x6024,0x6044,0x6058,0x6066,
  0x606e,0x6242,0x6243,0x62cf, 0x630d,0x630b,0x62f5,0x630e,
  0x6303,0x62eb,0x62f9,0x630f, 0x630c,0x62f8,0x62f6,0x6300,
  0x6313,0x6314,0x62fa,0x6315, 0x62fb,0x62f0,0x6541,0x6543,
  0x65aa,0x65bf,0x6636,0x6621, 0x6632,0x6635,0x661c,0x6626,
  0x6622,0x6633,0x662b,0x663a, 0x661d,0x6634,0x6639,0x662e,
  0x670f,0x6710,0x67c1,0x67f2, 0x67c8,0x67ba,
/* cf00 */
  0x67dc,0x67bb,0x67f8,0x67d8, 0x67c0,0x67b7,0x67c5,0x67eb,
  0x67e4,0x67df,0x67b5,0x67cd, 0x67b3,0x67f7,0x67f6,0x67ee,
  0x67e3,0x67c2,0x67b9,0x67ce, 0x67e7,0x67f0,0x67b2,0x67fc,
  0x67c6,0x67ed,0x67cc,0x67ae, 0x67e6,0x67db,0x67fa,0x67c9,
  0x67ca,0x67c3,0x67ea,0x67cb, 0x6b28,0x6b82,0x6b84,0x6bb6,
  0x6bd6,0x6bd8,0x6be0,0x6c20, 0x6c21,0x6d28,0x6d34,0x6d2d,
  0x6d1f,0x6d3c,0x6d3f,0x6d12, 0x6d0a,0x6cda,0x6d33,0x6d04,
  0x6d19,0x6d3a,0x6d1a,0x6d11, 0x6d00,0x6d1d,0x6d42,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x6d01,0x6d18,0x6d37,0x6d03, 0x6d0f,0x6d40,0x6d07,0x6d20,
  0x6d2c,0x6d08,0x6d22,0x6d09, 0x6d10,0x70b7,0x709f,0x70be,
  0x70b1,0x70b0,0x70a1,0x70b4, 0x70b5,0x70a9,0x7241,0x7249,
  0x724a,0x726c,0x7270,0x7273, 0x726e,0x72ca,0x72e4,0x72e8,
  0x72eb,0x72df,0x72ea,0x72e6, 0x72e3,0x7385,0x73cc,0x73c2,
  0x73c8,0x73c5,0x73b9,0x73b6, 0x73b5,0x73b4,0x73eb,0x73bf,
  0x73c7,0x73be,0x73c3,0x73c6, 0x73b8,0x73cb,0x74ec,0x74ee,
  0x752e,0x7547,0x7548,0x75a7, 0x75aa,0x7679,0x76c4,0x7708,
  0x7703,0x7704,0x7705,0x770a, 0x76f7,0x76fb,0x76fa,0x77e7,
  0x77e8,0x7806,0x7811,0x7812, 0x7805,0x7810,0x780f,0x780e,
  0x7809,0x7803,0x7813,0x794a, 0x794c,0x794b,0x7945,0x7944,
  0x79d5,0x79cd,0x79cf,0x79d6, 0x79ce,0x7a80,
/* d000 */
  0x7a7e,0x7ad1,0x7b00,0x7b01, 0x7c7a,0x7c78,0x7c79,0x7c7f,
  0x7c80,0x7c81,0x7d03,0x7d08, 0x7d01,0x7f58,0x7f91,0x7f8d,
  0x7fbe,0x8007,0x800e,0x800f, 0x8014,0x8037,0x80d8,0x80c7,
  0x80e0,0x80d1,0x80c8,0x80c2, 0x80d0,0x80c5,0x80e3,0x80d9,
  0x80dc,0x80ca,0x80d5,0x80c9, 0x80cf,0x80d7,0x80e6,0x80cd,
  0x81ff,0x8221,0x8294,0x82d9, 0x82fe,0x82f9,0x8307,0x82e8,
  0x8300,0x82d5,0x833a,0x82eb, 0x82d6,0x82f4,0x82ec,0x82e1,
  0x82f2,0x82f5,0x830c,0x82fb, 0x82f6,0x82f0,0x82ea,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x82e4,0x82e0,0x82fa,0x82f3, 0x82ed,0x8677,0x8674,0x867c,
  0x8673,0x8841,0x884e,0x8867, 0x886a,0x8869,0x89d3,0x8a04,
  0x8a07,0x8d72,0x8fe3,0x8fe1, 0x8fee,0x8fe0,0x90f1,0x90bd,
  0x90bf,0x90d5,0x90c5,0x90be, 0x90c7,0x90cb,0x90c8,0x91d4,
  0x91d3,0x9654,0x964f,0x9651, 0x9653,0x964a,0x964e,0x501e,
  0x5005,0x5007,0x5013,0x5022, 0x5030,0x501b,0x4ff5,0x4ff4,
  0x5033,0x5037,0x502c,0x4ff6, 0x4ff7,0x5017,0x501c,0x5020,
  0x5027,0x5035,0x502f,0x5031, 0x500e,0x515a,0x5194,0x5193,
  0x51ca,0x51c4,0x51c5,0x51c8, 0x51ce,0x5261,0x525a,0x5252,
  0x525e,0x525f,0x5255,0x5262, 0x52cd,0x530e,0x539e,0x5526,
  0x54e2,0x5517,0x5512,0x54e7, 0x54f3,0x54e4,0x551a,0x54ff,
  0x5504,0x5508,0x54eb,0x5511, 0x5505,0x54f1,
/* d100 */
  0x550a,0x54fb,0x54f7,0x54f8, 0x54e0,0x550e,0x5503,0x550b,
  0x5701,0x5702,0x57cc,0x5832, 0x57d5,0x57d2,0x57ba,0x57c6,
  0x57bd,0x57bc,0x57b8,0x57b6, 0x57bf,0x57c7,0x57d0,0x57b9,
  0x57c1,0x590e,0x594a,0x5a19, 0x5a16,0x5a2d,0x5a2e,0x5a15,
  0x5a0f,0x5a17,0x5a0a,0x5a1e, 0x5a33,0x5b6c,0x5ba7,0x5bad,
  0x5bac,0x5c03,0x5c56,0x5c54, 0x5cec,0x5cff,0x5cee,0x5cf1,
  0x5cf7,0x5d00,0x5cf9,0x5e29, 0x5e28,0x5ea8,0x5eae,0x5eaa,
  0x5eac,0x5f33,0x5f30,0x5f67, 0x605d,0x605a,0x6067,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x6041,0x60a2,0x6088,0x6080, 0x6092,0x6081,0x609d,0x6083,
  0x6095,0x609b,0x6097,0x6087, 0x609c,0x608e,0x6219,0x6246,
  0x62f2,0x6310,0x6356,0x632c, 0x6344,0x6345,0x6336,0x6343,
  0x63e4,0x6339,0x634b,0x634a, 0x633c,0x6329,0x6341,0x6334,
  0x6358,0x6354,0x6359,0x632d, 0x6347,0x6333,0x635a,0x6351,
  0x6338,0x6357,0x6340,0x6348, 0x654a,0x6546,0x65c6,0x65c3,
  0x65c4,0x65c2,0x664a,0x665f, 0x6647,0x6651,0x6712,0x6713,
  0x681f,0x681a,0x6849,0x6832, 0x6833,0x683b,0x684b,0x684f,
  0x6816,0x6831,0x681c,0x6835, 0x682b,0x682d,0x682f,0x684e,
  0x6844,0x6834,0x681d,0x6812, 0x6814,0x6826,0x6828,0x682e,
  0x684d,0x683a,0x6825,0x6820, 0x6b2c,0x6b2f,0x6b2d,0x6b31,
  0x6b34,0x6b6d,0x8082,0x6b88, 0x6be6,0x6be4,
/* d200 */
  0x6be8,0x6be3,0x6be2,0x6be7, 0x6c25,0x6d7a,0x6d63,0x6d64,
  0x6d76,0x6d0d,0x6d61,0x6d92, 0x6d58,0x6d62,0x6d6d,0x6d6f,
  0x6d91,0x6d8d,0x6def,0x6d7f, 0x6d86,0x6d5e,0x6d67,0x6d60,
  0x6d97,0x6d70,0x6d7c,0x6d5f, 0x6d82,0x6d98,0x6d2f,0x6d68,
  0x6d8b,0x6d7e,0x6d80,0x6d84, 0x6d16,0x6d83,0x6d7b,0x6d7d,
  0x6d75,0x6d90,0x70dc,0x70d3, 0x70d1,0x70dd,0x70cb,0x7f39,
  0x70e2,0x70d7,0x70d2,0x70de, 0x70e0,0x70d4,0x70cd,0x70c5,
  0x70c6,0x70c7,0x70da,0x70ce, 0x70e1,0x7242,0x7278,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x7277,0x7276,0x7300,0x72fa, 0x72f4,0x72fe,0x72f6,0x72f3,
  0x72fb,0x7301,0x73d3,0x73d9, 0x73e5,0x73d6,0x73bc,0x73e7,
  0x73e3,0x73e9,0x73dc,0x73d2, 0x73db,0x73d4,0x73dd,0x73da,
  0x73d7,0x73d8,0x73e8,0x74de, 0x74df,0x74f4,0x74f5,0x7521,
  0x755b,0x755f,0x75b0,0x75c1, 0x75bb,0x75c4,0x75c0,0x75bf,
  0x75b6,0x75ba,0x768a,0x76c9, 0x771d,0x771b,0x7710,0x7713,
  0x7712,0x7723,0x7711,0x7715, 0x7719,0x771a,0x7722,0x7727,
  0x7823,0x782c,0x7822,0x7835, 0x782f,0x7828,0x782e,0x782b,
  0x7821,0x7829,0x7833,0x782a, 0x7831,0x7954,0x795b,0x794f,
  0x795c,0x7953,0x7952,0x7951, 0x79eb,0x79ec,0x79e0,0x79ee,
  0x79ed,0x79ea,0x79dc,0x79de, 0x79dd,0x7a86,0x7a89,0x7a85,
  0x7a8b,0x7a8c,0x7a8a,0x7a87, 0x7ad8,0x7b10,
/* d300 */
  0x7b04,0x7b13,0x7b05,0x7b0f, 0x7b08,0x7b0a,0x7b0e,0x7b09,
  0x7b12,0x7c84,0x7c91,0x7c8a, 0x7c8c,0x7c88,0x7c8d,0x7c85,
  0x7d1e,0x7d1d,0x7d11,0x7d0e, 0x7d18,0x7d16,0x7d13,0x7d1f,
  0x7d12,0x7d0f,0x7d0c,0x7f5c, 0x7f61,0x7f5e,0x7f60,0x7f5d,
  0x7f5b,0x7f96,0x7f92,0x7fc3, 0x7fc2,0x7fc0,0x8016,0x803e,
  0x8039,0x80fa,0x80f2,0x80f9, 0x80f5,0x8101,0x80fb,0x8100,
  0x8201,0x822f,0x8225,0x8333, 0x832d,0x8344,0x8319,0x8351,
  0x8325,0x8356,0x833f,0x8341, 0x8326,0x831c,0x8322,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x8342,0x834e,0x831b,0x832a, 0x8308,0x833c,0x834d,0x8316,
  0x8324,0x8320,0x8337,0x832f, 0x8329,0x8347,0x8345,0x834c,
  0x8353,0x831e,0x832c,0x834b, 0x8327,0x8348,0x8653,0x8652,
  0x86a2,0x86a8,0x8696,0x868d, 0x8691,0x869e,0x8687,0x8697,
  0x8686,0x868b,0x869a,0x8685, 0x86a5,0x8699,0x86a1,0x86a7,
  0x8695,0x8698,0x868e,0x869d, 0x8690,0x8694,0x8843,0x8844,
  0x886d,0x8875,0x8876,0x8872, 0x8880,0x8871,0x887f,0x886f,
  0x8883,0x887e,0x8874,0x887c, 0x8a12,0x8c47,0x8c57,0x8c7b,
  0x8ca4,0x8ca3,0x8d76,0x8d78, 0x8db5,0x8db7,0x8db6,0x8ed1,
  0x8ed3,0x8ffe,0x8ff5,0x9002, 0x8fff,0x8ffb,0x9004,0x8ffc,
  0x8ff6,0x90d6,0x90e0,0x90d9, 0x90da,0x90e3,0x90df,0x90e5,
  0x90d8,0x90db,0x90d7,0x90dc, 0x90e4,0x9150,
/* d400 */
  0x914e,0x914f,0x91d5,0x91e2, 0x91da,0x965c,0x965f,0x96bc,
  0x98e3,0x9adf,0x9b2f,0x4e7f, 0x5070,0x506a,0x5061,0x505e,
  0x5060,0x5053,0x504b,0x505d, 0x5072,0x5048,0x504d,0x5041,
  0x505b,0x504a,0x5062,0x5015, 0x5045,0x505f,0x5069,0x506b,
  0x5063,0x5064,0x5046,0x5040, 0x506e,0x5073,0x5057,0x5051,
  0x51d0,0x526b,0x526d,0x526c, 0x526e,0x52d6,0x52d3,0x532d,
  0x539c,0x5575,0x5576,0x553c, 0x554d,0x5550,0x5534,0x552a,
  0x5551,0x5562,0x5536,0x5535, 0x5530,0x5552,0x5545,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x550c,0x5532,0x5565,0x554e, 0x5539,0x5548,0x552d,0x553b,
  0x5540,0x554b,0x570a,0x5707, 0x57fb,0x5814,0x57e2,0x57f6,
  0x57dc,0x57f4,0x5800,0x57ed, 0x57fd,0x5808,0x57f8,0x580b,
  0x57f3,0x57cf,0x5807,0x57ee, 0x57e3,0x57f2,0x57e5,0x57ec,
  0x57e1,0x580e,0x57fc,0x5810, 0x57e7,0x5801,0x580c,0x57f1,
  0x57e9,0x57f0,0x580d,0x5804, 0x595c,0x5a60,0x5a58,0x5a55,
  0x5a67,0x5a5e,0x5a38,0x5a35, 0x5a6d,0x5a50,0x5a5f,0x5a65,
  0x5a6c,0x5a53,0x5a64,0x5a57, 0x5a43,0x5a5d,0x5a52,0x5a44,
  0x5a5b,0x5a48,0x5a8e,0x5a3e, 0x5a4d,0x5a39,0x5a4c,0x5a70,
  0x5a69,0x5a47,0x5a51,0x5a56, 0x5a42,0x5a5c,0x5b72,0x5b6e,
  0x5bc1,0x5bc0,0x5c59,0x5d1e, 0x5d0b,0x5d1d,0x5d1a,0x5d20,
  0x5d0c,0x5d28,0x5d0d,0x5d26, 0x5d25,0x5d0f,
/* d500 */
  0x5d30,0x5d12,0x5d23,0x5d1f, 0x5d2e,0x5e3e,0x5e34,0x5eb1,
  0x5eb4,0x5eb9,0x5eb2,0x5eb3, 0x5f36,0x5f38,0x5f9b,0x5f96,
  0x5f9f,0x608a,0x6090,0x6086, 0x60be,0x60b0,0x60ba,0x60d3,
  0x60d4,0x60cf,0x60e4,0x60d9, 0x60dd,0x60c8,0x60b1,0x60db,
  0x60b7,0x60ca,0x60bf,0x60c3, 0x60cd,0x60c0,0x6332,0x6365,
  0x638a,0x6382,0x637d,0x63bd, 0x639e,0x63ad,0x639d,0x6397,
  0x63ab,0x638e,0x636f,0x6387, 0x6390,0x636e,0x63af,0x6375,
  0x639c,0x636d,0x63ae,0x637c, 0x63a4,0x633b,0x639f,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x6378,0x6385,0x6381,0x6391, 0x638d,0x6370,0x6553,0x65cd,
  0x6665,0x6661,0x665b,0x6659, 0x665c,0x6662,0x6718,0x6879,
  0x6887,0x6890,0x689c,0x686d, 0x686e,0x68ae,0x68ab,0x6956,
  0x686f,0x68a3,0x68ac,0x68a9, 0x6875,0x6874,0x68b2,0x688f,
  0x6877,0x6892,0x687c,0x686b, 0x6872,0x68aa,0x6880,0x6871,
  0x687e,0x689b,0x6896,0x688b, 0x68a0,0x6889,0x68a4,0x6878,
  0x687b,0x6891,0x688c,0x688a, 0x687d,0x6b36,0x6b33,0x6b37,
  0x6b38,0x6b91,0x6b8f,0x6b8d, 0x6b8e,0x6b8c,0x6c2a,0x6dc0,
  0x6dab,0x6db4,0x6db3,0x6e74, 0x6dac,0x6de9,0x6de2,0x6db7,
  0x6df6,0x6dd4,0x6e00,0x6dc8, 0x6de0,0x6ddf,0x6dd6,0x6dbe,
  0x6de5,0x6ddc,0x6ddd,0x6ddb, 0x6df4,0x6dca,0x6dbd,0x6ded,
  0x6df0,0x6dba,0x6dd5,0x6dc2, 0x6dcf,0x6dc9,
/* d600 */
  0x6dd0,0x6df2,0x6dd3,0x6dfd, 0x6dd7,0x6dcd,0x6de3,0x6dbb,
  0x70fa,0x710d,0x70f7,0x7117, 0x70f4,0x710c,0x70f0,0x7104,
  0x70f3,0x7110,0x70fc,0x70ff, 0x7106,0x7113,0x7100,0x70f8,
  0x70f6,0x710b,0x7102,0x710e, 0x727e,0x727b,0x727c,0x727f,
  0x731d,0x7317,0x7307,0x7311, 0x7318,0x730a,0x7308,0x72ff,
  0x730f,0x731e,0x7388,0x73f6, 0x73f8,0x73f5,0x7404,0x7401,
  0x73fd,0x7407,0x7400,0x73fa, 0x73fc,0x73ff,0x740c,0x740b,
  0x73f4,0x7408,0x7564,0x7563, 0x75ce,0x75d2,0x75cf,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x75cb,0x75cc,0x75d1,0x75d0, 0x768f,0x7689,0x76d3,0x7739,
  0x772f,0x772d,0x7731,0x7732, 0x7734,0x7733,0x773d,0x7725,
  0x773b,0x7735,0x7848,0x7852, 0x7849,0x784d,0x784a,0x784c,
  0x7826,0x7845,0x7850,0x7964, 0x7967,0x7969,0x796a,0x7963,
  0x796b,0x7961,0x79bb,0x79fa, 0x79f8,0x79f6,0x79f7,0x7a8f,
  0x7a94,0x7a90,0x7b35,0x7b47, 0x7b34,0x7b25,0x7b30,0x7b22,
  0x7b24,0x7b33,0x7b18,0x7b2a, 0x7b1d,0x7b31,0x7b2b,0x7b2d,
  0x7b2f,0x7b32,0x7b38,0x7b1a, 0x7b23,0x7c94,0x7c98,0x7c96,
  0x7ca3,0x7d35,0x7d3d,0x7d38, 0x7d36,0x7d3a,0x7d45,0x7d2c,
  0x7d29,0x7d41,0x7d47,0x7d3e, 0x7d3f,0x7d4a,0x7d3b,0x7d28,
  0x7f63,0x7f95,0x7f9c,0x7f9d, 0x7f9b,0x7fca,0x7fcb,0x7fcd,
  0x7fd0,0x7fd1,0x7fc7,0x7fcf, 0x7fc9,0x801f,
/* d700 */
  0x801e,0x801b,0x8047,0x8043, 0x8048,0x8118,0x8125,0x8119,
  0x811b,0x812d,0x811f,0x812c, 0x811e,0x8121,0x8115,0x8127,
  0x811d,0x8122,0x8211,0x8238, 0x8233,0x823a,0x8234,0x8232,
  0x8274,0x8390,0x83a3,0x83a8, 0x838d,0x837a,0x8373,0x83a4,
  0x8374,0x838f,0x8381,0x8395, 0x8399,0x8375,0x8394,0x83a9,
  0x837d,0x8383,0x838c,0x839d, 0x839b,0x83aa,0x838b,0x837e,
  0x83a5,0x83af,0x8388,0x8397, 0x83b0,0x837f,0x83a6,0x8387,
  0x83ae,0x8376,0x839a,0x8659, 0x8656,0x86bf,0x86b7,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x86c2,0x86c1,0x86c5,0x86ba, 0x86b0,0x86c8,0x86b9,0x86b3,
  0x86b8,0x86cc,0x86b4,0x86bb, 0x86bc,0x86c3,0x86bd,0x86be,
  0x8852,0x8889,0x8895,0x88a8, 0x88a2,0x88aa,0x889a,0x8891,
  0x88a1,0x889f,0x8898,0x88a7, 0x8899,0x889b,0x8897,0x88a4,
  0x88ac,0x888c,0x8893,0x888e, 0x8982,0x89d6,0x89d9,0x89d5,
  0x8a30,0x8a27,0x8a2c,0x8a1e, 0x8c39,0x8c3b,0x8c5c,0x8c5d,
  0x8c7d,0x8ca5,0x8d7d,0x8d7b, 0x8d79,0x8dbc,0x8dc2,0x8db9,
  0x8dbf,0x8dc1,0x8ed8,0x8ede, 0x8edd,0x8edc,0x8ed7,0x8ee0,
  0x8ee1,0x9024,0x900b,0x9011, 0x901c,0x900c,0x9021,0x90ef,
  0x90ea,0x90f0,0x90f4,0x90f2, 0x90f3,0x90d4,0x90eb,0x90ec,
  0x90e9,0x9156,0x9158,0x915a, 0x9153,0x9155,0x91ec,0x91f4,
  0x91f1,0x91f3,0x91f8,0x91e4, 0x91f9,0x91ea,
/* d800 */
  0x91eb,0x91f7,0x91e8,0x91ee, 0x957a,0x9586,0x9588,0x967c,
  0x966d,0x966b,0x9671,0x966f, 0x96bf,0x976a,0x9804,0x98e5,
  0x9997,0x509b,0x5095,0x5094, 0x509e,0x508b,0x50a3,0x5083,
  0x508c,0x508e,0x509d,0x5068, 0x509c,0x5092,0x5082,0x5087,
  0x515f,0x51d4,0x5312,0x5311, 0x53a4,0x53a7,0x5591,0x55a8,
  0x55a5,0x55ad,0x5577,0x5645, 0x55a2,0x5593,0x5588,0x558f,
  0x55b5,0x5581,0x55a3,0x5592, 0x55a4,0x557d,0x558c,0x55a6,
  0x557f,0x5595,0x55a1,0x558e, 0x570c,0x5829,0x5837,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x5819,0x581e,0x5827,0x5823, 0x5828,0x57f5,0x5848,0x5825,
  0x581c,0x581b,0x5833,0x583f, 0x5836,0x582e,0x5839,0x5838,
  0x582d,0x582c,0x583b,0x5961, 0x5aaf,0x5a94,0x5a9f,0x5a7a,
  0x5aa2,0x5a9e,0x5a78,0x5aa6, 0x5a7c,0x5aa5,0x5aac,0x5a95,
  0x5aae,0x5a37,0x5a84,0x5a8a, 0x5a97,0x5a83,0x5a8b,0x5aa9,
  0x5a7b,0x5a7d,0x5a8c,0x5a9c, 0x5a8f,0x5a93,0x5a9d,0x5bea,
  0x5bcd,0x5bcb,0x5bd4,0x5bd1, 0x5bca,0x5bce,0x5c0c,0x5c30,
  0x5d37,0x5d43,0x5d6b,0x5d41, 0x5d4b,0x5d3f,0x5d35,0x5d51,
  0x5d4e,0x5d55,0x5d33,0x5d3a, 0x5d52,0x5d3d,0x5d31,0x5d59,
  0x5d42,0x5d39,0x5d49,0x5d38, 0x5d3c,0x5d32,0x5d36,0x5d40,
  0x5d45,0x5e44,0x5e41,0x5f58, 0x5fa6,0x5fa5,0x5fab,0x60c9,
  0x60b9,0x60cc,0x60e2,0x60ce, 0x60c4,0x6114,
/* d900 */
  0x60f2,0x610a,0x6116,0x6105, 0x60f5,0x6113,0x60f8,0x60fc,
  0x60fe,0x60c1,0x6103,0x6118, 0x611d,0x6110,0x60ff,0x6104,
  0x610b,0x624a,0x6394,0x63b1, 0x63b0,0x63ce,0x63e5,0x63e8,
  0x63ef,0x63c3,0x649d,0x63f3, 0x63ca,0x63e0,0x63f6,0x63d5,
  0x63f2,0x63f5,0x6461,0x63df, 0x63be,0x63dd,0x63dc,0x63c4,
  0x63d8,0x63d3,0x63c2,0x63c7, 0x63cc,0x63cb,0x63c8,0x63f0,
  0x63d7,0x63d9,0x6532,0x6567, 0x656a,0x6564,0x655c,0x6568,
  0x6565,0x658c,0x659d,0x659e, 0x65ae,0x65d0,0x65d2,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x667c,0x666c,0x667b,0x6680, 0x6671,0x6679,0x666a,0x6672,
  0x6701,0x690c,0x68d3,0x6904, 0x68dc,0x692a,0x68ec,0x68ea,
  0x68f1,0x690f,0x68d6,0x68f7, 0x68eb,0x68e4,0x68f6,0x6913,
  0x6910,0x68f3,0x68e1,0x6907, 0x68cc,0x6908,0x6970,0x68b4,
  0x6911,0x68ef,0x68c6,0x6914, 0x68f8,0x68d0,0x68fd,0x68fc,
  0x68e8,0x690b,0x690a,0x6917, 0x68ce,0x68c8,0x68dd,0x68de,
  0x68e6,0x68f4,0x68d1,0x6906, 0x68d4,0x68e9,0x6915,0x6925,
  0x68c7,0x6b39,0x6b3b,0x6b3f, 0x6b3c,0x6b94,0x6b97,0x6b99,
  0x6b95,0x6bbd,0x6bf0,0x6bf2, 0x6bf3,0x6c30,0x6dfc,0x6e46,
  0x6e47,0x6e1f,0x6e49,0x6e88, 0x6e3c,0x6e3d,0x6e45,0x6e62,
  0x6e2b,0x6e3f,0x6e41,0x6e5d, 0x6e73,0x6e1c,0x6e33,0x6e4b,
  0x6e40,0x6e51,0x6e3b,0x6e03, 0x6e2e,0x6e5e,
/* da00 */
  0x6e68,0x6e5c,0x6e61,0x6e31, 0x6e28,0x6e60,0x6e71,0x6e6b,
  0x6e39,0x6e22,0x6e30,0x6e53, 0x6e65,0x6e27,0x6e78,0x6e64,
  0x6e77,0x6e55,0x6e79,0x6e52, 0x6e66,0x6e35,0x6e36,0x6e5a,
  0x7120,0x711e,0x712f,0x70fb, 0x712e,0x7131,0x7123,0x7125,
  0x7122,0x7132,0x711f,0x7128, 0x713a,0x711b,0x724b,0x725a,
  0x7288,0x7289,0x7286,0x7285, 0x728b,0x7312,0x730b,0x7330,
  0x7322,0x7331,0x7333,0x7327, 0x7332,0x732d,0x7326,0x7323,
  0x7335,0x730c,0x742e,0x742c, 0x7430,0x742b,0x7416,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x741a,0x7421,0x742d,0x7431, 0x7424,0x7423,0x741d,0x7429,
  0x7420,0x7432,0x74fb,0x752f, 0x756f,0x756c,0x75e7,0x75da,
  0x75e1,0x75e6,0x75dd,0x75df, 0x75e4,0x75d7,0x7695,0x7692,
  0x76da,0x7746,0x7747,0x7744, 0x774d,0x7745,0x774a,0x774e,
  0x774b,0x774c,0x77de,0x77ec, 0x7860,0x7864,0x7865,0x785c,
  0x786d,0x7871,0x786a,0x786e, 0x7870,0x7869,0x7868,0x785e,
  0x7862,0x7974,0x7973,0x7972, 0x7970,0x7a02,0x7a0a,0x7a03,
  0x7a0c,0x7a04,0x7a99,0x7ae6, 0x7ae4,0x7b4a,0x7b3b,0x7b44,
  0x7b48,0x7b4c,0x7b4e,0x7b40, 0x7b58,0x7b45,0x7ca2,0x7c9e,
  0x7ca8,0x7ca1,0x7d58,0x7d6f, 0x7d63,0x7d53,0x7d56,0x7d67,
  0x7d6a,0x7d4f,0x7d6d,0x7d5c, 0x7d6b,0x7d52,0x7d54,0x7d69,
  0x7d51,0x7d5f,0x7d4e,0x7f3e, 0x7f3f,0x7f65,
/* db00 */
  0x7f66,0x7fa2,0x7fa0,0x7fa1, 0x7fd7,0x8051,0x804f,0x8050,
  0x80fe,0x80d4,0x8143,0x814a, 0x8152,0x814f,0x8147,0x813d,
  0x814d,0x813a,0x81e6,0x81ee, 0x81f7,0x81f8,0x81f9,0x8204,
  0x823c,0x823d,0x823f,0x8275, 0x833b,0x83cf,0x83f9,0x8423,
  0x83c0,0x83e8,0x8412,0x83e7, 0x83e4,0x83fc,0x83f6,0x8410,
  0x83c6,0x83c8,0x83eb,0x83e3, 0x83bf,0x8401,0x83dd,0x83e5,
  0x83d8,0x83ff,0x83e1,0x83cb, 0x83ce,0x83d6,0x83f5,0x83c9,
  0x8409,0x840f,0x83de,0x8411, 0x8406,0x83c2,0x83f3,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x83d5,0x83fa,0x83c7,0x83d1, 0x83ea,0x8413,0x83c3,0x83ec,
  0x83ee,0x83c4,0x83fb,0x83d7, 0x83e2,0x841b,0x83db,0x83fe,
  0x86d8,0x86e2,0x86e6,0x86d3, 0x86e3,0x86da,0x86ea,0x86dd,
  0x86eb,0x86dc,0x86ec,0x86e9, 0x86d7,0x86e8,0x86d1,0x8848,
  0x8856,0x8855,0x88ba,0x88d7, 0x88b9,0x88b8,0x88c0,0x88be,
  0x88b6,0x88bc,0x88b7,0x88bd, 0x88b2,0x8901,0x88c9,0x8995,
  0x8998,0x8997,0x89dd,0x89da, 0x89db,0x8a4e,0x8a4d,0x8a39,
  0x8a59,0x8a40,0x8a57,0x8a58, 0x8a44,0x8a45,0x8a52,0x8a48,
  0x8a51,0x8a4a,0x8a4c,0x8a4f, 0x8c5f,0x8c81,0x8c80,0x8cba,
  0x8cbe,0x8cb0,0x8cb9,0x8cb5, 0x8d84,0x8d80,0x8d89,0x8dd8,
  0x8dd3,0x8dcd,0x8dc7,0x8dd6, 0x8ddc,0x8dcf,0x8dd5,0x8dd9,
  0x8dc8,0x8dd7,0x8dc5,0x8eef, 0x8ef7,0x8efa,
/* dc00 */
  0x8ef9,0x8ee6,0x8eee,0x8ee5, 0x8ef5,0x8ee7,0x8ee8,0x8ef6,
  0x8eeb,0x8ef1,0x8eec,0x8ef4, 0x8ee9,0x902d,0x9034,0x902f,
  0x9106,0x912c,0x9104,0x90ff, 0x90fc,0x9108,0x90f9,0x90fb,
  0x9101,0x9100,0x9107,0x9105, 0x9103,0x9161,0x9164,0x915f,
  0x9162,0x9160,0x9201,0x920a, 0x9225,0x9203,0x921a,0x9226,
  0x920f,0x920c,0x9200,0x9212, 0x91ff,0x91fd,0x9206,0x9204,
  0x9227,0x9202,0x921c,0x9224, 0x9219,0x9217,0x9205,0x9216,
  0x957b,0x958d,0x958c,0x9590, 0x9687,0x967e,0x9688,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x9689,0x9683,0x9680,0x96c2, 0x96c8,0x96c3,0x96f1,0x96f0,
  0x976c,0x9770,0x976e,0x9807, 0x98a9,0x98eb,0x9ce6,0x9ef9,
  0x4e83,0x4e84,0x4eb6,0x50bd, 0x50bf,0x50c6,0x50ae,0x50c4,
  0x50ca,0x50b4,0x50c8,0x50c2, 0x50b0,0x50c1,0x50ba,0x50b1,
  0x50cb,0x50c9,0x50b6,0x50b8, 0x51d7,0x527a,0x5278,0x527b,
  0x527c,0x55c3,0x55db,0x55cc, 0x55d0,0x55cb,0x55ca,0x55dd,
  0x55c0,0x55d4,0x55c4,0x55e9, 0x55bf,0x55d2,0x558d,0x55cf,
  0x55d5,0x55e2,0x55d6,0x55c8, 0x55f2,0x55cd,0x55d9,0x55c2,
  0x5714,0x5853,0x5868,0x5864, 0x584f,0x584d,0x5849,0x586f,
  0x5855,0x584e,0x585d,0x5859, 0x5865,0x585b,0x583d,0x5863,
  0x5871,0x58fc,0x5ac7,0x5ac4, 0x5acb,0x5aba,0x5ab8,0x5ab1,
  0x5ab5,0x5ab0,0x5abf,0x5ac8, 0x5abb,0x5ac6,
/* dd00 */
  0x5ab7,0x5ac0,0x5aca,0x5ab4, 0x5ab6,0x5acd,0x5ab9,0x5a90,
  0x5bd6,0x5bd8,0x5bd9,0x5c1f, 0x5c33,0x5d71,0x5d63,0x5d4a,
  0x5d65,0x5d72,0x5d6c,0x5d5e, 0x5d68,0x5d67,0x5d62,0x5df0,
  0x5e4f,0x5e4e,0x5e4a,0x5e4d, 0x5e4b,0x5ec5,0x5ecc,0x5ec6,
  0x5ecb,0x5ec7,0x5f40,0x5faf, 0x5fad,0x60f7,0x6149,0x614a,
  0x612b,0x6145,0x6136,0x6132, 0x612e,0x6146,0x612f,0x614f,
  0x6129,0x6140,0x6220,0x9168, 0x6223,0x6225,0x6224,0x63c5,
  0x63f1,0x63eb,0x6410,0x6412, 0x6409,0x6420,0x6424,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x6433,0x6443,0x641f,0x6415, 0x6418,0x6439,0x6437,0x6422,
  0x6423,0x640c,0x6426,0x6430, 0x6428,0x6441,0x6435,0x642f,
  0x640a,0x641a,0x6440,0x6425, 0x6427,0x640b,0x63e7,0x641b,
  0x642e,0x6421,0x640e,0x656f, 0x6592,0x65d3,0x6686,0x668c,
  0x6695,0x6690,0x668b,0x668a, 0x6699,0x6694,0x6678,0x6720,
  0x6966,0x695f,0x6938,0x694e, 0x6962,0x6971,0x693f,0x6945,
  0x696a,0x6939,0x6942,0x6957, 0x6959,0x697a,0x6948,0x6949,
  0x6935,0x696c,0x6933,0x693d, 0x6965,0x68f0,0x6978,0x6934,
  0x6969,0x6940,0x696f,0x6944, 0x6976,0x6958,0x6941,0x6974,
  0x694c,0x693b,0x694b,0x6937, 0x695c,0x694f,0x6951,0x6932,
  0x6952,0x692f,0x697b,0x693c, 0x6b46,0x6b45,0x6b43,0x6b42,
  0x6b48,0x6b41,0x6b9b,0xfa0d, 0x6bfb,0x6bfc,
/* de00 */
  0x6bf9,0x6bf7,0x6bf8,0x6e9b, 0x6ed6,0x6ec8,0x6e8f,0x6ec0,
  0x6e9f,0x6e93,0x6e94,0x6ea0, 0x6eb1,0x6eb9,0x6ec6,0x6ed2,
  0x6ebd,0x6ec1,0x6e9e,0x6ec9, 0x6eb7,0x6eb0,0x6ecd,0x6ea6,
  0x6ecf,0x6eb2,0x6ebe,0x6ec3, 0x6edc,0x6ed8,0x6e99,0x6e92,
  0x6e8e,0x6e8d,0x6ea4,0x6ea1, 0x6ebf,0x6eb3,0x6ed0,0x6eca,
  0x6e97,0x6eae,0x6ea3,0x7147, 0x7154,0x7152,0x7163,0x7160,
  0x7141,0x715d,0x7162,0x7172, 0x7178,0x716a,0x7161,0x7142,
  0x7158,0x7143,0x714b,0x7170, 0x715f,0x7150,0x7153,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x7144,0x714d,0x715a,0x724f, 0x728d,0x728c,0x7291,0x7290,
  0x728e,0x733c,0x7342,0x733b, 0x733a,0x7340,0x734a,0x7349,
  0x7444,0x744a,0x744b,0x7452, 0x7451,0x7457,0x7440,0x744f,
  0x7450,0x744e,0x7442,0x7446, 0x744d,0x7454,0x74e1,0x74ff,
  0x74fe,0x74fd,0x751d,0x7579, 0x7577,0x6983,0x75ef,0x760f,
  0x7603,0x75f7,0x75fe,0x75fc, 0x75f9,0x75f8,0x7610,0x75fb,
  0x75f6,0x75ed,0x75f5,0x75fd, 0x7699,0x76b5,0x76dd,0x7755,
  0x775f,0x7760,0x7752,0x7756, 0x775a,0x7769,0x7767,0x7754,
  0x7759,0x776d,0x77e0,0x7887, 0x789a,0x7894,0x788f,0x7884,
  0x7895,0x7885,0x7886,0x78a1, 0x7883,0x7879,0x7899,0x7880,
  0x7896,0x787b,0x797c,0x7982, 0x797d,0x7979,0x7a11,0x7a18,
  0x7a19,0x7a12,0x7a17,0x7a15, 0x7a22,0x7a13,
/* df00 */
  0x7a1b,0x7a10,0x7aa3,0x7aa2, 0x7a9e,0x7aeb,0x7b66,0x7b64,
  0x7b6d,0x7b74,0x7b69,0x7b72, 0x7b65,0x7b73,0x7b71,0x7b70,
  0x7b61,0x7b78,0x7b76,0x7b63, 0x7cb2,0x7cb4,0x7caf,0x7d88,
  0x7d86,0x7d80,0x7d8d,0x7d7f, 0x7d85,0x7d7a,0x7d8e,0x7d7b,
  0x7d83,0x7d7c,0x7d8c,0x7d94, 0x7d84,0x7d7d,0x7d92,0x7f6d,
  0x7f6b,0x7f67,0x7f68,0x7f6c, 0x7fa6,0x7fa5,0x7fa7,0x7fdb,
  0x7fdc,0x8021,0x8164,0x8160, 0x8177,0x815c,0x8169,0x815b,
  0x8162,0x8172,0x6721,0x815e, 0x8176,0x8167,0x816f,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x8144,0x8161,0x821d,0x8249, 0x8244,0x8240,0x8242,0x8245,
  0x84f1,0x843f,0x8456,0x8476, 0x8479,0x848f,0x848d,0x8465,
  0x8451,0x8440,0x8486,0x8467, 0x8430,0x844d,0x847d,0x845a,
  0x8459,0x8474,0x8473,0x845d, 0x8507,0x845e,0x8437,0x843a,
  0x8434,0x847a,0x8443,0x8478, 0x8432,0x8445,0x8429,0x83d9,
  0x844b,0x842f,0x8442,0x842d, 0x845f,0x8470,0x8439,0x844e,
  0x844c,0x8452,0x846f,0x84c5, 0x848e,0x843b,0x8447,0x8436,
  0x8433,0x8468,0x847e,0x8444, 0x842b,0x8460,0x8454,0x846e,
  0x8450,0x870b,0x8704,0x86f7, 0x870c,0x86fa,0x86d6,0x86f5,
  0x874d,0x86f8,0x870e,0x8709, 0x8701,0x86f6,0x870d,0x8705,
  0x88d6,0x88cb,0x88cd,0x88ce, 0x88de,0x88db,0x88da,0x88cc,
  0x88d0,0x8985,0x899b,0x89df, 0x89e5,0x89e4,
/* e000 */
  0x89e1,0x89e0,0x89e2,0x89dc, 0x89e6,0x8a76,0x8a86,0x8a7f,
  0x8a61,0x8a3f,0x8a77,0x8a82, 0x8a84,0x8a75,0x8a83,0x8a81,
  0x8a74,0x8a7a,0x8c3c,0x8c4b, 0x8c4a,0x8c65,0x8c64,0x8c66,
  0x8c86,0x8c84,0x8c85,0x8ccc, 0x8d68,0x8d69,0x8d91,0x8d8c,
  0x8d8e,0x8d8f,0x8d8d,0x8d93, 0x8d94,0x8d90,0x8d92,0x8df0,
  0x8de0,0x8dec,0x8df1,0x8dee, 0x8dd0,0x8de9,0x8de3,0x8de2,
  0x8de7,0x8df2,0x8deb,0x8df4, 0x8f06,0x8eff,0x8f01,0x8f00,
  0x8f05,0x8f07,0x8f08,0x8f02, 0x8f0b,0x9052,0x903f,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x9044,0x9049,0x903d,0x9110, 0x910d,0x910f,0x9111,0x9116,
  0x9114,0x910b,0x910e,0x916e, 0x916f,0x9248,0x9252,0x9230,
  0x923a,0x9266,0x9233,0x9265, 0x925e,0x9283,0x922e,0x924a,
  0x9246,0x926d,0x926c,0x924f, 0x9260,0x9267,0x926f,0x9236,
  0x9261,0x9270,0x9231,0x9254, 0x9263,0x9250,0x9272,0x924e,
  0x9253,0x924c,0x9256,0x9232, 0x959f,0x959c,0x959e,0x959b,
  0x9692,0x9693,0x9691,0x9697, 0x96ce,0x96fa,0x96fd,0x96f8,
  0x96f5,0x9773,0x9777,0x9778, 0x9772,0x980f,0x980d,0x980e,
  0x98ac,0x98f6,0x98f9,0x99af, 0x99b2,0x99b0,0x99b5,0x9aad,
  0x9aab,0x9b5b,0x9cea,0x9ced, 0x9ce7,0x9e80,0x9efd,0x50e6,
  0x50d4,0x50d7,0x50e8,0x50f3, 0x50db,0x50ea,0x50dd,0x50e4,
  0x50d3,0x50ec,0x50f0,0x50ef, 0x50e3,0x50e0,
/* e100 */
  0x51d8,0x5280,0x5281,0x52e9, 0x52eb,0x5330,0x53ac,0x5627,
  0x5615,0x560c,0x5612,0x55fc, 0x560f,0x561c,0x5601,0x5613,
  0x5602,0x55fa,0x561d,0x5604, 0x55ff,0x55f9,0x5889,0x587c,
  0x5890,0x5898,0x5886,0x5881, 0x587f,0x5874,0x588b,0x587a,
  0x5887,0x5891,0x588e,0x5876, 0x5882,0x5888,0x587b,0x5894,
  0x588f,0x58fe,0x596b,0x5adc, 0x5aee,0x5ae5,0x5ad5,0x5aea,
  0x5ada,0x5aed,0x5aeb,0x5af3, 0x5ae2,0x5ae0,0x5adb,0x5aec,
  0x5ade,0x5add,0x5ad9,0x5ae8, 0x5adf,0x5b77,0x5be0,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x5be3,0x5c63,0x5d82,0x5d80, 0x5d7d,0x5d86,0x5d7a,0x5d81,
  0x5d77,0x5d8a,0x5d89,0x5d88, 0x5d7e,0x5d7c,0x5d8d,0x5d79,
  0x5d7f,0x5e58,0x5e59,0x5e53, 0x5ed8,0x5ed1,0x5ed7,0x5ece,
  0x5edc,0x5ed5,0x5ed9,0x5ed2, 0x5ed4,0x5f44,0x5f43,0x5f6f,
  0x5fb6,0x612c,0x6128,0x6141, 0x615e,0x6171,0x6173,0x6152,
  0x6153,0x6172,0x616c,0x6180, 0x6174,0x6154,0x617a,0x615b,
  0x6165,0x613b,0x616a,0x6161, 0x6156,0x6229,0x6227,0x622b,
  0x642b,0x644d,0x645b,0x645d, 0x6474,0x6476,0x6472,0x6473,
  0x647d,0x6475,0x6466,0x64a6, 0x644e,0x6482,0x645e,0x645c,
  0x644b,0x6453,0x6460,0x6450, 0x647f,0x643f,0x646c,0x646b,
  0x6459,0x6465,0x6477,0x6573, 0x65a0,0x66a1,0x66a0,0x669f,
  0x6705,0x6704,0x6722,0x69b1, 0x69b6,0x69c9,
/* e200 */
  0x69a0,0x69ce,0x6996,0x69b0, 0x69ac,0x69bc,0x6991,0x6999,
  0x698e,0x69a7,0x698d,0x69a9, 0x69be,0x69af,0x69bf,0x69c4,
  0x69bd,0x69a4,0x69d4,0x69b9, 0x69ca,0x699a,0x69cf,0x69b3,
  0x6993,0x69aa,0x69a1,0x699e, 0x69d9,0x6997,0x6990,0x69c2,
  0x69b5,0x69a5,0x69c6,0x6b4a, 0x6b4d,0x6b4b,0x6b9e,0x6b9f,
  0x6ba0,0x6bc3,0x6bc4,0x6bfe, 0x6ece,0x6ef5,0x6ef1,0x6f03,
  0x6f25,0x6ef8,0x6f37,0x6efb, 0x6f2e,0x6f09,0x6f4e,0x6f19,
  0x6f1a,0x6f27,0x6f18,0x6f3b, 0x6f12,0x6eed,0x6f0a,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x6f36,0x6f73,0x6ef9,0x6eee, 0x6f2d,0x6f40,0x6f30,0x6f3c,
  0x6f35,0x6eeb,0x6f07,0x6f0e, 0x6f43,0x6f05,0x6efd,0x6ef6,
  0x6f39,0x6f1c,0x6efc,0x6f3a, 0x6f1f,0x6f0d,0x6f1e,0x6f08,
  0x6f21,0x7187,0x7190,0x7189, 0x7180,0x7185,0x7182,0x718f,
  0x717b,0x7186,0x7181,0x7197, 0x7244,0x7253,0x7297,0x7295,
  0x7293,0x7343,0x734d,0x7351, 0x734c,0x7462,0x7473,0x7471,
  0x7475,0x7472,0x7467,0x746e, 0x7500,0x7502,0x7503,0x757d,
  0x7590,0x7616,0x7608,0x760c, 0x7615,0x7611,0x760a,0x7614,
  0x76b8,0x7781,0x777c,0x7785, 0x7782,0x776e,0x7780,0x776f,
  0x777e,0x7783,0x78b2,0x78aa, 0x78b4,0x78ad,0x78a8,0x787e,
  0x78ab,0x789e,0x78a5,0x78a0, 0x78ac,0x78a2,0x78a4,0x7998,
  0x798a,0x798b,0x7996,0x7995, 0x7994,0x7993,
/* e300 */
  0x7997,0x7988,0x7992,0x7990, 0x7a2b,0x7a4a,0x7a30,0x7a2f,
  0x7a28,0x7a26,0x7aa8,0x7aab, 0x7aac,0x7aee,0x7b88,0x7b9c,
  0x7b8a,0x7b91,0x7b90,0x7b96, 0x7b8d,0x7b8c,0x7b9b,0x7b8e,
  0x7b85,0x7b98,0x5284,0x7b99, 0x7ba4,0x7b82,0x7cbb,0x7cbf,
  0x7cbc,0x7cba,0x7da7,0x7db7, 0x7dc2,0x7da3,0x7daa,0x7dc1,
  0x7dc0,0x7dc5,0x7d9d,0x7dce, 0x7dc4,0x7dc6,0x7dcb,0x7dcc,
  0x7daf,0x7db9,0x7d96,0x7dbc, 0x7d9f,0x7da6,0x7dae,0x7da9,
  0x7da1,0x7dc9,0x7f73,0x7fe2, 0x7fe3,0x7fe5,0x7fde,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x8024,0x805d,0x805c,0x8189, 0x8186,0x8183,0x8187,0x818d,
  0x818c,0x818b,0x8215,0x8497, 0x84a4,0x84a1,0x849f,0x84ba,
  0x84ce,0x84c2,0x84ac,0x84ae, 0x84ab,0x84b9,0x84b4,0x84c1,
  0x84cd,0x84aa,0x849a,0x84b1, 0x84d0,0x849d,0x84a7,0x84bb,
  0x84a2,0x8494,0x84c7,0x84cc, 0x849b,0x84a9,0x84af,0x84a8,
  0x84d6,0x8498,0x84b6,0x84cf, 0x84a0,0x84d7,0x84d4,0x84d2,
  0x84db,0x84b0,0x8491,0x8661, 0x8733,0x8723,0x8728,0x876b,
  0x8740,0x872e,0x871e,0x8721, 0x8719,0x871b,0x8743,0x872c,
  0x8741,0x873e,0x8746,0x8720, 0x8732,0x872a,0x872d,0x873c,
  0x8712,0x873a,0x8731,0x8735, 0x8742,0x8726,0x8727,0x8738,
  0x8724,0x871a,0x8730,0x8711, 0x88f7,0x88e7,0x88f1,0x88f2,
  0x88fa,0x88fe,0x88ee,0x88fc, 0x88f6,0x88fb,
/* e400 */
  0x88f0,0x88ec,0x88eb,0x899d, 0x89a1,0x899f,0x899e,0x89e9,
  0x89eb,0x89e8,0x8aab,0x8a99, 0x8a8b,0x8a92,0x8a8f,0x8a96,
  0x8c3d,0x8c68,0x8c69,0x8cd5, 0x8ccf,0x8cd7,0x8d96,0x8e09,
  0x8e02,0x8dff,0x8e0d,0x8dfd, 0x8e0a,0x8e03,0x8e07,0x8e06,
  0x8e05,0x8dfe,0x8e00,0x8e04, 0x8f10,0x8f11,0x8f0e,0x8f0d,
  0x9123,0x911c,0x9120,0x9122, 0x911f,0x911d,0x911a,0x9124,
  0x9121,0x911b,0x917a,0x9172, 0x9179,0x9173,0x92a5,0x92a4,
  0x9276,0x929b,0x927a,0x92a0, 0x9294,0x92aa,0x928d,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x92a6,0x929a,0x92ab,0x9279, 0x9297,0x927f,0x92a3,0x92ee,
  0x928e,0x9282,0x9295,0x92a2, 0x927d,0x9288,0x92a1,0x928a,
  0x9286,0x928c,0x9299,0x92a7, 0x927e,0x9287,0x92a9,0x929d,
  0x928b,0x922d,0x969e,0x96a1, 0x96ff,0x9758,0x977d,0x977a,
  0x977e,0x9783,0x9780,0x9782, 0x977b,0x9784,0x9781,0x977f,
  0x97ce,0x97cd,0x9816,0x98ad, 0x98ae,0x9902,0x9900,0x9907,
  0x999d,0x999c,0x99c3,0x99b9, 0x99bb,0x99ba,0x99c2,0x99bd,
  0x99c7,0x9ab1,0x9ae3,0x9ae7, 0x9b3e,0x9b3f,0x9b60,0x9b61,
  0x9b5f,0x9cf1,0x9cf2,0x9cf5, 0x9ea7,0x50ff,0x5103,0x5130,
  0x50f8,0x5106,0x5107,0x50f6, 0x50fe,0x510b,0x510c,0x50fd,
  0x510a,0x528b,0x528c,0x52f1, 0x52ef,0x5648,0x5642,0x564c,
  0x5635,0x5641,0x564a,0x5649, 0x5646,0x5658,
/* e500 */
  0x565a,0x5640,0x5633,0x563d, 0x562c,0x563e,0x5638,0x562a,
  0x563a,0x571a,0x58ab,0x589d, 0x58b1,0x58a0,0x58a3,0x58af,
  0x58ac,0x58a5,0x58a1,0x58ff, 0x5aff,0x5af4,0x5afd,0x5af7,
  0x5af6,0x5b03,0x5af8,0x5b02, 0x5af9,0x5b01,0x5b07,0x5b05,
  0x5b0f,0x5c67,0x5d99,0x5d97, 0x5d9f,0x5d92,0x5da2,0x5d93,
  0x5d95,0x5da0,0x5d9c,0x5da1, 0x5d9a,0x5d9e,0x5e69,0x5e5d,
  0x5e60,0x5e5c,0x7df3,0x5edb, 0x5ede,0x5ee1,0x5f49,0x5fb2,
  0x618b,0x6183,0x6179,0x61b1, 0x61b0,0x61a2,0x6189,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x619b,0x6193,0x61af,0x61ad, 0x619f,0x6192,0x61aa,0x61a1,
  0x618d,0x6166,0x61b3,0x622d, 0x646e,0x6470,0x6496,0x64a0,
  0x6485,0x6497,0x649c,0x648f, 0x648b,0x648a,0x648c,0x64a3,
  0x649f,0x6468,0x64b1,0x6498, 0x6576,0x657a,0x6579,0x657b,
  0x65b2,0x65b3,0x66b5,0x66b0, 0x66a9,0x66b2,0x66b7,0x66aa,
  0x66af,0x6a00,0x6a06,0x6a17, 0x69e5,0x69f8,0x6a15,0x69f1,
  0x69e4,0x6a20,0x69ff,0x69ec, 0x69e2,0x6a1b,0x6a1d,0x69fe,
  0x6a27,0x69f2,0x69ee,0x6a14, 0x69f7,0x69e7,0x6a40,0x6a08,
  0x69e6,0x69fb,0x6a0d,0x69fc, 0x69eb,0x6a09,0x6a04,0x6a18,
  0x6a25,0x6a0f,0x69f6,0x6a26, 0x6a07,0x69f4,0x6a16,0x6b51,
  0x6ba5,0x6ba3,0x6ba2,0x6ba6, 0x6c01,0x6c00,0x6bff,0x6c02,
  0x6f41,0x6f26,0x6f7e,0x6f87, 0x6fc6,0x6f92,
/* e600 */
  0x6f8d,0x6f89,0x6f8c,0x6f62, 0x6f4f,0x6f85,0x6f5a,0x6f96,
  0x6f76,0x6f6c,0x6f82,0x6f55, 0x6f72,0x6f52,0x6f50,0x6f57,
  0x6f94,0x6f93,0x6f5d,0x6f00, 0x6f61,0x6f6b,0x6f7d,0x6f67,
  0x6f90,0x6f53,0x6f8b,0x6f69, 0x6f7f,0x6f95,0x6f63,0x6f77,
  0x6f6a,0x6f7b,0x71b2,0x71af, 0x719b,0x71b0,0x71a0,0x719a,
  0x71a9,0x71b5,0x719d,0x71a5, 0x719e,0x71a4,0x71a1,0x71aa,
  0x719c,0x71a7,0x71b3,0x7298, 0x729a,0x7358,0x7352,0x735e,
  0x735f,0x7360,0x735d,0x735b, 0x7361,0x735a,0x7359,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x7362,0x7487,0x7489,0x748a, 0x7486,0x7481,0x747d,0x7485,
  0x7488,0x747c,0x7479,0x7508, 0x7507,0x757e,0x7625,0x761e,
  0x7619,0x761d,0x761c,0x7623, 0x761a,0x7628,0x761b,0x769c,
  0x769d,0x769e,0x769b,0x778d, 0x778f,0x7789,0x7788,0x78cd,
  0x78bb,0x78cf,0x78cc,0x78d1, 0x78ce,0x78d4,0x78c8,0x78c3,
  0x78c4,0x78c9,0x799a,0x79a1, 0x79a0,0x799c,0x79a2,0x799b,
  0x6b76,0x7a39,0x7ab2,0x7ab4, 0x7ab3,0x7bb7,0x7bcb,0x7bbe,
  0x7bac,0x7bce,0x7baf,0x7bb9, 0x7bca,0x7bb5,0x7cc5,0x7cc8,
  0x7ccc,0x7ccb,0x7df7,0x7ddb, 0x7dea,0x7de7,0x7dd7,0x7de1,
  0x7e03,0x7dfa,0x7de6,0x7df6, 0x7df1,0x7df0,0x7dee,0x7ddf,
  0x7f76,0x7fac,0x7fb0,0x7fad, 0x7fed,0x7feb,0x7fea,0x7fec,
  0x7fe6,0x7fe8,0x8064,0x8067, 0x81a3,0x819f,
/* e700 */
  0x819e,0x8195,0x81a2,0x8199, 0x8197,0x8216,0x824f,0x8253,
  0x8252,0x8250,0x824e,0x8251, 0x8524,0x853b,0x850f,0x8500,
  0x8529,0x850e,0x8509,0x850d, 0x851f,0x850a,0x8527,0x851c,
  0x84fb,0x852b,0x84fa,0x8508, 0x850c,0x84f4,0x852a,0x84f2,
  0x8515,0x84f7,0x84eb,0x84f3, 0x84fc,0x8512,0x84ea,0x84e9,
  0x8516,0x84fe,0x8528,0x851d, 0x852e,0x8502,0x84fd,0x851e,
  0x84f6,0x8531,0x8526,0x84e7, 0x84e8,0x84f0,0x84ef,0x84f9,
  0x8518,0x8520,0x8530,0x850b, 0x8519,0x852f,0x8662,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x8756,0x8763,0x8764,0x8777, 0x87e1,0x8773,0x8758,0x8754,
  0x875b,0x8752,0x8761,0x875a, 0x8751,0x875e,0x876d,0x876a,
  0x8750,0x874e,0x875f,0x875d, 0x876f,0x876c,0x877a,0x876e,
  0x875c,0x8765,0x874f,0x877b, 0x8775,0x8762,0x8767,0x8769,
  0x885a,0x8905,0x890c,0x8914, 0x890b,0x8917,0x8918,0x8919,
  0x8906,0x8916,0x8911,0x890e, 0x8909,0x89a2,0x89a4,0x89a3,
  0x89ed,0x89f0,0x89ec,0x8acf, 0x8ac6,0x8ab8,0x8ad3,0x8ad1,
  0x8ad4,0x8ad5,0x8abb,0x8ad7, 0x8abe,0x8ac0,0x8ac5,0x8ad8,
  0x8ac3,0x8aba,0x8abd,0x8ad9, 0x8c3e,0x8c4d,0x8c8f,0x8ce5,
  0x8cdf,0x8cd9,0x8ce8,0x8cda, 0x8cdd,0x8ce7,0x8da0,0x8d9c,
  0x8da1,0x8d9b,0x8e20,0x8e23, 0x8e25,0x8e24,0x8e2e,0x8e15,
  0x8e1b,0x8e16,0x8e11,0x8e19, 0x8e26,0x8e27,
/* e800 */
  0x8e14,0x8e12,0x8e18,0x8e13, 0x8e1c,0x8e17,0x8e1a,0x8f2c,
  0x8f24,0x8f18,0x8f1a,0x8f20, 0x8f23,0x8f16,0x8f17,0x9073,
  0x9070,0x906f,0x9067,0x906b, 0x912f,0x912b,0x9129,0x912a,
  0x9132,0x9126,0x912e,0x9185, 0x9186,0x918a,0x9181,0x9182,
  0x9184,0x9180,0x92d0,0x92c3, 0x92c4,0x92c0,0x92d9,0x92b6,
  0x92cf,0x92f1,0x92df,0x92d8, 0x92e9,0x92d7,0x92dd,0x92cc,
  0x92ef,0x92c2,0x92e8,0x92ca, 0x92c8,0x92ce,0x92e6,0x92cd,
  0x92d5,0x92c9,0x92e0,0x92de, 0x92e7,0x92d1,0x92d3,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x92b5,0x92e1,0x92c6,0x92b4, 0x957c,0x95ac,0x95ab,0x95ae,
  0x95b0,0x96a4,0x96a2,0x96d3, 0x9705,0x9708,0x9702,0x975a,
  0x978a,0x978e,0x9788,0x97d0, 0x97cf,0x981e,0x981d,0x9826,
  0x9829,0x9828,0x9820,0x981b, 0x9827,0x98b2,0x9908,0x98fa,
  0x9911,0x9914,0x9916,0x9917, 0x9915,0x99dc,0x99cd,0x99cf,
  0x99d3,0x99d4,0x99ce,0x99c9, 0x99d6,0x99d8,0x99cb,0x99d7,
  0x99cc,0x9ab3,0x9aec,0x9aeb, 0x9af3,0x9af2,0x9af1,0x9b46,
  0x9b43,0x9b67,0x9b74,0x9b71, 0x9b66,0x9b76,0x9b75,0x9b70,
  0x9b68,0x9b64,0x9b6c,0x9cfc, 0x9cfa,0x9cfd,0x9cff,0x9cf7,
  0x9d07,0x9d00,0x9cf9,0x9cfb, 0x9d08,0x9d05,0x9d04,0x9e83,
  0x9ed3,0x9f0f,0x9f10,0x511c, 0x5113,0x5117,0x511a,0x5111,
  0x51de,0x5334,0x53e1,0x5670, 0x5660,0x566e,
/* e900 */
  0x5673,0x5666,0x5663,0x566d, 0x5672,0x565e,0x5677,0x571c,
  0x571b,0x58c8,0x58bd,0x58c9, 0x58bf,0x58ba,0x58c2,0x58bc,
  0x58c6,0x5b17,0x5b19,0x5b1b, 0x5b21,0x5b14,0x5b13,0x5b10,
  0x5b16,0x5b28,0x5b1a,0x5b20, 0x5b1e,0x5bef,0x5dac,0x5db1,
  0x5da9,0x5da7,0x5db5,0x5db0, 0x5dae,0x5daa,0x5da8,0x5db2,
  0x5dad,0x5daf,0x5db4,0x5e67, 0x5e68,0x5e66,0x5e6f,0x5ee9,
  0x5ee7,0x5ee6,0x5ee8,0x5ee5, 0x5f4b,0x5fbc,0x619d,0x61a8,
  0x6196,0x61c5,0x61b4,0x61c6, 0x61c1,0x61cc,0x61ba,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x61bf,0x61b8,0x618c,0x64d7, 0x64d6,0x64d0,0x64cf,0x64c9,
  0x64bd,0x6489,0x64c3,0x64db, 0x64f3,0x64d9,0x6533,0x657f,
  0x657c,0x65a2,0x66c8,0x66be, 0x66c0,0x66ca,0x66cb,0x66cf,
  0x66bd,0x66bb,0x66ba,0x66cc, 0x6723,0x6a34,0x6a66,0x6a49,
  0x6a67,0x6a32,0x6a68,0x6a3e, 0x6a5d,0x6a6d,0x6a76,0x6a5b,
  0x6a51,0x6a28,0x6a5a,0x6a3b, 0x6a3f,0x6a41,0x6a6a,0x6a64,
  0x6a50,0x6a4f,0x6a54,0x6a6f, 0x6a69,0x6a60,0x6a3c,0x6a5e,
  0x6a56,0x6a55,0x6a4d,0x6a4e, 0x6a46,0x6b55,0x6b54,0x6b56,
  0x6ba7,0x6baa,0x6bab,0x6bc8, 0x6bc7,0x6c04,0x6c03,0x6c06,
  0x6fad,0x6fcb,0x6fa3,0x6fc7, 0x6fbc,0x6fce,0x6fc8,0x6f5e,
  0x6fc4,0x6fbd,0x6f9e,0x6fca, 0x6fa8,0x7004,0x6fa5,0x6fae,
  0x6fba,0x6fac,0x6faa,0x6fcf, 0x6fbf,0x6fb8,
/* ea00 */
  0x6fa2,0x6fc9,0x6fab,0x6fcd, 0x6faf,0x6fb2,0x6fb0,0x71c5,
  0x71c2,0x71bf,0x71b8,0x71d6, 0x71c0,0x71c1,0x71cb,0x71d4,
  0x71ca,0x71c7,0x71cf,0x71bd, 0x71d8,0x71bc,0x71c6,0x71da,
  0x71db,0x729d,0x729e,0x7369, 0x7366,0x7367,0x736c,0x7365,
  0x736b,0x736a,0x747f,0x749a, 0x74a0,0x7494,0x7492,0x7495,
  0x74a1,0x750b,0x7580,0x762f, 0x762d,0x7631,0x763d,0x7633,
  0x763c,0x7635,0x7632,0x7630, 0x76bb,0x76e6,0x779a,0x779d,
  0x77a1,0x779c,0x779b,0x77a2, 0x77a3,0x7795,0x7799,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x7797,0x78dd,0x78e9,0x78e5, 0x78ea,0x78de,0x78e3,0x78db,
  0x78e1,0x78e2,0x78ed,0x78df, 0x78e0,0x79a4,0x7a44,0x7a48,
  0x7a47,0x7ab6,0x7ab8,0x7ab5, 0x7ab1,0x7ab7,0x7bde,0x7be3,
  0x7be7,0x7bdd,0x7bd5,0x7be5, 0x7bda,0x7be8,0x7bf9,0x7bd4,
  0x7bea,0x7be2,0x7bdc,0x7beb, 0x7bd8,0x7bdf,0x7cd2,0x7cd4,
  0x7cd7,0x7cd0,0x7cd1,0x7e12, 0x7e21,0x7e17,0x7e0c,0x7e1f,
  0x7e20,0x7e13,0x7e0e,0x7e1c, 0x7e15,0x7e1a,0x7e22,0x7e0b,
  0x7e0f,0x7e16,0x7e0d,0x7e14, 0x7e25,0x7e24,0x7f43,0x7f7b,
  0x7f7c,0x7f7a,0x7fb1,0x7fef, 0x802a,0x8029,0x806c,0x81b1,
  0x81a6,0x81ae,0x81b9,0x81b5, 0x81ab,0x81b0,0x81ac,0x81b4,
  0x81b2,0x81b7,0x81a7,0x81f2, 0x8255,0x8256,0x8257,0x8556,
  0x8545,0x856b,0x854d,0x8553, 0x8561,0x8558,
/* eb00 */
  0x8540,0x8546,0x8564,0x8541, 0x8562,0x8544,0x8551,0x8547,
  0x8563,0x853e,0x855b,0x8571, 0x854e,0x856e,0x8575,0x8555,
  0x8567,0x8560,0x858c,0x8566, 0x855d,0x8554,0x8565,0x856c,
  0x8663,0x8665,0x8664,0x879b, 0x878f,0x8797,0x8793,0x8792,
  0x8788,0x8781,0x8796,0x8798, 0x8779,0x8787,0x87a3,0x8785,
  0x8790,0x8791,0x879d,0x8784, 0x8794,0x879c,0x879a,0x8789,
  0x891e,0x8926,0x8930,0x892d, 0x892e,0x8927,0x8931,0x8922,
  0x8929,0x8923,0x892f,0x892c, 0x891f,0x89f1,0x8ae0,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x8ae2,0x8af2,0x8af4,0x8af5, 0x8add,0x8b14,0x8ae4,0x8adf,
  0x8af0,0x8ac8,0x8ade,0x8ae1, 0x8ae8,0x8aff,0x8aef,0x8afb,
  0x8c91,0x8c92,0x8c90,0x8cf5, 0x8cee,0x8cf1,0x8cf0,0x8cf3,
  0x8d6c,0x8d6e,0x8da5,0x8da7, 0x8e33,0x8e3e,0x8e38,0x8e40,
  0x8e45,0x8e36,0x8e3c,0x8e3d, 0x8e41,0x8e30,0x8e3f,0x8ebd,
  0x8f36,0x8f2e,0x8f35,0x8f32, 0x8f39,0x8f37,0x8f34,0x9076,
  0x9079,0x907b,0x9086,0x90fa, 0x9133,0x9135,0x9136,0x9193,
  0x9190,0x9191,0x918d,0x918f, 0x9327,0x931e,0x9308,0x931f,
  0x9306,0x930f,0x937a,0x9338, 0x933c,0x931b,0x9323,0x9312,
  0x9301,0x9346,0x932d,0x930e, 0x930d,0x92cb,0x931d,0x92fa,
  0x9325,0x9313,0x92f9,0x92f7, 0x9334,0x9302,0x9324,0x92ff,
  0x9329,0x9339,0x9335,0x932a, 0x9314,0x930c,
/* ec00 */
  0x930b,0x92fe,0x9309,0x9300, 0x92fb,0x9316,0x95bc,0x95cd,
  0x95be,0x95b9,0x95ba,0x95b6, 0x95bf,0x95b5,0x95bd,0x96a9,
  0x96d4,0x970b,0x9712,0x9710, 0x9799,0x9797,0x9794,0x97f0,
  0x97f8,0x9835,0x982f,0x9832, 0x9924,0x991f,0x9927,0x9929,
  0x999e,0x99ee,0x99ec,0x99e5, 0x99e4,0x99f0,0x99e3,0x99ea,
  0x99e9,0x99e7,0x9ab9,0x9abf, 0x9ab4,0x9abb,0x9af6,0x9afa,
  0x9af9,0x9af7,0x9b33,0x9b80, 0x9b85,0x9b87,0x9b7c,0x9b7e,
  0x9b7b,0x9b82,0x9b93,0x9b92, 0x9b90,0x9b7a,0x9b95,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x9b7d,0x9b88,0x9d25,0x9d17, 0x9d20,0x9d1e,0x9d14,0x9d29,
  0x9d1d,0x9d18,0x9d22,0x9d10, 0x9d19,0x9d1f,0x9e88,0x9e86,
  0x9e87,0x9eae,0x9ead,0x9ed5, 0x9ed6,0x9efa,0x9f12,0x9f3d,
  0x5126,0x5125,0x5122,0x5124, 0x5120,0x5129,0x52f4,0x5693,
  0x568c,0x568d,0x5686,0x5684, 0x5683,0x567e,0x5682,0x567f,
  0x5681,0x58d6,0x58d4,0x58cf, 0x58d2,0x5b2d,0x5b25,0x5b32,
  0x5b23,0x5b2c,0x5b27,0x5b26, 0x5b2f,0x5b2e,0x5b7b,0x5bf1,
  0x5bf2,0x5db7,0x5e6c,0x5e6a, 0x5fbe,0x5fbb,0x61c3,0x61b5,
  0x61bc,0x61e7,0x61e0,0x61e5, 0x61e4,0x61e8,0x61de,0x64ef,
  0x64e9,0x64e3,0x64eb,0x64e4, 0x64e8,0x6581,0x6580,0x65b6,
  0x65da,0x66d2,0x6a8d,0x6a96, 0x6a81,0x6aa5,0x6a89,0x6a9f,
  0x6a9b,0x6aa1,0x6a9e,0x6a87, 0x6a93,0x6a8e,
/* ed00 */
  0x6a95,0x6a83,0x6aa8,0x6aa4, 0x6a91,0x6a7f,0x6aa6,0x6a9a,
  0x6a85,0x6a8c,0x6a92,0x6b5b, 0x6bad,0x6c09,0x6fcc,0x6fa9,
  0x6ff4,0x6fd4,0x6fe3,0x6fdc, 0x6fed,0x6fe7,0x6fe6,0x6fde,
  0x6ff2,0x6fdd,0x6fe2,0x6fe8, 0x71e1,0x71f1,0x71e8,0x71f2,
  0x71e4,0x71f0,0x71e2,0x7373, 0x736e,0x736f,0x7497,0x74b2,
  0x74ab,0x7490,0x74aa,0x74ad, 0x74b1,0x74a5,0x74af,0x7510,
  0x7511,0x7512,0x750f,0x7584, 0x7643,0x7648,0x7649,0x7647,
  0x76a4,0x76e9,0x77b5,0x77ab, 0x77b2,0x77b7,0x77b6,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x77b4,0x77b1,0x77a8,0x77f0, 0x78f3,0x78fd,0x7902,0x78fb,
  0x78fc,0x78f2,0x7905,0x78f9, 0x78fe,0x7904,0x79ab,0x79a8,
  0x7a5c,0x7a5b,0x7a56,0x7a58, 0x7a54,0x7a5a,0x7abe,0x7ac0,
  0x7ac1,0x7c05,0x7c0f,0x7bf2, 0x7c00,0x7bff,0x7bfb,0x7c0e,
  0x7bf4,0x7c0b,0x7bf3,0x7c02, 0x7c09,0x7c03,0x7c01,0x7bf8,
  0x7bfd,0x7c06,0x7bf0,0x7bf1, 0x7c10,0x7c0a,0x7ce8,0x7e2d,
  0x7e3c,0x7e42,0x7e33,0x9848, 0x7e38,0x7e2a,0x7e49,0x7e40,
  0x7e47,0x7e29,0x7e4c,0x7e30, 0x7e3b,0x7e36,0x7e44,0x7e3a,
  0x7f45,0x7f7f,0x7f7e,0x7f7d, 0x7ff4,0x7ff2,0x802c,0x81bb,
  0x81c4,0x81cc,0x81ca,0x81c5, 0x81c7,0x81bc,0x81e9,0x825b,
  0x825a,0x825c,0x8583,0x8580, 0x858f,0x85a7,0x8595,0x85a0,
  0x858b,0x85a3,0x857b,0x85a4, 0x859a,0x859e,
/* ee00 */
  0x8577,0x857c,0x8589,0x85a1, 0x857a,0x8578,0x8557,0x858e,
  0x8596,0x8586,0x858d,0x8599, 0x859d,0x8581,0x85a2,0x8582,
  0x8588,0x8585,0x8579,0x8576, 0x8598,0x8590,0x859f,0x8668,
  0x87be,0x87aa,0x87ad,0x87c5, 0x87b0,0x87ac,0x87b9,0x87b5,
  0x87bc,0x87ae,0x87c9,0x87c3, 0x87c2,0x87cc,0x87b7,0x87af,
  0x87c4,0x87ca,0x87b4,0x87b6, 0x87bf,0x87b8,0x87bd,0x87de,
  0x87b2,0x8935,0x8933,0x893c, 0x893e,0x8941,0x8952,0x8937,
  0x8942,0x89ad,0x89af,0x89ae, 0x89f2,0x89f3,0x8b1e,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x8b18,0x8b16,0x8b11,0x8b05, 0x8b0b,0x8b22,0x8b0f,0x8b12,
  0x8b15,0x8b07,0x8b0d,0x8b08, 0x8b06,0x8b1c,0x8b13,0x8b1a,
  0x8c4f,0x8c70,0x8c72,0x8c71, 0x8c6f,0x8c95,0x8c94,0x8cf9,
  0x8d6f,0x8e4e,0x8e4d,0x8e53, 0x8e50,0x8e4c,0x8e47,0x8f43,
  0x8f40,0x9085,0x907e,0x9138, 0x919a,0x91a2,0x919b,0x9199,
  0x919f,0x91a1,0x919d,0x91a0, 0x93a1,0x9383,0x93af,0x9364,
  0x9356,0x9347,0x937c,0x9358, 0x935c,0x9376,0x9349,0x9350,
  0x9351,0x9360,0x936d,0x938f, 0x934c,0x936a,0x9379,0x9357,
  0x9355,0x9352,0x934f,0x9371, 0x9377,0x937b,0x9361,0x935e,
  0x9363,0x9367,0x9380,0x934e, 0x9359,0x95c7,0x95c0,0x95c9,
  0x95c3,0x95c5,0x95b7,0x96ae, 0x96b0,0x96ac,0x9720,0x971f,
  0x9718,0x971d,0x9719,0x979a, 0x97a1,0x979c,
/* ef00 */
  0x979e,0x979d,0x97d5,0x97d4, 0x97f1,0x9841,0x9844,0x984a,
  0x9849,0x9845,0x9843,0x9925, 0x992b,0x992c,0x992a,0x9933,
  0x9932,0x992f,0x992d,0x9931, 0x9930,0x9998,0x99a3,0x99a1,
  0x9a02,0x99fa,0x99f4,0x99f7, 0x99f9,0x99f8,0x99f6,0x99fb,
  0x99fd,0x99fe,0x99fc,0x9a03, 0x9abe,0x9afe,0x9afd,0x9b01,
  0x9afc,0x9b48,0x9b9a,0x9ba8, 0x9b9e,0x9b9b,0x9ba6,0x9ba1,
  0x9ba5,0x9ba4,0x9b86,0x9ba2, 0x9ba0,0x9baf,0x9d33,0x9d41,
  0x9d67,0x9d36,0x9d2e,0x9d2f, 0x9d31,0x9d38,0x9d30,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x9d45,0x9d42,0x9d43,0x9d3e, 0x9d37,0x9d40,0x9d3d,0x7ff5,
  0x9d2d,0x9e8a,0x9e89,0x9e8d, 0x9eb0,0x9ec8,0x9eda,0x9efb,
  0x9eff,0x9f24,0x9f23,0x9f22, 0x9f54,0x9fa0,0x5131,0x512d,
  0x512e,0x5698,0x569c,0x5697, 0x569a,0x569d,0x5699,0x5970,
  0x5b3c,0x5c69,0x5c6a,0x5dc0, 0x5e6d,0x5e6e,0x61d8,0x61df,
  0x61ed,0x61ee,0x61f1,0x61ea, 0x61f0,0x61eb,0x61d6,0x61e9,
  0x64ff,0x6504,0x64fd,0x64f8, 0x6501,0x6503,0x64fc,0x6594,
  0x65db,0x66da,0x66db,0x66d8, 0x6ac5,0x6ab9,0x6abd,0x6ae1,
  0x6ac6,0x6aba,0x6ab6,0x6ab7, 0x6ac7,0x6ab4,0x6aad,0x6b5e,
  0x6bc9,0x6c0b,0x7007,0x700c, 0x700d,0x7001,0x7005,0x7014,
  0x700e,0x6fff,0x7000,0x6ffb, 0x7026,0x6ffc,0x6ff7,0x700a,
  0x7201,0x71ff,0x71f9,0x7203, 0x71fd,0x7376,
/* f000 */
  0x74b8,0x74c0,0x74b5,0x74c1, 0x74be,0x74b6,0x74bb,0x74c2,
  0x7514,0x7513,0x765c,0x7664, 0x7659,0x7650,0x7653,0x7657,
  0x765a,0x76a6,0x76bd,0x76ec, 0x77c2,0x77ba,0x78ff,0x790c,
  0x7913,0x7914,0x7909,0x7910, 0x7912,0x7911,0x79ad,0x79ac,
  0x7a5f,0x7c1c,0x7c29,0x7c19, 0x7c20,0x7c1f,0x7c2d,0x7c1d,
  0x7c26,0x7c28,0x7c22,0x7c25, 0x7c30,0x7e5c,0x7e50,0x7e56,
  0x7e63,0x7e58,0x7e62,0x7e5f, 0x7e51,0x7e60,0x7e57,0x7e53,
  0x7fb5,0x7fb3,0x7ff7,0x7ff8, 0x8075,0x81d1,0x81d2,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x81d0,0x825f,0x825e,0x85b4, 0x85c6,0x85c0,0x85c3,0x85c2,
  0x85b3,0x85b5,0x85bd,0x85c7, 0x85c4,0x85bf,0x85cb,0x85ce,
  0x85c8,0x85c5,0x85b1,0x85b6, 0x85d2,0x8624,0x85b8,0x85b7,
  0x85be,0x8669,0x87e7,0x87e6, 0x87e2,0x87db,0x87eb,0x87ea,
  0x87e5,0x87df,0x87f3,0x87e4, 0x87d4,0x87dc,0x87d3,0x87ed,
  0x87d8,0x87e3,0x87a4,0x87d7, 0x87d9,0x8801,0x87f4,0x87e8,
  0x87dd,0x8953,0x894b,0x894f, 0x894c,0x8946,0x8950,0x8951,
  0x8949,0x8b2a,0x8b27,0x8b23, 0x8b33,0x8b30,0x8b35,0x8b47,
  0x8b2f,0x8b3c,0x8b3e,0x8b31, 0x8b25,0x8b37,0x8b26,0x8b36,
  0x8b2e,0x8b24,0x8b3b,0x8b3d, 0x8b3a,0x8c42,0x8c75,0x8c99,
  0x8c98,0x8c97,0x8cfe,0x8d04, 0x8d02,0x8d00,0x8e5c,0x8e62,
  0x8e60,0x8e57,0x8e56,0x8e5e, 0x8e65,0x8e67,
/* f100 */
  0x8e5b,0x8e5a,0x8e61,0x8e5d, 0x8e69,0x8e54,0x8f46,0x8f47,
  0x8f48,0x8f4b,0x9128,0x913a, 0x913b,0x913e,0x91a8,0x91a5,
  0x91a7,0x91af,0x91aa,0x93b5, 0x938c,0x9392,0x93b7,0x939b,
  0x939d,0x9389,0x93a7,0x938e, 0x93aa,0x939e,0x93a6,0x9395,
  0x9388,0x9399,0x939f,0x938d, 0x93b1,0x9391,0x93b2,0x93a4,
  0x93a8,0x93b4,0x93a3,0x93a5, 0x95d2,0x95d3,0x95d1,0x96b3,
  0x96d7,0x96da,0x5dc2,0x96df, 0x96d8,0x96dd,0x9723,0x9722,
  0x9725,0x97ac,0x97ae,0x97a8, 0x97ab,0x97a4,0x97aa,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x97a2,0x97a5,0x97d7,0x97d9, 0x97d6,0x97d8,0x97fa,0x9850,
  0x9851,0x9852,0x98b8,0x9941, 0x993c,0x993a,0x9a0f,0x9a0b,
  0x9a09,0x9a0d,0x9a04,0x9a11, 0x9a0a,0x9a05,0x9a07,0x9a06,
  0x9ac0,0x9adc,0x9b08,0x9b04, 0x9b05,0x9b29,0x9b35,0x9b4a,
  0x9b4c,0x9b4b,0x9bc7,0x9bc6, 0x9bc3,0x9bbf,0x9bc1,0x9bb5,
  0x9bb8,0x9bd3,0x9bb6,0x9bc4, 0x9bb9,0x9bbd,0x9d5c,0x9d53,
  0x9d4f,0x9d4a,0x9d5b,0x9d4b, 0x9d59,0x9d56,0x9d4c,0x9d57,
  0x9d52,0x9d54,0x9d5f,0x9d58, 0x9d5a,0x9e8e,0x9e8c,0x9edf,
  0x9f01,0x9f00,0x9f16,0x9f25, 0x9f2b,0x9f2a,0x9f29,0x9f28,
  0x9f4c,0x9f55,0x5134,0x5135, 0x5296,0x52f7,0x53b4,0x56ab,
  0x56ad,0x56a6,0x56a7,0x56aa, 0x56ac,0x58da,0x58dd,0x58db,
  0x5912,0x5b3d,0x5b3e,0x5b3f, 0x5dc3,0x5e70,
/* f200 */
  0x5fbf,0x61fb,0x6507,0x6510, 0x650d,0x6509,0x650c,0x650e,
  0x6584,0x65de,0x65dd,0x66de, 0x6ae7,0x6ae0,0x6acc,0x6ad1,
  0x6ad9,0x6acb,0x6adf,0x6adc, 0x6ad0,0x6aeb,0x6acf,0x6acd,
  0x6ade,0x6b60,0x6bb0,0x6c0c, 0x7019,0x7027,0x7020,0x7016,
  0x702b,0x7021,0x7022,0x7023, 0x7029,0x7017,0x7024,0x701c,
  0x702a,0x720c,0x720a,0x7207, 0x7202,0x7205,0x72a5,0x72a6,
  0x72a4,0x72a3,0x72a1,0x74cb, 0x74c5,0x74b7,0x74c3,0x7516,
  0x7660,0x77c9,0x77ca,0x77c4, 0x77f1,0x791d,0x791b,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x7921,0x791c,0x7917,0x791e, 0x79b0,0x7a67,0x7a68,0x7c33,
  0x7c3c,0x7c39,0x7c2c,0x7c3b, 0x7cec,0x7cea,0x7e76,0x7e75,
  0x7e78,0x7e70,0x7e77,0x7e6f, 0x7e7a,0x7e72,0x7e74,0x7e68,
  0x7f4b,0x7f4a,0x7f83,0x7f86, 0x7fb7,0x7ffd,0x7ffe,0x8078,
  0x81d7,0x81d5,0x8264,0x8261, 0x8263,0x85eb,0x85f1,0x85ed,
  0x85d9,0x85e1,0x85e8,0x85da, 0x85d7,0x85ec,0x85f2,0x85f8,
  0x85d8,0x85df,0x85e3,0x85dc, 0x85d1,0x85f0,0x85e6,0x85ef,
  0x85de,0x85e2,0x8800,0x87fa, 0x8803,0x87f6,0x87f7,0x8809,
  0x880c,0x880b,0x8806,0x87fc, 0x8808,0x87ff,0x880a,0x8802,
  0x8962,0x895a,0x895b,0x8957, 0x8961,0x895c,0x8958,0x895d,
  0x8959,0x8988,0x89b7,0x89b6, 0x89f6,0x8b50,0x8b48,0x8b4a,
  0x8b40,0x8b53,0x8b56,0x8b54, 0x8b4b,0x8b55,
/* f300 */
  0x8b51,0x8b42,0x8b52,0x8b57, 0x8c43,0x8c77,0x8c76,0x8c9a,
  0x8d06,0x8d07,0x8d09,0x8dac, 0x8daa,0x8dad,0x8dab,0x8e6d,
  0x8e78,0x8e73,0x8e6a,0x8e6f, 0x8e7b,0x8ec2,0x8f52,0x8f51,
  0x8f4f,0x8f50,0x8f53,0x8fb4, 0x9140,0x913f,0x91b0,0x91ad,
  0x93de,0x93c7,0x93cf,0x93c2, 0x93da,0x93d0,0x93f9,0x93ec,
  0x93cc,0x93d9,0x93a9,0x93e6, 0x93ca,0x93d4,0x93ee,0x93e3,
  0x93d5,0x93c4,0x93ce,0x93c0, 0x93d2,0x93e7,0x957d,0x95da,
  0x95db,0x96e1,0x9729,0x972b, 0x972c,0x9728,0x9726,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x97b3,0x97b7,0x97b6,0x97dd, 0x97de,0x97df,0x985c,0x9859,
  0x985d,0x9857,0x98bf,0x98bd, 0x98bb,0x98be,0x9948,0x9947,
  0x9943,0x99a6,0x99a7,0x9a1a, 0x9a15,0x9a25,0x9a1d,0x9a24,
  0x9a1b,0x9a22,0x9a20,0x9a27, 0x9a23,0x9a1e,0x9a1c,0x9a14,
  0x9ac2,0x9b0b,0x9b0a,0x9b0e, 0x9b0c,0x9b37,0x9bea,0x9beb,
  0x9be0,0x9bde,0x9be4,0x9be6, 0x9be2,0x9bf0,0x9bd4,0x9bd7,
  0x9bec,0x9bdc,0x9bd9,0x9be5, 0x9bd5,0x9be1,0x9bda,0x9d77,
  0x9d81,0x9d8a,0x9d84,0x9d88, 0x9d71,0x9d80,0x9d78,0x9d86,
  0x9d8b,0x9d8c,0x9d7d,0x9d6b, 0x9d74,0x9d75,0x9d70,0x9d69,
  0x9d85,0x9d73,0x9d7b,0x9d82, 0x9d6f,0x9d79,0x9d7f,0x9d87,
  0x9d68,0x9e94,0x9e91,0x9ec0, 0x9efc,0x9f2d,0x9f40,0x9f41,
  0x9f4d,0x9f56,0x9f57,0x9f58, 0x5337,0x56b2,
/* f400 */
  0x56b5,0x56b3,0x58e3,0x5b45, 0x5dc6,0x5dc7,0x5eee,0x5eef,
  0x5fc0,0x5fc1,0x61f9,0x6517, 0x6516,0x6515,0x6513,0x65df,
  0x66e8,0x66e3,0x66e4,0x6af3, 0x6af0,0x6aea,0x6ae8,0x6af9,
  0x6af1,0x6aee,0x6aef,0x703c, 0x7035,0x702f,0x7037,0x7034,
  0x7031,0x7042,0x7038,0x703f, 0x703a,0x7039,0x7040,0x703b,
  0x7033,0x7041,0x7213,0x7214, 0x72a8,0x737d,0x737c,0x74ba,
  0x76ab,0x76aa,0x76be,0x76ed, 0x77cc,0x77ce,0x77cf,0x77cd,
  0x77f2,0x7925,0x7923,0x7927, 0x7928,0x7924,0x7929,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x79b2,0x7a6e,0x7a6c,0x7a6d, 0x7af7,0x7c49,0x7c48,0x7c4a,
  0x7c47,0x7c45,0x7cee,0x7e7b, 0x7e7e,0x7e81,0x7e80,0x7fba,
  0x7fff,0x8079,0x81db,0x81d9, 0x820b,0x8268,0x8269,0x8622,
  0x85ff,0x8601,0x85fe,0x861b, 0x8600,0x85f6,0x8604,0x8609,
  0x8605,0x860c,0x85fd,0x8819, 0x8810,0x8811,0x8817,0x8813,
  0x8816,0x8963,0x8966,0x89b9, 0x89f7,0x8b60,0x8b6a,0x8b5d,
  0x8b68,0x8b63,0x8b65,0x8b67, 0x8b6d,0x8dae,0x8e86,0x8e88,
  0x8e84,0x8f59,0x8f56,0x8f57, 0x8f55,0x8f58,0x8f5a,0x908d,
  0x9143,0x9141,0x91b7,0x91b5, 0x91b2,0x91b3,0x940b,0x9413,
  0x93fb,0x9420,0x940f,0x9414, 0x93fe,0x9415,0x9410,0x9428,
  0x9419,0x940d,0x93f5,0x9400, 0x93f7,0x9407,0x940e,0x9416,
  0x9412,0x93fa,0x9409,0x93f8, 0x940a,0x93ff,
/* f500 */
  0x93fc,0x940c,0x93f6,0x9411, 0x9406,0x95de,0x95e0,0x95df,
  0x972e,0x972f,0x97b9,0x97bb, 0x97fd,0x97fe,0x9860,0x9862,
  0x9863,0x985f,0x98c1,0x98c2, 0x9950,0x994e,0x9959,0x994c,
  0x994b,0x9953,0x9a32,0x9a34, 0x9a31,0x9a2c,0x9a2a,0x9a36,
  0x9a29,0x9a2e,0x9a38,0x9a2d, 0x9ac7,0x9aca,0x9ac6,0x9b10,
  0x9b12,0x9b11,0x9c0b,0x9c08, 0x9bf7,0x9c05,0x9c12,0x9bf8,
  0x9c40,0x9c07,0x9c0e,0x9c06, 0x9c17,0x9c14,0x9c09,0x9d9f,
  0x9d99,0x9da4,0x9d9d,0x9d92, 0x9d98,0x9d90,0x9d9b,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x9da0,0x9d94,0x9d9c,0x9daa, 0x9d97,0x9da1,0x9d9a,0x9da2,
  0x9da8,0x9d9e,0x9da3,0x9dbf, 0x9da9,0x9d96,0x9da6,0x9da7,
  0x9e99,0x9e9b,0x9e9a,0x9ee5, 0x9ee4,0x9ee7,0x9ee6,0x9f30,
  0x9f2e,0x9f5b,0x9f60,0x9f5e, 0x9f5d,0x9f59,0x9f91,0x513a,
  0x5139,0x5298,0x5297,0x56c3, 0x56bd,0x56be,0x5b48,0x5b47,
  0x5dcb,0x5dcf,0x5ef1,0x61fd, 0x651b,0x6b02,0x6afc,0x6b03,
  0x6af8,0x6b00,0x7043,0x7044, 0x704a,0x7048,0x7049,0x7045,
  0x7046,0x721d,0x721a,0x7219, 0x737e,0x7517,0x766a,0x77d0,
  0x792d,0x7931,0x792f,0x7c54, 0x7c53,0x7cf2,0x7e8a,0x7e87,
  0x7e88,0x7e8b,0x7e86,0x7e8d, 0x7f4d,0x7fbb,0x8030,0x81dd,
  0x8618,0x862a,0x8626,0x861f, 0x8623,0x861c,0x8619,0x8627,
  0x862e,0x8621,0x8620,0x8629, 0x861e,0x8625,
/* f600 */
  0x8829,0x881d,0x881b,0x8820, 0x8824,0x881c,0x882b,0x884a,
  0x896d,0x8969,0x896e,0x896b, 0x89fa,0x8b79,0x8b78,0x8b45,
  0x8b7a,0x8b7b,0x8d10,0x8d14, 0x8daf,0x8e8e,0x8e8c,0x8f5e,
  0x8f5b,0x8f5d,0x9146,0x9144, 0x9145,0x91b9,0x943f,0x943b,
  0x9436,0x9429,0x943d,0x943c, 0x9430,0x9439,0x942a,0x9437,
  0x942c,0x9440,0x9431,0x95e5, 0x95e4,0x95e3,0x9735,0x973a,
  0x97bf,0x97e1,0x9864,0x98c9, 0x98c6,0x98c0,0x9958,0x9956,
  0x9a39,0x9a3d,0x9a46,0x9a44, 0x9a42,0x9a41,0x9a3a,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x9a3f,0x9acd,0x9b15,0x9b17, 0x9b18,0x9b16,0x9b3a,0x9b52,
  0x9c2b,0x9c1d,0x9c1c,0x9c2c, 0x9c23,0x9c28,0x9c29,0x9c24,
  0x9c21,0x9db7,0x9db6,0x9dbc, 0x9dc1,0x9dc7,0x9dca,0x9dcf,
  0x9dbe,0x9dc5,0x9dc3,0x9dbb, 0x9db5,0x9dce,0x9db9,0x9dba,
  0x9dac,0x9dc8,0x9db1,0x9dad, 0x9dcc,0x9db3,0x9dcd,0x9db2,
  0x9e7a,0x9e9c,0x9eeb,0x9eee, 0x9eed,0x9f1b,0x9f18,0x9f1a,
  0x9f31,0x9f4e,0x9f65,0x9f64, 0x9f92,0x4eb9,0x56c6,0x56c5,
  0x56cb,0x5971,0x5b4b,0x5b4c, 0x5dd5,0x5dd1,0x5ef2,0x6521,
  0x6520,0x6526,0x6522,0x6b0b, 0x6b08,0x6b09,0x6c0d,0x7055,
  0x7056,0x7057,0x7052,0x721e, 0x721f,0x72a9,0x737f,0x74d8,
  0x74d5,0x74d9,0x74d7,0x766d, 0x76ad,0x7935,0x79b4,0x7a70,
  0x7a71,0x7c57,0x7c5c,0x7c59, 0x7c5b,0x7c5a,
/* f700 */
  0x7cf4,0x7cf1,0x7e91,0x7f4f, 0x7f87,0x81de,0x826b,0x8634,
  0x8635,0x8633,0x862c,0x8632, 0x8636,0x882c,0x8828,0x8826,
  0x882a,0x8825,0x8971,0x89bf, 0x89be,0x89fb,0x8b7e,0x8b84,
  0x8b82,0x8b86,0x8b85,0x8b7f, 0x8d15,0x8e95,0x8e94,0x8e9a,
  0x8e92,0x8e90,0x8e96,0x8e97, 0x8f60,0x8f62,0x9147,0x944c,
  0x9450,0x944a,0x944b,0x944f, 0x9447,0x9445,0x9448,0x9449,
  0x9446,0x973f,0x97e3,0x986a, 0x9869,0x98cb,0x9954,0x995b,
  0x9a4e,0x9a53,0x9a54,0x9a4c, 0x9a4f,0x9a48,0x9a4a,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x9a49,0x9a52,0x9a50,0x9ad0, 0x9b19,0x9b2b,0x9b3b,0x9b56,
  0x9b55,0x9c46,0x9c48,0x9c3f, 0x9c44,0x9c39,0x9c33,0x9c41,
  0x9c3c,0x9c37,0x9c34,0x9c32, 0x9c3d,0x9c36,0x9ddb,0x9dd2,
  0x9dde,0x9dda,0x9dcb,0x9dd0, 0x9ddc,0x9dd1,0x9ddf,0x9de9,
  0x9dd9,0x9dd8,0x9dd6,0x9df5, 0x9dd5,0x9ddd,0x9eb6,0x9ef0,
  0x9f35,0x9f33,0x9f32,0x9f42, 0x9f6b,0x9f95,0x9fa2,0x513d,
  0x5299,0x58e8,0x58e7,0x5972, 0x5b4d,0x5dd8,0x882f,0x5f4f,
  0x6201,0x6203,0x6204,0x6529, 0x6525,0x6596,0x66eb,0x6b11,
  0x6b12,0x6b0f,0x6bca,0x705b, 0x705a,0x7222,0x7382,0x7381,
  0x7383,0x7670,0x77d4,0x7c67, 0x7c66,0x7e95,0x826c,0x863a,
  0x8640,0x8639,0x863c,0x8631, 0x863b,0x863e,0x8830,0x8832,
  0x882e,0x8833,0x8976,0x8974, 0x8973,0x89fe,
/* f800 */
  0x8b8c,0x8b8e,0x8b8b,0x8b88, 0x8c45,0x8d19,0x8e98,0x8f64,
  0x8f63,0x91bc,0x9462,0x9455, 0x945d,0x9457,0x945e,0x97c4,
  0x97c5,0x9800,0x9a56,0x9a59, 0x9b1e,0x9b1f,0x9b20,0x9c52,
  0x9c58,0x9c50,0x9c4a,0x9c4d, 0x9c4b,0x9c55,0x9c59,0x9c4c,
  0x9c4e,0x9dfb,0x9df7,0x9def, 0x9de3,0x9deb,0x9df8,0x9de4,
  0x9df6,0x9de1,0x9dee,0x9de6, 0x9df2,0x9df0,0x9de2,0x9dec,
  0x9df4,0x9df3,0x9de8,0x9ded, 0x9ec2,0x9ed0,0x9ef2,0x9ef3,
  0x9f06,0x9f1c,0x9f38,0x9f37, 0x9f36,0x9f43,0x9f4f,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x9f71,0x9f70,0x9f6e,0x9f6f, 0x56d3,0x56cd,0x5b4e,0x5c6d,
  0x652d,0x66ed,0x66ee,0x6b13, 0x705f,0x7061,0x705d,0x7060,
  0x7223,0x74db,0x74e5,0x77d5, 0x7938,0x79b7,0x79b6,0x7c6a,
  0x7e97,0x7f89,0x826d,0x8643, 0x8838,0x8837,0x8835,0x884b,
  0x8b94,0x8b95,0x8e9e,0x8e9f, 0x8ea0,0x8e9d,0x91be,0x91bd,
  0x91c2,0x946b,0x9468,0x9469, 0x96e5,0x9746,0x9743,0x9747,
  0x97c7,0x97e5,0x9a5e,0x9ad5, 0x9b59,0x9c63,0x9c67,0x9c66,
  0x9c62,0x9c5e,0x9c60,0x9e02, 0x9dfe,0x9e07,0x9e03,0x9e06,
  0x9e05,0x9e00,0x9e01,0x9e09, 0x9dff,0x9dfd,0x9e04,0x9ea0,
  0x9f1e,0x9f46,0x9f74,0x9f75, 0x9f76,0x56d4,0x652e,0x65b8,
  0x6b18,0x6b19,0x6b17,0x6b1a, 0x7062,0x7226,0x72aa,0x77d8,
  0x77d9,0x7939,0x7c69,0x7c6b, 0x7cf6,0x7e9a,
/* f900 */
  0x7e98,0x7e9b,0x7e99,0x81e0, 0x81e1,0x8646,0x8647,0x8648,
  0x8979,0x897a,0x897c,0x897b, 0x89ff,0x8b98,0x8b99,0x8ea5,
  0x8ea4,0x8ea3,0x946e,0x946d, 0x946f,0x9471,0x9473,0x9749,
  0x9872,0x995f,0x9c68,0x9c6e, 0x9c6d,0x9e0b,0x9e0d,0x9e10,
  0x9e0f,0x9e12,0x9e11,0x9ea1, 0x9ef5,0x9f09,0x9f47,0x9f78,
  0x9f7b,0x9f7a,0x9f79,0x571e, 0x7066,0x7c6f,0x883c,0x8db2,
  0x8ea6,0x91c3,0x9474,0x9478, 0x9476,0x9475,0x9a60,0x9c74,
  0x9c73,0x9c71,0x9c75,0x9e14, 0x9e13,0x9ef6,0x9f0a,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x9fa4,0x7068,0x7065,0x7cf7, 0x866a,0x883e,0x883d,0x883f,
  0x8b9e,0x8c9c,0x8ea9,0x8ec9, 0x974b,0x9873,0x9874,0x98cc,
  0x9961,0x99ab,0x9a64,0x9a66, 0x9a67,0x9b24,0x9e15,0x9e17,
  0x9f48,0x6207,0x6b1e,0x7227, 0x864c,0x8ea8,0x9482,0x9480,
  0x9481,0x9a69,0x9a68,0x9b2e, 0x9e19,0x7229,0x864b,0x8b9f,
  0x9483,0x9c79,0x9eb7,0x7675, 0x9a6b,0x9c7a,0x9e1d,0x7069,
  0x706a,0x9ea4,0x9f7e,0x9f49, 0x9f98,0x7881,0x92b9,0x88cf,
  0x58bb,0x6052,0x7ca7,0x5afa, 0x2554,0x2566,0x2557,0x2560,
  0x256c,0x2563,0x255a,0x2569, 0x255d,0x2552,0x2564,0x2555,
  0x255e,0x256a,0x2561,0x2558, 0x2567,0x255b,0x2553,0x2565,
  0x2556,0x255f,0x256b,0x2562, 0x2559,0x2568,0x255c,0x2551,
  0x2550,0x256d,0x256e,0x2570, 0x256f,0x2593,
/* fa00 */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* fb00 */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* fc00 */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* fd00 */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,
/* fe00 */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000
}; 

unsigned short johab_uni_byte[JOHAB_TBL_LEN] = {
/* codelimit: 15040 */
  0x0000,0x0000,0x0000,0x3133, 0x0000,0x3135,0x3136,0x0000,
  0x0000,0x313a,0x313b,0x313c, 0x313d,0x313e,0x313f,0x3140,
  0x0000,0x0000,0x0000,0x3144, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x314f,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x3150,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x3151,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x3152,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x3153,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x3154,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x3155,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x3156,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x3157,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x3158,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x3159,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x315a,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x315b,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x315c,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x315d,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x315e,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x315f,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x3160,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x3161,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x3162,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x3163,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x3131,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xac00,0xac01,0xac02,0xac03, 0xac04,0xac05,0xac06,0xac07,
  0xac08,0xac09,0xac0a,0xac0b, 0xac0c,0xac0d,0xac0e,0xac0f,
  0xac10,0x0000,0xac11,0xac12, 0xac13,0xac14,0xac15,0xac16,
  0xac17,0xac18,0xac19,0xac1a, 0xac1b,0x0000,0xac1c,0xac1d,
  0xac1e,0xac1f,0xac20,0xac21, 0xac22,0xac23,0xac24,0xac25,
  0xac26,0xac27,0xac28,0xac29, 0xac2a,0xac2b,0xac2c,0x0000,
  0xac2d,0xac2e,0xac2f,0xac30, 0xac31,0xac32,0xac33,0xac34,
  0xac35,0xac36,0xac37,0x0000, 0x0000,0x0000,0xac38,0xac39,
  0xac3a,0xac3b,0xac3c,0xac3d, 0xac3e,0xac3f,0xac40,0xac41,
  0xac42,0xac43,0xac44,0xac45, 0xac46,0xac47,0xac48,0x0000,
  0xac49,0xac4a,0xac4b,0xac4c, 0xac4d,0xac4e,0xac4f,0xac50,
  0xac51,0xac52,0xac53,0x0000, 0x0000,0x0000,0xac54,0xac55,
  0xac56,0xac57,0xac58,0xac59, 0xac5a,0xac5b,0xac5c,0xac5d,
  0xac5e,0xac5f,0xac60,0xac61, 0xac62,0xac63,0xac64,0x0000,
  0xac65,0xac66,0xac67,0xac68, 0xac69,0xac6a,0xac6b,0xac6c,
  0xac6d,0xac6e,0xac6f,0x0000, 0x0000,0x0000,0xac70,0xac71,
  0xac72,0xac73,0xac74,0xac75, 0xac76,0xac77,0xac78,0xac79,
  0xac7a,0xac7b,0xac7c,0xac7d, 0xac7e,0xac7f,0xac80,0x0000,
  0xac81,0xac82,0xac83,0xac84, 0xac85,0xac86,0xac87,0xac88,
  0xac89,0xac8a,0xac8b,0x0000, 0xac8c,0xac8d,0xac8e,0xac8f,
  0xac90,0xac91,0xac92,0xac93, 0xac94,0xac95,0xac96,0xac97,
  0xac98,0xac99,0xac9a,0xac9b, 0xac9c,0x0000,0xac9d,0xac9e,
  0xac9f,0xaca0,0xaca1,0xaca2, 0xaca3,0xaca4,0xaca5,0xaca6,
  0xaca7,0x0000,0x0000,0x0000, 0xaca8,0xaca9,0xacaa,0xacab,
  0xacac,0xacad,0xacae,0xacaf, 0xacb0,0xacb1,0xacb2,0xacb3,
  0xacb4,0xacb5,0xacb6,0xacb7, 0xacb8,0x0000,0xacb9,0xacba,
  0xacbb,0xacbc,0xacbd,0xacbe, 0xacbf,0xacc0,0xacc1,0xacc2,
  0xacc3,0x0000,0xacc4,0xacc5, 0xacc6,0xacc7,0xacc8,0xacc9,
  0xacca,0xaccb,0xaccc,0xaccd, 0xacce,0xaccf,0xacd0,0xacd1,
  0xacd2,0xacd3,0xacd4,0x0000, 0xacd5,0xacd6,0xacd7,0xacd8,
  0xacd9,0xacda,0xacdb,0xacdc, 0xacdd,0xacde,0xacdf,0x0000,
  0x0000,0x0000,0xace0,0xace1, 0xace2,0xace3,0xace4,0xace5,
  0xace6,0xace7,0xace8,0xace9, 0xacea,0xaceb,0xacec,0xaced,
  0xacee,0xacef,0xacf0,0x0000, 0xacf1,0xacf2,0xacf3,0xacf4,
  0xacf5,0xacf6,0xacf7,0xacf8, 0xacf9,0xacfa,0xacfb,0x0000,
  0x0000,0x0000,0xacfc,0xacfd, 0xacfe,0xacff,0xad00,0xad01,
  0xad02,0xad03,0xad04,0xad05, 0xad06,0xad07,0xad08,0xad09,
  0xad0a,0xad0b,0xad0c,0x0000, 0xad0d,0xad0e,0xad0f,0xad10,
  0xad11,0xad12,0xad13,0xad14, 0xad15,0xad16,0xad17,0x0000,
  0x0000,0x0000,0xad18,0xad19, 0xad1a,0xad1b,0xad1c,0xad1d,
  0xad1e,0xad1f,0xad20,0xad21, 0xad22,0xad23,0xad24,0xad25,
  0xad26,0xad27,0xad28,0x0000, 0xad29,0xad2a,0xad2b,0xad2c,
  0xad2d,0xad2e,0xad2f,0xad30, 0xad31,0xad32,0xad33,0x0000,
  0xad34,0xad35,0xad36,0xad37, 0xad38,0xad39,0xad3a,0xad3b,
  0xad3c,0xad3d,0xad3e,0xad3f, 0xad40,0xad41,0xad42,0xad43,
  0xad44,0x0000,0xad45,0xad46, 0xad47,0xad48,0xad49,0xad4a,
  0xad4b,0xad4c,0xad4d,0xad4e, 0xad4f,0x0000,0x0000,0x0000,
  0xad50,0xad51,0xad52,0xad53, 0xad54,0xad55,0xad56,0xad57,
  0xad58,0xad59,0xad5a,0xad5b, 0xad5c,0xad5d,0xad5e,0xad5f,
  0xad60,0x0000,0xad61,0xad62, 0xad63,0xad64,0xad65,0xad66,
  0xad67,0xad68,0xad69,0xad6a, 0xad6b,0x0000,0xad6c,0xad6d,
  0xad6e,0xad6f,0xad70,0xad71, 0xad72,0xad73,0xad74,0xad75,
  0xad76,0xad77,0xad78,0xad79, 0xad7a,0xad7b,0xad7c,0x0000,
  0xad7d,0xad7e,0xad7f,0xad80, 0xad81,0xad82,0xad83,0xad84,
  0xad85,0xad86,0xad87,0x0000, 0x0000,0x0000,0xad88,0xad89,
  0xad8a,0xad8b,0xad8c,0xad8d, 0xad8e,0xad8f,0xad90,0xad91,
  0xad92,0xad93,0xad94,0xad95, 0xad96,0xad97,0xad98,0x0000,
  0xad99,0xad9a,0xad9b,0xad9c, 0xad9d,0xad9e,0xad9f,0xada0,
  0xada1,0xada2,0xada3,0x0000, 0x0000,0x0000,0xada4,0xada5,
  0xada6,0xada7,0xada8,0xada9, 0xadaa,0xadab,0xadac,0xadad,
  0xadae,0xadaf,0xadb0,0xadb1, 0xadb2,0xadb3,0xadb4,0x0000,
  0xadb5,0xadb6,0xadb7,0xadb8, 0xadb9,0xadba,0xadbb,0xadbc,
  0xadbd,0xadbe,0xadbf,0x0000, 0x0000,0x0000,0xadc0,0xadc1,
  0xadc2,0xadc3,0xadc4,0xadc5, 0xadc6,0xadc7,0xadc8,0xadc9,
  0xadca,0xadcb,0xadcc,0xadcd, 0xadce,0xadcf,0xadd0,0x0000,
  0xadd1,0xadd2,0xadd3,0xadd4, 0xadd5,0xadd6,0xadd7,0xadd8,
  0xadd9,0xadda,0xaddb,0x0000, 0xaddc,0xaddd,0xadde,0xaddf,
  0xade0,0xade1,0xade2,0xade3, 0xade4,0xade5,0xade6,0xade7,
  0xade8,0xade9,0xadea,0xadeb, 0xadec,0x0000,0xaded,0xadee,
  0xadef,0xadf0,0xadf1,0xadf2, 0xadf3,0xadf4,0xadf5,0xadf6,
  0xadf7,0x0000,0x0000,0x0000, 0xadf8,0xadf9,0xadfa,0xadfb,
  0xadfc,0xadfd,0xadfe,0xadff, 0xae00,0xae01,0xae02,0xae03,
  0xae04,0xae05,0xae06,0xae07, 0xae08,0x0000,0xae09,0xae0a,
  0xae0b,0xae0c,0xae0d,0xae0e, 0xae0f,0xae10,0xae11,0xae12,
  0xae13,0x0000,0xae14,0xae15, 0xae16,0xae17,0xae18,0xae19,
  0xae1a,0xae1b,0xae1c,0xae1d, 0xae1e,0xae1f,0xae20,0xae21,
  0xae22,0xae23,0xae24,0x0000, 0xae25,0xae26,0xae27,0xae28,
  0xae29,0xae2a,0xae2b,0xae2c, 0xae2d,0xae2e,0xae2f,0x0000,
  0x0000,0x0000,0xae30,0xae31, 0xae32,0xae33,0xae34,0xae35,
  0xae36,0xae37,0xae38,0xae39, 0xae3a,0xae3b,0xae3c,0xae3d,
  0xae3e,0xae3f,0xae40,0x0000, 0xae41,0xae42,0xae43,0xae44,
  0xae45,0xae46,0xae47,0xae48, 0xae49,0xae4a,0xae4b,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x3132,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xae4c,0xae4d,0xae4e,0xae4f, 0xae50,0xae51,0xae52,0xae53,
  0xae54,0xae55,0xae56,0xae57, 0xae58,0xae59,0xae5a,0xae5b,
  0xae5c,0x0000,0xae5d,0xae5e, 0xae5f,0xae60,0xae61,0xae62,
  0xae63,0xae64,0xae65,0xae66, 0xae67,0x0000,0xae68,0xae69,
  0xae6a,0xae6b,0xae6c,0xae6d, 0xae6e,0xae6f,0xae70,0xae71,
  0xae72,0xae73,0xae74,0xae75, 0xae76,0xae77,0xae78,0x0000,
  0xae79,0xae7a,0xae7b,0xae7c, 0xae7d,0xae7e,0xae7f,0xae80,
  0xae81,0xae82,0xae83,0x0000, 0x0000,0x0000,0xae84,0xae85,
  0xae86,0xae87,0xae88,0xae89, 0xae8a,0xae8b,0xae8c,0xae8d,
  0xae8e,0xae8f,0xae90,0xae91, 0xae92,0xae93,0xae94,0x0000,
  0xae95,0xae96,0xae97,0xae98, 0xae99,0xae9a,0xae9b,0xae9c,
  0xae9d,0xae9e,0xae9f,0x0000, 0x0000,0x0000,0xaea0,0xaea1,
  0xaea2,0xaea3,0xaea4,0xaea5, 0xaea6,0xaea7,0xaea8,0xaea9,
  0xaeaa,0xaeab,0xaeac,0xaead, 0xaeae,0xaeaf,0xaeb0,0x0000,
  0xaeb1,0xaeb2,0xaeb3,0xaeb4, 0xaeb5,0xaeb6,0xaeb7,0xaeb8,
  0xaeb9,0xaeba,0xaebb,0x0000, 0x0000,0x0000,0xaebc,0xaebd,
  0xaebe,0xaebf,0xaec0,0xaec1, 0xaec2,0xaec3,0xaec4,0xaec5,
  0xaec6,0xaec7,0xaec8,0xaec9, 0xaeca,0xaecb,0xaecc,0x0000,
  0xaecd,0xaece,0xaecf,0xaed0, 0xaed1,0xaed2,0xaed3,0xaed4,
  0xaed5,0xaed6,0xaed7,0x0000, 0xaed8,0xaed9,0xaeda,0xaedb,
  0xaedc,0xaedd,0xaede,0xaedf, 0xaee0,0xaee1,0xaee2,0xaee3,
  0xaee4,0xaee5,0xaee6,0xaee7, 0xaee8,0x0000,0xaee9,0xaeea,
  0xaeeb,0xaeec,0xaeed,0xaeee, 0xaeef,0xaef0,0xaef1,0xaef2,
  0xaef3,0x0000,0x0000,0x0000, 0xaef4,0xaef5,0xaef6,0xaef7,
  0xaef8,0xaef9,0xaefa,0xaefb, 0xaefc,0xaefd,0xaefe,0xaeff,
  0xaf00,0xaf01,0xaf02,0xaf03, 0xaf04,0x0000,0xaf05,0xaf06,
  0xaf07,0xaf08,0xaf09,0xaf0a, 0xaf0b,0xaf0c,0xaf0d,0xaf0e,
  0xaf0f,0x0000,0xaf10,0xaf11, 0xaf12,0xaf13,0xaf14,0xaf15,
  0xaf16,0xaf17,0xaf18,0xaf19, 0xaf1a,0xaf1b,0xaf1c,0xaf1d,
  0xaf1e,0xaf1f,0xaf20,0x0000, 0xaf21,0xaf22,0xaf23,0xaf24,
  0xaf25,0xaf26,0xaf27,0xaf28, 0xaf29,0xaf2a,0xaf2b,0x0000,
  0x0000,0x0000,0xaf2c,0xaf2d, 0xaf2e,0xaf2f,0xaf30,0xaf31,
  0xaf32,0xaf33,0xaf34,0xaf35, 0xaf36,0xaf37,0xaf38,0xaf39,
  0xaf3a,0xaf3b,0xaf3c,0x0000, 0xaf3d,0xaf3e,0xaf3f,0xaf40,
  0xaf41,0xaf42,0xaf43,0xaf44, 0xaf45,0xaf46,0xaf47,0x0000,
  0x0000,0x0000,0xaf48,0xaf49, 0xaf4a,0xaf4b,0xaf4c,0xaf4d,
  0xaf4e,0xaf4f,0xaf50,0xaf51, 0xaf52,0xaf53,0xaf54,0xaf55,
  0xaf56,0xaf57,0xaf58,0x0000, 0xaf59,0xaf5a,0xaf5b,0xaf5c,
  0xaf5d,0xaf5e,0xaf5f,0xaf60, 0xaf61,0xaf62,0xaf63,0x0000,
  0x0000,0x0000,0xaf64,0xaf65, 0xaf66,0xaf67,0xaf68,0xaf69,
  0xaf6a,0xaf6b,0xaf6c,0xaf6d, 0xaf6e,0xaf6f,0xaf70,0xaf71,
  0xaf72,0xaf73,0xaf74,0x0000, 0xaf75,0xaf76,0xaf77,0xaf78,
  0xaf79,0xaf7a,0xaf7b,0xaf7c, 0xaf7d,0xaf7e,0xaf7f,0x0000,
  0xaf80,0xaf81,0xaf82,0xaf83, 0xaf84,0xaf85,0xaf86,0xaf87,
  0xaf88,0xaf89,0xaf8a,0xaf8b, 0xaf8c,0xaf8d,0xaf8e,0xaf8f,
  0xaf90,0x0000,0xaf91,0xaf92, 0xaf93,0xaf94,0xaf95,0xaf96,
  0xaf97,0xaf98,0xaf99,0xaf9a, 0xaf9b,0x0000,0x0000,0x0000,
  0xaf9c,0xaf9d,0xaf9e,0xaf9f, 0xafa0,0xafa1,0xafa2,0xafa3,
  0xafa4,0xafa5,0xafa6,0xafa7, 0xafa8,0xafa9,0xafaa,0xafab,
  0xafac,0x0000,0xafad,0xafae, 0xafaf,0xafb0,0xafb1,0xafb2,
  0xafb3,0xafb4,0xafb5,0xafb6, 0xafb7,0x0000,0xafb8,0xafb9,
  0xafba,0xafbb,0xafbc,0xafbd, 0xafbe,0xafbf,0xafc0,0xafc1,
  0xafc2,0xafc3,0xafc4,0xafc5, 0xafc6,0xafc7,0xafc8,0x0000,
  0xafc9,0xafca,0xafcb,0xafcc, 0xafcd,0xafce,0xafcf,0xafd0,
  0xafd1,0xafd2,0xafd3,0x0000, 0x0000,0x0000,0xafd4,0xafd5,
  0xafd6,0xafd7,0xafd8,0xafd9, 0xafda,0xafdb,0xafdc,0xafdd,
  0xafde,0xafdf,0xafe0,0xafe1, 0xafe2,0xafe3,0xafe4,0x0000,
  0xafe5,0xafe6,0xafe7,0xafe8, 0xafe9,0xafea,0xafeb,0xafec,
  0xafed,0xafee,0xafef,0x0000, 0x0000,0x0000,0xaff0,0xaff1,
  0xaff2,0xaff3,0xaff4,0xaff5, 0xaff6,0xaff7,0xaff8,0xaff9,
  0xaffa,0xaffb,0xaffc,0xaffd, 0xaffe,0xafff,0xb000,0x0000,
  0xb001,0xb002,0xb003,0xb004, 0xb005,0xb006,0xb007,0xb008,
  0xb009,0xb00a,0xb00b,0x0000, 0x0000,0x0000,0xb00c,0xb00d,
  0xb00e,0xb00f,0xb010,0xb011, 0xb012,0xb013,0xb014,0xb015,
  0xb016,0xb017,0xb018,0xb019, 0xb01a,0xb01b,0xb01c,0x0000,
  0xb01d,0xb01e,0xb01f,0xb020, 0xb021,0xb022,0xb023,0xb024,
  0xb025,0xb026,0xb027,0x0000, 0xb028,0xb029,0xb02a,0xb02b,
  0xb02c,0xb02d,0xb02e,0xb02f, 0xb030,0xb031,0xb032,0xb033,
  0xb034,0xb035,0xb036,0xb037, 0xb038,0x0000,0xb039,0xb03a,
  0xb03b,0xb03c,0xb03d,0xb03e, 0xb03f,0xb040,0xb041,0xb042,
  0xb043,0x0000,0x0000,0x0000, 0xb044,0xb045,0xb046,0xb047,
  0xb048,0xb049,0xb04a,0xb04b, 0xb04c,0xb04d,0xb04e,0xb04f,
  0xb050,0xb051,0xb052,0xb053, 0xb054,0x0000,0xb055,0xb056,
  0xb057,0xb058,0xb059,0xb05a, 0xb05b,0xb05c,0xb05d,0xb05e,
  0xb05f,0x0000,0xb060,0xb061, 0xb062,0xb063,0xb064,0xb065,
  0xb066,0xb067,0xb068,0xb069, 0xb06a,0xb06b,0xb06c,0xb06d,
  0xb06e,0xb06f,0xb070,0x0000, 0xb071,0xb072,0xb073,0xb074,
  0xb075,0xb076,0xb077,0xb078, 0xb079,0xb07a,0xb07b,0x0000,
  0x0000,0x0000,0xb07c,0xb07d, 0xb07e,0xb07f,0xb080,0xb081,
  0xb082,0xb083,0xb084,0xb085, 0xb086,0xb087,0xb088,0xb089,
  0xb08a,0xb08b,0xb08c,0x0000, 0xb08d,0xb08e,0xb08f,0xb090,
  0xb091,0xb092,0xb093,0xb094, 0xb095,0xb096,0xb097,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x3134,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb098,0xb099,0xb09a,0xb09b, 0xb09c,0xb09d,0xb09e,0xb09f,
  0xb0a0,0xb0a1,0xb0a2,0xb0a3, 0xb0a4,0xb0a5,0xb0a6,0xb0a7,
  0xb0a8,0x0000,0xb0a9,0xb0aa, 0xb0ab,0xb0ac,0xb0ad,0xb0ae,
  0xb0af,0xb0b0,0xb0b1,0xb0b2, 0xb0b3,0x0000,0xb0b4,0xb0b5,
  0xb0b6,0xb0b7,0xb0b8,0xb0b9, 0xb0ba,0xb0bb,0xb0bc,0xb0bd,
  0xb0be,0xb0bf,0xb0c0,0xb0c1, 0xb0c2,0xb0c3,0xb0c4,0x0000,
  0xb0c5,0xb0c6,0xb0c7,0xb0c8, 0xb0c9,0xb0ca,0xb0cb,0xb0cc,
  0xb0cd,0xb0ce,0xb0cf,0x0000, 0x0000,0x0000,0xb0d0,0xb0d1,
  0xb0d2,0xb0d3,0xb0d4,0xb0d5, 0xb0d6,0xb0d7,0xb0d8,0xb0d9,
  0xb0da,0xb0db,0xb0dc,0xb0dd, 0xb0de,0xb0df,0xb0e0,0x0000,
  0xb0e1,0xb0e2,0xb0e3,0xb0e4, 0xb0e5,0xb0e6,0xb0e7,0xb0e8,
  0xb0e9,0xb0ea,0xb0eb,0x0000, 0x0000,0x0000,0xb0ec,0xb0ed,
  0xb0ee,0xb0ef,0xb0f0,0xb0f1, 0xb0f2,0xb0f3,0xb0f4,0xb0f5,
  0xb0f6,0xb0f7,0xb0f8,0xb0f9, 0xb0fa,0xb0fb,0xb0fc,0x0000,
  0xb0fd,0xb0fe,0xb0ff,0xb100, 0xb101,0xb102,0xb103,0xb104,
  0xb105,0xb106,0xb107,0x0000, 0x0000,0x0000,0xb108,0xb109,
  0xb10a,0xb10b,0xb10c,0xb10d, 0xb10e,0xb10f,0xb110,0xb111,
  0xb112,0xb113,0xb114,0xb115, 0xb116,0xb117,0xb118,0x0000,
  0xb119,0xb11a,0xb11b,0xb11c, 0xb11d,0xb11e,0xb11f,0xb120,
  0xb121,0xb122,0xb123,0x0000, 0xb124,0xb125,0xb126,0xb127,
  0xb128,0xb129,0xb12a,0xb12b, 0xb12c,0xb12d,0xb12e,0xb12f,
  0xb130,0xb131,0xb132,0xb133, 0xb134,0x0000,0xb135,0xb136,
  0xb137,0xb138,0xb139,0xb13a, 0xb13b,0xb13c,0xb13d,0xb13e,
  0xb13f,0x0000,0x0000,0x0000, 0xb140,0xb141,0xb142,0xb143,
  0xb144,0xb145,0xb146,0xb147, 0xb148,0xb149,0xb14a,0xb14b,
  0xb14c,0xb14d,0xb14e,0xb14f, 0xb150,0x0000,0xb151,0xb152,
  0xb153,0xb154,0xb155,0xb156, 0xb157,0xb158,0xb159,0xb15a,
  0xb15b,0x0000,0xb15c,0xb15d, 0xb15e,0xb15f,0xb160,0xb161,
  0xb162,0xb163,0xb164,0xb165, 0xb166,0xb167,0xb168,0xb169,
  0xb16a,0xb16b,0xb16c,0x0000, 0xb16d,0xb16e,0xb16f,0xb170,
  0xb171,0xb172,0xb173,0xb174, 0xb175,0xb176,0xb177,0x0000,
  0x0000,0x0000,0xb178,0xb179, 0xb17a,0xb17b,0xb17c,0xb17d,
  0xb17e,0xb17f,0xb180,0xb181, 0xb182,0xb183,0xb184,0xb185,
  0xb186,0xb187,0xb188,0x0000, 0xb189,0xb18a,0xb18b,0xb18c,
  0xb18d,0xb18e,0xb18f,0xb190, 0xb191,0xb192,0xb193,0x0000,
  0x0000,0x0000,0xb194,0xb195, 0xb196,0xb197,0xb198,0xb199,
  0xb19a,0xb19b,0xb19c,0xb19d, 0xb19e,0xb19f,0xb1a0,0xb1a1,
  0xb1a2,0xb1a3,0xb1a4,0x0000, 0xb1a5,0xb1a6,0xb1a7,0xb1a8,
  0xb1a9,0xb1aa,0xb1ab,0xb1ac, 0xb1ad,0xb1ae,0xb1af,0x0000,
  0x0000,0x0000,0xb1b0,0xb1b1, 0xb1b2,0xb1b3,0xb1b4,0xb1b5,
  0xb1b6,0xb1b7,0xb1b8,0xb1b9, 0xb1ba,0xb1bb,0xb1bc,0xb1bd,
  0xb1be,0xb1bf,0xb1c0,0x0000, 0xb1c1,0xb1c2,0xb1c3,0xb1c4,
  0xb1c5,0xb1c6,0xb1c7,0xb1c8, 0xb1c9,0xb1ca,0xb1cb,0x0000,
  0xb1cc,0xb1cd,0xb1ce,0xb1cf, 0xb1d0,0xb1d1,0xb1d2,0xb1d3,
  0xb1d4,0xb1d5,0xb1d6,0xb1d7, 0xb1d8,0xb1d9,0xb1da,0xb1db,
  0xb1dc,0x0000,0xb1dd,0xb1de, 0xb1df,0xb1e0,0xb1e1,0xb1e2,
  0xb1e3,0xb1e4,0xb1e5,0xb1e6, 0xb1e7,0x0000,0x0000,0x0000,
  0xb1e8,0xb1e9,0xb1ea,0xb1eb, 0xb1ec,0xb1ed,0xb1ee,0xb1ef,
  0xb1f0,0xb1f1,0xb1f2,0xb1f3, 0xb1f4,0xb1f5,0xb1f6,0xb1f7,
  0xb1f8,0x0000,0xb1f9,0xb1fa, 0xb1fb,0xb1fc,0xb1fd,0xb1fe,
  0xb1ff,0xb200,0xb201,0xb202, 0xb203,0x0000,0xb204,0xb205,
  0xb206,0xb207,0xb208,0xb209, 0xb20a,0xb20b,0xb20c,0xb20d,
  0xb20e,0xb20f,0xb210,0xb211, 0xb212,0xb213,0xb214,0x0000,
  0xb215,0xb216,0xb217,0xb218, 0xb219,0xb21a,0xb21b,0xb21c,
  0xb21d,0xb21e,0xb21f,0x0000, 0x0000,0x0000,0xb220,0xb221,
  0xb222,0xb223,0xb224,0xb225, 0xb226,0xb227,0xb228,0xb229,
  0xb22a,0xb22b,0xb22c,0xb22d, 0xb22e,0xb22f,0xb230,0x0000,
  0xb231,0xb232,0xb233,0xb234, 0xb235,0xb236,0xb237,0xb238,
  0xb239,0xb23a,0xb23b,0x0000, 0x0000,0x0000,0xb23c,0xb23d,
  0xb23e,0xb23f,0xb240,0xb241, 0xb242,0xb243,0xb244,0xb245,
  0xb246,0xb247,0xb248,0xb249, 0xb24a,0xb24b,0xb24c,0x0000,
  0xb24d,0xb24e,0xb24f,0xb250, 0xb251,0xb252,0xb253,0xb254,
  0xb255,0xb256,0xb257,0x0000, 0x0000,0x0000,0xb258,0xb259,
  0xb25a,0xb25b,0xb25c,0xb25d, 0xb25e,0xb25f,0xb260,0xb261,
  0xb262,0xb263,0xb264,0xb265, 0xb266,0xb267,0xb268,0x0000,
  0xb269,0xb26a,0xb26b,0xb26c, 0xb26d,0xb26e,0xb26f,0xb270,
  0xb271,0xb272,0xb273,0x0000, 0xb274,0xb275,0xb276,0xb277,
  0xb278,0xb279,0xb27a,0xb27b, 0xb27c,0xb27d,0xb27e,0xb27f,
  0xb280,0xb281,0xb282,0xb283, 0xb284,0x0000,0xb285,0xb286,
  0xb287,0xb288,0xb289,0xb28a, 0xb28b,0xb28c,0xb28d,0xb28e,
  0xb28f,0x0000,0x0000,0x0000, 0xb290,0xb291,0xb292,0xb293,
  0xb294,0xb295,0xb296,0xb297, 0xb298,0xb299,0xb29a,0xb29b,
  0xb29c,0xb29d,0xb29e,0xb29f, 0xb2a0,0x0000,0xb2a1,0xb2a2,
  0xb2a3,0xb2a4,0xb2a5,0xb2a6, 0xb2a7,0xb2a8,0xb2a9,0xb2aa,
  0xb2ab,0x0000,0xb2ac,0xb2ad, 0xb2ae,0xb2af,0xb2b0,0xb2b1,
  0xb2b2,0xb2b3,0xb2b4,0xb2b5, 0xb2b6,0xb2b7,0xb2b8,0xb2b9,
  0xb2ba,0xb2bb,0xb2bc,0x0000, 0xb2bd,0xb2be,0xb2bf,0xb2c0,
  0xb2c1,0xb2c2,0xb2c3,0xb2c4, 0xb2c5,0xb2c6,0xb2c7,0x0000,
  0x0000,0x0000,0xb2c8,0xb2c9, 0xb2ca,0xb2cb,0xb2cc,0xb2cd,
  0xb2ce,0xb2cf,0xb2d0,0xb2d1, 0xb2d2,0xb2d3,0xb2d4,0xb2d5,
  0xb2d6,0xb2d7,0xb2d8,0x0000, 0xb2d9,0xb2da,0xb2db,0xb2dc,
  0xb2dd,0xb2de,0xb2df,0xb2e0, 0xb2e1,0xb2e2,0xb2e3,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x3137,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb2e4,0xb2e5,0xb2e6,0xb2e7, 0xb2e8,0xb2e9,0xb2ea,0xb2eb,
  0xb2ec,0xb2ed,0xb2ee,0xb2ef, 0xb2f0,0xb2f1,0xb2f2,0xb2f3,
  0xb2f4,0x0000,0xb2f5,0xb2f6, 0xb2f7,0xb2f8,0xb2f9,0xb2fa,
  0xb2fb,0xb2fc,0xb2fd,0xb2fe, 0xb2ff,0x0000,0xb300,0xb301,
  0xb302,0xb303,0xb304,0xb305, 0xb306,0xb307,0xb308,0xb309,
  0xb30a,0xb30b,0xb30c,0xb30d, 0xb30e,0xb30f,0xb310,0x0000,
  0xb311,0xb312,0xb313,0xb314, 0xb315,0xb316,0xb317,0xb318,
  0xb319,0xb31a,0xb31b,0x0000, 0x0000,0x0000,0xb31c,0xb31d,
  0xb31e,0xb31f,0xb320,0xb321, 0xb322,0xb323,0xb324,0xb325,
  0xb326,0xb327,0xb328,0xb329, 0xb32a,0xb32b,0xb32c,0x0000,
  0xb32d,0xb32e,0xb32f,0xb330, 0xb331,0xb332,0xb333,0xb334,
  0xb335,0xb336,0xb337,0x0000, 0x0000,0x0000,0xb338,0xb339,
  0xb33a,0xb33b,0xb33c,0xb33d, 0xb33e,0xb33f,0xb340,0xb341,
  0xb342,0xb343,0xb344,0xb345, 0xb346,0xb347,0xb348,0x0000,
  0xb349,0xb34a,0xb34b,0xb34c, 0xb34d,0xb34e,0xb34f,0xb350,
  0xb351,0xb352,0xb353,0x0000, 0x0000,0x0000,0xb354,0xb355,
  0xb356,0xb357,0xb358,0xb359, 0xb35a,0xb35b,0xb35c,0xb35d,
  0xb35e,0xb35f,0xb360,0xb361, 0xb362,0xb363,0xb364,0x0000,
  0xb365,0xb366,0xb367,0xb368, 0xb369,0xb36a,0xb36b,0xb36c,
  0xb36d,0xb36e,0xb36f,0x0000, 0xb370,0xb371,0xb372,0xb373,
  0xb374,0xb375,0xb376,0xb377, 0xb378,0xb379,0xb37a,0xb37b,
  0xb37c,0xb37d,0xb37e,0xb37f, 0xb380,0x0000,0xb381,0xb382,
  0xb383,0xb384,0xb385,0xb386, 0xb387,0xb388,0xb389,0xb38a,
  0xb38b,0x0000,0x0000,0x0000, 0xb38c,0xb38d,0xb38e,0xb38f,
  0xb390,0xb391,0xb392,0xb393, 0xb394,0xb395,0xb396,0xb397,
  0xb398,0xb399,0xb39a,0xb39b, 0xb39c,0x0000,0xb39d,0xb39e,
  0xb39f,0xb3a0,0xb3a1,0xb3a2, 0xb3a3,0xb3a4,0xb3a5,0xb3a6,
  0xb3a7,0x0000,0xb3a8,0xb3a9, 0xb3aa,0xb3ab,0xb3ac,0xb3ad,
  0xb3ae,0xb3af,0xb3b0,0xb3b1, 0xb3b2,0xb3b3,0xb3b4,0xb3b5,
  0xb3b6,0xb3b7,0xb3b8,0x0000, 0xb3b9,0xb3ba,0xb3bb,0xb3bc,
  0xb3bd,0xb3be,0xb3bf,0xb3c0, 0xb3c1,0xb3c2,0xb3c3,0x0000,
  0x0000,0x0000,0xb3c4,0xb3c5, 0xb3c6,0xb3c7,0xb3c8,0xb3c9,
  0xb3ca,0xb3cb,0xb3cc,0xb3cd, 0xb3ce,0xb3cf,0xb3d0,0xb3d1,
  0xb3d2,0xb3d3,0xb3d4,0x0000, 0xb3d5,0xb3d6,0xb3d7,0xb3d8,
  0xb3d9,0xb3da,0xb3db,0xb3dc, 0xb3dd,0xb3de,0xb3df,0x0000,
  0x0000,0x0000,0xb3e0,0xb3e1, 0xb3e2,0xb3e3,0xb3e4,0xb3e5,
  0xb3e6,0xb3e7,0xb3e8,0xb3e9, 0xb3ea,0xb3eb,0xb3ec,0xb3ed,
  0xb3ee,0xb3ef,0xb3f0,0x0000, 0xb3f1,0xb3f2,0xb3f3,0xb3f4,
  0xb3f5,0xb3f6,0xb3f7,0xb3f8, 0xb3f9,0xb3fa,0xb3fb,0x0000,
  0x0000,0x0000,0xb3fc,0xb3fd, 0xb3fe,0xb3ff,0xb400,0xb401,
  0xb402,0xb403,0xb404,0xb405, 0xb406,0xb407,0xb408,0xb409,
  0xb40a,0xb40b,0xb40c,0x0000, 0xb40d,0xb40e,0xb40f,0xb410,
  0xb411,0xb412,0xb413,0xb414, 0xb415,0xb416,0xb417,0x0000,
  0xb418,0xb419,0xb41a,0xb41b, 0xb41c,0xb41d,0xb41e,0xb41f,
  0xb420,0xb421,0xb422,0xb423, 0xb424,0xb425,0xb426,0xb427,
  0xb428,0x0000,0xb429,0xb42a, 0xb42b,0xb42c,0xb42d,0xb42e,
  0xb42f,0xb430,0xb431,0xb432, 0xb433,0x0000,0x0000,0x0000,
  0xb434,0xb435,0xb436,0xb437, 0xb438,0xb439,0xb43a,0xb43b,
  0xb43c,0xb43d,0xb43e,0xb43f, 0xb440,0xb441,0xb442,0xb443,
  0xb444,0x0000,0xb445,0xb446, 0xb447,0xb448,0xb449,0xb44a,
  0xb44b,0xb44c,0xb44d,0xb44e, 0xb44f,0x0000,0xb450,0xb451,
  0xb452,0xb453,0xb454,0xb455, 0xb456,0xb457,0xb458,0xb459,
  0xb45a,0xb45b,0xb45c,0xb45d, 0xb45e,0xb45f,0xb460,0x0000,
  0xb461,0xb462,0xb463,0xb464, 0xb465,0xb466,0xb467,0xb468,
  0xb469,0xb46a,0xb46b,0x0000, 0x0000,0x0000,0xb46c,0xb46d,
  0xb46e,0xb46f,0xb470,0xb471, 0xb472,0xb473,0xb474,0xb475,
  0xb476,0xb477,0xb478,0xb479, 0xb47a,0xb47b,0xb47c,0x0000,
  0xb47d,0xb47e,0xb47f,0xb480, 0xb481,0xb482,0xb483,0xb484,
  0xb485,0xb486,0xb487,0x0000, 0x0000,0x0000,0xb488,0xb489,
  0xb48a,0xb48b,0xb48c,0xb48d, 0xb48e,0xb48f,0xb490,0xb491,
  0xb492,0xb493,0xb494,0xb495, 0xb496,0xb497,0xb498,0x0000,
  0xb499,0xb49a,0xb49b,0xb49c, 0xb49d,0xb49e,0xb49f,0xb4a0,
  0xb4a1,0xb4a2,0xb4a3,0x0000, 0x0000,0x0000,0xb4a4,0xb4a5,
  0xb4a6,0xb4a7,0xb4a8,0xb4a9, 0xb4aa,0xb4ab,0xb4ac,0xb4ad,
  0xb4ae,0xb4af,0xb4b0,0xb4b1, 0xb4b2,0xb4b3,0xb4b4,0x0000,
  0xb4b5,0xb4b6,0xb4b7,0xb4b8, 0xb4b9,0xb4ba,0xb4bb,0xb4bc,
  0xb4bd,0xb4be,0xb4bf,0x0000, 0xb4c0,0xb4c1,0xb4c2,0xb4c3,
  0xb4c4,0xb4c5,0xb4c6,0xb4c7, 0xb4c8,0xb4c9,0xb4ca,0xb4cb,
  0xb4cc,0xb4cd,0xb4ce,0xb4cf, 0xb4d0,0x0000,0xb4d1,0xb4d2,
  0xb4d3,0xb4d4,0xb4d5,0xb4d6, 0xb4d7,0xb4d8,0xb4d9,0xb4da,
  0xb4db,0x0000,0x0000,0x0000, 0xb4dc,0xb4dd,0xb4de,0xb4df,
  0xb4e0,0xb4e1,0xb4e2,0xb4e3, 0xb4e4,0xb4e5,0xb4e6,0xb4e7,
  0xb4e8,0xb4e9,0xb4ea,0xb4eb, 0xb4ec,0x0000,0xb4ed,0xb4ee,
  0xb4ef,0xb4f0,0xb4f1,0xb4f2, 0xb4f3,0xb4f4,0xb4f5,0xb4f6,
  0xb4f7,0x0000,0xb4f8,0xb4f9, 0xb4fa,0xb4fb,0xb4fc,0xb4fd,
  0xb4fe,0xb4ff,0xb500,0xb501, 0xb502,0xb503,0xb504,0xb505,
  0xb506,0xb507,0xb508,0x0000, 0xb509,0xb50a,0xb50b,0xb50c,
  0xb50d,0xb50e,0xb50f,0xb510, 0xb511,0xb512,0xb513,0x0000,
  0x0000,0x0000,0xb514,0xb515, 0xb516,0xb517,0xb518,0xb519,
  0xb51a,0xb51b,0xb51c,0xb51d, 0xb51e,0xb51f,0xb520,0xb521,
  0xb522,0xb523,0xb524,0x0000, 0xb525,0xb526,0xb527,0xb528,
  0xb529,0xb52a,0xb52b,0xb52c, 0xb52d,0xb52e,0xb52f,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x3138,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb530,0xb531,0xb532,0xb533, 0xb534,0xb535,0xb536,0xb537,
  0xb538,0xb539,0xb53a,0xb53b, 0xb53c,0xb53d,0xb53e,0xb53f,
  0xb540,0x0000,0xb541,0xb542, 0xb543,0xb544,0xb545,0xb546,
  0xb547,0xb548,0xb549,0xb54a, 0xb54b,0x0000,0xb54c,0xb54d,
  0xb54e,0xb54f,0xb550,0xb551, 0xb552,0xb553,0xb554,0xb555,
  0xb556,0xb557,0xb558,0xb559, 0xb55a,0xb55b,0xb55c,0x0000,
  0xb55d,0xb55e,0xb55f,0xb560, 0xb561,0xb562,0xb563,0xb564,
  0xb565,0xb566,0xb567,0x0000, 0x0000,0x0000,0xb568,0xb569,
  0xb56a,0xb56b,0xb56c,0xb56d, 0xb56e,0xb56f,0xb570,0xb571,
  0xb572,0xb573,0xb574,0xb575, 0xb576,0xb577,0xb578,0x0000,
  0xb579,0xb57a,0xb57b,0xb57c, 0xb57d,0xb57e,0xb57f,0xb580,
  0xb581,0xb582,0xb583,0x0000, 0x0000,0x0000,0xb584,0xb585,
  0xb586,0xb587,0xb588,0xb589, 0xb58a,0xb58b,0xb58c,0xb58d,
  0xb58e,0xb58f,0xb590,0xb591, 0xb592,0xb593,0xb594,0x0000,
  0xb595,0xb596,0xb597,0xb598, 0xb599,0xb59a,0xb59b,0xb59c,
  0xb59d,0xb59e,0xb59f,0x0000, 0x0000,0x0000,0xb5a0,0xb5a1,
  0xb5a2,0xb5a3,0xb5a4,0xb5a5, 0xb5a6,0xb5a7,0xb5a8,0xb5a9,
  0xb5aa,0xb5ab,0xb5ac,0xb5ad, 0xb5ae,0xb5af,0xb5b0,0x0000,
  0xb5b1,0xb5b2,0xb5b3,0xb5b4, 0xb5b5,0xb5b6,0xb5b7,0xb5b8,
  0xb5b9,0xb5ba,0xb5bb,0x0000, 0xb5bc,0xb5bd,0xb5be,0xb5bf,
  0xb5c0,0xb5c1,0xb5c2,0xb5c3, 0xb5c4,0xb5c5,0xb5c6,0xb5c7,
  0xb5c8,0xb5c9,0xb5ca,0xb5cb, 0xb5cc,0x0000,0xb5cd,0xb5ce,
  0xb5cf,0xb5d0,0xb5d1,0xb5d2, 0xb5d3,0xb5d4,0xb5d5,0xb5d6,
  0xb5d7,0x0000,0x0000,0x0000, 0xb5d8,0xb5d9,0xb5da,0xb5db,
  0xb5dc,0xb5dd,0xb5de,0xb5df, 0xb5e0,0xb5e1,0xb5e2,0xb5e3,
  0xb5e4,0xb5e5,0xb5e6,0xb5e7, 0xb5e8,0x0000,0xb5e9,0xb5ea,
  0xb5eb,0xb5ec,0xb5ed,0xb5ee, 0xb5ef,0xb5f0,0xb5f1,0xb5f2,
  0xb5f3,0x0000,0xb5f4,0xb5f5, 0xb5f6,0xb5f7,0xb5f8,0xb5f9,
  0xb5fa,0xb5fb,0xb5fc,0xb5fd, 0xb5fe,0xb5ff,0xb600,0xb601,
  0xb602,0xb603,0xb604,0x0000, 0xb605,0xb606,0xb607,0xb608,
  0xb609,0xb60a,0xb60b,0xb60c, 0xb60d,0xb60e,0xb60f,0x0000,
  0x0000,0x0000,0xb610,0xb611, 0xb612,0xb613,0xb614,0xb615,
  0xb616,0xb617,0xb618,0xb619, 0xb61a,0xb61b,0xb61c,0xb61d,
  0xb61e,0xb61f,0xb620,0x0000, 0xb621,0xb622,0xb623,0xb624,
  0xb625,0xb626,0xb627,0xb628, 0xb629,0xb62a,0xb62b,0x0000,
  0x0000,0x0000,0xb62c,0xb62d, 0xb62e,0xb62f,0xb630,0xb631,
  0xb632,0xb633,0xb634,0xb635, 0xb636,0xb637,0xb638,0xb639,
  0xb63a,0xb63b,0xb63c,0x0000, 0xb63d,0xb63e,0xb63f,0xb640,
  0xb641,0xb642,0xb643,0xb644, 0xb645,0xb646,0xb647,0x0000,
  0x0000,0x0000,0xb648,0xb649, 0xb64a,0xb64b,0xb64c,0xb64d,
  0xb64e,0xb64f,0xb650,0xb651, 0xb652,0xb653,0xb654,0xb655,
  0xb656,0xb657,0xb658,0x0000, 0xb659,0xb65a,0xb65b,0xb65c,
  0xb65d,0xb65e,0xb65f,0xb660, 0xb661,0xb662,0xb663,0x0000,
  0xb664,0xb665,0xb666,0xb667, 0xb668,0xb669,0xb66a,0xb66b,
  0xb66c,0xb66d,0xb66e,0xb66f, 0xb670,0xb671,0xb672,0xb673,
  0xb674,0x0000,0xb675,0xb676, 0xb677,0xb678,0xb679,0xb67a,
  0xb67b,0xb67c,0xb67d,0xb67e, 0xb67f,0x0000,0x0000,0x0000,
  0xb680,0xb681,0xb682,0xb683, 0xb684,0xb685,0xb686,0xb687,
  0xb688,0xb689,0xb68a,0xb68b, 0xb68c,0xb68d,0xb68e,0xb68f,
  0xb690,0x0000,0xb691,0xb692, 0xb693,0xb694,0xb695,0xb696,
  0xb697,0xb698,0xb699,0xb69a, 0xb69b,0x0000,0xb69c,0xb69d,
  0xb69e,0xb69f,0xb6a0,0xb6a1, 0xb6a2,0xb6a3,0xb6a4,0xb6a5,
  0xb6a6,0xb6a7,0xb6a8,0xb6a9, 0xb6aa,0xb6ab,0xb6ac,0x0000,
  0xb6ad,0xb6ae,0xb6af,0xb6b0, 0xb6b1,0xb6b2,0xb6b3,0xb6b4,
  0xb6b5,0xb6b6,0xb6b7,0x0000, 0x0000,0x0000,0xb6b8,0xb6b9,
  0xb6ba,0xb6bb,0xb6bc,0xb6bd, 0xb6be,0xb6bf,0xb6c0,0xb6c1,
  0xb6c2,0xb6c3,0xb6c4,0xb6c5, 0xb6c6,0xb6c7,0xb6c8,0x0000,
  0xb6c9,0xb6ca,0xb6cb,0xb6cc, 0xb6cd,0xb6ce,0xb6cf,0xb6d0,
  0xb6d1,0xb6d2,0xb6d3,0x0000, 0x0000,0x0000,0xb6d4,0xb6d5,
  0xb6d6,0xb6d7,0xb6d8,0xb6d9, 0xb6da,0xb6db,0xb6dc,0xb6dd,
  0xb6de,0xb6df,0xb6e0,0xb6e1, 0xb6e2,0xb6e3,0xb6e4,0x0000,
  0xb6e5,0xb6e6,0xb6e7,0xb6e8, 0xb6e9,0xb6ea,0xb6eb,0xb6ec,
  0xb6ed,0xb6ee,0xb6ef,0x0000, 0x0000,0x0000,0xb6f0,0xb6f1,
  0xb6f2,0xb6f3,0xb6f4,0xb6f5, 0xb6f6,0xb6f7,0xb6f8,0xb6f9,
  0xb6fa,0xb6fb,0xb6fc,0xb6fd, 0xb6fe,0xb6ff,0xb700,0x0000,
  0xb701,0xb702,0xb703,0xb704, 0xb705,0xb706,0xb707,0xb708,
  0xb709,0xb70a,0xb70b,0x0000, 0xb70c,0xb70d,0xb70e,0xb70f,
  0xb710,0xb711,0xb712,0xb713, 0xb714,0xb715,0xb716,0xb717,
  0xb718,0xb719,0xb71a,0xb71b, 0xb71c,0x0000,0xb71d,0xb71e,
  0xb71f,0xb720,0xb721,0xb722, 0xb723,0xb724,0xb725,0xb726,
  0xb727,0x0000,0x0000,0x0000, 0xb728,0xb729,0xb72a,0xb72b,
  0xb72c,0xb72d,0xb72e,0xb72f, 0xb730,0xb731,0xb732,0xb733,
  0xb734,0xb735,0xb736,0xb737, 0xb738,0x0000,0xb739,0xb73a,
  0xb73b,0xb73c,0xb73d,0xb73e, 0xb73f,0xb740,0xb741,0xb742,
  0xb743,0x0000,0xb744,0xb745, 0xb746,0xb747,0xb748,0xb749,
  0xb74a,0xb74b,0xb74c,0xb74d, 0xb74e,0xb74f,0xb750,0xb751,
  0xb752,0xb753,0xb754,0x0000, 0xb755,0xb756,0xb757,0xb758,
  0xb759,0xb75a,0xb75b,0xb75c, 0xb75d,0xb75e,0xb75f,0x0000,
  0x0000,0x0000,0xb760,0xb761, 0xb762,0xb763,0xb764,0xb765,
  0xb766,0xb767,0xb768,0xb769, 0xb76a,0xb76b,0xb76c,0xb76d,
  0xb76e,0xb76f,0xb770,0x0000, 0xb771,0xb772,0xb773,0xb774,
  0xb775,0xb776,0xb777,0xb778, 0xb779,0xb77a,0xb77b,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x3139,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb77c,0xb77d,0xb77e,0xb77f, 0xb780,0xb781,0xb782,0xb783,
  0xb784,0xb785,0xb786,0xb787, 0xb788,0xb789,0xb78a,0xb78b,
  0xb78c,0x0000,0xb78d,0xb78e, 0xb78f,0xb790,0xb791,0xb792,
  0xb793,0xb794,0xb795,0xb796, 0xb797,0x0000,0xb798,0xb799,
  0xb79a,0xb79b,0xb79c,0xb79d, 0xb79e,0xb79f,0xb7a0,0xb7a1,
  0xb7a2,0xb7a3,0xb7a4,0xb7a5, 0xb7a6,0xb7a7,0xb7a8,0x0000,
  0xb7a9,0xb7aa,0xb7ab,0xb7ac, 0xb7ad,0xb7ae,0xb7af,0xb7b0,
  0xb7b1,0xb7b2,0xb7b3,0x0000, 0x0000,0x0000,0xb7b4,0xb7b5,
  0xb7b6,0xb7b7,0xb7b8,0xb7b9, 0xb7ba,0xb7bb,0xb7bc,0xb7bd,
  0xb7be,0xb7bf,0xb7c0,0xb7c1, 0xb7c2,0xb7c3,0xb7c4,0x0000,
  0xb7c5,0xb7c6,0xb7c7,0xb7c8, 0xb7c9,0xb7ca,0xb7cb,0xb7cc,
  0xb7cd,0xb7ce,0xb7cf,0x0000, 0x0000,0x0000,0xb7d0,0xb7d1,
  0xb7d2,0xb7d3,0xb7d4,0xb7d5, 0xb7d6,0xb7d7,0xb7d8,0xb7d9,
  0xb7da,0xb7db,0xb7dc,0xb7dd, 0xb7de,0xb7df,0xb7e0,0x0000,
  0xb7e1,0xb7e2,0xb7e3,0xb7e4, 0xb7e5,0xb7e6,0xb7e7,0xb7e8,
  0xb7e9,0xb7ea,0xb7eb,0x0000, 0x0000,0x0000,0xb7ec,0xb7ed,
  0xb7ee,0xb7ef,0xb7f0,0xb7f1, 0xb7f2,0xb7f3,0xb7f4,0xb7f5,
  0xb7f6,0xb7f7,0xb7f8,0xb7f9, 0xb7fa,0xb7fb,0xb7fc,0x0000,
  0xb7fd,0xb7fe,0xb7ff,0xb800, 0xb801,0xb802,0xb803,0xb804,
  0xb805,0xb806,0xb807,0x0000, 0xb808,0xb809,0xb80a,0xb80b,
  0xb80c,0xb80d,0xb80e,0xb80f, 0xb810,0xb811,0xb812,0xb813,
  0xb814,0xb815,0xb816,0xb817, 0xb818,0x0000,0xb819,0xb81a,
  0xb81b,0xb81c,0xb81d,0xb81e, 0xb81f,0xb820,0xb821,0xb822,
  0xb823,0x0000,0x0000,0x0000, 0xb824,0xb825,0xb826,0xb827,
  0xb828,0xb829,0xb82a,0xb82b, 0xb82c,0xb82d,0xb82e,0xb82f,
  0xb830,0xb831,0xb832,0xb833, 0xb834,0x0000,0xb835,0xb836,
  0xb837,0xb838,0xb839,0xb83a, 0xb83b,0xb83c,0xb83d,0xb83e,
  0xb83f,0x0000,0xb840,0xb841, 0xb842,0xb843,0xb844,0xb845,
  0xb846,0xb847,0xb848,0xb849, 0xb84a,0xb84b,0xb84c,0xb84d,
  0xb84e,0xb84f,0xb850,0x0000, 0xb851,0xb852,0xb853,0xb854,
  0xb855,0xb856,0xb857,0xb858, 0xb859,0xb85a,0xb85b,0x0000,
  0x0000,0x0000,0xb85c,0xb85d, 0xb85e,0xb85f,0xb860,0xb861,
  0xb862,0xb863,0xb864,0xb865, 0xb866,0xb867,0xb868,0xb869,
  0xb86a,0xb86b,0xb86c,0x0000, 0xb86d,0xb86e,0xb86f,0xb870,
  0xb871,0xb872,0xb873,0xb874, 0xb875,0xb876,0xb877,0x0000,
  0x0000,0x0000,0xb878,0xb879, 0xb87a,0xb87b,0xb87c,0xb87d,
  0xb87e,0xb87f,0xb880,0xb881, 0xb882,0xb883,0xb884,0xb885,
  0xb886,0xb887,0xb888,0x0000, 0xb889,0xb88a,0xb88b,0xb88c,
  0xb88d,0xb88e,0xb88f,0xb890, 0xb891,0xb892,0xb893,0x0000,
  0x0000,0x0000,0xb894,0xb895, 0xb896,0xb897,0xb898,0xb899,
  0xb89a,0xb89b,0xb89c,0xb89d, 0xb89e,0xb89f,0xb8a0,0xb8a1,
  0xb8a2,0xb8a3,0xb8a4,0x0000, 0xb8a5,0xb8a6,0xb8a7,0xb8a8,
  0xb8a9,0xb8aa,0xb8ab,0xb8ac, 0xb8ad,0xb8ae,0xb8af,0x0000,
  0xb8b0,0xb8b1,0xb8b2,0xb8b3, 0xb8b4,0xb8b5,0xb8b6,0xb8b7,
  0xb8b8,0xb8b9,0xb8ba,0xb8bb, 0xb8bc,0xb8bd,0xb8be,0xb8bf,
  0xb8c0,0x0000,0xb8c1,0xb8c2, 0xb8c3,0xb8c4,0xb8c5,0xb8c6,
  0xb8c7,0xb8c8,0xb8c9,0xb8ca, 0xb8cb,0x0000,0x0000,0x0000,
  0xb8cc,0xb8cd,0xb8ce,0xb8cf, 0xb8d0,0xb8d1,0xb8d2,0xb8d3,
  0xb8d4,0xb8d5,0xb8d6,0xb8d7, 0xb8d8,0xb8d9,0xb8da,0xb8db,
  0xb8dc,0x0000,0xb8dd,0xb8de, 0xb8df,0xb8e0,0xb8e1,0xb8e2,
  0xb8e3,0xb8e4,0xb8e5,0xb8e6, 0xb8e7,0x0000,0xb8e8,0xb8e9,
  0xb8ea,0xb8eb,0xb8ec,0xb8ed, 0xb8ee,0xb8ef,0xb8f0,0xb8f1,
  0xb8f2,0xb8f3,0xb8f4,0xb8f5, 0xb8f6,0xb8f7,0xb8f8,0x0000,
  0xb8f9,0xb8fa,0xb8fb,0xb8fc, 0xb8fd,0xb8fe,0xb8ff,0xb900,
  0xb901,0xb902,0xb903,0x0000, 0x0000,0x0000,0xb904,0xb905,
  0xb906,0xb907,0xb908,0xb909, 0xb90a,0xb90b,0xb90c,0xb90d,
  0xb90e,0xb90f,0xb910,0xb911, 0xb912,0xb913,0xb914,0x0000,
  0xb915,0xb916,0xb917,0xb918, 0xb919,0xb91a,0xb91b,0xb91c,
  0xb91d,0xb91e,0xb91f,0x0000, 0x0000,0x0000,0xb920,0xb921,
  0xb922,0xb923,0xb924,0xb925, 0xb926,0xb927,0xb928,0xb929,
  0xb92a,0xb92b,0xb92c,0xb92d, 0xb92e,0xb92f,0xb930,0x0000,
  0xb931,0xb932,0xb933,0xb934, 0xb935,0xb936,0xb937,0xb938,
  0xb939,0xb93a,0xb93b,0x0000, 0x0000,0x0000,0xb93c,0xb93d,
  0xb93e,0xb93f,0xb940,0xb941, 0xb942,0xb943,0xb944,0xb945,
  0xb946,0xb947,0xb948,0xb949, 0xb94a,0xb94b,0xb94c,0x0000,
  0xb94d,0xb94e,0xb94f,0xb950, 0xb951,0xb952,0xb953,0xb954,
  0xb955,0xb956,0xb957,0x0000, 0xb958,0xb959,0xb95a,0xb95b,
  0xb95c,0xb95d,0xb95e,0xb95f, 0xb960,0xb961,0xb962,0xb963,
  0xb964,0xb965,0xb966,0xb967, 0xb968,0x0000,0xb969,0xb96a,
  0xb96b,0xb96c,0xb96d,0xb96e, 0xb96f,0xb970,0xb971,0xb972,
  0xb973,0x0000,0x0000,0x0000, 0xb974,0xb975,0xb976,0xb977,
  0xb978,0xb979,0xb97a,0xb97b, 0xb97c,0xb97d,0xb97e,0xb97f,
  0xb980,0xb981,0xb982,0xb983, 0xb984,0x0000,0xb985,0xb986,
  0xb987,0xb988,0xb989,0xb98a, 0xb98b,0xb98c,0xb98d,0xb98e,
  0xb98f,0x0000,0xb990,0xb991, 0xb992,0xb993,0xb994,0xb995,
  0xb996,0xb997,0xb998,0xb999, 0xb99a,0xb99b,0xb99c,0xb99d,
  0xb99e,0xb99f,0xb9a0,0x0000, 0xb9a1,0xb9a2,0xb9a3,0xb9a4,
  0xb9a5,0xb9a6,0xb9a7,0xb9a8, 0xb9a9,0xb9aa,0xb9ab,0x0000,
  0x0000,0x0000,0xb9ac,0xb9ad, 0xb9ae,0xb9af,0xb9b0,0xb9b1,
  0xb9b2,0xb9b3,0xb9b4,0xb9b5, 0xb9b6,0xb9b7,0xb9b8,0xb9b9,
  0xb9ba,0xb9bb,0xb9bc,0x0000, 0xb9bd,0xb9be,0xb9bf,0xb9c0,
  0xb9c1,0xb9c2,0xb9c3,0xb9c4, 0xb9c5,0xb9c6,0xb9c7,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x3141,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xb9c8,0xb9c9,0xb9ca,0xb9cb, 0xb9cc,0xb9cd,0xb9ce,0xb9cf,
  0xb9d0,0xb9d1,0xb9d2,0xb9d3, 0xb9d4,0xb9d5,0xb9d6,0xb9d7,
  0xb9d8,0x0000,0xb9d9,0xb9da, 0xb9db,0xb9dc,0xb9dd,0xb9de,
  0xb9df,0xb9e0,0xb9e1,0xb9e2, 0xb9e3,0x0000,0xb9e4,0xb9e5,
  0xb9e6,0xb9e7,0xb9e8,0xb9e9, 0xb9ea,0xb9eb,0xb9ec,0xb9ed,
  0xb9ee,0xb9ef,0xb9f0,0xb9f1, 0xb9f2,0xb9f3,0xb9f4,0x0000,
  0xb9f5,0xb9f6,0xb9f7,0xb9f8, 0xb9f9,0xb9fa,0xb9fb,0xb9fc,
  0xb9fd,0xb9fe,0xb9ff,0x0000, 0x0000,0x0000,0xba00,0xba01,
  0xba02,0xba03,0xba04,0xba05, 0xba06,0xba07,0xba08,0xba09,
  0xba0a,0xba0b,0xba0c,0xba0d, 0xba0e,0xba0f,0xba10,0x0000,
  0xba11,0xba12,0xba13,0xba14, 0xba15,0xba16,0xba17,0xba18,
  0xba19,0xba1a,0xba1b,0x0000, 0x0000,0x0000,0xba1c,0xba1d,
  0xba1e,0xba1f,0xba20,0xba21, 0xba22,0xba23,0xba24,0xba25,
  0xba26,0xba27,0xba28,0xba29, 0xba2a,0xba2b,0xba2c,0x0000,
  0xba2d,0xba2e,0xba2f,0xba30, 0xba31,0xba32,0xba33,0xba34,
  0xba35,0xba36,0xba37,0x0000, 0x0000,0x0000,0xba38,0xba39,
  0xba3a,0xba3b,0xba3c,0xba3d, 0xba3e,0xba3f,0xba40,0xba41,
  0xba42,0xba43,0xba44,0xba45, 0xba46,0xba47,0xba48,0x0000,
  0xba49,0xba4a,0xba4b,0xba4c, 0xba4d,0xba4e,0xba4f,0xba50,
  0xba51,0xba52,0xba53,0x0000, 0xba54,0xba55,0xba56,0xba57,
  0xba58,0xba59,0xba5a,0xba5b, 0xba5c,0xba5d,0xba5e,0xba5f,
  0xba60,0xba61,0xba62,0xba63, 0xba64,0x0000,0xba65,0xba66,
  0xba67,0xba68,0xba69,0xba6a, 0xba6b,0xba6c,0xba6d,0xba6e,
  0xba6f,0x0000,0x0000,0x0000, 0xba70,0xba71,0xba72,0xba73,
  0xba74,0xba75,0xba76,0xba77, 0xba78,0xba79,0xba7a,0xba7b,
  0xba7c,0xba7d,0xba7e,0xba7f, 0xba80,0x0000,0xba81,0xba82,
  0xba83,0xba84,0xba85,0xba86, 0xba87,0xba88,0xba89,0xba8a,
  0xba8b,0x0000,0xba8c,0xba8d, 0xba8e,0xba8f,0xba90,0xba91,
  0xba92,0xba93,0xba94,0xba95, 0xba96,0xba97,0xba98,0xba99,
  0xba9a,0xba9b,0xba9c,0x0000, 0xba9d,0xba9e,0xba9f,0xbaa0,
  0xbaa1,0xbaa2,0xbaa3,0xbaa4, 0xbaa5,0xbaa6,0xbaa7,0x0000,
  0x0000,0x0000,0xbaa8,0xbaa9, 0xbaaa,0xbaab,0xbaac,0xbaad,
  0xbaae,0xbaaf,0xbab0,0xbab1, 0xbab2,0xbab3,0xbab4,0xbab5,
  0xbab6,0xbab7,0xbab8,0x0000, 0xbab9,0xbaba,0xbabb,0xbabc,
  0xbabd,0xbabe,0xbabf,0xbac0, 0xbac1,0xbac2,0xbac3,0x0000,
  0x0000,0x0000,0xbac4,0xbac5, 0xbac6,0xbac7,0xbac8,0xbac9,
  0xbaca,0xbacb,0xbacc,0xbacd, 0xbace,0xbacf,0xbad0,0xbad1,
  0xbad2,0xbad3,0xbad4,0x0000, 0xbad5,0xbad6,0xbad7,0xbad8,
  0xbad9,0xbada,0xbadb,0xbadc, 0xbadd,0xbade,0xbadf,0x0000,
  0x0000,0x0000,0xbae0,0xbae1, 0xbae2,0xbae3,0xbae4,0xbae5,
  0xbae6,0xbae7,0xbae8,0xbae9, 0xbaea,0xbaeb,0xbaec,0xbaed,
  0xbaee,0xbaef,0xbaf0,0x0000, 0xbaf1,0xbaf2,0xbaf3,0xbaf4,
  0xbaf5,0xbaf6,0xbaf7,0xbaf8, 0xbaf9,0xbafa,0xbafb,0x0000,
  0xbafc,0xbafd,0xbafe,0xbaff, 0xbb00,0xbb01,0xbb02,0xbb03,
  0xbb04,0xbb05,0xbb06,0xbb07, 0xbb08,0xbb09,0xbb0a,0xbb0b,
  0xbb0c,0x0000,0xbb0d,0xbb0e, 0xbb0f,0xbb10,0xbb11,0xbb12,
  0xbb13,0xbb14,0xbb15,0xbb16, 0xbb17,0x0000,0x0000,0x0000,
  0xbb18,0xbb19,0xbb1a,0xbb1b, 0xbb1c,0xbb1d,0xbb1e,0xbb1f,
  0xbb20,0xbb21,0xbb22,0xbb23, 0xbb24,0xbb25,0xbb26,0xbb27,
  0xbb28,0x0000,0xbb29,0xbb2a, 0xbb2b,0xbb2c,0xbb2d,0xbb2e,
  0xbb2f,0xbb30,0xbb31,0xbb32, 0xbb33,0x0000,0xbb34,0xbb35,
  0xbb36,0xbb37,0xbb38,0xbb39, 0xbb3a,0xbb3b,0xbb3c,0xbb3d,
  0xbb3e,0xbb3f,0xbb40,0xbb41, 0xbb42,0xbb43,0xbb44,0x0000,
  0xbb45,0xbb46,0xbb47,0xbb48, 0xbb49,0xbb4a,0xbb4b,0xbb4c,
  0xbb4d,0xbb4e,0xbb4f,0x0000, 0x0000,0x0000,0xbb50,0xbb51,
  0xbb52,0xbb53,0xbb54,0xbb55, 0xbb56,0xbb57,0xbb58,0xbb59,
  0xbb5a,0xbb5b,0xbb5c,0xbb5d, 0xbb5e,0xbb5f,0xbb60,0x0000,
  0xbb61,0xbb62,0xbb63,0xbb64, 0xbb65,0xbb66,0xbb67,0xbb68,
  0xbb69,0xbb6a,0xbb6b,0x0000, 0x0000,0x0000,0xbb6c,0xbb6d,
  0xbb6e,0xbb6f,0xbb70,0xbb71, 0xbb72,0xbb73,0xbb74,0xbb75,
  0xbb76,0xbb77,0xbb78,0xbb79, 0xbb7a,0xbb7b,0xbb7c,0x0000,
  0xbb7d,0xbb7e,0xbb7f,0xbb80, 0xbb81,0xbb82,0xbb83,0xbb84,
  0xbb85,0xbb86,0xbb87,0x0000, 0x0000,0x0000,0xbb88,0xbb89,
  0xbb8a,0xbb8b,0xbb8c,0xbb8d, 0xbb8e,0xbb8f,0xbb90,0xbb91,
  0xbb92,0xbb93,0xbb94,0xbb95, 0xbb96,0xbb97,0xbb98,0x0000,
  0xbb99,0xbb9a,0xbb9b,0xbb9c, 0xbb9d,0xbb9e,0xbb9f,0xbba0,
  0xbba1,0xbba2,0xbba3,0x0000, 0xbba4,0xbba5,0xbba6,0xbba7,
  0xbba8,0xbba9,0xbbaa,0xbbab, 0xbbac,0xbbad,0xbbae,0xbbaf,
  0xbbb0,0xbbb1,0xbbb2,0xbbb3, 0xbbb4,0x0000,0xbbb5,0xbbb6,
  0xbbb7,0xbbb8,0xbbb9,0xbbba, 0xbbbb,0xbbbc,0xbbbd,0xbbbe,
  0xbbbf,0x0000,0x0000,0x0000, 0xbbc0,0xbbc1,0xbbc2,0xbbc3,
  0xbbc4,0xbbc5,0xbbc6,0xbbc7, 0xbbc8,0xbbc9,0xbbca,0xbbcb,
  0xbbcc,0xbbcd,0xbbce,0xbbcf, 0xbbd0,0x0000,0xbbd1,0xbbd2,
  0xbbd3,0xbbd4,0xbbd5,0xbbd6, 0xbbd7,0xbbd8,0xbbd9,0xbbda,
  0xbbdb,0x0000,0xbbdc,0xbbdd, 0xbbde,0xbbdf,0xbbe0,0xbbe1,
  0xbbe2,0xbbe3,0xbbe4,0xbbe5, 0xbbe6,0xbbe7,0xbbe8,0xbbe9,
  0xbbea,0xbbeb,0xbbec,0x0000, 0xbbed,0xbbee,0xbbef,0xbbf0,
  0xbbf1,0xbbf2,0xbbf3,0xbbf4, 0xbbf5,0xbbf6,0xbbf7,0x0000,
  0x0000,0x0000,0xbbf8,0xbbf9, 0xbbfa,0xbbfb,0xbbfc,0xbbfd,
  0xbbfe,0xbbff,0xbc00,0xbc01, 0xbc02,0xbc03,0xbc04,0xbc05,
  0xbc06,0xbc07,0xbc08,0x0000, 0xbc09,0xbc0a,0xbc0b,0xbc0c,
  0xbc0d,0xbc0e,0xbc0f,0xbc10, 0xbc11,0xbc12,0xbc13,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x3142,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xbc14,0xbc15,0xbc16,0xbc17, 0xbc18,0xbc19,0xbc1a,0xbc1b,
  0xbc1c,0xbc1d,0xbc1e,0xbc1f, 0xbc20,0xbc21,0xbc22,0xbc23,
  0xbc24,0x0000,0xbc25,0xbc26, 0xbc27,0xbc28,0xbc29,0xbc2a,
  0xbc2b,0xbc2c,0xbc2d,0xbc2e, 0xbc2f,0x0000,0xbc30,0xbc31,
  0xbc32,0xbc33,0xbc34,0xbc35, 0xbc36,0xbc37,0xbc38,0xbc39,
  0xbc3a,0xbc3b,0xbc3c,0xbc3d, 0xbc3e,0xbc3f,0xbc40,0x0000,
  0xbc41,0xbc42,0xbc43,0xbc44, 0xbc45,0xbc46,0xbc47,0xbc48,
  0xbc49,0xbc4a,0xbc4b,0x0000, 0x0000,0x0000,0xbc4c,0xbc4d,
  0xbc4e,0xbc4f,0xbc50,0xbc51, 0xbc52,0xbc53,0xbc54,0xbc55,
  0xbc56,0xbc57,0xbc58,0xbc59, 0xbc5a,0xbc5b,0xbc5c,0x0000,
  0xbc5d,0xbc5e,0xbc5f,0xbc60, 0xbc61,0xbc62,0xbc63,0xbc64,
  0xbc65,0xbc66,0xbc67,0x0000, 0x0000,0x0000,0xbc68,0xbc69,
  0xbc6a,0xbc6b,0xbc6c,0xbc6d, 0xbc6e,0xbc6f,0xbc70,0xbc71,
  0xbc72,0xbc73,0xbc74,0xbc75, 0xbc76,0xbc77,0xbc78,0x0000,
  0xbc79,0xbc7a,0xbc7b,0xbc7c, 0xbc7d,0xbc7e,0xbc7f,0xbc80,
  0xbc81,0xbc82,0xbc83,0x0000, 0x0000,0x0000,0xbc84,0xbc85,
  0xbc86,0xbc87,0xbc88,0xbc89, 0xbc8a,0xbc8b,0xbc8c,0xbc8d,
  0xbc8e,0xbc8f,0xbc90,0xbc91, 0xbc92,0xbc93,0xbc94,0x0000,
  0xbc95,0xbc96,0xbc97,0xbc98, 0xbc99,0xbc9a,0xbc9b,0xbc9c,
  0xbc9d,0xbc9e,0xbc9f,0x0000, 0xbca0,0xbca1,0xbca2,0xbca3,
  0xbca4,0xbca5,0xbca6,0xbca7, 0xbca8,0xbca9,0xbcaa,0xbcab,
  0xbcac,0xbcad,0xbcae,0xbcaf, 0xbcb0,0x0000,0xbcb1,0xbcb2,
  0xbcb3,0xbcb4,0xbcb5,0xbcb6, 0xbcb7,0xbcb8,0xbcb9,0xbcba,
  0xbcbb,0x0000,0x0000,0x0000, 0xbcbc,0xbcbd,0xbcbe,0xbcbf,
  0xbcc0,0xbcc1,0xbcc2,0xbcc3, 0xbcc4,0xbcc5,0xbcc6,0xbcc7,
  0xbcc8,0xbcc9,0xbcca,0xbccb, 0xbccc,0x0000,0xbccd,0xbcce,
  0xbccf,0xbcd0,0xbcd1,0xbcd2, 0xbcd3,0xbcd4,0xbcd5,0xbcd6,
  0xbcd7,0x0000,0xbcd8,0xbcd9, 0xbcda,0xbcdb,0xbcdc,0xbcdd,
  0xbcde,0xbcdf,0xbce0,0xbce1, 0xbce2,0xbce3,0xbce4,0xbce5,
  0xbce6,0xbce7,0xbce8,0x0000, 0xbce9,0xbcea,0xbceb,0xbcec,
  0xbced,0xbcee,0xbcef,0xbcf0, 0xbcf1,0xbcf2,0xbcf3,0x0000,
  0x0000,0x0000,0xbcf4,0xbcf5, 0xbcf6,0xbcf7,0xbcf8,0xbcf9,
  0xbcfa,0xbcfb,0xbcfc,0xbcfd, 0xbcfe,0xbcff,0xbd00,0xbd01,
  0xbd02,0xbd03,0xbd04,0x0000, 0xbd05,0xbd06,0xbd07,0xbd08,
  0xbd09,0xbd0a,0xbd0b,0xbd0c, 0xbd0d,0xbd0e,0xbd0f,0x0000,
  0x0000,0x0000,0xbd10,0xbd11, 0xbd12,0xbd13,0xbd14,0xbd15,
  0xbd16,0xbd17,0xbd18,0xbd19, 0xbd1a,0xbd1b,0xbd1c,0xbd1d,
  0xbd1e,0xbd1f,0xbd20,0x0000, 0xbd21,0xbd22,0xbd23,0xbd24,
  0xbd25,0xbd26,0xbd27,0xbd28, 0xbd29,0xbd2a,0xbd2b,0x0000,
  0x0000,0x0000,0xbd2c,0xbd2d, 0xbd2e,0xbd2f,0xbd30,0xbd31,
  0xbd32,0xbd33,0xbd34,0xbd35, 0xbd36,0xbd37,0xbd38,0xbd39,
  0xbd3a,0xbd3b,0xbd3c,0x0000, 0xbd3d,0xbd3e,0xbd3f,0xbd40,
  0xbd41,0xbd42,0xbd43,0xbd44, 0xbd45,0xbd46,0xbd47,0x0000,
  0xbd48,0xbd49,0xbd4a,0xbd4b, 0xbd4c,0xbd4d,0xbd4e,0xbd4f,
  0xbd50,0xbd51,0xbd52,0xbd53, 0xbd54,0xbd55,0xbd56,0xbd57,
  0xbd58,0x0000,0xbd59,0xbd5a, 0xbd5b,0xbd5c,0xbd5d,0xbd5e,
  0xbd5f,0xbd60,0xbd61,0xbd62, 0xbd63,0x0000,0x0000,0x0000,
  0xbd64,0xbd65,0xbd66,0xbd67, 0xbd68,0xbd69,0xbd6a,0xbd6b,
  0xbd6c,0xbd6d,0xbd6e,0xbd6f, 0xbd70,0xbd71,0xbd72,0xbd73,
  0xbd74,0x0000,0xbd75,0xbd76, 0xbd77,0xbd78,0xbd79,0xbd7a,
  0xbd7b,0xbd7c,0xbd7d,0xbd7e, 0xbd7f,0x0000,0xbd80,0xbd81,
  0xbd82,0xbd83,0xbd84,0xbd85, 0xbd86,0xbd87,0xbd88,0xbd89,
  0xbd8a,0xbd8b,0xbd8c,0xbd8d, 0xbd8e,0xbd8f,0xbd90,0x0000,
  0xbd91,0xbd92,0xbd93,0xbd94, 0xbd95,0xbd96,0xbd97,0xbd98,
  0xbd99,0xbd9a,0xbd9b,0x0000, 0x0000,0x0000,0xbd9c,0xbd9d,
  0xbd9e,0xbd9f,0xbda0,0xbda1, 0xbda2,0xbda3,0xbda4,0xbda5,
  0xbda6,0xbda7,0xbda8,0xbda9, 0xbdaa,0xbdab,0xbdac,0x0000,
  0xbdad,0xbdae,0xbdaf,0xbdb0, 0xbdb1,0xbdb2,0xbdb3,0xbdb4,
  0xbdb5,0xbdb6,0xbdb7,0x0000, 0x0000,0x0000,0xbdb8,0xbdb9,
  0xbdba,0xbdbb,0xbdbc,0xbdbd, 0xbdbe,0xbdbf,0xbdc0,0xbdc1,
  0xbdc2,0xbdc3,0xbdc4,0xbdc5, 0xbdc6,0xbdc7,0xbdc8,0x0000,
  0xbdc9,0xbdca,0xbdcb,0xbdcc, 0xbdcd,0xbdce,0xbdcf,0xbdd0,
  0xbdd1,0xbdd2,0xbdd3,0x0000, 0x0000,0x0000,0xbdd4,0xbdd5,
  0xbdd6,0xbdd7,0xbdd8,0xbdd9, 0xbdda,0xbddb,0xbddc,0xbddd,
  0xbdde,0xbddf,0xbde0,0xbde1, 0xbde2,0xbde3,0xbde4,0x0000,
  0xbde5,0xbde6,0xbde7,0xbde8, 0xbde9,0xbdea,0xbdeb,0xbdec,
  0xbded,0xbdee,0xbdef,0x0000, 0xbdf0,0xbdf1,0xbdf2,0xbdf3,
  0xbdf4,0xbdf5,0xbdf6,0xbdf7, 0xbdf8,0xbdf9,0xbdfa,0xbdfb,
  0xbdfc,0xbdfd,0xbdfe,0xbdff, 0xbe00,0x0000,0xbe01,0xbe02,
  0xbe03,0xbe04,0xbe05,0xbe06, 0xbe07,0xbe08,0xbe09,0xbe0a,
  0xbe0b,0x0000,0x0000,0x0000, 0xbe0c,0xbe0d,0xbe0e,0xbe0f,
  0xbe10,0xbe11,0xbe12,0xbe13, 0xbe14,0xbe15,0xbe16,0xbe17,
  0xbe18,0xbe19,0xbe1a,0xbe1b, 0xbe1c,0x0000,0xbe1d,0xbe1e,
  0xbe1f,0xbe20,0xbe21,0xbe22, 0xbe23,0xbe24,0xbe25,0xbe26,
  0xbe27,0x0000,0xbe28,0xbe29, 0xbe2a,0xbe2b,0xbe2c,0xbe2d,
  0xbe2e,0xbe2f,0xbe30,0xbe31, 0xbe32,0xbe33,0xbe34,0xbe35,
  0xbe36,0xbe37,0xbe38,0x0000, 0xbe39,0xbe3a,0xbe3b,0xbe3c,
  0xbe3d,0xbe3e,0xbe3f,0xbe40, 0xbe41,0xbe42,0xbe43,0x0000,
  0x0000,0x0000,0xbe44,0xbe45, 0xbe46,0xbe47,0xbe48,0xbe49,
  0xbe4a,0xbe4b,0xbe4c,0xbe4d, 0xbe4e,0xbe4f,0xbe50,0xbe51,
  0xbe52,0xbe53,0xbe54,0x0000, 0xbe55,0xbe56,0xbe57,0xbe58,
  0xbe59,0xbe5a,0xbe5b,0xbe5c, 0xbe5d,0xbe5e,0xbe5f,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x3143,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xbe60,0xbe61,0xbe62,0xbe63, 0xbe64,0xbe65,0xbe66,0xbe67,
  0xbe68,0xbe69,0xbe6a,0xbe6b, 0xbe6c,0xbe6d,0xbe6e,0xbe6f,
  0xbe70,0x0000,0xbe71,0xbe72, 0xbe73,0xbe74,0xbe75,0xbe76,
  0xbe77,0xbe78,0xbe79,0xbe7a, 0xbe7b,0x0000,0xbe7c,0xbe7d,
  0xbe7e,0xbe7f,0xbe80,0xbe81, 0xbe82,0xbe83,0xbe84,0xbe85,
  0xbe86,0xbe87,0xbe88,0xbe89, 0xbe8a,0xbe8b,0xbe8c,0x0000,
  0xbe8d,0xbe8e,0xbe8f,0xbe90, 0xbe91,0xbe92,0xbe93,0xbe94,
  0xbe95,0xbe96,0xbe97,0x0000, 0x0000,0x0000,0xbe98,0xbe99,
  0xbe9a,0xbe9b,0xbe9c,0xbe9d, 0xbe9e,0xbe9f,0xbea0,0xbea1,
  0xbea2,0xbea3,0xbea4,0xbea5, 0xbea6,0xbea7,0xbea8,0x0000,
  0xbea9,0xbeaa,0xbeab,0xbeac, 0xbead,0xbeae,0xbeaf,0xbeb0,
  0xbeb1,0xbeb2,0xbeb3,0x0000, 0x0000,0x0000,0xbeb4,0xbeb5,
  0xbeb6,0xbeb7,0xbeb8,0xbeb9, 0xbeba,0xbebb,0xbebc,0xbebd,
  0xbebe,0xbebf,0xbec0,0xbec1, 0xbec2,0xbec3,0xbec4,0x0000,
  0xbec5,0xbec6,0xbec7,0xbec8, 0xbec9,0xbeca,0xbecb,0xbecc,
  0xbecd,0xbece,0xbecf,0x0000, 0x0000,0x0000,0xbed0,0xbed1,
  0xbed2,0xbed3,0xbed4,0xbed5, 0xbed6,0xbed7,0xbed8,0xbed9,
  0xbeda,0xbedb,0xbedc,0xbedd, 0xbede,0xbedf,0xbee0,0x0000,
  0xbee1,0xbee2,0xbee3,0xbee4, 0xbee5,0xbee6,0xbee7,0xbee8,
  0xbee9,0xbeea,0xbeeb,0x0000, 0xbeec,0xbeed,0xbeee,0xbeef,
  0xbef0,0xbef1,0xbef2,0xbef3, 0xbef4,0xbef5,0xbef6,0xbef7,
  0xbef8,0xbef9,0xbefa,0xbefb, 0xbefc,0x0000,0xbefd,0xbefe,
  0xbeff,0xbf00,0xbf01,0xbf02, 0xbf03,0xbf04,0xbf05,0xbf06,
  0xbf07,0x0000,0x0000,0x0000, 0xbf08,0xbf09,0xbf0a,0xbf0b,
  0xbf0c,0xbf0d,0xbf0e,0xbf0f, 0xbf10,0xbf11,0xbf12,0xbf13,
  0xbf14,0xbf15,0xbf16,0xbf17, 0xbf18,0x0000,0xbf19,0xbf1a,
  0xbf1b,0xbf1c,0xbf1d,0xbf1e, 0xbf1f,0xbf20,0xbf21,0xbf22,
  0xbf23,0x0000,0xbf24,0xbf25, 0xbf26,0xbf27,0xbf28,0xbf29,
  0xbf2a,0xbf2b,0xbf2c,0xbf2d, 0xbf2e,0xbf2f,0xbf30,0xbf31,
  0xbf32,0xbf33,0xbf34,0x0000, 0xbf35,0xbf36,0xbf37,0xbf38,
  0xbf39,0xbf3a,0xbf3b,0xbf3c, 0xbf3d,0xbf3e,0xbf3f,0x0000,
  0x0000,0x0000,0xbf40,0xbf41, 0xbf42,0xbf43,0xbf44,0xbf45,
  0xbf46,0xbf47,0xbf48,0xbf49, 0xbf4a,0xbf4b,0xbf4c,0xbf4d,
  0xbf4e,0xbf4f,0xbf50,0x0000, 0xbf51,0xbf52,0xbf53,0xbf54,
  0xbf55,0xbf56,0xbf57,0xbf58, 0xbf59,0xbf5a,0xbf5b,0x0000,
  0x0000,0x0000,0xbf5c,0xbf5d, 0xbf5e,0xbf5f,0xbf60,0xbf61,
  0xbf62,0xbf63,0xbf64,0xbf65, 0xbf66,0xbf67,0xbf68,0xbf69,
  0xbf6a,0xbf6b,0xbf6c,0x0000, 0xbf6d,0xbf6e,0xbf6f,0xbf70,
  0xbf71,0xbf72,0xbf73,0xbf74, 0xbf75,0xbf76,0xbf77,0x0000,
  0x0000,0x0000,0xbf78,0xbf79, 0xbf7a,0xbf7b,0xbf7c,0xbf7d,
  0xbf7e,0xbf7f,0xbf80,0xbf81, 0xbf82,0xbf83,0xbf84,0xbf85,
  0xbf86,0xbf87,0xbf88,0x0000, 0xbf89,0xbf8a,0xbf8b,0xbf8c,
  0xbf8d,0xbf8e,0xbf8f,0xbf90, 0xbf91,0xbf92,0xbf93,0x0000,
  0xbf94,0xbf95,0xbf96,0xbf97, 0xbf98,0xbf99,0xbf9a,0xbf9b,
  0xbf9c,0xbf9d,0xbf9e,0xbf9f, 0xbfa0,0xbfa1,0xbfa2,0xbfa3,
  0xbfa4,0x0000,0xbfa5,0xbfa6, 0xbfa7,0xbfa8,0xbfa9,0xbfaa,
  0xbfab,0xbfac,0xbfad,0xbfae, 0xbfaf,0x0000,0x0000,0x0000,
  0xbfb0,0xbfb1,0xbfb2,0xbfb3, 0xbfb4,0xbfb5,0xbfb6,0xbfb7,
  0xbfb8,0xbfb9,0xbfba,0xbfbb, 0xbfbc,0xbfbd,0xbfbe,0xbfbf,
  0xbfc0,0x0000,0xbfc1,0xbfc2, 0xbfc3,0xbfc4,0xbfc5,0xbfc6,
  0xbfc7,0xbfc8,0xbfc9,0xbfca, 0xbfcb,0x0000,0xbfcc,0xbfcd,
  0xbfce,0xbfcf,0xbfd0,0xbfd1, 0xbfd2,0xbfd3,0xbfd4,0xbfd5,
  0xbfd6,0xbfd7,0xbfd8,0xbfd9, 0xbfda,0xbfdb,0xbfdc,0x0000,
  0xbfdd,0xbfde,0xbfdf,0xbfe0, 0xbfe1,0xbfe2,0xbfe3,0xbfe4,
  0xbfe5,0xbfe6,0xbfe7,0x0000, 0x0000,0x0000,0xbfe8,0xbfe9,
  0xbfea,0xbfeb,0xbfec,0xbfed, 0xbfee,0xbfef,0xbff0,0xbff1,
  0xbff2,0xbff3,0xbff4,0xbff5, 0xbff6,0xbff7,0xbff8,0x0000,
  0xbff9,0xbffa,0xbffb,0xbffc, 0xbffd,0xbffe,0xbfff,0xc000,
  0xc001,0xc002,0xc003,0x0000, 0x0000,0x0000,0xc004,0xc005,
  0xc006,0xc007,0xc008,0xc009, 0xc00a,0xc00b,0xc00c,0xc00d,
  0xc00e,0xc00f,0xc010,0xc011, 0xc012,0xc013,0xc014,0x0000,
  0xc015,0xc016,0xc017,0xc018, 0xc019,0xc01a,0xc01b,0xc01c,
  0xc01d,0xc01e,0xc01f,0x0000, 0x0000,0x0000,0xc020,0xc021,
  0xc022,0xc023,0xc024,0xc025, 0xc026,0xc027,0xc028,0xc029,
  0xc02a,0xc02b,0xc02c,0xc02d, 0xc02e,0xc02f,0xc030,0x0000,
  0xc031,0xc032,0xc033,0xc034, 0xc035,0xc036,0xc037,0xc038,
  0xc039,0xc03a,0xc03b,0x0000, 0xc03c,0xc03d,0xc03e,0xc03f,
  0xc040,0xc041,0xc042,0xc043, 0xc044,0xc045,0xc046,0xc047,
  0xc048,0xc049,0xc04a,0xc04b, 0xc04c,0x0000,0xc04d,0xc04e,
  0xc04f,0xc050,0xc051,0xc052, 0xc053,0xc054,0xc055,0xc056,
  0xc057,0x0000,0x0000,0x0000, 0xc058,0xc059,0xc05a,0xc05b,
  0xc05c,0xc05d,0xc05e,0xc05f, 0xc060,0xc061,0xc062,0xc063,
  0xc064,0xc065,0xc066,0xc067, 0xc068,0x0000,0xc069,0xc06a,
  0xc06b,0xc06c,0xc06d,0xc06e, 0xc06f,0xc070,0xc071,0xc072,
  0xc073,0x0000,0xc074,0xc075, 0xc076,0xc077,0xc078,0xc079,
  0xc07a,0xc07b,0xc07c,0xc07d, 0xc07e,0xc07f,0xc080,0xc081,
  0xc082,0xc083,0xc084,0x0000, 0xc085,0xc086,0xc087,0xc088,
  0xc089,0xc08a,0xc08b,0xc08c, 0xc08d,0xc08e,0xc08f,0x0000,
  0x0000,0x0000,0xc090,0xc091, 0xc092,0xc093,0xc094,0xc095,
  0xc096,0xc097,0xc098,0xc099, 0xc09a,0xc09b,0xc09c,0xc09d,
  0xc09e,0xc09f,0xc0a0,0x0000, 0xc0a1,0xc0a2,0xc0a3,0xc0a4,
  0xc0a5,0xc0a6,0xc0a7,0xc0a8, 0xc0a9,0xc0aa,0xc0ab,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x3145,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc0ac,0xc0ad,0xc0ae,0xc0af, 0xc0b0,0xc0b1,0xc0b2,0xc0b3,
  0xc0b4,0xc0b5,0xc0b6,0xc0b7, 0xc0b8,0xc0b9,0xc0ba,0xc0bb,
  0xc0bc,0x0000,0xc0bd,0xc0be, 0xc0bf,0xc0c0,0xc0c1,0xc0c2,
  0xc0c3,0xc0c4,0xc0c5,0xc0c6, 0xc0c7,0x0000,0xc0c8,0xc0c9,
  0xc0ca,0xc0cb,0xc0cc,0xc0cd, 0xc0ce,0xc0cf,0xc0d0,0xc0d1,
  0xc0d2,0xc0d3,0xc0d4,0xc0d5, 0xc0d6,0xc0d7,0xc0d8,0x0000,
  0xc0d9,0xc0da,0xc0db,0xc0dc, 0xc0dd,0xc0de,0xc0df,0xc0e0,
  0xc0e1,0xc0e2,0xc0e3,0x0000, 0x0000,0x0000,0xc0e4,0xc0e5,
  0xc0e6,0xc0e7,0xc0e8,0xc0e9, 0xc0ea,0xc0eb,0xc0ec,0xc0ed,
  0xc0ee,0xc0ef,0xc0f0,0xc0f1, 0xc0f2,0xc0f3,0xc0f4,0x0000,
  0xc0f5,0xc0f6,0xc0f7,0xc0f8, 0xc0f9,0xc0fa,0xc0fb,0xc0fc,
  0xc0fd,0xc0fe,0xc0ff,0x0000, 0x0000,0x0000,0xc100,0xc101,
  0xc102,0xc103,0xc104,0xc105, 0xc106,0xc107,0xc108,0xc109,
  0xc10a,0xc10b,0xc10c,0xc10d, 0xc10e,0xc10f,0xc110,0x0000,
  0xc111,0xc112,0xc113,0xc114, 0xc115,0xc116,0xc117,0xc118,
  0xc119,0xc11a,0xc11b,0x0000, 0x0000,0x0000,0xc11c,0xc11d,
  0xc11e,0xc11f,0xc120,0xc121, 0xc122,0xc123,0xc124,0xc125,
  0xc126,0xc127,0xc128,0xc129, 0xc12a,0xc12b,0xc12c,0x0000,
  0xc12d,0xc12e,0xc12f,0xc130, 0xc131,0xc132,0xc133,0xc134,
  0xc135,0xc136,0xc137,0x0000, 0xc138,0xc139,0xc13a,0xc13b,
  0xc13c,0xc13d,0xc13e,0xc13f, 0xc140,0xc141,0xc142,0xc143,
  0xc144,0xc145,0xc146,0xc147, 0xc148,0x0000,0xc149,0xc14a,
  0xc14b,0xc14c,0xc14d,0xc14e, 0xc14f,0xc150,0xc151,0xc152,
  0xc153,0x0000,0x0000,0x0000, 0xc154,0xc155,0xc156,0xc157,
  0xc158,0xc159,0xc15a,0xc15b, 0xc15c,0xc15d,0xc15e,0xc15f,
  0xc160,0xc161,0xc162,0xc163, 0xc164,0x0000,0xc165,0xc166,
  0xc167,0xc168,0xc169,0xc16a, 0xc16b,0xc16c,0xc16d,0xc16e,
  0xc16f,0x0000,0xc170,0xc171, 0xc172,0xc173,0xc174,0xc175,
  0xc176,0xc177,0xc178,0xc179, 0xc17a,0xc17b,0xc17c,0xc17d,
  0xc17e,0xc17f,0xc180,0x0000, 0xc181,0xc182,0xc183,0xc184,
  0xc185,0xc186,0xc187,0xc188, 0xc189,0xc18a,0xc18b,0x0000,
  0x0000,0x0000,0xc18c,0xc18d, 0xc18e,0xc18f,0xc190,0xc191,
  0xc192,0xc193,0xc194,0xc195, 0xc196,0xc197,0xc198,0xc199,
  0xc19a,0xc19b,0xc19c,0x0000, 0xc19d,0xc19e,0xc19f,0xc1a0,
  0xc1a1,0xc1a2,0xc1a3,0xc1a4, 0xc1a5,0xc1a6,0xc1a7,0x0000,
  0x0000,0x0000,0xc1a8,0xc1a9, 0xc1aa,0xc1ab,0xc1ac,0xc1ad,
  0xc1ae,0xc1af,0xc1b0,0xc1b1, 0xc1b2,0xc1b3,0xc1b4,0xc1b5,
  0xc1b6,0xc1b7,0xc1b8,0x0000, 0xc1b9,0xc1ba,0xc1bb,0xc1bc,
  0xc1bd,0xc1be,0xc1bf,0xc1c0, 0xc1c1,0xc1c2,0xc1c3,0x0000,
  0x0000,0x0000,0xc1c4,0xc1c5, 0xc1c6,0xc1c7,0xc1c8,0xc1c9,
  0xc1ca,0xc1cb,0xc1cc,0xc1cd, 0xc1ce,0xc1cf,0xc1d0,0xc1d1,
  0xc1d2,0xc1d3,0xc1d4,0x0000, 0xc1d5,0xc1d6,0xc1d7,0xc1d8,
  0xc1d9,0xc1da,0xc1db,0xc1dc, 0xc1dd,0xc1de,0xc1df,0x0000,
  0xc1e0,0xc1e1,0xc1e2,0xc1e3, 0xc1e4,0xc1e5,0xc1e6,0xc1e7,
  0xc1e8,0xc1e9,0xc1ea,0xc1eb, 0xc1ec,0xc1ed,0xc1ee,0xc1ef,
  0xc1f0,0x0000,0xc1f1,0xc1f2, 0xc1f3,0xc1f4,0xc1f5,0xc1f6,
  0xc1f7,0xc1f8,0xc1f9,0xc1fa, 0xc1fb,0x0000,0x0000,0x0000,
  0xc1fc,0xc1fd,0xc1fe,0xc1ff, 0xc200,0xc201,0xc202,0xc203,
  0xc204,0xc205,0xc206,0xc207, 0xc208,0xc209,0xc20a,0xc20b,
  0xc20c,0x0000,0xc20d,0xc20e, 0xc20f,0xc210,0xc211,0xc212,
  0xc213,0xc214,0xc215,0xc216, 0xc217,0x0000,0xc218,0xc219,
  0xc21a,0xc21b,0xc21c,0xc21d, 0xc21e,0xc21f,0xc220,0xc221,
  0xc222,0xc223,0xc224,0xc225, 0xc226,0xc227,0xc228,0x0000,
  0xc229,0xc22a,0xc22b,0xc22c, 0xc22d,0xc22e,0xc22f,0xc230,
  0xc231,0xc232,0xc233,0x0000, 0x0000,0x0000,0xc234,0xc235,
  0xc236,0xc237,0xc238,0xc239, 0xc23a,0xc23b,0xc23c,0xc23d,
  0xc23e,0xc23f,0xc240,0xc241, 0xc242,0xc243,0xc244,0x0000,
  0xc245,0xc246,0xc247,0xc248, 0xc249,0xc24a,0xc24b,0xc24c,
  0xc24d,0xc24e,0xc24f,0x0000, 0x0000,0x0000,0xc250,0xc251,
  0xc252,0xc253,0xc254,0xc255, 0xc256,0xc257,0xc258,0xc259,
  0xc25a,0xc25b,0xc25c,0xc25d, 0xc25e,0xc25f,0xc260,0x0000,
  0xc261,0xc262,0xc263,0xc264, 0xc265,0xc266,0xc267,0xc268,
  0xc269,0xc26a,0xc26b,0x0000, 0x0000,0x0000,0xc26c,0xc26d,
  0xc26e,0xc26f,0xc270,0xc271, 0xc272,0xc273,0xc274,0xc275,
  0xc276,0xc277,0xc278,0xc279, 0xc27a,0xc27b,0xc27c,0x0000,
  0xc27d,0xc27e,0xc27f,0xc280, 0xc281,0xc282,0xc283,0xc284,
  0xc285,0xc286,0xc287,0x0000, 0xc288,0xc289,0xc28a,0xc28b,
  0xc28c,0xc28d,0xc28e,0xc28f, 0xc290,0xc291,0xc292,0xc293,
  0xc294,0xc295,0xc296,0xc297, 0xc298,0x0000,0xc299,0xc29a,
  0xc29b,0xc29c,0xc29d,0xc29e, 0xc29f,0xc2a0,0xc2a1,0xc2a2,
  0xc2a3,0x0000,0x0000,0x0000, 0xc2a4,0xc2a5,0xc2a6,0xc2a7,
  0xc2a8,0xc2a9,0xc2aa,0xc2ab, 0xc2ac,0xc2ad,0xc2ae,0xc2af,
  0xc2b0,0xc2b1,0xc2b2,0xc2b3, 0xc2b4,0x0000,0xc2b5,0xc2b6,
  0xc2b7,0xc2b8,0xc2b9,0xc2ba, 0xc2bb,0xc2bc,0xc2bd,0xc2be,
  0xc2bf,0x0000,0xc2c0,0xc2c1, 0xc2c2,0xc2c3,0xc2c4,0xc2c5,
  0xc2c6,0xc2c7,0xc2c8,0xc2c9, 0xc2ca,0xc2cb,0xc2cc,0xc2cd,
  0xc2ce,0xc2cf,0xc2d0,0x0000, 0xc2d1,0xc2d2,0xc2d3,0xc2d4,
  0xc2d5,0xc2d6,0xc2d7,0xc2d8, 0xc2d9,0xc2da,0xc2db,0x0000,
  0x0000,0x0000,0xc2dc,0xc2dd, 0xc2de,0xc2df,0xc2e0,0xc2e1,
  0xc2e2,0xc2e3,0xc2e4,0xc2e5, 0xc2e6,0xc2e7,0xc2e8,0xc2e9,
  0xc2ea,0xc2eb,0xc2ec,0x0000, 0xc2ed,0xc2ee,0xc2ef,0xc2f0,
  0xc2f1,0xc2f2,0xc2f3,0xc2f4, 0xc2f5,0xc2f6,0xc2f7,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x3146,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc2f8,0xc2f9,0xc2fa,0xc2fb, 0xc2fc,0xc2fd,0xc2fe,0xc2ff,
  0xc300,0xc301,0xc302,0xc303, 0xc304,0xc305,0xc306,0xc307,
  0xc308,0x0000,0xc309,0xc30a, 0xc30b,0xc30c,0xc30d,0xc30e,
  0xc30f,0xc310,0xc311,0xc312, 0xc313,0x0000,0xc314,0xc315,
  0xc316,0xc317,0xc318,0xc319, 0xc31a,0xc31b,0xc31c,0xc31d,
  0xc31e,0xc31f,0xc320,0xc321, 0xc322,0xc323,0xc324,0x0000,
  0xc325,0xc326,0xc327,0xc328, 0xc329,0xc32a,0xc32b,0xc32c,
  0xc32d,0xc32e,0xc32f,0x0000, 0x0000,0x0000,0xc330,0xc331,
  0xc332,0xc333,0xc334,0xc335, 0xc336,0xc337,0xc338,0xc339,
  0xc33a,0xc33b,0xc33c,0xc33d, 0xc33e,0xc33f,0xc340,0x0000,
  0xc341,0xc342,0xc343,0xc344, 0xc345,0xc346,0xc347,0xc348,
  0xc349,0xc34a,0xc34b,0x0000, 0x0000,0x0000,0xc34c,0xc34d,
  0xc34e,0xc34f,0xc350,0xc351, 0xc352,0xc353,0xc354,0xc355,
  0xc356,0xc357,0xc358,0xc359, 0xc35a,0xc35b,0xc35c,0x0000,
  0xc35d,0xc35e,0xc35f,0xc360, 0xc361,0xc362,0xc363,0xc364,
  0xc365,0xc366,0xc367,0x0000, 0x0000,0x0000,0xc368,0xc369,
  0xc36a,0xc36b,0xc36c,0xc36d, 0xc36e,0xc36f,0xc370,0xc371,
  0xc372,0xc373,0xc374,0xc375, 0xc376,0xc377,0xc378,0x0000,
  0xc379,0xc37a,0xc37b,0xc37c, 0xc37d,0xc37e,0xc37f,0xc380,
  0xc381,0xc382,0xc383,0x0000, 0xc384,0xc385,0xc386,0xc387,
  0xc388,0xc389,0xc38a,0xc38b, 0xc38c,0xc38d,0xc38e,0xc38f,
  0xc390,0xc391,0xc392,0xc393, 0xc394,0x0000,0xc395,0xc396,
  0xc397,0xc398,0xc399,0xc39a, 0xc39b,0xc39c,0xc39d,0xc39e,
  0xc39f,0x0000,0x0000,0x0000, 0xc3a0,0xc3a1,0xc3a2,0xc3a3,
  0xc3a4,0xc3a5,0xc3a6,0xc3a7, 0xc3a8,0xc3a9,0xc3aa,0xc3ab,
  0xc3ac,0xc3ad,0xc3ae,0xc3af, 0xc3b0,0x0000,0xc3b1,0xc3b2,
  0xc3b3,0xc3b4,0xc3b5,0xc3b6, 0xc3b7,0xc3b8,0xc3b9,0xc3ba,
  0xc3bb,0x0000,0xc3bc,0xc3bd, 0xc3be,0xc3bf,0xc3c0,0xc3c1,
  0xc3c2,0xc3c3,0xc3c4,0xc3c5, 0xc3c6,0xc3c7,0xc3c8,0xc3c9,
  0xc3ca,0xc3cb,0xc3cc,0x0000, 0xc3cd,0xc3ce,0xc3cf,0xc3d0,
  0xc3d1,0xc3d2,0xc3d3,0xc3d4, 0xc3d5,0xc3d6,0xc3d7,0x0000,
  0x0000,0x0000,0xc3d8,0xc3d9, 0xc3da,0xc3db,0xc3dc,0xc3dd,
  0xc3de,0xc3df,0xc3e0,0xc3e1, 0xc3e2,0xc3e3,0xc3e4,0xc3e5,
  0xc3e6,0xc3e7,0xc3e8,0x0000, 0xc3e9,0xc3ea,0xc3eb,0xc3ec,
  0xc3ed,0xc3ee,0xc3ef,0xc3f0, 0xc3f1,0xc3f2,0xc3f3,0x0000,
  0x0000,0x0000,0xc3f4,0xc3f5, 0xc3f6,0xc3f7,0xc3f8,0xc3f9,
  0xc3fa,0xc3fb,0xc3fc,0xc3fd, 0xc3fe,0xc3ff,0xc400,0xc401,
  0xc402,0xc403,0xc404,0x0000, 0xc405,0xc406,0xc407,0xc408,
  0xc409,0xc40a,0xc40b,0xc40c, 0xc40d,0xc40e,0xc40f,0x0000,
  0x0000,0x0000,0xc410,0xc411, 0xc412,0xc413,0xc414,0xc415,
  0xc416,0xc417,0xc418,0xc419, 0xc41a,0xc41b,0xc41c,0xc41d,
  0xc41e,0xc41f,0xc420,0x0000, 0xc421,0xc422,0xc423,0xc424,
  0xc425,0xc426,0xc427,0xc428, 0xc429,0xc42a,0xc42b,0x0000,
  0xc42c,0xc42d,0xc42e,0xc42f, 0xc430,0xc431,0xc432,0xc433,
  0xc434,0xc435,0xc436,0xc437, 0xc438,0xc439,0xc43a,0xc43b,
  0xc43c,0x0000,0xc43d,0xc43e, 0xc43f,0xc440,0xc441,0xc442,
  0xc443,0xc444,0xc445,0xc446, 0xc447,0x0000,0x0000,0x0000,
  0xc448,0xc449,0xc44a,0xc44b, 0xc44c,0xc44d,0xc44e,0xc44f,
  0xc450,0xc451,0xc452,0xc453, 0xc454,0xc455,0xc456,0xc457,
  0xc458,0x0000,0xc459,0xc45a, 0xc45b,0xc45c,0xc45d,0xc45e,
  0xc45f,0xc460,0xc461,0xc462, 0xc463,0x0000,0xc464,0xc465,
  0xc466,0xc467,0xc468,0xc469, 0xc46a,0xc46b,0xc46c,0xc46d,
  0xc46e,0xc46f,0xc470,0xc471, 0xc472,0xc473,0xc474,0x0000,
  0xc475,0xc476,0xc477,0xc478, 0xc479,0xc47a,0xc47b,0xc47c,
  0xc47d,0xc47e,0xc47f,0x0000, 0x0000,0x0000,0xc480,0xc481,
  0xc482,0xc483,0xc484,0xc485, 0xc486,0xc487,0xc488,0xc489,
  0xc48a,0xc48b,0xc48c,0xc48d, 0xc48e,0xc48f,0xc490,0x0000,
  0xc491,0xc492,0xc493,0xc494, 0xc495,0xc496,0xc497,0xc498,
  0xc499,0xc49a,0xc49b,0x0000, 0x0000,0x0000,0xc49c,0xc49d,
  0xc49e,0xc49f,0xc4a0,0xc4a1, 0xc4a2,0xc4a3,0xc4a4,0xc4a5,
  0xc4a6,0xc4a7,0xc4a8,0xc4a9, 0xc4aa,0xc4ab,0xc4ac,0x0000,
  0xc4ad,0xc4ae,0xc4af,0xc4b0, 0xc4b1,0xc4b2,0xc4b3,0xc4b4,
  0xc4b5,0xc4b6,0xc4b7,0x0000, 0x0000,0x0000,0xc4b8,0xc4b9,
  0xc4ba,0xc4bb,0xc4bc,0xc4bd, 0xc4be,0xc4bf,0xc4c0,0xc4c1,
  0xc4c2,0xc4c3,0xc4c4,0xc4c5, 0xc4c6,0xc4c7,0xc4c8,0x0000,
  0xc4c9,0xc4ca,0xc4cb,0xc4cc, 0xc4cd,0xc4ce,0xc4cf,0xc4d0,
  0xc4d1,0xc4d2,0xc4d3,0x0000, 0xc4d4,0xc4d5,0xc4d6,0xc4d7,
  0xc4d8,0xc4d9,0xc4da,0xc4db, 0xc4dc,0xc4dd,0xc4de,0xc4df,
  0xc4e0,0xc4e1,0xc4e2,0xc4e3, 0xc4e4,0x0000,0xc4e5,0xc4e6,
  0xc4e7,0xc4e8,0xc4e9,0xc4ea, 0xc4eb,0xc4ec,0xc4ed,0xc4ee,
  0xc4ef,0x0000,0x0000,0x0000, 0xc4f0,0xc4f1,0xc4f2,0xc4f3,
  0xc4f4,0xc4f5,0xc4f6,0xc4f7, 0xc4f8,0xc4f9,0xc4fa,0xc4fb,
  0xc4fc,0xc4fd,0xc4fe,0xc4ff, 0xc500,0x0000,0xc501,0xc502,
  0xc503,0xc504,0xc505,0xc506, 0xc507,0xc508,0xc509,0xc50a,
  0xc50b,0x0000,0xc50c,0xc50d, 0xc50e,0xc50f,0xc510,0xc511,
  0xc512,0xc513,0xc514,0xc515, 0xc516,0xc517,0xc518,0xc519,
  0xc51a,0xc51b,0xc51c,0x0000, 0xc51d,0xc51e,0xc51f,0xc520,
  0xc521,0xc522,0xc523,0xc524, 0xc525,0xc526,0xc527,0x0000,
  0x0000,0x0000,0xc528,0xc529, 0xc52a,0xc52b,0xc52c,0xc52d,
  0xc52e,0xc52f,0xc530,0xc531, 0xc532,0xc533,0xc534,0xc535,
  0xc536,0xc537,0xc538,0x0000, 0xc539,0xc53a,0xc53b,0xc53c,
  0xc53d,0xc53e,0xc53f,0xc540, 0xc541,0xc542,0xc543,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x3147,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc544,0xc545,0xc546,0xc547, 0xc548,0xc549,0xc54a,0xc54b,
  0xc54c,0xc54d,0xc54e,0xc54f, 0xc550,0xc551,0xc552,0xc553,
  0xc554,0x0000,0xc555,0xc556, 0xc557,0xc558,0xc559,0xc55a,
  0xc55b,0xc55c,0xc55d,0xc55e, 0xc55f,0x0000,0xc560,0xc561,
  0xc562,0xc563,0xc564,0xc565, 0xc566,0xc567,0xc568,0xc569,
  0xc56a,0xc56b,0xc56c,0xc56d, 0xc56e,0xc56f,0xc570,0x0000,
  0xc571,0xc572,0xc573,0xc574, 0xc575,0xc576,0xc577,0xc578,
  0xc579,0xc57a,0xc57b,0x0000, 0x0000,0x0000,0xc57c,0xc57d,
  0xc57e,0xc57f,0xc580,0xc581, 0xc582,0xc583,0xc584,0xc585,
  0xc586,0xc587,0xc588,0xc589, 0xc58a,0xc58b,0xc58c,0x0000,
  0xc58d,0xc58e,0xc58f,0xc590, 0xc591,0xc592,0xc593,0xc594,
  0xc595,0xc596,0xc597,0x0000, 0x0000,0x0000,0xc598,0xc599,
  0xc59a,0xc59b,0xc59c,0xc59d, 0xc59e,0xc59f,0xc5a0,0xc5a1,
  0xc5a2,0xc5a3,0xc5a4,0xc5a5, 0xc5a6,0xc5a7,0xc5a8,0x0000,
  0xc5a9,0xc5aa,0xc5ab,0xc5ac, 0xc5ad,0xc5ae,0xc5af,0xc5b0,
  0xc5b1,0xc5b2,0xc5b3,0x0000, 0x0000,0x0000,0xc5b4,0xc5b5,
  0xc5b6,0xc5b7,0xc5b8,0xc5b9, 0xc5ba,0xc5bb,0xc5bc,0xc5bd,
  0xc5be,0xc5bf,0xc5c0,0xc5c1, 0xc5c2,0xc5c3,0xc5c4,0x0000,
  0xc5c5,0xc5c6,0xc5c7,0xc5c8, 0xc5c9,0xc5ca,0xc5cb,0xc5cc,
  0xc5cd,0xc5ce,0xc5cf,0x0000, 0xc5d0,0xc5d1,0xc5d2,0xc5d3,
  0xc5d4,0xc5d5,0xc5d6,0xc5d7, 0xc5d8,0xc5d9,0xc5da,0xc5db,
  0xc5dc,0xc5dd,0xc5de,0xc5df, 0xc5e0,0x0000,0xc5e1,0xc5e2,
  0xc5e3,0xc5e4,0xc5e5,0xc5e6, 0xc5e7,0xc5e8,0xc5e9,0xc5ea,
  0xc5eb,0x0000,0x0000,0x0000, 0xc5ec,0xc5ed,0xc5ee,0xc5ef,
  0xc5f0,0xc5f1,0xc5f2,0xc5f3, 0xc5f4,0xc5f5,0xc5f6,0xc5f7,
  0xc5f8,0xc5f9,0xc5fa,0xc5fb, 0xc5fc,0x0000,0xc5fd,0xc5fe,
  0xc5ff,0xc600,0xc601,0xc602, 0xc603,0xc604,0xc605,0xc606,
  0xc607,0x0000,0xc608,0xc609, 0xc60a,0xc60b,0xc60c,0xc60d,
  0xc60e,0xc60f,0xc610,0xc611, 0xc612,0xc613,0xc614,0xc615,
  0xc616,0xc617,0xc618,0x0000, 0xc619,0xc61a,0xc61b,0xc61c,
  0xc61d,0xc61e,0xc61f,0xc620, 0xc621,0xc622,0xc623,0x0000,
  0x0000,0x0000,0xc624,0xc625, 0xc626,0xc627,0xc628,0xc629,
  0xc62a,0xc62b,0xc62c,0xc62d, 0xc62e,0xc62f,0xc630,0xc631,
  0xc632,0xc633,0xc634,0x0000, 0xc635,0xc636,0xc637,0xc638,
  0xc639,0xc63a,0xc63b,0xc63c, 0xc63d,0xc63e,0xc63f,0x0000,
  0x0000,0x0000,0xc640,0xc641, 0xc642,0xc643,0xc644,0xc645,
  0xc646,0xc647,0xc648,0xc649, 0xc64a,0xc64b,0xc64c,0xc64d,
  0xc64e,0xc64f,0xc650,0x0000, 0xc651,0xc652,0xc653,0xc654,
  0xc655,0xc656,0xc657,0xc658, 0xc659,0xc65a,0xc65b,0x0000,
  0x0000,0x0000,0xc65c,0xc65d, 0xc65e,0xc65f,0xc660,0xc661,
  0xc662,0xc663,0xc664,0xc665, 0xc666,0xc667,0xc668,0xc669,
  0xc66a,0xc66b,0xc66c,0x0000, 0xc66d,0xc66e,0xc66f,0xc670,
  0xc671,0xc672,0xc673,0xc674, 0xc675,0xc676,0xc677,0x0000,
  0xc678,0xc679,0xc67a,0xc67b, 0xc67c,0xc67d,0xc67e,0xc67f,
  0xc680,0xc681,0xc682,0xc683, 0xc684,0xc685,0xc686,0xc687,
  0xc688,0x0000,0xc689,0xc68a, 0xc68b,0xc68c,0xc68d,0xc68e,
  0xc68f,0xc690,0xc691,0xc692, 0xc693,0x0000,0x0000,0x0000,
  0xc694,0xc695,0xc696,0xc697, 0xc698,0xc699,0xc69a,0xc69b,
  0xc69c,0xc69d,0xc69e,0xc69f, 0xc6a0,0xc6a1,0xc6a2,0xc6a3,
  0xc6a4,0x0000,0xc6a5,0xc6a6, 0xc6a7,0xc6a8,0xc6a9,0xc6aa,
  0xc6ab,0xc6ac,0xc6ad,0xc6ae, 0xc6af,0x0000,0xc6b0,0xc6b1,
  0xc6b2,0xc6b3,0xc6b4,0xc6b5, 0xc6b6,0xc6b7,0xc6b8,0xc6b9,
  0xc6ba,0xc6bb,0xc6bc,0xc6bd, 0xc6be,0xc6bf,0xc6c0,0x0000,
  0xc6c1,0xc6c2,0xc6c3,0xc6c4, 0xc6c5,0xc6c6,0xc6c7,0xc6c8,
  0xc6c9,0xc6ca,0xc6cb,0x0000, 0x0000,0x0000,0xc6cc,0xc6cd,
  0xc6ce,0xc6cf,0xc6d0,0xc6d1, 0xc6d2,0xc6d3,0xc6d4,0xc6d5,
  0xc6d6,0xc6d7,0xc6d8,0xc6d9, 0xc6da,0xc6db,0xc6dc,0x0000,
  0xc6dd,0xc6de,0xc6df,0xc6e0, 0xc6e1,0xc6e2,0xc6e3,0xc6e4,
  0xc6e5,0xc6e6,0xc6e7,0x0000, 0x0000,0x0000,0xc6e8,0xc6e9,
  0xc6ea,0xc6eb,0xc6ec,0xc6ed, 0xc6ee,0xc6ef,0xc6f0,0xc6f1,
  0xc6f2,0xc6f3,0xc6f4,0xc6f5, 0xc6f6,0xc6f7,0xc6f8,0x0000,
  0xc6f9,0xc6fa,0xc6fb,0xc6fc, 0xc6fd,0xc6fe,0xc6ff,0xc700,
  0xc701,0xc702,0xc703,0x0000, 0x0000,0x0000,0xc704,0xc705,
  0xc706,0xc707,0xc708,0xc709, 0xc70a,0xc70b,0xc70c,0xc70d,
  0xc70e,0xc70f,0xc710,0xc711, 0xc712,0xc713,0xc714,0x0000,
  0xc715,0xc716,0xc717,0xc718, 0xc719,0xc71a,0xc71b,0xc71c,
  0xc71d,0xc71e,0xc71f,0x0000, 0xc720,0xc721,0xc722,0xc723,
  0xc724,0xc725,0xc726,0xc727, 0xc728,0xc729,0xc72a,0xc72b,
  0xc72c,0xc72d,0xc72e,0xc72f, 0xc730,0x0000,0xc731,0xc732,
  0xc733,0xc734,0xc735,0xc736, 0xc737,0xc738,0xc739,0xc73a,
  0xc73b,0x0000,0x0000,0x0000, 0xc73c,0xc73d,0xc73e,0xc73f,
  0xc740,0xc741,0xc742,0xc743, 0xc744,0xc745,0xc746,0xc747,
  0xc748,0xc749,0xc74a,0xc74b, 0xc74c,0x0000,0xc74d,0xc74e,
  0xc74f,0xc750,0xc751,0xc752, 0xc753,0xc754,0xc755,0xc756,
  0xc757,0x0000,0xc758,0xc759, 0xc75a,0xc75b,0xc75c,0xc75d,
  0xc75e,0xc75f,0xc760,0xc761, 0xc762,0xc763,0xc764,0xc765,
  0xc766,0xc767,0xc768,0x0000, 0xc769,0xc76a,0xc76b,0xc76c,
  0xc76d,0xc76e,0xc76f,0xc770, 0xc771,0xc772,0xc773,0x0000,
  0x0000,0x0000,0xc774,0xc775, 0xc776,0xc777,0xc778,0xc779,
  0xc77a,0xc77b,0xc77c,0xc77d, 0xc77e,0xc77f,0xc780,0xc781,
  0xc782,0xc783,0xc784,0x0000, 0xc785,0xc786,0xc787,0xc788,
  0xc789,0xc78a,0xc78b,0xc78c, 0xc78d,0xc78e,0xc78f,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x3148,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc790,0xc791,0xc792,0xc793, 0xc794,0xc795,0xc796,0xc797,
  0xc798,0xc799,0xc79a,0xc79b, 0xc79c,0xc79d,0xc79e,0xc79f,
  0xc7a0,0x0000,0xc7a1,0xc7a2, 0xc7a3,0xc7a4,0xc7a5,0xc7a6,
  0xc7a7,0xc7a8,0xc7a9,0xc7aa, 0xc7ab,0x0000,0xc7ac,0xc7ad,
  0xc7ae,0xc7af,0xc7b0,0xc7b1, 0xc7b2,0xc7b3,0xc7b4,0xc7b5,
  0xc7b6,0xc7b7,0xc7b8,0xc7b9, 0xc7ba,0xc7bb,0xc7bc,0x0000,
  0xc7bd,0xc7be,0xc7bf,0xc7c0, 0xc7c1,0xc7c2,0xc7c3,0xc7c4,
  0xc7c5,0xc7c6,0xc7c7,0x0000, 0x0000,0x0000,0xc7c8,0xc7c9,
  0xc7ca,0xc7cb,0xc7cc,0xc7cd, 0xc7ce,0xc7cf,0xc7d0,0xc7d1,
  0xc7d2,0xc7d3,0xc7d4,0xc7d5, 0xc7d6,0xc7d7,0xc7d8,0x0000,
  0xc7d9,0xc7da,0xc7db,0xc7dc, 0xc7dd,0xc7de,0xc7df,0xc7e0,
  0xc7e1,0xc7e2,0xc7e3,0x0000, 0x0000,0x0000,0xc7e4,0xc7e5,
  0xc7e6,0xc7e7,0xc7e8,0xc7e9, 0xc7ea,0xc7eb,0xc7ec,0xc7ed,
  0xc7ee,0xc7ef,0xc7f0,0xc7f1, 0xc7f2,0xc7f3,0xc7f4,0x0000,
  0xc7f5,0xc7f6,0xc7f7,0xc7f8, 0xc7f9,0xc7fa,0xc7fb,0xc7fc,
  0xc7fd,0xc7fe,0xc7ff,0x0000, 0x0000,0x0000,0xc800,0xc801,
  0xc802,0xc803,0xc804,0xc805, 0xc806,0xc807,0xc808,0xc809,
  0xc80a,0xc80b,0xc80c,0xc80d, 0xc80e,0xc80f,0xc810,0x0000,
  0xc811,0xc812,0xc813,0xc814, 0xc815,0xc816,0xc817,0xc818,
  0xc819,0xc81a,0xc81b,0x0000, 0xc81c,0xc81d,0xc81e,0xc81f,
  0xc820,0xc821,0xc822,0xc823, 0xc824,0xc825,0xc826,0xc827,
  0xc828,0xc829,0xc82a,0xc82b, 0xc82c,0x0000,0xc82d,0xc82e,
  0xc82f,0xc830,0xc831,0xc832, 0xc833,0xc834,0xc835,0xc836,
  0xc837,0x0000,0x0000,0x0000, 0xc838,0xc839,0xc83a,0xc83b,
  0xc83c,0xc83d,0xc83e,0xc83f, 0xc840,0xc841,0xc842,0xc843,
  0xc844,0xc845,0xc846,0xc847, 0xc848,0x0000,0xc849,0xc84a,
  0xc84b,0xc84c,0xc84d,0xc84e, 0xc84f,0xc850,0xc851,0xc852,
  0xc853,0x0000,0xc854,0xc855, 0xc856,0xc857,0xc858,0xc859,
  0xc85a,0xc85b,0xc85c,0xc85d, 0xc85e,0xc85f,0xc860,0xc861,
  0xc862,0xc863,0xc864,0x0000, 0xc865,0xc866,0xc867,0xc868,
  0xc869,0xc86a,0xc86b,0xc86c, 0xc86d,0xc86e,0xc86f,0x0000,
  0x0000,0x0000,0xc870,0xc871, 0xc872,0xc873,0xc874,0xc875,
  0xc876,0xc877,0xc878,0xc879, 0xc87a,0xc87b,0xc87c,0xc87d,
  0xc87e,0xc87f,0xc880,0x0000, 0xc881,0xc882,0xc883,0xc884,
  0xc885,0xc886,0xc887,0xc888, 0xc889,0xc88a,0xc88b,0x0000,
  0x0000,0x0000,0xc88c,0xc88d, 0xc88e,0xc88f,0xc890,0xc891,
  0xc892,0xc893,0xc894,0xc895, 0xc896,0xc897,0xc898,0xc899,
  0xc89a,0xc89b,0xc89c,0x0000, 0xc89d,0xc89e,0xc89f,0xc8a0,
  0xc8a1,0xc8a2,0xc8a3,0xc8a4, 0xc8a5,0xc8a6,0xc8a7,0x0000,
  0x0000,0x0000,0xc8a8,0xc8a9, 0xc8aa,0xc8ab,0xc8ac,0xc8ad,
  0xc8ae,0xc8af,0xc8b0,0xc8b1, 0xc8b2,0xc8b3,0xc8b4,0xc8b5,
  0xc8b6,0xc8b7,0xc8b8,0x0000, 0xc8b9,0xc8ba,0xc8bb,0xc8bc,
  0xc8bd,0xc8be,0xc8bf,0xc8c0, 0xc8c1,0xc8c2,0xc8c3,0x0000,
  0xc8c4,0xc8c5,0xc8c6,0xc8c7, 0xc8c8,0xc8c9,0xc8ca,0xc8cb,
  0xc8cc,0xc8cd,0xc8ce,0xc8cf, 0xc8d0,0xc8d1,0xc8d2,0xc8d3,
  0xc8d4,0x0000,0xc8d5,0xc8d6, 0xc8d7,0xc8d8,0xc8d9,0xc8da,
  0xc8db,0xc8dc,0xc8dd,0xc8de, 0xc8df,0x0000,0x0000,0x0000,
  0xc8e0,0xc8e1,0xc8e2,0xc8e3, 0xc8e4,0xc8e5,0xc8e6,0xc8e7,
  0xc8e8,0xc8e9,0xc8ea,0xc8eb, 0xc8ec,0xc8ed,0xc8ee,0xc8ef,
  0xc8f0,0x0000,0xc8f1,0xc8f2, 0xc8f3,0xc8f4,0xc8f5,0xc8f6,
  0xc8f7,0xc8f8,0xc8f9,0xc8fa, 0xc8fb,0x0000,0xc8fc,0xc8fd,
  0xc8fe,0xc8ff,0xc900,0xc901, 0xc902,0xc903,0xc904,0xc905,
  0xc906,0xc907,0xc908,0xc909, 0xc90a,0xc90b,0xc90c,0x0000,
  0xc90d,0xc90e,0xc90f,0xc910, 0xc911,0xc912,0xc913,0xc914,
  0xc915,0xc916,0xc917,0x0000, 0x0000,0x0000,0xc918,0xc919,
  0xc91a,0xc91b,0xc91c,0xc91d, 0xc91e,0xc91f,0xc920,0xc921,
  0xc922,0xc923,0xc924,0xc925, 0xc926,0xc927,0xc928,0x0000,
  0xc929,0xc92a,0xc92b,0xc92c, 0xc92d,0xc92e,0xc92f,0xc930,
  0xc931,0xc932,0xc933,0x0000, 0x0000,0x0000,0xc934,0xc935,
  0xc936,0xc937,0xc938,0xc939, 0xc93a,0xc93b,0xc93c,0xc93d,
  0xc93e,0xc93f,0xc940,0xc941, 0xc942,0xc943,0xc944,0x0000,
  0xc945,0xc946,0xc947,0xc948, 0xc949,0xc94a,0xc94b,0xc94c,
  0xc94d,0xc94e,0xc94f,0x0000, 0x0000,0x0000,0xc950,0xc951,
  0xc952,0xc953,0xc954,0xc955, 0xc956,0xc957,0xc958,0xc959,
  0xc95a,0xc95b,0xc95c,0xc95d, 0xc95e,0xc95f,0xc960,0x0000,
  0xc961,0xc962,0xc963,0xc964, 0xc965,0xc966,0xc967,0xc968,
  0xc969,0xc96a,0xc96b,0x0000, 0xc96c,0xc96d,0xc96e,0xc96f,
  0xc970,0xc971,0xc972,0xc973, 0xc974,0xc975,0xc976,0xc977,
  0xc978,0xc979,0xc97a,0xc97b, 0xc97c,0x0000,0xc97d,0xc97e,
  0xc97f,0xc980,0xc981,0xc982, 0xc983,0xc984,0xc985,0xc986,
  0xc987,0x0000,0x0000,0x0000, 0xc988,0xc989,0xc98a,0xc98b,
  0xc98c,0xc98d,0xc98e,0xc98f, 0xc990,0xc991,0xc992,0xc993,
  0xc994,0xc995,0xc996,0xc997, 0xc998,0x0000,0xc999,0xc99a,
  0xc99b,0xc99c,0xc99d,0xc99e, 0xc99f,0xc9a0,0xc9a1,0xc9a2,
  0xc9a3,0x0000,0xc9a4,0xc9a5, 0xc9a6,0xc9a7,0xc9a8,0xc9a9,
  0xc9aa,0xc9ab,0xc9ac,0xc9ad, 0xc9ae,0xc9af,0xc9b0,0xc9b1,
  0xc9b2,0xc9b3,0xc9b4,0x0000, 0xc9b5,0xc9b6,0xc9b7,0xc9b8,
  0xc9b9,0xc9ba,0xc9bb,0xc9bc, 0xc9bd,0xc9be,0xc9bf,0x0000,
  0x0000,0x0000,0xc9c0,0xc9c1, 0xc9c2,0xc9c3,0xc9c4,0xc9c5,
  0xc9c6,0xc9c7,0xc9c8,0xc9c9, 0xc9ca,0xc9cb,0xc9cc,0xc9cd,
  0xc9ce,0xc9cf,0xc9d0,0x0000, 0xc9d1,0xc9d2,0xc9d3,0xc9d4,
  0xc9d5,0xc9d6,0xc9d7,0xc9d8, 0xc9d9,0xc9da,0xc9db,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x3149,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xc9dc,0xc9dd,0xc9de,0xc9df, 0xc9e0,0xc9e1,0xc9e2,0xc9e3,
  0xc9e4,0xc9e5,0xc9e6,0xc9e7, 0xc9e8,0xc9e9,0xc9ea,0xc9eb,
  0xc9ec,0x0000,0xc9ed,0xc9ee, 0xc9ef,0xc9f0,0xc9f1,0xc9f2,
  0xc9f3,0xc9f4,0xc9f5,0xc9f6, 0xc9f7,0x0000,0xc9f8,0xc9f9,
  0xc9fa,0xc9fb,0xc9fc,0xc9fd, 0xc9fe,0xc9ff,0xca00,0xca01,
  0xca02,0xca03,0xca04,0xca05, 0xca06,0xca07,0xca08,0x0000,
  0xca09,0xca0a,0xca0b,0xca0c, 0xca0d,0xca0e,0xca0f,0xca10,
  0xca11,0xca12,0xca13,0x0000, 0x0000,0x0000,0xca14,0xca15,
  0xca16,0xca17,0xca18,0xca19, 0xca1a,0xca1b,0xca1c,0xca1d,
  0xca1e,0xca1f,0xca20,0xca21, 0xca22,0xca23,0xca24,0x0000,
  0xca25,0xca26,0xca27,0xca28, 0xca29,0xca2a,0xca2b,0xca2c,
  0xca2d,0xca2e,0xca2f,0x0000, 0x0000,0x0000,0xca30,0xca31,
  0xca32,0xca33,0xca34,0xca35, 0xca36,0xca37,0xca38,0xca39,
  0xca3a,0xca3b,0xca3c,0xca3d, 0xca3e,0xca3f,0xca40,0x0000,
  0xca41,0xca42,0xca43,0xca44, 0xca45,0xca46,0xca47,0xca48,
  0xca49,0xca4a,0xca4b,0x0000, 0x0000,0x0000,0xca4c,0xca4d,
  0xca4e,0xca4f,0xca50,0xca51, 0xca52,0xca53,0xca54,0xca55,
  0xca56,0xca57,0xca58,0xca59, 0xca5a,0xca5b,0xca5c,0x0000,
  0xca5d,0xca5e,0xca5f,0xca60, 0xca61,0xca62,0xca63,0xca64,
  0xca65,0xca66,0xca67,0x0000, 0xca68,0xca69,0xca6a,0xca6b,
  0xca6c,0xca6d,0xca6e,0xca6f, 0xca70,0xca71,0xca72,0xca73,
  0xca74,0xca75,0xca76,0xca77, 0xca78,0x0000,0xca79,0xca7a,
  0xca7b,0xca7c,0xca7d,0xca7e, 0xca7f,0xca80,0xca81,0xca82,
  0xca83,0x0000,0x0000,0x0000, 0xca84,0xca85,0xca86,0xca87,
  0xca88,0xca89,0xca8a,0xca8b, 0xca8c,0xca8d,0xca8e,0xca8f,
  0xca90,0xca91,0xca92,0xca93, 0xca94,0x0000,0xca95,0xca96,
  0xca97,0xca98,0xca99,0xca9a, 0xca9b,0xca9c,0xca9d,0xca9e,
  0xca9f,0x0000,0xcaa0,0xcaa1, 0xcaa2,0xcaa3,0xcaa4,0xcaa5,
  0xcaa6,0xcaa7,0xcaa8,0xcaa9, 0xcaaa,0xcaab,0xcaac,0xcaad,
  0xcaae,0xcaaf,0xcab0,0x0000, 0xcab1,0xcab2,0xcab3,0xcab4,
  0xcab5,0xcab6,0xcab7,0xcab8, 0xcab9,0xcaba,0xcabb,0x0000,
  0x0000,0x0000,0xcabc,0xcabd, 0xcabe,0xcabf,0xcac0,0xcac1,
  0xcac2,0xcac3,0xcac4,0xcac5, 0xcac6,0xcac7,0xcac8,0xcac9,
  0xcaca,0xcacb,0xcacc,0x0000, 0xcacd,0xcace,0xcacf,0xcad0,
  0xcad1,0xcad2,0xcad3,0xcad4, 0xcad5,0xcad6,0xcad7,0x0000,
  0x0000,0x0000,0xcad8,0xcad9, 0xcada,0xcadb,0xcadc,0xcadd,
  0xcade,0xcadf,0xcae0,0xcae1, 0xcae2,0xcae3,0xcae4,0xcae5,
  0xcae6,0xcae7,0xcae8,0x0000, 0xcae9,0xcaea,0xcaeb,0xcaec,
  0xcaed,0xcaee,0xcaef,0xcaf0, 0xcaf1,0xcaf2,0xcaf3,0x0000,
  0x0000,0x0000,0xcaf4,0xcaf5, 0xcaf6,0xcaf7,0xcaf8,0xcaf9,
  0xcafa,0xcafb,0xcafc,0xcafd, 0xcafe,0xcaff,0xcb00,0xcb01,
  0xcb02,0xcb03,0xcb04,0x0000, 0xcb05,0xcb06,0xcb07,0xcb08,
  0xcb09,0xcb0a,0xcb0b,0xcb0c, 0xcb0d,0xcb0e,0xcb0f,0x0000,
  0xcb10,0xcb11,0xcb12,0xcb13, 0xcb14,0xcb15,0xcb16,0xcb17,
  0xcb18,0xcb19,0xcb1a,0xcb1b, 0xcb1c,0xcb1d,0xcb1e,0xcb1f,
  0xcb20,0x0000,0xcb21,0xcb22, 0xcb23,0xcb24,0xcb25,0xcb26,
  0xcb27,0xcb28,0xcb29,0xcb2a, 0xcb2b,0x0000,0x0000,0x0000,
  0xcb2c,0xcb2d,0xcb2e,0xcb2f, 0xcb30,0xcb31,0xcb32,0xcb33,
  0xcb34,0xcb35,0xcb36,0xcb37, 0xcb38,0xcb39,0xcb3a,0xcb3b,
  0xcb3c,0x0000,0xcb3d,0xcb3e, 0xcb3f,0xcb40,0xcb41,0xcb42,
  0xcb43,0xcb44,0xcb45,0xcb46, 0xcb47,0x0000,0xcb48,0xcb49,
  0xcb4a,0xcb4b,0xcb4c,0xcb4d, 0xcb4e,0xcb4f,0xcb50,0xcb51,
  0xcb52,0xcb53,0xcb54,0xcb55, 0xcb56,0xcb57,0xcb58,0x0000,
  0xcb59,0xcb5a,0xcb5b,0xcb5c, 0xcb5d,0xcb5e,0xcb5f,0xcb60,
  0xcb61,0xcb62,0xcb63,0x0000, 0x0000,0x0000,0xcb64,0xcb65,
  0xcb66,0xcb67,0xcb68,0xcb69, 0xcb6a,0xcb6b,0xcb6c,0xcb6d,
  0xcb6e,0xcb6f,0xcb70,0xcb71, 0xcb72,0xcb73,0xcb74,0x0000,
  0xcb75,0xcb76,0xcb77,0xcb78, 0xcb79,0xcb7a,0xcb7b,0xcb7c,
  0xcb7d,0xcb7e,0xcb7f,0x0000, 0x0000,0x0000,0xcb80,0xcb81,
  0xcb82,0xcb83,0xcb84,0xcb85, 0xcb86,0xcb87,0xcb88,0xcb89,
  0xcb8a,0xcb8b,0xcb8c,0xcb8d, 0xcb8e,0xcb8f,0xcb90,0x0000,
  0xcb91,0xcb92,0xcb93,0xcb94, 0xcb95,0xcb96,0xcb97,0xcb98,
  0xcb99,0xcb9a,0xcb9b,0x0000, 0x0000,0x0000,0xcb9c,0xcb9d,
  0xcb9e,0xcb9f,0xcba0,0xcba1, 0xcba2,0xcba3,0xcba4,0xcba5,
  0xcba6,0xcba7,0xcba8,0xcba9, 0xcbaa,0xcbab,0xcbac,0x0000,
  0xcbad,0xcbae,0xcbaf,0xcbb0, 0xcbb1,0xcbb2,0xcbb3,0xcbb4,
  0xcbb5,0xcbb6,0xcbb7,0x0000, 0xcbb8,0xcbb9,0xcbba,0xcbbb,
  0xcbbc,0xcbbd,0xcbbe,0xcbbf, 0xcbc0,0xcbc1,0xcbc2,0xcbc3,
  0xcbc4,0xcbc5,0xcbc6,0xcbc7, 0xcbc8,0x0000,0xcbc9,0xcbca,
  0xcbcb,0xcbcc,0xcbcd,0xcbce, 0xcbcf,0xcbd0,0xcbd1,0xcbd2,
  0xcbd3,0x0000,0x0000,0x0000, 0xcbd4,0xcbd5,0xcbd6,0xcbd7,
  0xcbd8,0xcbd9,0xcbda,0xcbdb, 0xcbdc,0xcbdd,0xcbde,0xcbdf,
  0xcbe0,0xcbe1,0xcbe2,0xcbe3, 0xcbe4,0x0000,0xcbe5,0xcbe6,
  0xcbe7,0xcbe8,0xcbe9,0xcbea, 0xcbeb,0xcbec,0xcbed,0xcbee,
  0xcbef,0x0000,0xcbf0,0xcbf1, 0xcbf2,0xcbf3,0xcbf4,0xcbf5,
  0xcbf6,0xcbf7,0xcbf8,0xcbf9, 0xcbfa,0xcbfb,0xcbfc,0xcbfd,
  0xcbfe,0xcbff,0xcc00,0x0000, 0xcc01,0xcc02,0xcc03,0xcc04,
  0xcc05,0xcc06,0xcc07,0xcc08, 0xcc09,0xcc0a,0xcc0b,0x0000,
  0x0000,0x0000,0xcc0c,0xcc0d, 0xcc0e,0xcc0f,0xcc10,0xcc11,
  0xcc12,0xcc13,0xcc14,0xcc15, 0xcc16,0xcc17,0xcc18,0xcc19,
  0xcc1a,0xcc1b,0xcc1c,0x0000, 0xcc1d,0xcc1e,0xcc1f,0xcc20,
  0xcc21,0xcc22,0xcc23,0xcc24, 0xcc25,0xcc26,0xcc27,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x314a,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xcc28,0xcc29,0xcc2a,0xcc2b, 0xcc2c,0xcc2d,0xcc2e,0xcc2f,
  0xcc30,0xcc31,0xcc32,0xcc33, 0xcc34,0xcc35,0xcc36,0xcc37,
  0xcc38,0x0000,0xcc39,0xcc3a, 0xcc3b,0xcc3c,0xcc3d,0xcc3e,
  0xcc3f,0xcc40,0xcc41,0xcc42, 0xcc43,0x0000,0xcc44,0xcc45,
  0xcc46,0xcc47,0xcc48,0xcc49, 0xcc4a,0xcc4b,0xcc4c,0xcc4d,
  0xcc4e,0xcc4f,0xcc50,0xcc51, 0xcc52,0xcc53,0xcc54,0x0000,
  0xcc55,0xcc56,0xcc57,0xcc58, 0xcc59,0xcc5a,0xcc5b,0xcc5c,
  0xcc5d,0xcc5e,0xcc5f,0x0000, 0x0000,0x0000,0xcc60,0xcc61,
  0xcc62,0xcc63,0xcc64,0xcc65, 0xcc66,0xcc67,0xcc68,0xcc69,
  0xcc6a,0xcc6b,0xcc6c,0xcc6d, 0xcc6e,0xcc6f,0xcc70,0x0000,
  0xcc71,0xcc72,0xcc73,0xcc74, 0xcc75,0xcc76,0xcc77,0xcc78,
  0xcc79,0xcc7a,0xcc7b,0x0000, 0x0000,0x0000,0xcc7c,0xcc7d,
  0xcc7e,0xcc7f,0xcc80,0xcc81, 0xcc82,0xcc83,0xcc84,0xcc85,
  0xcc86,0xcc87,0xcc88,0xcc89, 0xcc8a,0xcc8b,0xcc8c,0x0000,
  0xcc8d,0xcc8e,0xcc8f,0xcc90, 0xcc91,0xcc92,0xcc93,0xcc94,
  0xcc95,0xcc96,0xcc97,0x0000, 0x0000,0x0000,0xcc98,0xcc99,
  0xcc9a,0xcc9b,0xcc9c,0xcc9d, 0xcc9e,0xcc9f,0xcca0,0xcca1,
  0xcca2,0xcca3,0xcca4,0xcca5, 0xcca6,0xcca7,0xcca8,0x0000,
  0xcca9,0xccaa,0xccab,0xccac, 0xccad,0xccae,0xccaf,0xccb0,
  0xccb1,0xccb2,0xccb3,0x0000, 0xccb4,0xccb5,0xccb6,0xccb7,
  0xccb8,0xccb9,0xccba,0xccbb, 0xccbc,0xccbd,0xccbe,0xccbf,
  0xccc0,0xccc1,0xccc2,0xccc3, 0xccc4,0x0000,0xccc5,0xccc6,
  0xccc7,0xccc8,0xccc9,0xccca, 0xcccb,0xcccc,0xcccd,0xccce,
  0xcccf,0x0000,0x0000,0x0000, 0xccd0,0xccd1,0xccd2,0xccd3,
  0xccd4,0xccd5,0xccd6,0xccd7, 0xccd8,0xccd9,0xccda,0xccdb,
  0xccdc,0xccdd,0xccde,0xccdf, 0xcce0,0x0000,0xcce1,0xcce2,
  0xcce3,0xcce4,0xcce5,0xcce6, 0xcce7,0xcce8,0xcce9,0xccea,
  0xcceb,0x0000,0xccec,0xcced, 0xccee,0xccef,0xccf0,0xccf1,
  0xccf2,0xccf3,0xccf4,0xccf5, 0xccf6,0xccf7,0xccf8,0xccf9,
  0xccfa,0xccfb,0xccfc,0x0000, 0xccfd,0xccfe,0xccff,0xcd00,
  0xcd01,0xcd02,0xcd03,0xcd04, 0xcd05,0xcd06,0xcd07,0x0000,
  0x0000,0x0000,0xcd08,0xcd09, 0xcd0a,0xcd0b,0xcd0c,0xcd0d,
  0xcd0e,0xcd0f,0xcd10,0xcd11, 0xcd12,0xcd13,0xcd14,0xcd15,
  0xcd16,0xcd17,0xcd18,0x0000, 0xcd19,0xcd1a,0xcd1b,0xcd1c,
  0xcd1d,0xcd1e,0xcd1f,0xcd20, 0xcd21,0xcd22,0xcd23,0x0000,
  0x0000,0x0000,0xcd24,0xcd25, 0xcd26,0xcd27,0xcd28,0xcd29,
  0xcd2a,0xcd2b,0xcd2c,0xcd2d, 0xcd2e,0xcd2f,0xcd30,0xcd31,
  0xcd32,0xcd33,0xcd34,0x0000, 0xcd35,0xcd36,0xcd37,0xcd38,
  0xcd39,0xcd3a,0xcd3b,0xcd3c, 0xcd3d,0xcd3e,0xcd3f,0x0000,
  0x0000,0x0000,0xcd40,0xcd41, 0xcd42,0xcd43,0xcd44,0xcd45,
  0xcd46,0xcd47,0xcd48,0xcd49, 0xcd4a,0xcd4b,0xcd4c,0xcd4d,
  0xcd4e,0xcd4f,0xcd50,0x0000, 0xcd51,0xcd52,0xcd53,0xcd54,
  0xcd55,0xcd56,0xcd57,0xcd58, 0xcd59,0xcd5a,0xcd5b,0x0000,
  0xcd5c,0xcd5d,0xcd5e,0xcd5f, 0xcd60,0xcd61,0xcd62,0xcd63,
  0xcd64,0xcd65,0xcd66,0xcd67, 0xcd68,0xcd69,0xcd6a,0xcd6b,
  0xcd6c,0x0000,0xcd6d,0xcd6e, 0xcd6f,0xcd70,0xcd71,0xcd72,
  0xcd73,0xcd74,0xcd75,0xcd76, 0xcd77,0x0000,0x0000,0x0000,
  0xcd78,0xcd79,0xcd7a,0xcd7b, 0xcd7c,0xcd7d,0xcd7e,0xcd7f,
  0xcd80,0xcd81,0xcd82,0xcd83, 0xcd84,0xcd85,0xcd86,0xcd87,
  0xcd88,0x0000,0xcd89,0xcd8a, 0xcd8b,0xcd8c,0xcd8d,0xcd8e,
  0xcd8f,0xcd90,0xcd91,0xcd92, 0xcd93,0x0000,0xcd94,0xcd95,
  0xcd96,0xcd97,0xcd98,0xcd99, 0xcd9a,0xcd9b,0xcd9c,0xcd9d,
  0xcd9e,0xcd9f,0xcda0,0xcda1, 0xcda2,0xcda3,0xcda4,0x0000,
  0xcda5,0xcda6,0xcda7,0xcda8, 0xcda9,0xcdaa,0xcdab,0xcdac,
  0xcdad,0xcdae,0xcdaf,0x0000, 0x0000,0x0000,0xcdb0,0xcdb1,
  0xcdb2,0xcdb3,0xcdb4,0xcdb5, 0xcdb6,0xcdb7,0xcdb8,0xcdb9,
  0xcdba,0xcdbb,0xcdbc,0xcdbd, 0xcdbe,0xcdbf,0xcdc0,0x0000,
  0xcdc1,0xcdc2,0xcdc3,0xcdc4, 0xcdc5,0xcdc6,0xcdc7,0xcdc8,
  0xcdc9,0xcdca,0xcdcb,0x0000, 0x0000,0x0000,0xcdcc,0xcdcd,
  0xcdce,0xcdcf,0xcdd0,0xcdd1, 0xcdd2,0xcdd3,0xcdd4,0xcdd5,
  0xcdd6,0xcdd7,0xcdd8,0xcdd9, 0xcdda,0xcddb,0xcddc,0x0000,
  0xcddd,0xcdde,0xcddf,0xcde0, 0xcde1,0xcde2,0xcde3,0xcde4,
  0xcde5,0xcde6,0xcde7,0x0000, 0x0000,0x0000,0xcde8,0xcde9,
  0xcdea,0xcdeb,0xcdec,0xcded, 0xcdee,0xcdef,0xcdf0,0xcdf1,
  0xcdf2,0xcdf3,0xcdf4,0xcdf5, 0xcdf6,0xcdf7,0xcdf8,0x0000,
  0xcdf9,0xcdfa,0xcdfb,0xcdfc, 0xcdfd,0xcdfe,0xcdff,0xce00,
  0xce01,0xce02,0xce03,0x0000, 0xce04,0xce05,0xce06,0xce07,
  0xce08,0xce09,0xce0a,0xce0b, 0xce0c,0xce0d,0xce0e,0xce0f,
  0xce10,0xce11,0xce12,0xce13, 0xce14,0x0000,0xce15,0xce16,
  0xce17,0xce18,0xce19,0xce1a, 0xce1b,0xce1c,0xce1d,0xce1e,
  0xce1f,0x0000,0x0000,0x0000, 0xce20,0xce21,0xce22,0xce23,
  0xce24,0xce25,0xce26,0xce27, 0xce28,0xce29,0xce2a,0xce2b,
  0xce2c,0xce2d,0xce2e,0xce2f, 0xce30,0x0000,0xce31,0xce32,
  0xce33,0xce34,0xce35,0xce36, 0xce37,0xce38,0xce39,0xce3a,
  0xce3b,0x0000,0xce3c,0xce3d, 0xce3e,0xce3f,0xce40,0xce41,
  0xce42,0xce43,0xce44,0xce45, 0xce46,0xce47,0xce48,0xce49,
  0xce4a,0xce4b,0xce4c,0x0000, 0xce4d,0xce4e,0xce4f,0xce50,
  0xce51,0xce52,0xce53,0xce54, 0xce55,0xce56,0xce57,0x0000,
  0x0000,0x0000,0xce58,0xce59, 0xce5a,0xce5b,0xce5c,0xce5d,
  0xce5e,0xce5f,0xce60,0xce61, 0xce62,0xce63,0xce64,0xce65,
  0xce66,0xce67,0xce68,0x0000, 0xce69,0xce6a,0xce6b,0xce6c,
  0xce6d,0xce6e,0xce6f,0xce70, 0xce71,0xce72,0xce73,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x314b,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xce74,0xce75,0xce76,0xce77, 0xce78,0xce79,0xce7a,0xce7b,
  0xce7c,0xce7d,0xce7e,0xce7f, 0xce80,0xce81,0xce82,0xce83,
  0xce84,0x0000,0xce85,0xce86, 0xce87,0xce88,0xce89,0xce8a,
  0xce8b,0xce8c,0xce8d,0xce8e, 0xce8f,0x0000,0xce90,0xce91,
  0xce92,0xce93,0xce94,0xce95, 0xce96,0xce97,0xce98,0xce99,
  0xce9a,0xce9b,0xce9c,0xce9d, 0xce9e,0xce9f,0xcea0,0x0000,
  0xcea1,0xcea2,0xcea3,0xcea4, 0xcea5,0xcea6,0xcea7,0xcea8,
  0xcea9,0xceaa,0xceab,0x0000, 0x0000,0x0000,0xceac,0xcead,
  0xceae,0xceaf,0xceb0,0xceb1, 0xceb2,0xceb3,0xceb4,0xceb5,
  0xceb6,0xceb7,0xceb8,0xceb9, 0xceba,0xcebb,0xcebc,0x0000,
  0xcebd,0xcebe,0xcebf,0xcec0, 0xcec1,0xcec2,0xcec3,0xcec4,
  0xcec5,0xcec6,0xcec7,0x0000, 0x0000,0x0000,0xcec8,0xcec9,
  0xceca,0xcecb,0xcecc,0xcecd, 0xcece,0xcecf,0xced0,0xced1,
  0xced2,0xced3,0xced4,0xced5, 0xced6,0xced7,0xced8,0x0000,
  0xced9,0xceda,0xcedb,0xcedc, 0xcedd,0xcede,0xcedf,0xcee0,
  0xcee1,0xcee2,0xcee3,0x0000, 0x0000,0x0000,0xcee4,0xcee5,
  0xcee6,0xcee7,0xcee8,0xcee9, 0xceea,0xceeb,0xceec,0xceed,
  0xceee,0xceef,0xcef0,0xcef1, 0xcef2,0xcef3,0xcef4,0x0000,
  0xcef5,0xcef6,0xcef7,0xcef8, 0xcef9,0xcefa,0xcefb,0xcefc,
  0xcefd,0xcefe,0xceff,0x0000, 0xcf00,0xcf01,0xcf02,0xcf03,
  0xcf04,0xcf05,0xcf06,0xcf07, 0xcf08,0xcf09,0xcf0a,0xcf0b,
  0xcf0c,0xcf0d,0xcf0e,0xcf0f, 0xcf10,0x0000,0xcf11,0xcf12,
  0xcf13,0xcf14,0xcf15,0xcf16, 0xcf17,0xcf18,0xcf19,0xcf1a,
  0xcf1b,0x0000,0x0000,0x0000, 0xcf1c,0xcf1d,0xcf1e,0xcf1f,
  0xcf20,0xcf21,0xcf22,0xcf23, 0xcf24,0xcf25,0xcf26,0xcf27,
  0xcf28,0xcf29,0xcf2a,0xcf2b, 0xcf2c,0x0000,0xcf2d,0xcf2e,
  0xcf2f,0xcf30,0xcf31,0xcf32, 0xcf33,0xcf34,0xcf35,0xcf36,
  0xcf37,0x0000,0xcf38,0xcf39, 0xcf3a,0xcf3b,0xcf3c,0xcf3d,
  0xcf3e,0xcf3f,0xcf40,0xcf41, 0xcf42,0xcf43,0xcf44,0xcf45,
  0xcf46,0xcf47,0xcf48,0x0000, 0xcf49,0xcf4a,0xcf4b,0xcf4c,
  0xcf4d,0xcf4e,0xcf4f,0xcf50, 0xcf51,0xcf52,0xcf53,0x0000,
  0x0000,0x0000,0xcf54,0xcf55, 0xcf56,0xcf57,0xcf58,0xcf59,
  0xcf5a,0xcf5b,0xcf5c,0xcf5d, 0xcf5e,0xcf5f,0xcf60,0xcf61,
  0xcf62,0xcf63,0xcf64,0x0000, 0xcf65,0xcf66,0xcf67,0xcf68,
  0xcf69,0xcf6a,0xcf6b,0xcf6c, 0xcf6d,0xcf6e,0xcf6f,0x0000,
  0x0000,0x0000,0xcf70,0xcf71, 0xcf72,0xcf73,0xcf74,0xcf75,
  0xcf76,0xcf77,0xcf78,0xcf79, 0xcf7a,0xcf7b,0xcf7c,0xcf7d,
  0xcf7e,0xcf7f,0xcf80,0x0000, 0xcf81,0xcf82,0xcf83,0xcf84,
  0xcf85,0xcf86,0xcf87,0xcf88, 0xcf89,0xcf8a,0xcf8b,0x0000,
  0x0000,0x0000,0xcf8c,0xcf8d, 0xcf8e,0xcf8f,0xcf90,0xcf91,
  0xcf92,0xcf93,0xcf94,0xcf95, 0xcf96,0xcf97,0xcf98,0xcf99,
  0xcf9a,0xcf9b,0xcf9c,0x0000, 0xcf9d,0xcf9e,0xcf9f,0xcfa0,
  0xcfa1,0xcfa2,0xcfa3,0xcfa4, 0xcfa5,0xcfa6,0xcfa7,0x0000,
  0xcfa8,0xcfa9,0xcfaa,0xcfab, 0xcfac,0xcfad,0xcfae,0xcfaf,
  0xcfb0,0xcfb1,0xcfb2,0xcfb3, 0xcfb4,0xcfb5,0xcfb6,0xcfb7,
  0xcfb8,0x0000,0xcfb9,0xcfba, 0xcfbb,0xcfbc,0xcfbd,0xcfbe,
  0xcfbf,0xcfc0,0xcfc1,0xcfc2, 0xcfc3,0x0000,0x0000,0x0000,
  0xcfc4,0xcfc5,0xcfc6,0xcfc7, 0xcfc8,0xcfc9,0xcfca,0xcfcb,
  0xcfcc,0xcfcd,0xcfce,0xcfcf, 0xcfd0,0xcfd1,0xcfd2,0xcfd3,
  0xcfd4,0x0000,0xcfd5,0xcfd6, 0xcfd7,0xcfd8,0xcfd9,0xcfda,
  0xcfdb,0xcfdc,0xcfdd,0xcfde, 0xcfdf,0x0000,0xcfe0,0xcfe1,
  0xcfe2,0xcfe3,0xcfe4,0xcfe5, 0xcfe6,0xcfe7,0xcfe8,0xcfe9,
  0xcfea,0xcfeb,0xcfec,0xcfed, 0xcfee,0xcfef,0xcff0,0x0000,
  0xcff1,0xcff2,0xcff3,0xcff4, 0xcff5,0xcff6,0xcff7,0xcff8,
  0xcff9,0xcffa,0xcffb,0x0000, 0x0000,0x0000,0xcffc,0xcffd,
  0xcffe,0xcfff,0xd000,0xd001, 0xd002,0xd003,0xd004,0xd005,
  0xd006,0xd007,0xd008,0xd009, 0xd00a,0xd00b,0xd00c,0x0000,
  0xd00d,0xd00e,0xd00f,0xd010, 0xd011,0xd012,0xd013,0xd014,
  0xd015,0xd016,0xd017,0x0000, 0x0000,0x0000,0xd018,0xd019,
  0xd01a,0xd01b,0xd01c,0xd01d, 0xd01e,0xd01f,0xd020,0xd021,
  0xd022,0xd023,0xd024,0xd025, 0xd026,0xd027,0xd028,0x0000,
  0xd029,0xd02a,0xd02b,0xd02c, 0xd02d,0xd02e,0xd02f,0xd030,
  0xd031,0xd032,0xd033,0x0000, 0x0000,0x0000,0xd034,0xd035,
  0xd036,0xd037,0xd038,0xd039, 0xd03a,0xd03b,0xd03c,0xd03d,
  0xd03e,0xd03f,0xd040,0xd041, 0xd042,0xd043,0xd044,0x0000,
  0xd045,0xd046,0xd047,0xd048, 0xd049,0xd04a,0xd04b,0xd04c,
  0xd04d,0xd04e,0xd04f,0x0000, 0xd050,0xd051,0xd052,0xd053,
  0xd054,0xd055,0xd056,0xd057, 0xd058,0xd059,0xd05a,0xd05b,
  0xd05c,0xd05d,0xd05e,0xd05f, 0xd060,0x0000,0xd061,0xd062,
  0xd063,0xd064,0xd065,0xd066, 0xd067,0xd068,0xd069,0xd06a,
  0xd06b,0x0000,0x0000,0x0000, 0xd06c,0xd06d,0xd06e,0xd06f,
  0xd070,0xd071,0xd072,0xd073, 0xd074,0xd075,0xd076,0xd077,
  0xd078,0xd079,0xd07a,0xd07b, 0xd07c,0x0000,0xd07d,0xd07e,
  0xd07f,0xd080,0xd081,0xd082, 0xd083,0xd084,0xd085,0xd086,
  0xd087,0x0000,0xd088,0xd089, 0xd08a,0xd08b,0xd08c,0xd08d,
  0xd08e,0xd08f,0xd090,0xd091, 0xd092,0xd093,0xd094,0xd095,
  0xd096,0xd097,0xd098,0x0000, 0xd099,0xd09a,0xd09b,0xd09c,
  0xd09d,0xd09e,0xd09f,0xd0a0, 0xd0a1,0xd0a2,0xd0a3,0x0000,
  0x0000,0x0000,0xd0a4,0xd0a5, 0xd0a6,0xd0a7,0xd0a8,0xd0a9,
  0xd0aa,0xd0ab,0xd0ac,0xd0ad, 0xd0ae,0xd0af,0xd0b0,0xd0b1,
  0xd0b2,0xd0b3,0xd0b4,0x0000, 0xd0b5,0xd0b6,0xd0b7,0xd0b8,
  0xd0b9,0xd0ba,0xd0bb,0xd0bc, 0xd0bd,0xd0be,0xd0bf,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x314c,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd0c0,0xd0c1,0xd0c2,0xd0c3, 0xd0c4,0xd0c5,0xd0c6,0xd0c7,
  0xd0c8,0xd0c9,0xd0ca,0xd0cb, 0xd0cc,0xd0cd,0xd0ce,0xd0cf,
  0xd0d0,0x0000,0xd0d1,0xd0d2, 0xd0d3,0xd0d4,0xd0d5,0xd0d6,
  0xd0d7,0xd0d8,0xd0d9,0xd0da, 0xd0db,0x0000,0xd0dc,0xd0dd,
  0xd0de,0xd0df,0xd0e0,0xd0e1, 0xd0e2,0xd0e3,0xd0e4,0xd0e5,
  0xd0e6,0xd0e7,0xd0e8,0xd0e9, 0xd0ea,0xd0eb,0xd0ec,0x0000,
  0xd0ed,0xd0ee,0xd0ef,0xd0f0, 0xd0f1,0xd0f2,0xd0f3,0xd0f4,
  0xd0f5,0xd0f6,0xd0f7,0x0000, 0x0000,0x0000,0xd0f8,0xd0f9,
  0xd0fa,0xd0fb,0xd0fc,0xd0fd, 0xd0fe,0xd0ff,0xd100,0xd101,
  0xd102,0xd103,0xd104,0xd105, 0xd106,0xd107,0xd108,0x0000,
  0xd109,0xd10a,0xd10b,0xd10c, 0xd10d,0xd10e,0xd10f,0xd110,
  0xd111,0xd112,0xd113,0x0000, 0x0000,0x0000,0xd114,0xd115,
  0xd116,0xd117,0xd118,0xd119, 0xd11a,0xd11b,0xd11c,0xd11d,
  0xd11e,0xd11f,0xd120,0xd121, 0xd122,0xd123,0xd124,0x0000,
  0xd125,0xd126,0xd127,0xd128, 0xd129,0xd12a,0xd12b,0xd12c,
  0xd12d,0xd12e,0xd12f,0x0000, 0x0000,0x0000,0xd130,0xd131,
  0xd132,0xd133,0xd134,0xd135, 0xd136,0xd137,0xd138,0xd139,
  0xd13a,0xd13b,0xd13c,0xd13d, 0xd13e,0xd13f,0xd140,0x0000,
  0xd141,0xd142,0xd143,0xd144, 0xd145,0xd146,0xd147,0xd148,
  0xd149,0xd14a,0xd14b,0x0000, 0xd14c,0xd14d,0xd14e,0xd14f,
  0xd150,0xd151,0xd152,0xd153, 0xd154,0xd155,0xd156,0xd157,
  0xd158,0xd159,0xd15a,0xd15b, 0xd15c,0x0000,0xd15d,0xd15e,
  0xd15f,0xd160,0xd161,0xd162, 0xd163,0xd164,0xd165,0xd166,
  0xd167,0x0000,0x0000,0x0000, 0xd168,0xd169,0xd16a,0xd16b,
  0xd16c,0xd16d,0xd16e,0xd16f, 0xd170,0xd171,0xd172,0xd173,
  0xd174,0xd175,0xd176,0xd177, 0xd178,0x0000,0xd179,0xd17a,
  0xd17b,0xd17c,0xd17d,0xd17e, 0xd17f,0xd180,0xd181,0xd182,
  0xd183,0x0000,0xd184,0xd185, 0xd186,0xd187,0xd188,0xd189,
  0xd18a,0xd18b,0xd18c,0xd18d, 0xd18e,0xd18f,0xd190,0xd191,
  0xd192,0xd193,0xd194,0x0000, 0xd195,0xd196,0xd197,0xd198,
  0xd199,0xd19a,0xd19b,0xd19c, 0xd19d,0xd19e,0xd19f,0x0000,
  0x0000,0x0000,0xd1a0,0xd1a1, 0xd1a2,0xd1a3,0xd1a4,0xd1a5,
  0xd1a6,0xd1a7,0xd1a8,0xd1a9, 0xd1aa,0xd1ab,0xd1ac,0xd1ad,
  0xd1ae,0xd1af,0xd1b0,0x0000, 0xd1b1,0xd1b2,0xd1b3,0xd1b4,
  0xd1b5,0xd1b6,0xd1b7,0xd1b8, 0xd1b9,0xd1ba,0xd1bb,0x0000,
  0x0000,0x0000,0xd1bc,0xd1bd, 0xd1be,0xd1bf,0xd1c0,0xd1c1,
  0xd1c2,0xd1c3,0xd1c4,0xd1c5, 0xd1c6,0xd1c7,0xd1c8,0xd1c9,
  0xd1ca,0xd1cb,0xd1cc,0x0000, 0xd1cd,0xd1ce,0xd1cf,0xd1d0,
  0xd1d1,0xd1d2,0xd1d3,0xd1d4, 0xd1d5,0xd1d6,0xd1d7,0x0000,
  0x0000,0x0000,0xd1d8,0xd1d9, 0xd1da,0xd1db,0xd1dc,0xd1dd,
  0xd1de,0xd1df,0xd1e0,0xd1e1, 0xd1e2,0xd1e3,0xd1e4,0xd1e5,
  0xd1e6,0xd1e7,0xd1e8,0x0000, 0xd1e9,0xd1ea,0xd1eb,0xd1ec,
  0xd1ed,0xd1ee,0xd1ef,0xd1f0, 0xd1f1,0xd1f2,0xd1f3,0x0000,
  0xd1f4,0xd1f5,0xd1f6,0xd1f7, 0xd1f8,0xd1f9,0xd1fa,0xd1fb,
  0xd1fc,0xd1fd,0xd1fe,0xd1ff, 0xd200,0xd201,0xd202,0xd203,
  0xd204,0x0000,0xd205,0xd206, 0xd207,0xd208,0xd209,0xd20a,
  0xd20b,0xd20c,0xd20d,0xd20e, 0xd20f,0x0000,0x0000,0x0000,
  0xd210,0xd211,0xd212,0xd213, 0xd214,0xd215,0xd216,0xd217,
  0xd218,0xd219,0xd21a,0xd21b, 0xd21c,0xd21d,0xd21e,0xd21f,
  0xd220,0x0000,0xd221,0xd222, 0xd223,0xd224,0xd225,0xd226,
  0xd227,0xd228,0xd229,0xd22a, 0xd22b,0x0000,0xd22c,0xd22d,
  0xd22e,0xd22f,0xd230,0xd231, 0xd232,0xd233,0xd234,0xd235,
  0xd236,0xd237,0xd238,0xd239, 0xd23a,0xd23b,0xd23c,0x0000,
  0xd23d,0xd23e,0xd23f,0xd240, 0xd241,0xd242,0xd243,0xd244,
  0xd245,0xd246,0xd247,0x0000, 0x0000,0x0000,0xd248,0xd249,
  0xd24a,0xd24b,0xd24c,0xd24d, 0xd24e,0xd24f,0xd250,0xd251,
  0xd252,0xd253,0xd254,0xd255, 0xd256,0xd257,0xd258,0x0000,
  0xd259,0xd25a,0xd25b,0xd25c, 0xd25d,0xd25e,0xd25f,0xd260,
  0xd261,0xd262,0xd263,0x0000, 0x0000,0x0000,0xd264,0xd265,
  0xd266,0xd267,0xd268,0xd269, 0xd26a,0xd26b,0xd26c,0xd26d,
  0xd26e,0xd26f,0xd270,0xd271, 0xd272,0xd273,0xd274,0x0000,
  0xd275,0xd276,0xd277,0xd278, 0xd279,0xd27a,0xd27b,0xd27c,
  0xd27d,0xd27e,0xd27f,0x0000, 0x0000,0x0000,0xd280,0xd281,
  0xd282,0xd283,0xd284,0xd285, 0xd286,0xd287,0xd288,0xd289,
  0xd28a,0xd28b,0xd28c,0xd28d, 0xd28e,0xd28f,0xd290,0x0000,
  0xd291,0xd292,0xd293,0xd294, 0xd295,0xd296,0xd297,0xd298,
  0xd299,0xd29a,0xd29b,0x0000, 0xd29c,0xd29d,0xd29e,0xd29f,
  0xd2a0,0xd2a1,0xd2a2,0xd2a3, 0xd2a4,0xd2a5,0xd2a6,0xd2a7,
  0xd2a8,0xd2a9,0xd2aa,0xd2ab, 0xd2ac,0x0000,0xd2ad,0xd2ae,
  0xd2af,0xd2b0,0xd2b1,0xd2b2, 0xd2b3,0xd2b4,0xd2b5,0xd2b6,
  0xd2b7,0x0000,0x0000,0x0000, 0xd2b8,0xd2b9,0xd2ba,0xd2bb,
  0xd2bc,0xd2bd,0xd2be,0xd2bf, 0xd2c0,0xd2c1,0xd2c2,0xd2c3,
  0xd2c4,0xd2c5,0xd2c6,0xd2c7, 0xd2c8,0x0000,0xd2c9,0xd2ca,
  0xd2cb,0xd2cc,0xd2cd,0xd2ce, 0xd2cf,0xd2d0,0xd2d1,0xd2d2,
  0xd2d3,0x0000,0xd2d4,0xd2d5, 0xd2d6,0xd2d7,0xd2d8,0xd2d9,
  0xd2da,0xd2db,0xd2dc,0xd2dd, 0xd2de,0xd2df,0xd2e0,0xd2e1,
  0xd2e2,0xd2e3,0xd2e4,0x0000, 0xd2e5,0xd2e6,0xd2e7,0xd2e8,
  0xd2e9,0xd2ea,0xd2eb,0xd2ec, 0xd2ed,0xd2ee,0xd2ef,0x0000,
  0x0000,0x0000,0xd2f0,0xd2f1, 0xd2f2,0xd2f3,0xd2f4,0xd2f5,
  0xd2f6,0xd2f7,0xd2f8,0xd2f9, 0xd2fa,0xd2fb,0xd2fc,0xd2fd,
  0xd2fe,0xd2ff,0xd300,0x0000, 0xd301,0xd302,0xd303,0xd304,
  0xd305,0xd306,0xd307,0xd308, 0xd309,0xd30a,0xd30b,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x314d,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd30c,0xd30d,0xd30e,0xd30f, 0xd310,0xd311,0xd312,0xd313,
  0xd314,0xd315,0xd316,0xd317, 0xd318,0xd319,0xd31a,0xd31b,
  0xd31c,0x0000,0xd31d,0xd31e, 0xd31f,0xd320,0xd321,0xd322,
  0xd323,0xd324,0xd325,0xd326, 0xd327,0x0000,0xd328,0xd329,
  0xd32a,0xd32b,0xd32c,0xd32d, 0xd32e,0xd32f,0xd330,0xd331,
  0xd332,0xd333,0xd334,0xd335, 0xd336,0xd337,0xd338,0x0000,
  0xd339,0xd33a,0xd33b,0xd33c, 0xd33d,0xd33e,0xd33f,0xd340,
  0xd341,0xd342,0xd343,0x0000, 0x0000,0x0000,0xd344,0xd345,
  0xd346,0xd347,0xd348,0xd349, 0xd34a,0xd34b,0xd34c,0xd34d,
  0xd34e,0xd34f,0xd350,0xd351, 0xd352,0xd353,0xd354,0x0000,
  0xd355,0xd356,0xd357,0xd358, 0xd359,0xd35a,0xd35b,0xd35c,
  0xd35d,0xd35e,0xd35f,0x0000, 0x0000,0x0000,0xd360,0xd361,
  0xd362,0xd363,0xd364,0xd365, 0xd366,0xd367,0xd368,0xd369,
  0xd36a,0xd36b,0xd36c,0xd36d, 0xd36e,0xd36f,0xd370,0x0000,
  0xd371,0xd372,0xd373,0xd374, 0xd375,0xd376,0xd377,0xd378,
  0xd379,0xd37a,0xd37b,0x0000, 0x0000,0x0000,0xd37c,0xd37d,
  0xd37e,0xd37f,0xd380,0xd381, 0xd382,0xd383,0xd384,0xd385,
  0xd386,0xd387,0xd388,0xd389, 0xd38a,0xd38b,0xd38c,0x0000,
  0xd38d,0xd38e,0xd38f,0xd390, 0xd391,0xd392,0xd393,0xd394,
  0xd395,0xd396,0xd397,0x0000, 0xd398,0xd399,0xd39a,0xd39b,
  0xd39c,0xd39d,0xd39e,0xd39f, 0xd3a0,0xd3a1,0xd3a2,0xd3a3,
  0xd3a4,0xd3a5,0xd3a6,0xd3a7, 0xd3a8,0x0000,0xd3a9,0xd3aa,
  0xd3ab,0xd3ac,0xd3ad,0xd3ae, 0xd3af,0xd3b0,0xd3b1,0xd3b2,
  0xd3b3,0x0000,0x0000,0x0000, 0xd3b4,0xd3b5,0xd3b6,0xd3b7,
  0xd3b8,0xd3b9,0xd3ba,0xd3bb, 0xd3bc,0xd3bd,0xd3be,0xd3bf,
  0xd3c0,0xd3c1,0xd3c2,0xd3c3, 0xd3c4,0x0000,0xd3c5,0xd3c6,
  0xd3c7,0xd3c8,0xd3c9,0xd3ca, 0xd3cb,0xd3cc,0xd3cd,0xd3ce,
  0xd3cf,0x0000,0xd3d0,0xd3d1, 0xd3d2,0xd3d3,0xd3d4,0xd3d5,
  0xd3d6,0xd3d7,0xd3d8,0xd3d9, 0xd3da,0xd3db,0xd3dc,0xd3dd,
  0xd3de,0xd3df,0xd3e0,0x0000, 0xd3e1,0xd3e2,0xd3e3,0xd3e4,
  0xd3e5,0xd3e6,0xd3e7,0xd3e8, 0xd3e9,0xd3ea,0xd3eb,0x0000,
  0x0000,0x0000,0xd3ec,0xd3ed, 0xd3ee,0xd3ef,0xd3f0,0xd3f1,
  0xd3f2,0xd3f3,0xd3f4,0xd3f5, 0xd3f6,0xd3f7,0xd3f8,0xd3f9,
  0xd3fa,0xd3fb,0xd3fc,0x0000, 0xd3fd,0xd3fe,0xd3ff,0xd400,
  0xd401,0xd402,0xd403,0xd404, 0xd405,0xd406,0xd407,0x0000,
  0x0000,0x0000,0xd408,0xd409, 0xd40a,0xd40b,0xd40c,0xd40d,
  0xd40e,0xd40f,0xd410,0xd411, 0xd412,0xd413,0xd414,0xd415,
  0xd416,0xd417,0xd418,0x0000, 0xd419,0xd41a,0xd41b,0xd41c,
  0xd41d,0xd41e,0xd41f,0xd420, 0xd421,0xd422,0xd423,0x0000,
  0x0000,0x0000,0xd424,0xd425, 0xd426,0xd427,0xd428,0xd429,
  0xd42a,0xd42b,0xd42c,0xd42d, 0xd42e,0xd42f,0xd430,0xd431,
  0xd432,0xd433,0xd434,0x0000, 0xd435,0xd436,0xd437,0xd438,
  0xd439,0xd43a,0xd43b,0xd43c, 0xd43d,0xd43e,0xd43f,0x0000,
  0xd440,0xd441,0xd442,0xd443, 0xd444,0xd445,0xd446,0xd447,
  0xd448,0xd449,0xd44a,0xd44b, 0xd44c,0xd44d,0xd44e,0xd44f,
  0xd450,0x0000,0xd451,0xd452, 0xd453,0xd454,0xd455,0xd456,
  0xd457,0xd458,0xd459,0xd45a, 0xd45b,0x0000,0x0000,0x0000,
  0xd45c,0xd45d,0xd45e,0xd45f, 0xd460,0xd461,0xd462,0xd463,
  0xd464,0xd465,0xd466,0xd467, 0xd468,0xd469,0xd46a,0xd46b,
  0xd46c,0x0000,0xd46d,0xd46e, 0xd46f,0xd470,0xd471,0xd472,
  0xd473,0xd474,0xd475,0xd476, 0xd477,0x0000,0xd478,0xd479,
  0xd47a,0xd47b,0xd47c,0xd47d, 0xd47e,0xd47f,0xd480,0xd481,
  0xd482,0xd483,0xd484,0xd485, 0xd486,0xd487,0xd488,0x0000,
  0xd489,0xd48a,0xd48b,0xd48c, 0xd48d,0xd48e,0xd48f,0xd490,
  0xd491,0xd492,0xd493,0x0000, 0x0000,0x0000,0xd494,0xd495,
  0xd496,0xd497,0xd498,0xd499, 0xd49a,0xd49b,0xd49c,0xd49d,
  0xd49e,0xd49f,0xd4a0,0xd4a1, 0xd4a2,0xd4a3,0xd4a4,0x0000,
  0xd4a5,0xd4a6,0xd4a7,0xd4a8, 0xd4a9,0xd4aa,0xd4ab,0xd4ac,
  0xd4ad,0xd4ae,0xd4af,0x0000, 0x0000,0x0000,0xd4b0,0xd4b1,
  0xd4b2,0xd4b3,0xd4b4,0xd4b5, 0xd4b6,0xd4b7,0xd4b8,0xd4b9,
  0xd4ba,0xd4bb,0xd4bc,0xd4bd, 0xd4be,0xd4bf,0xd4c0,0x0000,
  0xd4c1,0xd4c2,0xd4c3,0xd4c4, 0xd4c5,0xd4c6,0xd4c7,0xd4c8,
  0xd4c9,0xd4ca,0xd4cb,0x0000, 0x0000,0x0000,0xd4cc,0xd4cd,
  0xd4ce,0xd4cf,0xd4d0,0xd4d1, 0xd4d2,0xd4d3,0xd4d4,0xd4d5,
  0xd4d6,0xd4d7,0xd4d8,0xd4d9, 0xd4da,0xd4db,0xd4dc,0x0000,
  0xd4dd,0xd4de,0xd4df,0xd4e0, 0xd4e1,0xd4e2,0xd4e3,0xd4e4,
  0xd4e5,0xd4e6,0xd4e7,0x0000, 0xd4e8,0xd4e9,0xd4ea,0xd4eb,
  0xd4ec,0xd4ed,0xd4ee,0xd4ef, 0xd4f0,0xd4f1,0xd4f2,0xd4f3,
  0xd4f4,0xd4f5,0xd4f6,0xd4f7, 0xd4f8,0x0000,0xd4f9,0xd4fa,
  0xd4fb,0xd4fc,0xd4fd,0xd4fe, 0xd4ff,0xd500,0xd501,0xd502,
  0xd503,0x0000,0x0000,0x0000, 0xd504,0xd505,0xd506,0xd507,
  0xd508,0xd509,0xd50a,0xd50b, 0xd50c,0xd50d,0xd50e,0xd50f,
  0xd510,0xd511,0xd512,0xd513, 0xd514,0x0000,0xd515,0xd516,
  0xd517,0xd518,0xd519,0xd51a, 0xd51b,0xd51c,0xd51d,0xd51e,
  0xd51f,0x0000,0xd520,0xd521, 0xd522,0xd523,0xd524,0xd525,
  0xd526,0xd527,0xd528,0xd529, 0xd52a,0xd52b,0xd52c,0xd52d,
  0xd52e,0xd52f,0xd530,0x0000, 0xd531,0xd532,0xd533,0xd534,
  0xd535,0xd536,0xd537,0xd538, 0xd539,0xd53a,0xd53b,0x0000,
  0x0000,0x0000,0xd53c,0xd53d, 0xd53e,0xd53f,0xd540,0xd541,
  0xd542,0xd543,0xd544,0xd545, 0xd546,0xd547,0xd548,0xd549,
  0xd54a,0xd54b,0xd54c,0x0000, 0xd54d,0xd54e,0xd54f,0xd550,
  0xd551,0xd552,0xd553,0xd554, 0xd555,0xd556,0xd557,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x314e,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xd558,0xd559,0xd55a,0xd55b, 0xd55c,0xd55d,0xd55e,0xd55f,
  0xd560,0xd561,0xd562,0xd563, 0xd564,0xd565,0xd566,0xd567,
  0xd568,0x0000,0xd569,0xd56a, 0xd56b,0xd56c,0xd56d,0xd56e,
  0xd56f,0xd570,0xd571,0xd572, 0xd573,0x0000,0xd574,0xd575,
  0xd576,0xd577,0xd578,0xd579, 0xd57a,0xd57b,0xd57c,0xd57d,
  0xd57e,0xd57f,0xd580,0xd581, 0xd582,0xd583,0xd584,0x0000,
  0xd585,0xd586,0xd587,0xd588, 0xd589,0xd58a,0xd58b,0xd58c,
  0xd58d,0xd58e,0xd58f,0x0000, 0x0000,0x0000,0xd590,0xd591,
  0xd592,0xd593,0xd594,0xd595, 0xd596,0xd597,0xd598,0xd599,
  0xd59a,0xd59b,0xd59c,0xd59d, 0xd59e,0xd59f,0xd5a0,0x0000,
  0xd5a1,0xd5a2,0xd5a3,0xd5a4, 0xd5a5,0xd5a6,0xd5a7,0xd5a8,
  0xd5a9,0xd5aa,0xd5ab,0x0000, 0x0000,0x0000,0xd5ac,0xd5ad,
  0xd5ae,0xd5af,0xd5b0,0xd5b1, 0xd5b2,0xd5b3,0xd5b4,0xd5b5,
  0xd5b6,0xd5b7,0xd5b8,0xd5b9, 0xd5ba,0xd5bb,0xd5bc,0x0000,
  0xd5bd,0xd5be,0xd5bf,0xd5c0, 0xd5c1,0xd5c2,0xd5c3,0xd5c4,
  0xd5c5,0xd5c6,0xd5c7,0x0000, 0x0000,0x0000,0xd5c8,0xd5c9,
  0xd5ca,0xd5cb,0xd5cc,0xd5cd, 0xd5ce,0xd5cf,0xd5d0,0xd5d1,
  0xd5d2,0xd5d3,0xd5d4,0xd5d5, 0xd5d6,0xd5d7,0xd5d8,0x0000,
  0xd5d9,0xd5da,0xd5db,0xd5dc, 0xd5dd,0xd5de,0xd5df,0xd5e0,
  0xd5e1,0xd5e2,0xd5e3,0x0000, 0xd5e4,0xd5e5,0xd5e6,0xd5e7,
  0xd5e8,0xd5e9,0xd5ea,0xd5eb, 0xd5ec,0xd5ed,0xd5ee,0xd5ef,
  0xd5f0,0xd5f1,0xd5f2,0xd5f3, 0xd5f4,0x0000,0xd5f5,0xd5f6,
  0xd5f7,0xd5f8,0xd5f9,0xd5fa, 0xd5fb,0xd5fc,0xd5fd,0xd5fe,
  0xd5ff,0x0000,0x0000,0x0000, 0xd600,0xd601,0xd602,0xd603,
  0xd604,0xd605,0xd606,0xd607, 0xd608,0xd609,0xd60a,0xd60b,
  0xd60c,0xd60d,0xd60e,0xd60f, 0xd610,0x0000,0xd611,0xd612,
  0xd613,0xd614,0xd615,0xd616, 0xd617,0xd618,0xd619,0xd61a,
  0xd61b,0x0000,0xd61c,0xd61d, 0xd61e,0xd61f,0xd620,0xd621,
  0xd622,0xd623,0xd624,0xd625, 0xd626,0xd627,0xd628,0xd629,
  0xd62a,0xd62b,0xd62c,0x0000, 0xd62d,0xd62e,0xd62f,0xd630,
  0xd631,0xd632,0xd633,0xd634, 0xd635,0xd636,0xd637,0x0000,
  0x0000,0x0000,0xd638,0xd639, 0xd63a,0xd63b,0xd63c,0xd63d,
  0xd63e,0xd63f,0xd640,0xd641, 0xd642,0xd643,0xd644,0xd645,
  0xd646,0xd647,0xd648,0x0000, 0xd649,0xd64a,0xd64b,0xd64c,
  0xd64d,0xd64e,0xd64f,0xd650, 0xd651,0xd652,0xd653,0x0000,
  0x0000,0x0000,0xd654,0xd655, 0xd656,0xd657,0xd658,0xd659,
  0xd65a,0xd65b,0xd65c,0xd65d, 0xd65e,0xd65f,0xd660,0xd661,
  0xd662,0xd663,0xd664,0x0000, 0xd665,0xd666,0xd667,0xd668,
  0xd669,0xd66a,0xd66b,0xd66c, 0xd66d,0xd66e,0xd66f,0x0000,
  0x0000,0x0000,0xd670,0xd671, 0xd672,0xd673,0xd674,0xd675,
  0xd676,0xd677,0xd678,0xd679, 0xd67a,0xd67b,0xd67c,0xd67d,
  0xd67e,0xd67f,0xd680,0x0000, 0xd681,0xd682,0xd683,0xd684,
  0xd685,0xd686,0xd687,0xd688, 0xd689,0xd68a,0xd68b,0x0000,
  0xd68c,0xd68d,0xd68e,0xd68f, 0xd690,0xd691,0xd692,0xd693,
  0xd694,0xd695,0xd696,0xd697, 0xd698,0xd699,0xd69a,0xd69b,
  0xd69c,0x0000,0xd69d,0xd69e, 0xd69f,0xd6a0,0xd6a1,0xd6a2,
  0xd6a3,0xd6a4,0xd6a5,0xd6a6, 0xd6a7,0x0000,0x0000,0x0000,
  0xd6a8,0xd6a9,0xd6aa,0xd6ab, 0xd6ac,0xd6ad,0xd6ae,0xd6af,
  0xd6b0,0xd6b1,0xd6b2,0xd6b3, 0xd6b4,0xd6b5,0xd6b6,0xd6b7,
  0xd6b8,0x0000,0xd6b9,0xd6ba, 0xd6bb,0xd6bc,0xd6bd,0xd6be,
  0xd6bf,0xd6c0,0xd6c1,0xd6c2, 0xd6c3,0x0000,0xd6c4,0xd6c5,
  0xd6c6,0xd6c7,0xd6c8,0xd6c9, 0xd6ca,0xd6cb,0xd6cc,0xd6cd,
  0xd6ce,0xd6cf,0xd6d0,0xd6d1, 0xd6d2,0xd6d3,0xd6d4,0x0000,
  0xd6d5,0xd6d6,0xd6d7,0xd6d8, 0xd6d9,0xd6da,0xd6db,0xd6dc,
  0xd6dd,0xd6de,0xd6df,0x0000, 0x0000,0x0000,0xd6e0,0xd6e1,
  0xd6e2,0xd6e3,0xd6e4,0xd6e5, 0xd6e6,0xd6e7,0xd6e8,0xd6e9,
  0xd6ea,0xd6eb,0xd6ec,0xd6ed, 0xd6ee,0xd6ef,0xd6f0,0x0000,
  0xd6f1,0xd6f2,0xd6f3,0xd6f4, 0xd6f5,0xd6f6,0xd6f7,0xd6f8,
  0xd6f9,0xd6fa,0xd6fb,0x0000, 0x0000,0x0000,0xd6fc,0xd6fd,
  0xd6fe,0xd6ff,0xd700,0xd701, 0xd702,0xd703,0xd704,0xd705,
  0xd706,0xd707,0xd708,0xd709, 0xd70a,0xd70b,0xd70c,0x0000,
  0xd70d,0xd70e,0xd70f,0xd710, 0xd711,0xd712,0xd713,0xd714,
  0xd715,0xd716,0xd717,0x0000, 0x0000,0x0000,0xd718,0xd719,
  0xd71a,0xd71b,0xd71c,0xd71d, 0xd71e,0xd71f,0xd720,0xd721,
  0xd722,0xd723,0xd724,0xd725, 0xd726,0xd727,0xd728,0x0000,
  0xd729,0xd72a,0xd72b,0xd72c, 0xd72d,0xd72e,0xd72f,0xd730,
  0xd731,0xd732,0xd733,0x0000, 0xd734,0xd735,0xd736,0xd737,
  0xd738,0xd739,0xd73a,0xd73b, 0xd73c,0xd73d,0xd73e,0xd73f,
  0xd740,0xd741,0xd742,0xd743, 0xd744,0x0000,0xd745,0xd746,
  0xd747,0xd748,0xd749,0xd74a, 0xd74b,0xd74c,0xd74d,0xd74e,
  0xd74f,0x0000,0x0000,0x0000, 0xd750,0xd751,0xd752,0xd753,
  0xd754,0xd755,0xd756,0xd757, 0xd758,0xd759,0xd75a,0xd75b,
  0xd75c,0xd75d,0xd75e,0xd75f, 0xd760,0x0000,0xd761,0xd762,
  0xd763,0xd764,0xd765,0xd766, 0xd767,0xd768,0xd769,0xd76a,
  0xd76b,0x0000,0xd76c,0xd76d, 0xd76e,0xd76f,0xd770,0xd771,
  0xd772,0xd773,0xd774,0xd775, 0xd776,0xd777,0xd778,0xd779,
  0xd77a,0xd77b,0xd77c,0x0000, 0xd77d,0xd77e,0xd77f,0xd780,
  0xd781,0xd782,0xd783,0xd784, 0xd785,0xd786,0xd787,0x0000,
  0x0000,0x0000,0xd788,0xd789, 0xd78a,0xd78b,0xd78c,0xd78d,
  0xd78e,0xd78f,0xd790,0xd791, 0xd792,0xd793,0xd794,0xd795,
  0xd796,0xd797,0xd798,0x0000, 0xd799,0xd79a,0xd79b,0xd79c,
  0xd79d,0xd79e,0xd79f,0xd7a0, 0xd7a1,0xd7a2,0xd7a3,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000
};

unsigned short uni_t_cns11643_1[ISOMB_CODE_END] = {
  0x3000,0xff0c,0x3001,0x3002, 0xff0e,0x30fb,0xff1b,0xff1a,
  0xff1f,0xff01,0xfe30,0x2026, 0x2025,0xfe50,0xfe51,0xfe52,
  0x00b7,0xfe54,0xfe55,0xfe56, 0xfe57,0xfe31,0x2014,0xfe32,
  0x2013,0xfe33,0x203e,0xfe34, 0xfe4f,0xff08,0xff09,0xfe35,
  0xfe36,0xff5b,0xff5d,0xfe37, 0xfe38,0x3014,0x3015,0xfe39,
  0xfe3a,0x3010,0x3011,0xfe3b, 0xfe3c,0x300a,0x300b,0xfe3d,
  0xfe3e,0x3008,0x3009,0xfe3f, 0xfe40,0x300c,0x300d,0xfe41,
  0xfe42,0x300e,0x300f,0xfe43, 0xfe44,0xfe59,0xfe5a,0xfe5b,
  0xfe5c,0xfe5d,0xfe5e,0x2018, 0x2019,0x201c,0x201d,0x301d,
  0x301e,0x2032,0x2035,0xff03, 0xff06,0xff0a,0x203b,0x00a7,
  0x3003,0x25cb,0x25cf,0x25b3, 0x25b2,0x25ce,0x2606,0x2605,
  0x25c7,0x25c6,0x25a1,0x25a0, 0x25bd,0x25bc,0x32a3,0x2105,
  0x203e,0x0000,0xff3f,0x0000, 0xfe49,0xfe4a,0xfe4d,0xfe4e,
  0xfe4b,0xfe4c,0xfe5f,0xfe60, 0xfe61,0xff0b,0xff0d,0x00d7,
  0x00f7,0x00b1,0x221a,0xff1c, 0xff1e,0xff1d,0x2266,0x2267,
  0x2260,0x221e,0x2252,0x2261, 0xfe62,0xfe63,0xfe64,0xfe66,
  0xfe65,0x223c,0x2229,0x222a, 0x22a5,0x2220,0x221f,0x22bf,
  0x33d2,0x33d1,0x222b,0x222e, 0x2235,0x2234,0x2640,0x2642,
  0x2641,0x2609,0x2191,0x2193, 0x2192,0x2190,0x2196,0x2197,
  0x2199,0x2198,0x2016,0xff5c, 0xff0f,0xff3c,0x2215,0xfe68,
  0xff04,0xffe5,0x3012,0xffe0, 0xffe1,0xff05,0xff20,0x2103,
  0x2109,0xfe69,0xfe6a,0xfe6b, 0x33d5,0x339c,0x339d,0x339e,
  0x33ce,0x33a1,0x338e,0x338f, 0x33c4,0x00b0,0x5159,0x515b,
  0x515e,0x515d,0x5161,0x5163, 0x55e7,0x74e9,0x7cce,0x2581,
  0x2582,0x2583,0x2584,0x2585, 0x2586,0x2587,0x2588,0x258f,
  0x258e,0x258d,0x258c,0x258b, 0x258a,0x2589,0x253c,0x2534,
  0x252c,0x2524,0x251c,0x2594, 0x2500,0x2502,0x2595,0x250c,
  0x2510,0x2514,0x2518,0x256d, 0x256e,0x2570,0x256f,0x2550,
  0x255e,0x256a,0x2561,0x25e2, 0x25e3,0x25e5,0x25e4,0x2571,
  0x2572,0x2573,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0xff10,0xff11, 0xff12,0xff13,0xff14,0xff15,
  0xff16,0xff17,0xff18,0xff19, 0x2160,0x2161,0x2162,0x2163,
  0x2164,0x2165,0x2166,0x2167, 0x2168,0x2169,0x3021,0x3022,
  0x3023,0x3024,0x3025,0x3026, 0x3027,0x3028,0x3029,0x3038,
  0x5344,0x303a,0xff21,0xff22, 0xff23,0xff24,0xff25,0xff26,
  0xff27,0xff28,0xff29,0xff2a, 0xff2b,0xff2c,0xff2d,0xff2e,
  0xff2f,0xff30,0xff31,0xff32, 0xff33,0xff34,0xff35,0xff36,
  0xff37,0xff38,0xff39,0xff3a, 0xff41,0xff42,0xff43,0xff44,
  0xff45,0xff46,0xff47,0xff48, 0xff49,0xff4a,0xff4b,0xff4c,
  0xff4d,0xff4e,0xff4f,0xff50, 0xff51,0xff52,0xff53,0xff54,
  0xff55,0xff56,0xff57,0xff58, 0xff59,0xff5a,0x0391,0x0392,
  0x0393,0x0394,0x0395,0x0396, 0x0397,0x0398,0x0399,0x039a,
  0x039b,0x039c,0x039d,0x039e, 0x039f,0x03a0,0x03a1,0x03a3,
  0x03a4,0x03a5,0x03a6,0x03a7, 0x03a8,0x03a9,0x03b1,0x03b2,
  0x03b3,0x03b4,0x03b5,0x03b6, 0x03b7,0x03b8,0x03b9,0x03ba,
  0x03bb,0x03bc,0x03bd,0x03be, 0x03bf,0x03c0,0x03c1,0x03c3,
  0x03c4,0x03c5,0x03c6,0x03c7, 0x03c8,0x03c9,0x3105,0x3106,
  0x3107,0x3108,0x3109,0x310a, 0x310b,0x310c,0x310d,0x310e,
  0x310f,0x3110,0x3111,0x3112, 0x3113,0x3114,0x3115,0x3116,
  0x3117,0x3118,0x3119,0x311a, 0x311b,0x311c,0x311d,0x311e,
  0x311f,0x3120,0x3121,0x3122, 0x3123,0x3124,0x3125,0x3126,
  0x3127,0x3128,0x3129,0x02d9, 0x02c9,0x02ca,0x02c7,0x02cb,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x2460,0x2461,
  0x2462,0x2463,0x2464,0x2465, 0x2466,0x2467,0x2468,0x2469,
  0x2474,0x2475,0x2476,0x2477, 0x2478,0x2479,0x247a,0x247b,
  0x247c,0x247d,0x2170,0x2171, 0x2172,0x2173,0x2174,0x2175,
  0x2176,0x2177,0x2178,0x2179, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x2f00,0x2f01,0x2f02,0x2f03,
  0x2f04,0x2f05,0x2f06,0x2f07, 0x2f08,0x2f09,0x2f0a,0x2f0b,
  0x2f0c,0x2f0d,0x2f0e,0x2f0f, 0x2f10,0x2f11,0x2f12,0x2f13,
  0x2f14,0x2f15,0x2f16,0x2f17, 0x2f18,0x2f19,0x2f1a,0x2f1b,
  0x2f1c,0x2f1d,0x2f1e,0x2f1f, 0x2f20,0x2f21,0x2f22,0x2f23,
  0x2f24,0x2f25,0x2f26,0x2f27, 0x2f28,0x2f29,0x2f2a,0x2f2b,
  0x2f2c,0x2f2d,0x2f2e,0x2f2f, 0x2f30,0x2f31,0x2f32,0x2f33,
  0x2f34,0x2f35,0x2f36,0x2f37, 0x2f38,0x2f39,0x2f3a,0x2f3b,
  0x2f3c,0x2f3d,0x2f3e,0x2f3f, 0x2f40,0x2f41,0x2f42,0x2f43,
  0x2f44,0x2f45,0x2f46,0x2f47, 0x2f48,0x2f49,0x2f4a,0x2f4b,
  0x2f4c,0x2f4d,0x2f4e,0x2f4f, 0x2f50,0x2f51,0x2f52,0x2f53,
  0x2f54,0x2f55,0x2f56,0x2f57, 0x2f58,0x2f59,0x2f5a,0x2f5b,
  0x2f5c,0x2f5d,0x2f5e,0x2f5f, 0x2f60,0x2f61,0x2f62,0x2f63,
  0x2f64,0x2f65,0x2f66,0x2f67, 0x2f68,0x2f69,0x2f6a,0x2f6b,
  0x2f6c,0x2f6d,0x2f6e,0x2f6f, 0x2f70,0x2f71,0x2f72,0x2f73,
  0x2f74,0x2f75,0x2f76,0x2f77, 0x2f78,0x2f79,0x2f7a,0x2f7b,
  0x2f7c,0x2f7d,0x2f7e,0x2f7f, 0x2f80,0x2f81,0x2f82,0x2f83,
  0x2f84,0x2f85,0x2f86,0x2f87, 0x2f88,0x2f89,0x2f8a,0x2f8b,
  0x2f8c,0x2f8d,0x2f8e,0x2f8f, 0x2f90,0x2f91,0x2f92,0x2f93,
  0x2f94,0x2f95,0x2f96,0x2f97, 0x2f98,0x2f99,0x2f9a,0x2f9b,
  0x2f9c,0x2f9d,0x2f9e,0x2f9f, 0x2fa0,0x2fa1,0x2fa2,0x2fa3,
  0x2fa4,0x2fa5,0x2fa6,0x2fa7, 0x2fa8,0x2fa9,0x2faa,0x2fab,
  0x2fac,0x2fad,0x2fae,0x2faf, 0x2fb0,0x2fb1,0x2fb2,0x2fb3,
  0x2fb4,0x2fb5,0x2fb6,0x2fb7, 0x2fb8,0x2fb9,0x2fba,0x2fbb,
  0x2fbc,0x2fbd,0x2fbe,0x2fbf, 0x2fc0,0x2fc1,0x2fc2,0x2fc3,
  0x2fc4,0x2fc5,0x2fc6,0x2fc7, 0x2fc8,0x2fc9,0x2fca,0x2fcb,
  0x2fcc,0x2fcd,0x2fce,0x2fcf, 0x2fd0,0x2fd1,0x2fd2,0x2fd3,
  0x2fd4,0x2fd5,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x2400,0x2401,
  0x2402,0x2403,0x2404,0x2405, 0x2406,0x2407,0x2408,0x2409,
  0x240a,0x240b,0x240c,0x240d, 0x240e,0x240f,0x2410,0x2411,
  0x2412,0x2413,0x2414,0x2415, 0x2416,0x2417,0x2418,0x2419,
  0x241a,0x241b,0x241c,0x241d, 0x241e,0x241f,0x2421,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x4e00,0x4e59, 0x4e01,0x4e03,0x4e43,0x4e5d,
  0x4e86,0x4e8c,0x4eba,0x513f, 0x5165,0x516b,0x51e0,0x5200,
  0x5201,0x529b,0x5315,0x5341, 0x535c,0x53c8,0x4e09,0x4e0b,
  0x4e08,0x4e0a,0x4e2b,0x4e38, 0x51e1,0x4e45,0x4e48,0x4e5f,
  0x4e5e,0x4e8e,0x4ea1,0x5140, 0x5203,0x52fa,0x5343,0x53c9,
  0x53e3,0x571f,0x58eb,0x5915, 0x5927,0x5973,0x5b50,0x5b51,
  0x5b53,0x5bf8,0x5c0f,0x5c22, 0x5c38,0x5c71,0x5ddd,0x5de5,
  0x5df1,0x5df2,0x5df3,0x5dfe, 0x5e72,0x5efe,0x5f0b,0x5f13,
  0x624d,0x4e11,0x4e10,0x4e0d, 0x4e2d,0x4e30,0x4e39,0x4e4b,
  0x5c39,0x4e88,0x4e91,0x4e95, 0x4e92,0x4e94,0x4ea2,0x4ec1,
  0x4ec0,0x4ec3,0x4ec6,0x4ec7, 0x4ecd,0x4eca,0x4ecb,0x4ec4,
  0x5143,0x5141,0x5167,0x516d, 0x516e,0x516c,0x5197,0x51f6,
  0x5206,0x5207,0x5208,0x52fb, 0x52fe,0x52ff,0x5316,0x5339,
  0x5348,0x5347,0x5345,0x535e, 0x5384,0x53cb,0x53ca,0x53cd,
  0x58ec,0x5929,0x592b,0x592a, 0x592d,0x5b54,0x5c11,0x5c24,
  0x5c3a,0x5c6f,0x5df4,0x5e7b, 0x5eff,0x5f14,0x5f15,0x5fc3,
  0x6208,0x6236,0x624b,0x624e, 0x652f,0x6587,0x6597,0x65a4,
  0x65b9,0x65e5,0x66f0,0x6708, 0x6728,0x6b20,0x6b62,0x6b79,
  0x6bcb,0x6bd4,0x6bdb,0x6c0f, 0x6c34,0x706b,0x722a,0x7236,
  0x723b,0x7247,0x7259,0x725b, 0x72ac,0x738b,0x4e19,0x4e16,
  0x4e15,0x4e14,0x4e18,0x4e3b, 0x4e4d,0x4e4f,0x4e4e,0x4ee5,
  0x4ed8,0x4ed4,0x4ed5,0x4ed6, 0x4ed7,0x4ee3,0x4ee4,0x4ed9,
  0x4ede,0x5145,0x5144,0x5189, 0x518a,0x51ac,0x51f9,0x51fa,
  0x51f8,0x520a,0x52a0,0x529f, 0x5305,0x5306,0x5317,0x531d,
  0x4edf,0x534a,0x5349,0x5361, 0x5360,0x536f,0x536e,0x53bb,
  0x53ef,0x53e4,0x53f3,0x53ec, 0x53ee,0x53e9,0x53e8,0x53fc,
  0x53f8,0x53f5,0x53eb,0x53e6, 0x53ea,0x53f2,0x53f1,0x53f0,
  0x53e5,0x53ed,0x53fb,0x56db, 0x56da,0x5916,0x592e,0x5931,
  0x5974,0x5976,0x5b55,0x5b83, 0x5c3c,0x5de8,0x5de7,0x5de6,
  0x5e02,0x5e03,0x5e73,0x5e7c, 0x5f01,0x5f18,0x5f17,0x5fc5,
  0x620a,0x6253,0x6254,0x6252, 0x6251,0x65a5,0x65e6,0x672e,
  0x672c,0x672a,0x672b,0x672d, 0x6b63,0x6bcd,0x6c11,0x6c10,
  0x6c38,0x6c41,0x6c40,0x6c3e, 0x72af,0x7384,0x7389,0x74dc,
  0x74e6,0x7518,0x751f,0x7528, 0x7529,0x7530,0x7531,0x7532,
  0x7533,0x758b,0x767d,0x76ae, 0x76bf,0x76ee,0x77db,0x77e2,
  0x77f3,0x793a,0x79be,0x7a74, 0x7acb,0x4e1e,0x4e1f,0x4e52,
  0x4e53,0x4e69,0x4e99,0x4ea4, 0x4ea6,0x4ea5,0x4eff,0x4f09,
  0x4f19,0x4f0a,0x4f15,0x4f0d, 0x4f10,0x4f11,0x4f0f,0x4ef2,
  0x4ef6,0x4efb,0x4ef0,0x4ef3, 0x4efd,0x4f01,0x4f0b,0x5149,
  0x5147,0x5146,0x5148,0x5168, 0x5171,0x518d,0x51b0,0x5217,
  0x5211,0x5212,0x520e,0x5216, 0x52a3,0x5308,0x5321,0x5320,
  0x5370,0x5371,0x5409,0x540f, 0x540c,0x540a,0x5410,0x5401,
  0x540b,0x5404,0x5411,0x540d, 0x5408,0x5403,0x540e,0x5406,
  0x5412,0x56e0,0x56de,0x56dd, 0x5733,0x5730,0x5728,0x572d,
  0x572c,0x572f,0x5729,0x5919, 0x591a,0x5937,0x5938,0x5984,
  0x5978,0x5983,0x597d,0x5979, 0x5982,0x5981,0x5b57,0x5b58,
  0x5b87,0x5b88,0x5b85,0x5b89, 0x5bfa,0x5c16,0x5c79,0x5dde,
  0x5e06,0x5e76,0x5e74,0x5f0f, 0x5f1b,0x5fd9,0x5fd6,0x620e,
  0x620c,0x620d,0x6210,0x6263, 0x625b,0x6258,0x6536,0x65e9,
  0x65e8,0x65ec,0x65ed,0x66f2, 0x66f3,0x6709,0x673d,0x6734,
  0x6731,0x6735,0x6b21,0x6b64, 0x6b7b,0x6c16,0x6c5d,0x6c57,
  0x6c59,0x6c5f,0x6c60,0x6c50, 0x6c55,0x6c61,0x6c5b,0x6c4d,
  0x6c4e,0x7070,0x725f,0x725d, 0x767e,0x7af9,0x7c73,0x7cf8,
  0x7f36,0x7f8a,0x7fbd,0x8001, 0x8003,0x800c,0x8012,0x8033,
  0x807f,0x8089,0x808b,0x808c, 0x81e3,0x81ea,0x81f3,0x81fc,
  0x820c,0x821b,0x821f,0x826e, 0x8272,0x827e,0x866b,0x8840,
  0x884c,0x8863,0x897f,0x9621, 0x4e32,0x4ea8,0x4f4d,0x4f4f,
  0x4f47,0x4f57,0x4f5e,0x4f34, 0x4f5b,0x4f55,0x4f30,0x4f50,
  0x4f51,0x4f3d,0x4f3a,0x4f38, 0x4f43,0x4f54,0x4f3c,0x4f46,
  0x4f63,0x4f5c,0x4f60,0x4f2f, 0x4f4e,0x4f36,0x4f59,0x4f5d,
  0x4f48,0x4f5a,0x514c,0x514b, 0x514d,0x5175,0x51b6,0x51b7,
  0x5225,0x5224,0x5229,0x522a, 0x5228,0x52ab,0x52a9,0x52aa,
  0x52ac,0x5323,0x5373,0x5375, 0x541d,0x542d,0x541e,0x543e,
  0x5426,0x544e,0x5427,0x5446, 0x5443,0x5433,0x5448,0x5442,
  0x541b,0x5429,0x544a,0x5439, 0x543b,0x5438,0x542e,0x5435,
  0x5436,0x5420,0x543c,0x5440, 0x5431,0x542b,0x541f,0x542c,
  0x56ea,0x56f0,0x56e4,0x56eb, 0x574a,0x5751,0x5740,0x574d,
  0x5747,0x574e,0x573e,0x5750, 0x574f,0x573b,0x58ef,0x593e,
  0x599d,0x5992,0x59a8,0x599e, 0x59a3,0x5999,0x5996,0x598d,
  0x59a4,0x5993,0x598a,0x59a5, 0x5b5d,0x5b5c,0x5b5a,0x5b5b,
  0x5b8c,0x5b8b,0x5b8f,0x5c2c, 0x5c40,0x5c41,0x5c3f,0x5c3e,
  0x5c90,0x5c91,0x5c94,0x5c8c, 0x5deb,0x5e0c,0x5e8f,0x5e87,
  0x5e8a,0x5ef7,0x5f04,0x5f1f, 0x5f64,0x5f62,0x5f77,0x5f79,
  0x5fd8,0x5fcc,0x5fd7,0x5fcd, 0x5ff1,0x5feb,0x5ff8,0x5fea,
  0x6212,0x6211,0x6284,0x6297, 0x6296,0x6280,0x6276,0x6289,
  0x626d,0x628a,0x627c,0x627e, 0x6279,0x6273,0x6292,0x626f,
  0x6298,0x626e,0x6295,0x6293, 0x6291,0x6286,0x6539,0x653b,
  0x6538,0x65f1,0x66f4,0x675f, 0x674e,0x674f,0x6750,0x6751,
  0x675c,0x6756,0x675e,0x6749, 0x6746,0x6760,0x6753,0x6757,
  0x6b65,0x6bcf,0x6c42,0x6c5e, 0x6c99,0x6c81,0x6c88,0x6c89,
  0x6c85,0x6c9b,0x6c6a,0x6c7a, 0x6c90,0x6c70,0x6c8c,0x6c68,
  0x6c96,0x6c92,0x6c7d,0x6c83, 0x6c72,0x6c7e,0x6c74,0x6c86,
  0x6c76,0x6c8d,0x6c94,0x6c98, 0x6c82,0x7076,0x707c,0x707d,
  0x7078,0x7262,0x7261,0x7260, 0x72c4,0x72c2,0x7396,0x752c,
  0x752b,0x7537,0x7538,0x7682, 0x76ef,0x77e3,0x79c1,0x79c0,
  0x79bf,0x7a76,0x7cfb,0x7f55, 0x8096,0x8093,0x809d,0x8098,
  0x809b,0x809a,0x80b2,0x826f, 0x8292,0x828b,0x828d,0x898b,
  0x89d2,0x8a00,0x8c37,0x8c46, 0x8c55,0x8c9d,0x8d64,0x8d70,
  0x8db3,0x8eab,0x8eca,0x8f9b, 0x8fb0,0x8fc2,0x8fc6,0x8fc5,
  0x8fc4,0x5de1,0x9091,0x90a2, 0x90aa,0x90a6,0x90a3,0x9149,
  0x91c6,0x91cc,0x9632,0x962e, 0x9631,0x962a,0x962c,0x4e26,
  0x4e56,0x4e73,0x4e8b,0x4e9b, 0x4e9e,0x4eab,0x4eac,0x4f6f,
  0x4f9d,0x4f8d,0x4f73,0x4f7f, 0x4f6c,0x4f9b,0x4f8b,0x4f86,
  0x4f83,0x4f70,0x4f75,0x4f88, 0x4f69,0x4f7b,0x4f96,0x4f7e,
  0x4f8f,0x4f91,0x4f7a,0x5154, 0x5152,0x5155,0x5169,0x5177,
  0x5176,0x5178,0x51bd,0x51fd, 0x523b,0x5238,0x5237,0x523a,
  0x5230,0x522e,0x5236,0x5241, 0x52be,0x52bb,0x5352,0x5354,
  0x5353,0x5351,0x5366,0x5377, 0x5378,0x5379,0x53d6,0x53d4,
  0x53d7,0x5473,0x5475,0x5496, 0x5478,0x5495,0x5480,0x547b,
  0x5477,0x5484,0x5492,0x5486, 0x547c,0x5490,0x5471,0x5476,
  0x548c,0x549a,0x5462,0x5468, 0x548b,0x547d,0x548e,0x56fa,
  0x5783,0x5777,0x576a,0x5769, 0x5761,0x5766,0x5764,0x577c,
  0x591c,0x5949,0x5947,0x5948, 0x5944,0x5954,0x59be,0x59bb,
  0x59d4,0x59b9,0x59ae,0x59d1, 0x59c6,0x59d0,0x59cd,0x59cb,
  0x59d3,0x59ca,0x59af,0x59b3, 0x59d2,0x59c5,0x5b5f,0x5b64,
  0x5b63,0x5b97,0x5b9a,0x5b98, 0x5b9c,0x5b99,0x5b9b,0x5c1a,
  0x5c48,0x5c45,0x5c46,0x5cb7, 0x5ca1,0x5cb8,0x5ca9,0x5cab,
  0x5cb1,0x5cb3,0x5e18,0x5e1a, 0x5e16,0x5e15,0x5e1b,0x5e11,
  0x5e78,0x5e9a,0x5e97,0x5e9c, 0x5e95,0x5e96,0x5ef6,0x5f26,
  0x5f27,0x5f29,0x5f80,0x5f81, 0x5f7f,0x5f7c,0x5fdd,0x5fe0,
  0x5ffd,0x5ff5,0x5fff,0x600f, 0x6014,0x602f,0x6035,0x6016,
  0x602a,0x6015,0x6021,0x6027, 0x6029,0x602b,0x601b,0x6216,
  0x6215,0x623f,0x623e,0x6240, 0x627f,0x62c9,0x62cc,0x62c4,
  0x62bf,0x62c2,0x62b9,0x62d2, 0x62db,0x62ab,0x62d3,0x62d4,
  0x62cb,0x62c8,0x62a8,0x62bd, 0x62bc,0x62d0,0x62d9,0x62c7,
  0x62cd,0x62b5,0x62da,0x62b1, 0x62d8,0x62d6,0x62d7,0x62c6,
  0x62ac,0x62ce,0x653e,0x65a7, 0x65bc,0x65fa,0x6614,0x6613,
  0x660c,0x6606,0x6602,0x660e, 0x6600,0x660f,0x6615,0x660a,
  0x6607,0x670d,0x670b,0x676d, 0x678b,0x6795,0x6771,0x679c,
  0x6773,0x6777,0x6787,0x679d, 0x6797,0x676f,0x6770,0x677f,
  0x6789,0x677e,0x6790,0x6775, 0x679a,0x6793,0x677c,0x676a,
  0x6772,0x6b23,0x6b66,0x6b67, 0x6b7f,0x6c13,0x6c1b,0x6ce3,
  0x6ce8,0x6cf3,0x6cb1,0x6ccc, 0x6ce5,0x6cb3,0x6cbd,0x6cbe,
  0x6cbc,0x6ce2,0x6cab,0x6cd5, 0x6cd3,0x6cb8,0x6cc4,0x6cb9,
  0x6cc1,0x6cae,0x6cd7,0x6cc5, 0x6cf1,0x6cbf,0x6cbb,0x6ce1,
  0x6cdb,0x6cca,0x6cac,0x6cef, 0x6cdc,0x6cd6,0x6ce0,0x7095,
  0x708e,0x7092,0x708a,0x7099, 0x722c,0x722d,0x7238,0x7248,
  0x7267,0x7269,0x72c0,0x72ce, 0x72d9,0x72d7,0x72d0,0x73a9,
  0x73a8,0x739f,0x73ab,0x73a5, 0x753d,0x759d,0x7599,0x759a,
  0x7684,0x76c2,0x76f2,0x76f4, 0x77e5,0x77fd,0x793e,0x7940,
  0x7941,0x79c9,0x79c8,0x7a7a, 0x7a79,0x7afa,0x7cfe,0x7f54,
  0x7f8c,0x7f8b,0x8005,0x80ba, 0x80a5,0x80a2,0x80b1,0x80a1,
  0x80ab,0x80a9,0x80b4,0x80aa, 0x80af,0x81e5,0x81fe,0x820d,
  0x82b3,0x829d,0x8299,0x82ad, 0x82bd,0x829f,0x82b9,0x82b1,
  0x82ac,0x82a5,0x82af,0x82b8, 0x82a3,0x82b0,0x82be,0x82b7,
  0x864e,0x8671,0x521d,0x8868, 0x8ecb,0x8fce,0x8fd4,0x8fd1,
  0x90b5,0x90b8,0x90b1,0x90b6, 0x91c7,0x91d1,0x9577,0x9580,
  0x961c,0x9640,0x963f,0x963b, 0x9644,0x9642,0x96b9,0x96e8,
  0x9752,0x975e,0x4e9f,0x4ead, 0x4eae,0x4fe1,0x4fb5,0x4faf,
  0x4fbf,0x4fe0,0x4fd1,0x4fcf, 0x4fdd,0x4fc3,0x4fb6,0x4fd8,
  0x4fdf,0x4fca,0x4fd7,0x4fae, 0x4fd0,0x4fc4,0x4fc2,0x4fda,
  0x4fce,0x4fde,0x4fb7,0x5157, 0x5192,0x5191,0x51a0,0x524e,
  0x5243,0x524a,0x524d,0x524c, 0x524b,0x5247,0x52c7,0x52c9,
  0x52c3,0x52c1,0x530d,0x5357, 0x537b,0x539a,0x53db,0x54ac,
  0x54c0,0x54a8,0x54ce,0x54c9, 0x54b8,0x54a6,0x54b3,0x54c7,
  0x54c2,0x54bd,0x54aa,0x54c1, 0x54c4,0x54c8,0x54af,0x54ab,
  0x54b1,0x54bb,0x54a9,0x54a7, 0x54bf,0x56ff,0x5782,0x578b,
  0x57a0,0x57a3,0x57a2,0x57ce, 0x57ae,0x5793,0x5955,0x5951,
  0x594f,0x594e,0x5950,0x59dc, 0x59d8,0x59ff,0x59e3,0x59e8,
  0x5a03,0x59e5,0x59ea,0x59da, 0x59e6,0x5a01,0x59fb,0x5b69,
  0x5ba3,0x5ba6,0x5ba4,0x5ba2, 0x5ba5,0x5c01,0x5c4e,0x5c4f,
  0x5c4d,0x5c4b,0x5cd9,0x5cd2, 0x5df7,0x5e1d,0x5e25,0x5e1f,
  0x5e7d,0x5ea0,0x5ea6,0x5efa, 0x5f08,0x5f2d,0x5f65,0x5f88,
  0x5f85,0x5f8a,0x5f8b,0x5f87, 0x5f8c,0x5f89,0x6012,0x601d,
  0x6020,0x6025,0x600e,0x6028, 0x604d,0x6070,0x6068,0x6062,
  0x6046,0x6043,0x606c,0x606b, 0x606a,0x6064,0x6241,0x62dc,
  0x6316,0x6309,0x62fc,0x62ed, 0x6301,0x62ee,0x62fd,0x6307,
  0x62f1,0x62f7,0x62ef,0x62ec, 0x62fe,0x62f4,0x6311,0x6302,
  0x653f,0x6545,0x65ab,0x65bd, 0x65e2,0x6625,0x662d,0x6620,
  0x6627,0x662f,0x661f,0x6628, 0x6631,0x6624,0x66f7,0x67ff,
  0x67d3,0x67f1,0x67d4,0x67d0, 0x67ec,0x67b6,0x67af,0x67f5,
  0x67e9,0x67ef,0x67c4,0x67d1, 0x67b4,0x67da,0x67e5,0x67b8,
  0x67cf,0x67de,0x67f3,0x67b0, 0x67d9,0x67e2,0x67dd,0x67d2,
  0x6b6a,0x6b83,0x6b86,0x6bb5, 0x6bd2,0x6bd7,0x6c1f,0x6cc9,
  0x6d0b,0x6d32,0x6d2a,0x6d41, 0x6d25,0x6d0c,0x6d31,0x6d1e,
  0x6d17,0x6d3b,0x6d3d,0x6d3e, 0x6d36,0x6d1b,0x6cf5,0x6d39,
  0x6d27,0x6d38,0x6d29,0x6d2e, 0x6d35,0x6d0e,0x6d2b,0x70ab,
  0x70ba,0x70b3,0x70ac,0x70af, 0x70ad,0x70b8,0x70ae,0x70a4,
  0x7230,0x7272,0x726f,0x7274, 0x72e9,0x72e0,0x72e1,0x73b7,
  0x73ca,0x73bb,0x73b2,0x73cd, 0x73c0,0x73b3,0x751a,0x752d,
  0x754f,0x754c,0x754e,0x754b, 0x75ab,0x75a4,0x75a5,0x75a2,
  0x75a3,0x7678,0x7686,0x7687, 0x7688,0x76c8,0x76c6,0x76c3,
  0x76c5,0x7701,0x76f9,0x76f8, 0x7709,0x770b,0x76fe,0x76fc,
  0x7707,0x77dc,0x7802,0x7814, 0x780c,0x780d,0x7946,0x7949,
  0x7948,0x7947,0x79b9,0x79ba, 0x79d1,0x79d2,0x79cb,0x7a7f,
  0x7a81,0x7aff,0x7afd,0x7c7d, 0x7d02,0x7d05,0x7d00,0x7d09,
  0x7d07,0x7d04,0x7d06,0x7f38, 0x7f8e,0x7fbf,0x8010,0x800d,
  0x8011,0x8036,0x80d6,0x80e5, 0x80da,0x80c3,0x80c4,0x80cc,
  0x80e1,0x80db,0x80ce,0x80de, 0x80e4,0x80dd,0x81f4,0x8222,
  0x82e7,0x8303,0x8305,0x82e3, 0x82db,0x82e6,0x8304,0x82e5,
  0x8302,0x8309,0x82d2,0x82d7, 0x82f1,0x8301,0x82dc,0x82d4,
  0x82d1,0x82de,0x82d3,0x82df, 0x82ef,0x8306,0x8650,0x8679,
  0x867b,0x867a,0x884d,0x886b, 0x8981,0x89d4,0x8a08,0x8a02,
  0x8a03,0x8c9e,0x8ca0,0x8d74, 0x8d73,0x8db4,0x8ecd,0x8ecc,
  0x8ff0,0x8fe6,0x8fe2,0x8fea, 0x8fe5,0x8fed,0x8feb,0x8fe4,
  0x8fe8,0x90ca,0x90ce,0x90c1, 0x90c3,0x914b,0x914a,0x91cd,
  0x9582,0x9650,0x964b,0x964c, 0x964d,0x9762,0x9769,0x97cb,
  0x97ed,0x97f3,0x9801,0x98a8, 0x98db,0x98df,0x9996,0x9999,
  0x4e58,0x4eb3,0x500c,0x500d, 0x5023,0x4fef,0x5026,0x5025,
  0x4ff8,0x5029,0x5016,0x5006, 0x503c,0x501f,0x501a,0x5012,
  0x5011,0x4ffa,0x5000,0x5014, 0x5028,0x4ff1,0x5021,0x500b,
  0x5019,0x5018,0x4ff3,0x4fee, 0x502d,0x502a,0x4ffe,0x502b,
  0x5009,0x517c,0x51a4,0x51a5, 0x51a2,0x51cd,0x51cc,0x51c6,
  0x51cb,0x5256,0x525c,0x5254, 0x525b,0x525d,0x532a,0x537f,
  0x539f,0x539d,0x53df,0x54e8, 0x5510,0x5501,0x5537,0x54fc,
  0x54e5,0x54f2,0x5506,0x54fa, 0x5514,0x54e9,0x54ed,0x54e1,
  0x5509,0x54ee,0x54ea,0x54e6, 0x5527,0x5507,0x54fd,0x550f,
  0x5703,0x5704,0x57c2,0x57d4, 0x57cb,0x57c3,0x5809,0x590f,
  0x5957,0x5958,0x595a,0x5a11, 0x5a18,0x5a1c,0x5a1f,0x5a1b,
  0x5a13,0x59ec,0x5a20,0x5a23, 0x5a29,0x5a25,0x5a0c,0x5a09,
  0x5b6b,0x5c58,0x5bb0,0x5bb3, 0x5bb6,0x5bb4,0x5bae,0x5bb5,
  0x5bb9,0x5bb8,0x5c04,0x5c51, 0x5c55,0x5c50,0x5ced,0x5cfd,
  0x5cfb,0x5cea,0x5ce8,0x5cf0, 0x5cf6,0x5d01,0x5cf4,0x5dee,
  0x5e2d,0x5e2b,0x5eab,0x5ead, 0x5ea7,0x5f31,0x5f92,0x5f91,
  0x5f90,0x6059,0x6063,0x6065, 0x6050,0x6055,0x606d,0x6069,
  0x606f,0x6084,0x609f,0x609a, 0x608d,0x6094,0x608c,0x6085,
  0x6096,0x6247,0x62f3,0x6308, 0x62ff,0x634e,0x633e,0x632f,
  0x6355,0x6342,0x6346,0x634f, 0x6349,0x633a,0x6350,0x633d,
  0x632a,0x632b,0x6328,0x634d, 0x634c,0x6548,0x6549,0x6599,
  0x65c1,0x65c5,0x6642,0x6649, 0x664f,0x6643,0x6652,0x664c,
  0x6645,0x6641,0x66f8,0x6714, 0x6715,0x6717,0x6821,0x6838,
  0x6848,0x6846,0x6853,0x6839, 0x6842,0x6854,0x6829,0x68b3,
  0x6817,0x684c,0x6851,0x683d, 0x67f4,0x6850,0x6840,0x683c,
  0x6843,0x682a,0x6845,0x6813, 0x6818,0x6841,0x6b8a,0x6b89,
  0x6bb7,0x6c23,0x6c27,0x6c28, 0x6c26,0x6c24,0x6cf0,0x6d6a,
  0x6d95,0x6d88,0x6d87,0x6d66, 0x6d78,0x6d77,0x6d59,0x6d93,
  0x6d6c,0x6d89,0x6d6e,0x6d5a, 0x6d74,0x6d69,0x6d8c,0x6d8a,
  0x6d79,0x6d85,0x6d65,0x6d94, 0x70ca,0x70d8,0x70e4,0x70d9,
  0x70c8,0x70cf,0x7239,0x7279, 0x72fc,0x72f9,0x72fd,0x72f8,
  0x72f7,0x7386,0x73ed,0x7409, 0x73ee,0x73e0,0x73ea,0x73de,
  0x7554,0x755d,0x755c,0x755a, 0x7559,0x75be,0x75c5,0x75c7,
  0x75b2,0x75b3,0x75bd,0x75bc, 0x75b9,0x75c2,0x75b8,0x768b,
  0x76b0,0x76ca,0x76cd,0x76ce, 0x7729,0x771f,0x7720,0x7728,
  0x77e9,0x7830,0x7827,0x7838, 0x781d,0x7834,0x7837,0x7825,
  0x782d,0x7820,0x781f,0x7832, 0x7955,0x7950,0x7960,0x795f,
  0x7956,0x795e,0x795d,0x7957, 0x795a,0x79e4,0x79e3,0x79e7,
  0x79df,0x79e6,0x79e9,0x79d8, 0x7a84,0x7a88,0x7ad9,0x7b06,
  0x7b11,0x7c89,0x7d21,0x7d17, 0x7d0b,0x7d0a,0x7d20,0x7d22,
  0x7d14,0x7d10,0x7d15,0x7d1a, 0x7d1c,0x7d0d,0x7d19,0x7d1b,
  0x7f3a,0x7f5f,0x7f94,0x7fc5, 0x7fc1,0x8006,0x8004,0x8018,
  0x8015,0x8019,0x8017,0x803d, 0x803f,0x80f1,0x8102,0x80f0,
  0x8105,0x80ed,0x80f4,0x8106, 0x80f8,0x80f3,0x8108,0x80fd,
  0x810a,0x80fc,0x80ef,0x81ed, 0x81ec,0x8200,0x8210,0x822a,
  0x822b,0x8228,0x822c,0x82bb, 0x832b,0x8352,0x8354,0x834a,
  0x8338,0x8350,0x8349,0x8335, 0x8334,0x834f,0x8332,0x8339,
  0x8336,0x8317,0x8340,0x8331, 0x8328,0x8343,0x8654,0x868a,
  0x86aa,0x8693,0x86a4,0x86a9, 0x868c,0x86a3,0x869c,0x8870,
  0x8877,0x8881,0x8882,0x887d, 0x8879,0x8a18,0x8a10,0x8a0e,
  0x8a0c,0x8a15,0x8a0a,0x8a17, 0x8a13,0x8a16,0x8a0f,0x8a11,
  0x8c48,0x8c7a,0x8c79,0x8ca1, 0x8ca2,0x8d77,0x8eac,0x8ed2,
  0x8ed4,0x8ecf,0x8fb1,0x9001, 0x9006,0x8ff7,0x9000,0x8ffa,
  0x8ff4,0x9003,0x8ffd,0x9005, 0x8ff8,0x9095,0x90e1,0x90dd,
  0x90e2,0x9152,0x914d,0x914c, 0x91d8,0x91dd,0x91d7,0x91dc,
  0x91d9,0x9583,0x9662,0x9663, 0x9661,0x965b,0x965d,0x9664,
  0x9658,0x965e,0x96bb,0x98e2, 0x99ac,0x9aa8,0x9ad8,0x9b25,
  0x9b32,0x9b3c,0x4e7e,0x507a, 0x507d,0x505c,0x5047,0x5043,
  0x504c,0x505a,0x5049,0x5065, 0x5076,0x504e,0x5055,0x5075,
  0x5074,0x5077,0x504f,0x500f, 0x506f,0x506d,0x515c,0x5195,
  0x51f0,0x526a,0x526f,0x52d2, 0x52d9,0x52d8,0x52d5,0x5310,
  0x530f,0x5319,0x533f,0x5340, 0x533e,0x53c3,0x66fc,0x5546,
  0x556a,0x5566,0x5544,0x555e, 0x5561,0x5543,0x554a,0x5531,
  0x5556,0x554f,0x5555,0x552f, 0x5564,0x5538,0x552e,0x555c,
  0x552c,0x5563,0x5533,0x5541, 0x5557,0x5708,0x570b,0x5709,
  0x57df,0x5805,0x580a,0x5806, 0x57e0,0x57e4,0x57fa,0x5802,
  0x5835,0x57f7,0x57f9,0x5920, 0x5962,0x5a36,0x5a41,0x5a49,
  0x5a66,0x5a6a,0x5a40,0x5a3c, 0x5a62,0x5a5a,0x5a46,0x5a4a,
  0x5b70,0x5bc7,0x5bc5,0x5bc4, 0x5bc2,0x5bbf,0x5bc6,0x5c09,
  0x5c08,0x5c07,0x5c60,0x5c5c, 0x5c5d,0x5d07,0x5d06,0x5d0e,
  0x5d1b,0x5d16,0x5d22,0x5d11, 0x5d29,0x5d14,0x5d19,0x5d24,
  0x5d27,0x5d17,0x5de2,0x5e38, 0x5e36,0x5e33,0x5e37,0x5eb7,
  0x5eb8,0x5eb6,0x5eb5,0x5ebe, 0x5f35,0x5f37,0x5f57,0x5f6c,
  0x5f69,0x5f6b,0x5f97,0x5f99, 0x5f9e,0x5f98,0x5fa1,0x5fa0,
  0x5f9c,0x607f,0x60a3,0x6089, 0x60a0,0x60a8,0x60cb,0x60b4,
  0x60e6,0x60bd,0x60c5,0x60bb, 0x60b5,0x60dc,0x60bc,0x60d8,
  0x60d5,0x60c6,0x60df,0x60b8, 0x60da,0x60c7,0x621a,0x621b,
  0x6248,0x63a0,0x63a7,0x6372, 0x6396,0x63a2,0x63a5,0x6377,
  0x6367,0x6398,0x63aa,0x6371, 0x63a9,0x6389,0x6383,0x639b,
  0x636b,0x63a8,0x6384,0x6388, 0x6399,0x63a1,0x63ac,0x6392,
  0x638f,0x6380,0x637b,0x6369, 0x6368,0x637a,0x655d,0x6556,
  0x6551,0x6559,0x6557,0x555f, 0x654f,0x6558,0x6555,0x6554,
  0x659c,0x659b,0x65ac,0x65cf, 0x65cb,0x65cc,0x65ce,0x665d,
  0x665a,0x6664,0x6668,0x6666, 0x665e,0x66f9,0x52d7,0x671b,
  0x6881,0x68af,0x68a2,0x6893, 0x68b5,0x687f,0x6876,0x68b1,
  0x68a7,0x6897,0x68b0,0x6883, 0x68c4,0x68ad,0x6886,0x6885,
  0x6894,0x689d,0x68a8,0x689f, 0x68a1,0x6882,0x6b32,0x6bba,
  0x6beb,0x6bec,0x6c2b,0x6d8e, 0x6dbc,0x6df3,0x6dd9,0x6db2,
  0x6de1,0x6dcc,0x6de4,0x6dfb, 0x6dfa,0x6e05,0x6dc7,0x6dcb,
  0x6daf,0x6dd1,0x6dae,0x6dde, 0x6df9,0x6db8,0x6df7,0x6df5,
  0x6dc5,0x6dd2,0x6e1a,0x6db5, 0x6dda,0x6deb,0x6dd8,0x6dea,
  0x6df1,0x6dee,0x6de8,0x6dc6, 0x6dc4,0x6daa,0x6dec,0x6dbf,
  0x6de6,0x70f9,0x7109,0x710a, 0x70fd,0x70ef,0x723d,0x727d,
  0x7281,0x731c,0x731b,0x7316, 0x7313,0x7319,0x7387,0x7405,
  0x740a,0x7403,0x7406,0x73fe, 0x740d,0x74e0,0x74f6,0x74f7,
  0x751c,0x7522,0x7565,0x7566, 0x7562,0x7570,0x758f,0x75d4,
  0x75d5,0x75b5,0x75ca,0x75cd, 0x768e,0x76d4,0x76d2,0x76db,
  0x7737,0x773e,0x773c,0x7736, 0x7738,0x773a,0x786b,0x7843,
  0x784e,0x7965,0x7968,0x796d, 0x79fb,0x7a92,0x7a95,0x7b20,
  0x7b28,0x7b1b,0x7b2c,0x7b26, 0x7b19,0x7b1e,0x7b2e,0x7c92,
  0x7c97,0x7c95,0x7d46,0x7d43, 0x7d71,0x7d2e,0x7d39,0x7d3c,
  0x7d40,0x7d30,0x7d33,0x7d44, 0x7d2f,0x7d42,0x7d32,0x7d31,
  0x7f3d,0x7f9e,0x7f9a,0x7fcc, 0x7fce,0x7fd2,0x801c,0x804a,
  0x8046,0x812f,0x8116,0x8123, 0x812b,0x8129,0x8130,0x8124,
  0x8202,0x8235,0x8237,0x8236, 0x8239,0x838e,0x839e,0x8398,
  0x8378,0x83a2,0x8396,0x83bd, 0x83ab,0x8392,0x838a,0x8393,
  0x8389,0x83a0,0x8377,0x837b, 0x837c,0x8386,0x83a7,0x8655,
  0x5f6a,0x86c7,0x86c0,0x86b6, 0x86c4,0x86b5,0x86c6,0x86cb,
  0x86b1,0x86af,0x86c9,0x8853, 0x889e,0x8888,0x88ab,0x8892,
  0x8896,0x888d,0x888b,0x8993, 0x898f,0x8a2a,0x8a1d,0x8a23,
  0x8a25,0x8a31,0x8a2d,0x8a1f, 0x8a1b,0x8a22,0x8c49,0x8c5a,
  0x8ca9,0x8cac,0x8cab,0x8ca8, 0x8caa,0x8ca7,0x8d67,0x8d66,
  0x8dbe,0x8dba,0x8edb,0x8edf, 0x9019,0x900d,0x901a,0x9017,
  0x9023,0x901f,0x901d,0x9010, 0x9015,0x901e,0x9020,0x900f,
  0x9022,0x9016,0x901b,0x9014, 0x90e8,0x90ed,0x90fd,0x9157,
  0x91ce,0x91f5,0x91e6,0x91e3, 0x91e7,0x91ed,0x91e9,0x9589,
  0x966a,0x9675,0x9673,0x9678, 0x9670,0x9674,0x9676,0x9677,
  0x966c,0x96c0,0x96ea,0x96e9, 0x7ae0,0x7adf,0x9802,0x9803,
  0x9b5a,0x9ce5,0x9e75,0x9e7f, 0x9ea5,0x9ebb,0x50a2,0x508d,
  0x5085,0x5099,0x5091,0x5080, 0x5096,0x5098,0x509a,0x6700,
  0x51f1,0x5272,0x5274,0x5275, 0x5269,0x52de,0x52dd,0x52db,
  0x535a,0x53a5,0x557b,0x5580, 0x55a7,0x557c,0x558a,0x559d,
  0x5598,0x5582,0x559c,0x55aa, 0x5594,0x5587,0x558b,0x5583,
  0x55b3,0x55ae,0x559f,0x553e, 0x55b2,0x559a,0x55bb,0x55ac,
  0x55b1,0x557e,0x5589,0x55ab, 0x5599,0x570d,0x582f,0x582a,
  0x5834,0x5824,0x5830,0x5831, 0x5821,0x581d,0x5820,0x58f9,
  0x58fa,0x5960,0x5a77,0x5a9a, 0x5a7f,0x5a92,0x5a9b,0x5aa7,
  0x5b73,0x5b71,0x5bd2,0x5bcc, 0x5bd3,0x5bd0,0x5c0a,0x5c0b,
  0x5c31,0x5d4c,0x5d50,0x5d34, 0x5d47,0x5dfd,0x5e45,0x5e3d,
  0x5e40,0x5e43,0x5e7e,0x5eca, 0x5ec1,0x5ec2,0x5ec4,0x5f3c,
  0x5f6d,0x5fa9,0x5faa,0x5fa8, 0x60d1,0x60e1,0x60b2,0x60b6,
  0x60e0,0x611c,0x6123,0x60fa, 0x6115,0x60f0,0x60fb,0x60f4,
  0x6168,0x60f1,0x610e,0x60f6, 0x6109,0x6100,0x6112,0x621f,
  0x6249,0x63a3,0x638c,0x63cf, 0x63c0,0x63e9,0x63c9,0x63c6,
  0x63cd,0x63d2,0x63e3,0x63d0, 0x63e1,0x63d6,0x63ed,0x63ee,
  0x6376,0x63f4,0x63ea,0x63db, 0x6452,0x63da,0x63f9,0x655e,
  0x6566,0x6562,0x6563,0x6591, 0x6590,0x65af,0x666e,0x6670,
  0x6674,0x6676,0x666f,0x6691, 0x667a,0x667e,0x6677,0x66fe,
  0x66ff,0x671f,0x671d,0x68fa, 0x68d5,0x68e0,0x68d8,0x68d7,
  0x6905,0x68df,0x68f5,0x68ee, 0x68e7,0x68f9,0x68d2,0x68f2,
  0x68e3,0x68cb,0x68cd,0x690d, 0x6912,0x690e,0x68c9,0x68da,
  0x696e,0x68fb,0x6b3e,0x6b3a, 0x6b3d,0x6b98,0x6b96,0x6bbc,
  0x6bef,0x6c2e,0x6c2f,0x6c2c, 0x6e2f,0x6e38,0x6e54,0x6e21,
  0x6e32,0x6e67,0x6e4a,0x6e20, 0x6e25,0x6e23,0x6e1b,0x6e5b,
  0x6e58,0x6e24,0x6e56,0x6e6e, 0x6e2d,0x6e26,0x6e6f,0x6e34,
  0x6e4d,0x6e3a,0x6e2c,0x6e43, 0x6e1d,0x6e3e,0x6ecb,0x6e89,
  0x6e19,0x6e4e,0x6e63,0x6e44, 0x6e72,0x6e69,0x6e5f,0x7119,
  0x711a,0x7126,0x7130,0x7121, 0x7136,0x716e,0x711c,0x724c,
  0x7284,0x7280,0x7336,0x7325, 0x7334,0x7329,0x743a,0x742a,
  0x7433,0x7422,0x7425,0x7435, 0x7436,0x7434,0x742f,0x741b,
  0x7426,0x7428,0x7525,0x7526, 0x756b,0x756a,0x75e2,0x75db,
  0x75e3,0x75d9,0x75d8,0x75de, 0x75e0,0x767b,0x767c,0x7696,
  0x7693,0x76b4,0x76dc,0x774f, 0x77ed,0x785d,0x786c,0x786f,
  0x7a0d,0x7a08,0x7a0b,0x7a05, 0x7a00,0x7a98,0x7a97,0x7a96,
  0x7ae5,0x7ae3,0x7b49,0x7b56, 0x7b46,0x7b50,0x7b52,0x7b54,
  0x7b4d,0x7b4b,0x7b4f,0x7b51, 0x7c9f,0x7ca5,0x7d5e,0x7d50,
  0x7d68,0x7d55,0x7d2b,0x7d6e, 0x7d72,0x7d61,0x7d66,0x7d62,
  0x7d70,0x7d73,0x5584,0x7fd4, 0x7fd5,0x800b,0x8052,0x8085,
  0x8155,0x8154,0x814b,0x8151, 0x814e,0x8139,0x8146,0x813e,
  0x814c,0x8153,0x8174,0x8212, 0x821c,0x83e9,0x8403,0x83f8,
  0x840d,0x83e0,0x83c5,0x840b, 0x83c1,0x83ef,0x83f1,0x83f4,
  0x8457,0x840a,0x83f0,0x840c, 0x83cc,0x83fd,0x83f2,0x83ca,
  0x8438,0x840e,0x8404,0x83dc, 0x8407,0x83d4,0x83df,0x865b,
  0x86df,0x86d9,0x86ed,0x86d4, 0x86db,0x86e4,0x86d0,0x86de,
  0x8857,0x88c1,0x88c2,0x88b1, 0x8983,0x8996,0x8a3b,0x8a60,
  0x8a55,0x8a5e,0x8a3c,0x8a41, 0x8a54,0x8a5b,0x8a50,0x8a46,
  0x8a34,0x8a3a,0x8a36,0x8a56, 0x8c61,0x8c82,0x8caf,0x8cbc,
  0x8cb3,0x8cbd,0x8cc1,0x8cbb, 0x8cc0,0x8cb4,0x8cb7,0x8cb6,
  0x8cbf,0x8cb8,0x8d8a,0x8d85, 0x8d81,0x8dce,0x8ddd,0x8dcb,
  0x8dda,0x8dd1,0x8dcc,0x8ddb, 0x8dc6,0x8efb,0x8ef8,0x8efc,
  0x8f9c,0x902e,0x9035,0x9031, 0x9038,0x9032,0x9036,0x9102,
  0x90f5,0x9109,0x90fe,0x9163, 0x9165,0x91cf,0x9214,0x9215,
  0x9223,0x9209,0x921e,0x920d, 0x9210,0x9207,0x9211,0x9594,
  0x958f,0x958b,0x9591,0x9593, 0x9592,0x958e,0x968a,0x968e,
  0x968b,0x967d,0x9685,0x9686, 0x968d,0x9672,0x9684,0x96c1,
  0x96c5,0x96c4,0x96c6,0x96c7, 0x96ef,0x96f2,0x97cc,0x9805,
  0x9806,0x9808,0x98e7,0x98ea, 0x98ef,0x98e9,0x98f2,0x98ed,
  0x99ae,0x99ad,0x9ec3,0x9ecd, 0x9ed1,0x4e82,0x50ad,0x50b5,
  0x50b2,0x50b3,0x50c5,0x50be, 0x50ac,0x50b7,0x50bb,0x50af,
  0x50c7,0x527f,0x5277,0x527d, 0x52df,0x52e6,0x52e4,0x52e2,
  0x52e3,0x532f,0x55df,0x55e8, 0x55d3,0x55e6,0x55ce,0x55dc,
  0x55c7,0x55d1,0x55e3,0x55e4, 0x55ef,0x55da,0x55e1,0x55c5,
  0x55c6,0x55e5,0x55c9,0x5712, 0x5713,0x585e,0x5851,0x5858,
  0x5857,0x585a,0x5854,0x586b, 0x584c,0x586d,0x584a,0x5862,
  0x5852,0x584b,0x5967,0x5ac1, 0x5ac9,0x5acc,0x5abe,0x5abd,
  0x5abc,0x5ab3,0x5ac2,0x5ab2, 0x5d69,0x5d6f,0x5e4c,0x5e79,
  0x5ec9,0x5ec8,0x5f12,0x5f59, 0x5fac,0x5fae,0x611a,0x610f,
  0x6148,0x611f,0x60f3,0x611b, 0x60f9,0x6101,0x6108,0x614e,
  0x614c,0x6144,0x614d,0x613e, 0x6134,0x6127,0x610d,0x6106,
  0x6137,0x6221,0x6222,0x6413, 0x643e,0x641e,0x642a,0x642d,
  0x643d,0x642c,0x640f,0x641c, 0x6414,0x640d,0x6436,0x6416,
  0x6417,0x6406,0x656c,0x659f, 0x65b0,0x6697,0x6689,0x6687,
  0x6688,0x6696,0x6684,0x6698, 0x668d,0x6703,0x6994,0x696d,
  0x695a,0x6977,0x6960,0x6954, 0x6975,0x6930,0x6982,0x694a,
  0x6968,0x696b,0x695e,0x6953, 0x6979,0x6986,0x695d,0x6963,
  0x695b,0x6b47,0x6b72,0x6bc0, 0x6bbf,0x6bd3,0x6bfd,0x6ea2,
  0x6eaf,0x6ed3,0x6eb6,0x6ec2, 0x6e90,0x6e9d,0x6ec7,0x6ec5,
  0x6ea5,0x6e98,0x6ebc,0x6eba, 0x6eab,0x6ed1,0x6e96,0x6e9c,
  0x6ec4,0x6ed4,0x6eaa,0x6ea7, 0x6eb4,0x714e,0x7159,0x7169,
  0x7164,0x7149,0x7167,0x715c, 0x716c,0x7166,0x714c,0x7165,
  0x715e,0x7146,0x7168,0x7156, 0x723a,0x7252,0x7337,0x7345,
  0x733f,0x733e,0x746f,0x745a, 0x7455,0x745f,0x745e,0x7441,
  0x743f,0x7459,0x745b,0x745c, 0x7576,0x7578,0x7600,0x75f0,
  0x7601,0x75f2,0x75f1,0x75fa, 0x75ff,0x75f4,0x75f3,0x76de,
  0x76df,0x775b,0x776b,0x7766, 0x775e,0x7763,0x7779,0x776a,
  0x776c,0x775c,0x7765,0x7768, 0x7762,0x77ee,0x788e,0x78b0,
  0x7897,0x7898,0x788c,0x7889, 0x787c,0x7891,0x7893,0x787f,
  0x797a,0x797f,0x7981,0x842c, 0x79bd,0x7a1c,0x7a1a,0x7a20,
  0x7a14,0x7a1f,0x7a1e,0x7a9f, 0x7aa0,0x7b77,0x7bc0,0x7b60,
  0x7b6e,0x7b67,0x7cb1,0x7cb3, 0x7cb5,0x7d93,0x7d79,0x7d91,
  0x7d81,0x7d8f,0x7d5b,0x7f6e, 0x7f69,0x7f6a,0x7f72,0x7fa9,
  0x7fa8,0x7fa4,0x8056,0x8058, 0x8086,0x8084,0x8171,0x8170,
  0x8178,0x8165,0x816e,0x8173, 0x816b,0x8179,0x817a,0x8166,
  0x8205,0x8247,0x8482,0x8477, 0x843d,0x8431,0x8475,0x8466,
  0x846b,0x8449,0x846c,0x845b, 0x843c,0x8435,0x8461,0x8463,
  0x8469,0x846d,0x8446,0x865e, 0x865c,0x865f,0x86f9,0x8713,
  0x8708,0x8707,0x8700,0x86fe, 0x86fb,0x8702,0x8703,0x8706,
  0x870a,0x8859,0x88df,0x88d4, 0x88d9,0x88dc,0x88d8,0x88dd,
  0x88e1,0x88ca,0x88d5,0x88d2, 0x899c,0x89e3,0x8a6b,0x8a72,
  0x8a73,0x8a66,0x8a69,0x8a70, 0x8a87,0x8a7c,0x8a63,0x8aa0,
  0x8a71,0x8a85,0x8a6d,0x8a62, 0x8a6e,0x8a6c,0x8a79,0x8a7b,
  0x8a3e,0x8a68,0x8c62,0x8c8a, 0x8c89,0x8cca,0x8cc7,0x8cc8,
  0x8cc4,0x8cb2,0x8cc3,0x8cc2, 0x8cc5,0x8de1,0x8ddf,0x8de8,
  0x8def,0x8df3,0x8dfa,0x8dea, 0x8de4,0x8de6,0x8eb2,0x8f03,
  0x8f09,0x8efe,0x8f0a,0x8f9f, 0x8fb2,0x904b,0x904a,0x9053,
  0x9042,0x9054,0x903c,0x9055, 0x9050,0x9047,0x904f,0x904e,
  0x904d,0x9051,0x903e,0x9041, 0x9112,0x9117,0x916c,0x916a,
  0x9169,0x91c9,0x9237,0x9257, 0x9238,0x923d,0x9240,0x923e,
  0x925b,0x924b,0x9264,0x9251, 0x9234,0x9249,0x924d,0x9245,
  0x9239,0x923f,0x925a,0x9598, 0x9698,0x9694,0x9695,0x96cd,
  0x96cb,0x96c9,0x96ca,0x96f7, 0x96fb,0x96f9,0x96f6,0x9756,
  0x9774,0x9776,0x9810,0x9811, 0x9813,0x980a,0x9812,0x980c,
  0x98fc,0x98f4,0x98fd,0x98fe, 0x99b3,0x99b1,0x99b4,0x9ae1,
  0x9ce9,0x9e82,0x9f0e,0x9f13, 0x9f20,0x50e7,0x50ee,0x50e5,
  0x50d6,0x50ed,0x50da,0x50d5, 0x50cf,0x50d1,0x50f1,0x50ce,
  0x50e9,0x5162,0x51f3,0x5283, 0x5282,0x5331,0x53ad,0x55fe,
  0x5600,0x561b,0x5617,0x55fd, 0x5614,0x5606,0x5609,0x560d,
  0x560e,0x55f7,0x5616,0x561f, 0x5608,0x5610,0x55f6,0x5718,
  0x5716,0x5875,0x587e,0x5883, 0x5893,0x588a,0x5879,0x5885,
  0x587d,0x58fd,0x5925,0x5922, 0x5924,0x596a,0x5969,0x5ae1,
  0x5ae6,0x5ae9,0x5ad7,0x5ad6, 0x5ad8,0x5ae3,0x5b75,0x5bde,
  0x5be7,0x5be1,0x5be5,0x5be6, 0x5be8,0x5be2,0x5be4,0x5bdf,
  0x5c0d,0x5c62,0x5d84,0x5d87, 0x5e5b,0x5e63,0x5e55,0x5e57,
  0x5e54,0x5ed3,0x5ed6,0x5f0a, 0x5f46,0x5f70,0x5fb9,0x6147,
  0x613f,0x614b,0x6177,0x6162, 0x6163,0x615f,0x615a,0x6158,
  0x6175,0x622a,0x6487,0x6458, 0x6454,0x64a4,0x6478,0x645f,
  0x647a,0x6451,0x6467,0x6434, 0x646d,0x647b,0x6572,0x65a1,
  0x65d7,0x65d6,0x66a2,0x66a8, 0x669d,0x699c,0x69a8,0x6995,
  0x69c1,0x69ae,0x69d3,0x69cb, 0x699b,0x69b7,0x69bb,0x69ab,
  0x69b4,0x69d0,0x69cd,0x69ad, 0x69cc,0x69a6,0x69c3,0x69a3,
  0x6b49,0x6b4c,0x6c33,0x6f33, 0x6f14,0x6efe,0x6f13,0x6ef4,
  0x6f29,0x6f3e,0x6f20,0x6f2c, 0x6f0f,0x6f02,0x6f22,0x6eff,
  0x6eef,0x6f06,0x6f31,0x6f38, 0x6f32,0x6f23,0x6f15,0x6f2b,
  0x6f2f,0x6f88,0x6f2a,0x6eec, 0x6f01,0x6ef2,0x6ecc,0x6ef7,
  0x7194,0x7199,0x717d,0x718a, 0x7184,0x7192,0x723e,0x7292,
  0x7296,0x7344,0x7350,0x7464, 0x7463,0x746a,0x7470,0x746d,
  0x7504,0x7591,0x7627,0x760d, 0x760b,0x7609,0x7613,0x76e1,
  0x76e3,0x7784,0x777d,0x777f, 0x7761,0x78c1,0x789f,0x78a7,
  0x78b3,0x78a9,0x78a3,0x798e, 0x798f,0x798d,0x7a2e,0x7a31,
  0x7aaa,0x7aa9,0x7aed,0x7aef, 0x7ba1,0x7b95,0x7b8b,0x7b75,
  0x7b97,0x7b9d,0x7b94,0x7b8f, 0x7bb8,0x7b87,0x7b84,0x7cb9,
  0x7cbd,0x7cbe,0x7dbb,0x7db0, 0x7d9c,0x7dbd,0x7dbe,0x7da0,
  0x7dca,0x7db4,0x7db2,0x7db1, 0x7dba,0x7da2,0x7dbf,0x7db5,
  0x7db8,0x7dad,0x7dd2,0x7dc7, 0x7dac,0x7f70,0x7fe0,0x7fe1,
  0x7fdf,0x805e,0x805a,0x8087, 0x8150,0x8180,0x818f,0x8188,
  0x818a,0x817f,0x8182,0x81e7, 0x81fa,0x8207,0x8214,0x821e,
  0x824b,0x84c9,0x84bf,0x84c6, 0x84c4,0x8499,0x849e,0x84b2,
  0x849c,0x84cb,0x84b8,0x84c0, 0x84d3,0x8490,0x84bc,0x84d1,
  0x84ca,0x873f,0x871c,0x873b, 0x8722,0x8725,0x8734,0x8718,
  0x8755,0x8737,0x8729,0x88f3, 0x8902,0x88f4,0x88f9,0x88f8,
  0x88fd,0x88e8,0x891a,0x88ef, 0x8aa6,0x8a8c,0x8a9e,0x8aa3,
  0x8a8d,0x8aa1,0x8a93,0x8aa4, 0x8aaa,0x8aa5,0x8aa8,0x8a98,
  0x8a91,0x8a9a,0x8aa7,0x8c6a, 0x8c8d,0x8c8c,0x8cd3,0x8cd1,
  0x8cd2,0x8d6b,0x8d99,0x8d95, 0x8dfc,0x8f14,0x8f12,0x8f15,
  0x8f13,0x8fa3,0x9060,0x9058, 0x905c,0x9063,0x9059,0x905e,
  0x9062,0x905d,0x905b,0x9119, 0x9118,0x911e,0x9175,0x9178,
  0x9177,0x9174,0x9278,0x92ac, 0x9280,0x9285,0x9298,0x9296,
  0x927b,0x9293,0x929c,0x92a8, 0x927c,0x9291,0x95a1,0x95a8,
  0x95a9,0x95a3,0x95a5,0x95a4, 0x9699,0x969c,0x969b,0x96cc,
  0x96d2,0x9700,0x977c,0x9785, 0x97f6,0x9817,0x9818,0x98af,
  0x98b1,0x9903,0x9905,0x990c, 0x9909,0x99c1,0x9aaf,0x9ab0,
  0x9ae6,0x9b41,0x9b42,0x9cf4, 0x9cf6,0x9cf3,0x9ebc,0x9f3b,
  0x9f4a,0x5104,0x5100,0x50fb, 0x50f5,0x50f9,0x5102,0x5108,
  0x5109,0x5105,0x51dc,0x5287, 0x5288,0x5289,0x528d,0x528a,
  0x52f0,0x53b2,0x562e,0x563b, 0x5639,0x5632,0x563f,0x5634,
  0x5629,0x5653,0x564e,0x5657, 0x5674,0x5636,0x562f,0x5630,
  0x5880,0x589f,0x589e,0x58b3, 0x589c,0x58ae,0x58a9,0x58a6,
  0x596d,0x5b09,0x5afb,0x5b0b, 0x5af5,0x5b0c,0x5b08,0x5bee,
  0x5bec,0x5be9,0x5beb,0x5c64, 0x5c65,0x5d9d,0x5d94,0x5e62,
  0x5e5f,0x5e61,0x5ee2,0x5eda, 0x5edf,0x5edd,0x5ee3,0x5ee0,
  0x5f48,0x5f71,0x5fb7,0x5fb5, 0x6176,0x6167,0x616e,0x615d,
  0x6155,0x6182,0x617c,0x6170, 0x616b,0x617e,0x61a7,0x6190,
  0x61ab,0x618e,0x61ac,0x619a, 0x61a4,0x6194,0x61ae,0x622e,
  0x6469,0x646f,0x6479,0x649e, 0x64b2,0x6488,0x6490,0x64b0,
  0x64a5,0x6493,0x6495,0x64a9, 0x6492,0x64ae,0x64ad,0x64ab,
  0x649a,0x64ac,0x6499,0x64a2, 0x64b3,0x6575,0x6577,0x6578,
  0x66ae,0x66ab,0x66b4,0x66b1, 0x6a23,0x6a1f,0x69e8,0x6a01,
  0x6a1e,0x6a19,0x69fd,0x6a21, 0x6a13,0x6a0a,0x69f3,0x6a02,
  0x6a05,0x69ed,0x6a11,0x6b50, 0x6b4e,0x6ba4,0x6bc5,0x6bc6,
  0x6f3f,0x6f7c,0x6f84,0x6f51, 0x6f66,0x6f54,0x6f86,0x6f6d,
  0x6f5b,0x6f78,0x6f6e,0x6f8e, 0x6f7a,0x6f70,0x6f64,0x6f97,
  0x6f58,0x6ed5,0x6f6f,0x6f60, 0x6f5f,0x719f,0x71ac,0x71b1,
  0x71a8,0x7256,0x729b,0x734e, 0x7357,0x7469,0x748b,0x7483,
  0x747e,0x7480,0x757f,0x7620, 0x7629,0x761f,0x7624,0x7626,
  0x7621,0x7622,0x769a,0x76ba, 0x76e4,0x778e,0x7787,0x778c,
  0x7791,0x778b,0x78cb,0x78c5, 0x78ba,0x78ca,0x78be,0x78d5,
  0x78bc,0x78d0,0x7a3f,0x7a3c, 0x7a40,0x7a3d,0x7a37,0x7a3b,
  0x7aaf,0x7aae,0x7bad,0x7bb1, 0x7bc4,0x7bb4,0x7bc6,0x7bc7,
  0x7bc1,0x7ba0,0x7bcc,0x7cca, 0x7de0,0x7df4,0x7def,0x7dfb,
  0x7dd8,0x7dec,0x7ddd,0x7de8, 0x7de3,0x7dda,0x7dde,0x7de9,
  0x7d9e,0x7dd9,0x7df2,0x7df9, 0x7f75,0x7f77,0x7faf,0x7fe9,
  0x8026,0x819b,0x819c,0x819d, 0x81a0,0x819a,0x8198,0x8517,
  0x853d,0x851a,0x84ee,0x852c, 0x852d,0x8513,0x8511,0x8523,
  0x8521,0x8514,0x84ec,0x8525, 0x84ff,0x8506,0x8782,0x8774,
  0x8776,0x8760,0x8766,0x8778, 0x8768,0x8759,0x8757,0x874c,
  0x8753,0x885b,0x885d,0x8910, 0x8907,0x8912,0x8913,0x8915,
  0x890a,0x8abc,0x8ad2,0x8ac7, 0x8ac4,0x8a95,0x8acb,0x8af8,
  0x8ab2,0x8ac9,0x8ac2,0x8abf, 0x8ab0,0x8ad6,0x8acd,0x8ab6,
  0x8ab9,0x8adb,0x8c4c,0x8c4e, 0x8c6c,0x8ce0,0x8cde,0x8ce6,
  0x8ce4,0x8cec,0x8ced,0x8ce2, 0x8ce3,0x8cdc,0x8cea,0x8ce1,
  0x8d6d,0x8d9f,0x8da3,0x8e2b, 0x8e10,0x8e1d,0x8e22,0x8e0f,
  0x8e29,0x8e1f,0x8e21,0x8e1e, 0x8eba,0x8f1d,0x8f1b,0x8f1f,
  0x8f29,0x8f26,0x8f2a,0x8f1c, 0x8f1e,0x8f25,0x9069,0x906e,
  0x9068,0x906d,0x9077,0x9130, 0x912d,0x9127,0x9131,0x9187,
  0x9189,0x918b,0x9183,0x92c5, 0x92bb,0x92b7,0x92ea,0x92e4,
  0x92c1,0x92b3,0x92bc,0x92d2, 0x92c7,0x92f0,0x92b2,0x95ad,
  0x95b1,0x9704,0x9706,0x9707, 0x9709,0x9760,0x978d,0x978b,
  0x978f,0x9821,0x982b,0x981c, 0x98b3,0x990a,0x9913,0x9912,
  0x9918,0x99dd,0x99d0,0x99df, 0x99db,0x99d1,0x99d5,0x99d2,
  0x99d9,0x9ab7,0x9aee,0x9aef, 0x9b27,0x9b45,0x9b44,0x9b77,
  0x9b6f,0x9d06,0x9d09,0x9d03, 0x9ea9,0x9ebe,0x9ece,0x58a8,
  0x9f52,0x5112,0x5118,0x5114, 0x5110,0x5115,0x5180,0x51aa,
  0x51dd,0x5291,0x5293,0x52f3, 0x5659,0x566b,0x5679,0x5669,
  0x5664,0x5678,0x566a,0x5668, 0x5665,0x5671,0x566f,0x566c,
  0x5662,0x5676,0x58c1,0x58be, 0x58c7,0x58c5,0x596e,0x5b1d,
  0x5b34,0x5b78,0x5bf0,0x5c0e, 0x5f4a,0x61b2,0x6191,0x61a9,
  0x618a,0x61cd,0x61b6,0x61be, 0x61ca,0x61c8,0x6230,0x64c5,
  0x64c1,0x64cb,0x64bb,0x64bc, 0x64da,0x64c4,0x64c7,0x64c2,
  0x64cd,0x64bf,0x64d2,0x64d4, 0x64be,0x6574,0x66c6,0x66c9,
  0x66b9,0x66c4,0x66c7,0x66b8, 0x6a3d,0x6a38,0x6a3a,0x6a59,
  0x6a6b,0x6a58,0x6a39,0x6a44, 0x6a62,0x6a61,0x6a4b,0x6a47,
  0x6a35,0x6a5f,0x6a48,0x6b59, 0x6b77,0x6c05,0x6fc2,0x6fb1,
  0x6fa1,0x6fc3,0x6fa4,0x6fc1, 0x6fa7,0x6fb3,0x6fc0,0x6fb9,
  0x6fb6,0x6fa6,0x6fa0,0x6fb4, 0x71be,0x71c9,0x71d0,0x71d2,
  0x71c8,0x71d5,0x71b9,0x71ce, 0x71d9,0x71dc,0x71c3,0x71c4,
  0x7368,0x749c,0x74a3,0x7498, 0x749f,0x749e,0x74e2,0x750c,
  0x750d,0x7634,0x7638,0x763a, 0x76e7,0x76e5,0x77a0,0x779e,
  0x779f,0x77a5,0x78e8,0x78da, 0x78ec,0x78e7,0x79a6,0x7a4d,
  0x7a4e,0x7a46,0x7a4c,0x7a4b, 0x7aba,0x7bd9,0x7c11,0x7bc9,
  0x7be4,0x7bdb,0x7be1,0x7be9, 0x7be6,0x7cd5,0x7cd6,0x7e0a,
  0x7e11,0x7e08,0x7e1b,0x7e23, 0x7e1e,0x7e1d,0x7e09,0x7e10,
  0x7f79,0x7fb2,0x7ff0,0x7ff1, 0x7fee,0x8028,0x81b3,0x81a9,
  0x81a8,0x81fb,0x8208,0x8258, 0x8259,0x854a,0x8559,0x8548,
  0x8568,0x8569,0x8543,0x8549, 0x856d,0x856a,0x855e,0x8783,
  0x879f,0x879e,0x87a2,0x878d, 0x8861,0x892a,0x8932,0x8925,
  0x892b,0x8921,0x89aa,0x89a6, 0x8ae6,0x8afa,0x8aeb,0x8af1,
  0x8b00,0x8adc,0x8ae7,0x8aee, 0x8afe,0x8b01,0x8b02,0x8af7,
  0x8aed,0x8af3,0x8af6,0x8afc, 0x8c6b,0x8c6d,0x8c93,0x8cf4,
  0x8e44,0x8e31,0x8e34,0x8e42, 0x8e39,0x8e35,0x8f3b,0x8f2f,
  0x8f38,0x8f33,0x8fa8,0x8fa6, 0x9075,0x9074,0x9078,0x9072,
  0x907c,0x907a,0x9134,0x9192, 0x9320,0x9336,0x92f8,0x9333,
  0x932f,0x9322,0x92fc,0x932b, 0x9304,0x931a,0x9310,0x9326,
  0x9321,0x9315,0x932e,0x9319, 0x95bb,0x96a7,0x96a8,0x96aa,
  0x96d5,0x970e,0x9711,0x9716, 0x970d,0x9713,0x970f,0x975b,
  0x975c,0x9766,0x9798,0x9830, 0x9838,0x983b,0x9837,0x982d,
  0x9839,0x9824,0x9910,0x9928, 0x991e,0x991b,0x9921,0x991a,
  0x99ed,0x99e2,0x99f1,0x9ab8, 0x9abc,0x9afb,0x9aed,0x9b28,
  0x9b91,0x9d15,0x9d23,0x9d26, 0x9d28,0x9d12,0x9d1b,0x9ed8,
  0x9ed4,0x9f8d,0x9f9c,0x512a, 0x511f,0x5121,0x5132,0x52f5,
  0x568e,0x5680,0x5690,0x5685, 0x5687,0x568f,0x58d5,0x58d3,
  0x58d1,0x58ce,0x5b30,0x5b2a, 0x5b24,0x5b7a,0x5c37,0x5c68,
  0x5dbc,0x5dba,0x5dbd,0x5db8, 0x5e6b,0x5f4c,0x5fbd,0x61c9,
  0x61c2,0x61c7,0x61e6,0x61cb, 0x6232,0x6234,0x64ce,0x64ca,
  0x64d8,0x64e0,0x64f0,0x64e6, 0x64ec,0x64f1,0x64e2,0x64ed,
  0x6582,0x6583,0x66d9,0x66d6, 0x6a80,0x6a94,0x6a84,0x6aa2,
  0x6a9c,0x6adb,0x6aa3,0x6a7e, 0x6a97,0x6a90,0x6aa0,0x6b5c,
  0x6bae,0x6bda,0x6c08,0x6fd8, 0x6ff1,0x6fdf,0x6fe0,0x6fdb,
  0x6fe4,0x6feb,0x6fef,0x6f80, 0x6fec,0x6fe1,0x6fe9,0x6fd5,
  0x6fee,0x6ff0,0x71e7,0x71df, 0x71ee,0x71e6,0x71e5,0x71ed,
  0x71ec,0x71f4,0x71e0,0x7235, 0x7246,0x7370,0x7372,0x74a9,
  0x74b0,0x74a6,0x74a8,0x7646, 0x7642,0x764c,0x76ea,0x77b3,
  0x77aa,0x77b0,0x77ac,0x77a7, 0x77ad,0x77ef,0x78f7,0x78fa,
  0x78f4,0x78ef,0x7901,0x79a7, 0x79aa,0x7a57,0x7abf,0x7c07,
  0x7c0d,0x7bfe,0x7bf7,0x7c0c, 0x7be0,0x7ce0,0x7cdc,0x7cde,
  0x7ce2,0x7cdf,0x7cd9,0x7cdd, 0x7e2e,0x7e3e,0x7e46,0x7e37,
  0x7e32,0x7e43,0x7e2b,0x7e3d, 0x7e31,0x7e45,0x7e41,0x7e34,
  0x7e39,0x7e48,0x7e35,0x7e3f, 0x7e2f,0x7f44,0x7ff3,0x7ffc,
  0x8071,0x8072,0x8070,0x806f, 0x8073,0x81c6,0x81c3,0x81ba,
  0x81c2,0x81c0,0x81bf,0x81bd, 0x81c9,0x81be,0x81e8,0x8209,
  0x8271,0x85aa,0x8584,0x857e, 0x859c,0x8591,0x8594,0x85af,
  0x859b,0x8587,0x85a8,0x858a, 0x85a6,0x8667,0x87c0,0x87d1,
  0x87b3,0x87d2,0x87c6,0x87ab, 0x87bb,0x87ba,0x87c8,0x87cb,
  0x893b,0x8936,0x8944,0x8938, 0x893d,0x89ac,0x8b0e,0x8b17,
  0x8b19,0x8b1b,0x8b0a,0x8b20, 0x8b1d,0x8b04,0x8b10,0x8c41,
  0x8c3f,0x8c73,0x8cfa,0x8cfd, 0x8cfc,0x8cf8,0x8cfb,0x8da8,
  0x8e49,0x8e4b,0x8e48,0x8e4a, 0x8f44,0x8f3e,0x8f42,0x8f45,
  0x8f3f,0x907f,0x907d,0x9084, 0x9081,0x9082,0x9080,0x9139,
  0x91a3,0x919e,0x919c,0x934d, 0x9382,0x9328,0x9375,0x934a,
  0x9365,0x934b,0x9318,0x937e, 0x936c,0x935b,0x9370,0x935a,
  0x9354,0x95ca,0x95cb,0x95cc, 0x95c8,0x95c6,0x96b1,0x96b8,
  0x96d6,0x971c,0x971e,0x97a0, 0x97d3,0x9846,0x98b6,0x9935,
  0x9a01,0x99ff,0x9bae,0x9bab, 0x9baa,0x9bad,0x9d3b,0x9d3f,
  0x9e8b,0x9ecf,0x9ede,0x9edc, 0x9edd,0x9edb,0x9f3e,0x9f4b,
  0x53e2,0x5695,0x56ae,0x58d9, 0x58d8,0x5b38,0x5f5e,0x61e3,
  0x6233,0x64f4,0x64f2,0x64fe, 0x6506,0x64fa,0x64fb,0x64f7,
  0x65b7,0x66dc,0x6726,0x6ab3, 0x6aac,0x6ac3,0x6abb,0x6ab8,
  0x6ac2,0x6aae,0x6aaf,0x6b5f, 0x6b78,0x6baf,0x7009,0x700b,
  0x6ffe,0x7006,0x6ffa,0x7011, 0x700f,0x71fb,0x71fc,0x71fe,
  0x71f8,0x7377,0x7375,0x74a7, 0x74bf,0x7515,0x7656,0x7658,
  0x7652,0x77bd,0x77bf,0x77bb, 0x77bc,0x790e,0x79ae,0x7a61,
  0x7a62,0x7a60,0x7ac4,0x7ac5, 0x7c2b,0x7c27,0x7c2a,0x7c1e,
  0x7c23,0x7c21,0x7ce7,0x7e54, 0x7e55,0x7e5e,0x7e5a,0x7e61,
  0x7e52,0x7e59,0x7f48,0x7ff9, 0x7ffb,0x8077,0x8076,0x81cd,
  0x81cf,0x820a,0x85cf,0x85a9, 0x85cd,0x85d0,0x85c9,0x85b0,
  0x85ba,0x85b9,0x87ef,0x87ec, 0x87f2,0x87e0,0x8986,0x89b2,
  0x89f4,0x8b28,0x8b39,0x8b2c, 0x8b2b,0x8c50,0x8d05,0x8e59,
  0x8e63,0x8e66,0x8e64,0x8e5f, 0x8e55,0x8ec0,0x8f49,0x8f4d,
  0x9087,0x9083,0x9088,0x91ab, 0x91ac,0x91d0,0x9394,0x938a,
  0x9396,0x93a2,0x93b3,0x93ae, 0x93ac,0x93b0,0x9398,0x939a,
  0x9397,0x95d4,0x95d6,0x95d0, 0x95d5,0x96e2,0x96dc,0x96d9,
  0x96db,0x96de,0x9724,0x97a3, 0x97a6,0x97ad,0x97f9,0x984d,
  0x984f,0x984c,0x984e,0x9853, 0x98ba,0x993e,0x993f,0x993d,
  0x992e,0x99a5,0x9a0e,0x9ac1, 0x9b03,0x9b06,0x9b4f,0x9b4e,
  0x9b4d,0x9bca,0x9bc9,0x9bfd, 0x9bc8,0x9bc0,0x9d51,0x9d5d,
  0x9d60,0x9ee0,0x9f15,0x9f2c, 0x5133,0x56a5,0x56a8,0x58de,
  0x58df,0x58e2,0x5bf5,0x9f90, 0x5eec,0x61f2,0x61f7,0x61f6,
  0x61f5,0x6500,0x650f,0x66e0, 0x66dd,0x6ae5,0x6add,0x6ada,
  0x6ad3,0x701b,0x701f,0x7028, 0x701a,0x701d,0x7015,0x7018,
  0x7206,0x720d,0x7258,0x72a2, 0x7378,0x737a,0x74bd,0x74ca,
  0x74e3,0x7587,0x7586,0x765f, 0x7661,0x77c7,0x7919,0x79b1,
  0x7a6b,0x7a69,0x7c3e,0x7c3f, 0x7c38,0x7c3d,0x7c37,0x7c40,
  0x7e6b,0x7e6d,0x7e79,0x7e69, 0x7e6a,0x7e73,0x7f85,0x7fb6,
  0x7fb9,0x7fb8,0x81d8,0x85e9, 0x85dd,0x85ea,0x85d5,0x85e4,
  0x85e5,0x85f7,0x87fb,0x8805, 0x880d,0x87f9,0x87fe,0x8960,
  0x895f,0x8956,0x895e,0x8b41, 0x8b5c,0x8b58,0x8b49,0x8b5a,
  0x8b4e,0x8b4f,0x8b46,0x8b59, 0x8d08,0x8d0a,0x8e7c,0x8e72,
  0x8e87,0x8e76,0x8e6c,0x8e7a, 0x8e74,0x8f54,0x8f4e,0x8fad,
  0x908a,0x908b,0x91b1,0x91ae, 0x93e1,0x93d1,0x93df,0x93c3,
  0x93c8,0x93dc,0x93dd,0x93d6, 0x93e2,0x93cd,0x93d8,0x93e4,
  0x93d7,0x93e8,0x95dc,0x96b4, 0x96e3,0x972a,0x9727,0x9761,
  0x97dc,0x97fb,0x985e,0x9858, 0x985b,0x98bc,0x9945,0x9949,
  0x9a16,0x9a19,0x9b0d,0x9be8, 0x9be7,0x9bd6,0x9bdb,0x9d89,
  0x9d61,0x9d72,0x9d6a,0x9d6c, 0x9e92,0x9e97,0x9e93,0x9eb4,
  0x52f8,0x56b7,0x56b6,0x56b4, 0x56bc,0x58e4,0x5b40,0x5b43,
  0x5b7d,0x5bf6,0x5dc9,0x61f8, 0x61fa,0x6518,0x6514,0x6519,
  0x66e6,0x6727,0x6aec,0x703e, 0x7030,0x7032,0x7210,0x737b,
  0x74cf,0x7662,0x7665,0x7926, 0x792a,0x792c,0x792b,0x7ac7,
  0x7af6,0x7c4c,0x7c43,0x7c4d, 0x7cef,0x7cf0,0x8fae,0x7e7d,
  0x7e7c,0x7e82,0x7f4c,0x8000, 0x81da,0x8266,0x85fb,0x85f9,
  0x8611,0x85fa,0x8606,0x860b, 0x8607,0x860a,0x8814,0x8815,
  0x8964,0x89ba,0x89f8,0x8b70, 0x8b6c,0x8b66,0x8b6f,0x8b5f,
  0x8b6b,0x8d0f,0x8d0d,0x8e89, 0x8e81,0x8e85,0x8e82,0x91b4,
  0x91cb,0x9418,0x9403,0x93fd, 0x95e1,0x9730,0x98c4,0x9952,
  0x9951,0x99a8,0x9a2b,0x9a30, 0x9a37,0x9a35,0x9c13,0x9c0d,
  0x9e79,0x9eb5,0x9ee8,0x9f2f, 0x9f5f,0x9f63,0x9f61,0x5137,
  0x5138,0x56c1,0x56c0,0x56c2, 0x5914,0x5c6c,0x5dcd,0x61fc,
  0x61fe,0x651d,0x651c,0x6595, 0x66e9,0x6afb,0x6b04,0x6afa,
  0x6bb2,0x704c,0x721b,0x72a7, 0x74d6,0x74d4,0x7669,0x77d3,
  0x7c50,0x7e8f,0x7e8c,0x7fbc, 0x8617,0x862d,0x861a,0x8823,
  0x8822,0x8821,0x881f,0x896a, 0x896c,0x89bd,0x8b74,0x8b77,
  0x8b7d,0x8d13,0x8e8a,0x8e8d, 0x8e8b,0x8f5f,0x8faf,0x91ba,
  0x942e,0x9433,0x9435,0x943a, 0x9438,0x9432,0x942b,0x95e2,
  0x9738,0x9739,0x9732,0x97ff, 0x9867,0x9865,0x9957,0x9a45,
  0x9a43,0x9a40,0x9a3e,0x9acf, 0x9b54,0x9b51,0x9c2d,0x9c25,
  0x9daf,0x9db4,0x9dc2,0x9db8, 0x9e9d,0x9eef,0x9f19,0x9f5c,
  0x9f66,0x9f67,0x513c,0x513b, 0x56c8,0x56ca,0x56c9,0x5b7f,
  0x5dd4,0x5dd2,0x5f4e,0x61ff, 0x6524,0x6b0a,0x6b61,0x7051,
  0x7058,0x7380,0x74e4,0x758a, 0x766e,0x766c,0x79b3,0x7c60,
  0x7c5f,0x807e,0x807d,0x81df, 0x8972,0x896f,0x89fc,0x8b80,
  0x8d16,0x8d17,0x8e91,0x8e93, 0x8f61,0x9148,0x9444,0x9451,
  0x9452,0x973d,0x973e,0x97c3, 0x97c1,0x986b,0x9955,0x9a55,
  0x9a4d,0x9ad2,0x9b1a,0x9c49, 0x9c31,0x9c3e,0x9c3b,0x9dd3,
  0x9dd7,0x9f34,0x9f6c,0x9f6a, 0x9f94,0x56cc,0x5dd6,0x6200,
  0x6523,0x652b,0x652a,0x66ec, 0x6b10,0x74da,0x7aca,0x7c64,
  0x7c63,0x7c65,0x7e93,0x7e96, 0x7e94,0x81e2,0x8638,0x863f,
  0x8831,0x8b8a,0x9090,0x908f, 0x9463,0x9460,0x9464,0x9768,
  0x986f,0x995c,0x9a5a,0x9a5b, 0x9a57,0x9ad3,0x9ad4,0x9ad1,
  0x9c54,0x9c57,0x9c56,0x9de5, 0x9e9f,0x9ef4,0x56d1,0x58e9,
  0x652c,0x705e,0x7671,0x7672, 0x77d7,0x7f50,0x7f88,0x8836,
  0x8839,0x8862,0x8b93,0x8b92, 0x8b96,0x8277,0x8d1b,0x91c0,
  0x946a,0x9742,0x9748,0x9744, 0x97c6,0x9870,0x9a5f,0x9b22,
  0x9b58,0x9c5f,0x9df9,0x9dfa, 0x9e7c,0x9e7d,0x9f07,0x9f77,
  0x9f72,0x5ef3,0x6b16,0x7063, 0x7c6c,0x7c6e,0x883b,0x89c0,
  0x8ea1,0x91c1,0x9472,0x9470, 0x9871,0x995e,0x9ad6,0x9b23,
  0x9ecc,0x7064,0x77da,0x8b9a, 0x9477,0x97c9,0x9a62,0x9a65,
  0x7e9c,0x8b9c,0x8eaa,0x91c5, 0x947d,0x947e,0x947c,0x9c77,
  0x9c78,0x9ef7,0x8c54,0x947f, 0x9e1a,0x7228,0x9a6a,0x9b31,
  0x9e1b,0x9e1e,0x7c72,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000
};
unsigned short uni_t_cns11643_2[ISOMB_CODE_END] = {
/* codelimit: 8836 */
  0x4e42,0x4e5c,0x51f5,0x531a, 0x5382,0x4e07,0x4e0c,0x4e47,
  0x4e8d,0x56d7,0x5c6e,0x5f73, 0x4e0f,0x5187,0x4e0e,0x4e2e,
  0x4e93,0x4ec2,0x4ec9,0x4ec8, 0x5198,0x52fc,0x536c,0x53b9,
  0x5720,0x5903,0x592c,0x5c10, 0x5dff,0x65e1,0x6bb3,0x6bcc,
  0x6c14,0x723f,0x4e31,0x4e3c, 0x4ee8,0x4edc,0x4ee9,0x4ee1,
  0x4edd,0x4eda,0x520c,0x5209, 0x531c,0x534c,0x5722,0x5723,
  0x5917,0x592f,0x5b81,0x5b84, 0x5c12,0x5c3b,0x5c74,0x5c73,
  0x5e04,0x5e80,0x5e82,0x5fc9, 0x6209,0x6250,0x6c15,0x6c36,
  0x6c43,0x6c3f,0x6c3b,0x72ae, 0x72b0,0x738a,0x79b8,0x808a,
  0x961e,0x4f0e,0x4f18,0x4f2c, 0x4ef5,0x4f14,0x4ef1,0x4f00,
  0x4ef7,0x4f08,0x4f1d,0x4f02, 0x4f05,0x4f22,0x4f13,0x4f04,
  0x4ef4,0x4f12,0x51b1,0x5213, 0x5210,0x52a6,0x5322,0x531f,
  0x534d,0x538a,0x5407,0x56e1, 0x56df,0x572e,0x572a,0x5734,
  0x593c,0x5980,0x597c,0x5985, 0x597b,0x597e,0x5977,0x597f,
  0x5b56,0x5c15,0x5c25,0x5c7c, 0x5c7a,0x5c7b,0x5c7e,0x5ddf,
  0x5e75,0x5e84,0x5f02,0x5f1a, 0x5f74,0x5fd5,0x5fd4,0x5fcf,
  0x625c,0x625e,0x6264,0x6261, 0x6266,0x6262,0x6259,0x6260,
  0x625a,0x6265,0x6537,0x65ef, 0x65ee,0x673e,0x6739,0x6738,
  0x673b,0x673a,0x673f,0x673c, 0x6733,0x6c18,0x6c46,0x6c52,
  0x6c5c,0x6c4f,0x6c4a,0x6c54, 0x6c4b,0x6c4c,0x7071,0x725e,
  0x72b4,0x72b5,0x738e,0x752a, 0x767f,0x7a75,0x7f51,0x8278,
  0x827c,0x8280,0x827d,0x827f, 0x864d,0x897e,0x9099,0x9097,
  0x9098,0x909b,0x9094,0x9622, 0x9624,0x9620,0x9623,0x4f56,
  0x4f3b,0x4f62,0x4f49,0x4f53, 0x4f64,0x4f3e,0x4f67,0x4f52,
  0x4f5f,0x4f41,0x4f58,0x4f2d, 0x4f33,0x4f3f,0x4f61,0x518f,
  0x51b9,0x521c,0x521e,0x5221, 0x52ad,0x52ae,0x5309,0x5363,
  0x5372,0x538e,0x538f,0x5430, 0x5437,0x542a,0x5454,0x5445,
  0x5419,0x541c,0x5425,0x5418, 0x543d,0x544f,0x5441,0x5428,
  0x5424,0x5447,0x56ee,0x56e7, 0x56e5,0x5741,0x5745,0x574c,
  0x5749,0x574b,0x5752,0x5906, 0x5940,0x59a6,0x5998,0x59a0,
  0x5997,0x598e,0x59a2,0x5990, 0x598f,0x59a7,0x59a1,0x5b8e,
  0x5b92,0x5c28,0x5c2a,0x5c8d, 0x5c8f,0x5c88,0x5c8b,0x5c89,
  0x5c92,0x5c8a,0x5c86,0x5c93, 0x5c95,0x5de0,0x5e0a,0x5e0e,
  0x5e8b,0x5e89,0x5e8c,0x5e88, 0x5e8d,0x5f05,0x5f1d,0x5f78,
  0x5f76,0x5fd2,0x5fd1,0x5fd0, 0x5fed,0x5fe8,0x5fee,0x5ff3,
  0x5fe1,0x5fe4,0x5fe3,0x5ffa, 0x5fef,0x5ff7,0x5ffb,0x6000,
  0x5ff4,0x623a,0x6283,0x628c, 0x628e,0x628f,0x6294,0x6287,
  0x6271,0x627b,0x627a,0x6270, 0x6281,0x6288,0x6277,0x627d,
  0x6272,0x6274,0x65f0,0x65f4, 0x65f3,0x65f2,0x65f5,0x6745,
  0x6747,0x6759,0x6755,0x674c, 0x6748,0x675d,0x674d,0x675a,
  0x674b,0x6bd0,0x6c19,0x6c1a, 0x6c78,0x6c67,0x6c6b,0x6c84,
  0x6c8b,0x6c8f,0x6c71,0x6c6f, 0x6c69,0x6c9a,0x6c6d,0x6c87,
  0x6c95,0x6c9c,0x6c66,0x6c73, 0x6c65,0x6c7b,0x6c8e,0x7074,
  0x707a,0x7263,0x72bf,0x72bd, 0x72c3,0x72c6,0x72c1,0x72ba,
  0x72c5,0x7395,0x7397,0x7393, 0x7394,0x7392,0x753a,0x7539,
  0x7594,0x7595,0x7681,0x793d, 0x8034,0x8095,0x8099,0x8090,
  0x8092,0x809c,0x8290,0x828f, 0x8285,0x828e,0x8291,0x8293,
  0x828a,0x8283,0x8284,0x8c78, 0x8fc9,0x8fbf,0x909f,0x90a1,
  0x90a5,0x909e,0x90a7,0x90a0, 0x9630,0x9628,0x962f,0x962d,
  0x4e33,0x4f98,0x4f7c,0x4f85, 0x4f7d,0x4f80,0x4f87,0x4f76,
  0x4f74,0x4f89,0x4f84,0x4f77, 0x4f4c,0x4f97,0x4f6a,0x4f9a,
  0x4f79,0x4f81,0x4f78,0x4f90, 0x4f9c,0x4f94,0x4f9e,0x4f92,
  0x4f82,0x4f95,0x4f6b,0x4f6e, 0x519e,0x51bc,0x51be,0x5235,
  0x5232,0x5233,0x5246,0x5231, 0x52bc,0x530a,0x530b,0x533c,
  0x5392,0x5394,0x5487,0x547f, 0x5481,0x5491,0x5482,0x5488,
  0x546b,0x547a,0x547e,0x5465, 0x546c,0x5474,0x5466,0x548d,
  0x546f,0x5461,0x5460,0x5498, 0x5463,0x5467,0x5464,0x56f7,
  0x56f9,0x576f,0x5772,0x576d, 0x576b,0x5771,0x5770,0x5776,
  0x5780,0x5775,0x577b,0x5773, 0x5774,0x5762,0x5768,0x577d,
  0x590c,0x5945,0x59b5,0x59ba, 0x59cf,0x59ce,0x59b2,0x59cc,
  0x59c1,0x59b6,0x59bc,0x59c3, 0x59d6,0x59b1,0x59bd,0x59c0,
  0x59c8,0x59b4,0x59c7,0x5b62, 0x5b65,0x5b93,0x5b95,0x5c44,
  0x5c47,0x5cae,0x5ca4,0x5ca0, 0x5cb5,0x5caf,0x5ca8,0x5cac,
  0x5c9f,0x5ca3,0x5cad,0x5ca2, 0x5caa,0x5ca7,0x5c9d,0x5ca5,
  0x5cb6,0x5cb0,0x5ca6,0x5e17, 0x5e14,0x5e19,0x5f28,0x5f22,
  0x5f23,0x5f24,0x5f54,0x5f82, 0x5f7e,0x5f7d,0x5fde,0x5fe5,
  0x602d,0x6026,0x6019,0x6032, 0x600b,0x6034,0x600a,0x6017,
  0x6033,0x601a,0x601e,0x602c, 0x6022,0x600d,0x6010,0x602e,
  0x6013,0x6011,0x600c,0x6009, 0x601c,0x6214,0x623d,0x62ad,
  0x62b4,0x62d1,0x62be,0x62aa, 0x62b6,0x62ca,0x62ae,0x62b3,
  0x62af,0x62bb,0x62a9,0x62b0, 0x62b8,0x653d,0x65a8,0x65bb,
  0x6609,0x65fc,0x6604,0x6612, 0x6608,0x65fb,0x6603,0x660b,
  0x660d,0x6605,0x65fd,0x6611, 0x6610,0x66f6,0x670a,0x6785,
  0x676c,0x678e,0x6792,0x6776, 0x677b,0x6798,0x6786,0x6784,
  0x6774,0x678d,0x678c,0x677a, 0x679f,0x6791,0x6799,0x6783,
  0x677d,0x6781,0x6778,0x6779, 0x6794,0x6b25,0x6b80,0x6b7e,
  0x6bde,0x6c1d,0x6c93,0x6cec, 0x6ceb,0x6cee,0x6cd9,0x6cb6,
  0x6cd4,0x6cad,0x6ce7,0x6cb7, 0x6cd0,0x6cc2,0x6cba,0x6cc3,
  0x6cc6,0x6ced,0x6cf2,0x6cd2, 0x6cdd,0x6cb4,0x6c8a,0x6c9d,
  0x6c80,0x6cde,0x6cc0,0x6d30, 0x6ccd,0x6cc7,0x6cb0,0x6cf9,
  0x6ccf,0x6ce9,0x6cd1,0x7094, 0x7098,0x7085,0x7093,0x7086,
  0x7084,0x7091,0x7096,0x7082, 0x709a,0x7083,0x726a,0x72d6,
  0x72cb,0x72d8,0x72c9,0x72dc, 0x72d2,0x72d4,0x72da,0x72cc,
  0x72d1,0x73a4,0x73a1,0x73ad, 0x73a6,0x73a2,0x73a0,0x73ac,
  0x739d,0x74dd,0x74e8,0x753f, 0x7540,0x753e,0x758c,0x7598,
  0x76af,0x76f3,0x76f1,0x76f0, 0x76f5,0x77f8,0x77fc,0x77f9,
  0x77fb,0x77fa,0x77f7,0x7942, 0x793f,0x79c5,0x7a78,0x7a7b,
  0x7afb,0x7c75,0x7cfd,0x8035, 0x808f,0x80ae,0x80a3,0x80b8,
  0x80b5,0x80ad,0x8220,0x82a0, 0x82c0,0x82ab,0x829a,0x8298,
  0x829b,0x82b5,0x82a7,0x82ae, 0x82bc,0x829e,0x82ba,0x82b4,
  0x82a8,0x82a1,0x82a9,0x82c2, 0x82a4,0x82c3,0x82b6,0x82a2,
  0x8670,0x866f,0x866d,0x866e, 0x8c56,0x8fd2,0x8fcb,0x8fd3,
  0x8fcd,0x8fd6,0x8fd5,0x8fd7, 0x90b2,0x90b4,0x90af,0x90b3,
  0x90b0,0x9639,0x963d,0x963c, 0x963a,0x9643,0x4fcd,0x4fc5,
  0x4fd3,0x4fb2,0x4fc9,0x4fcb, 0x4fc1,0x4fd4,0x4fdc,0x4fd9,
  0x4fbb,0x4fb3,0x4fdb,0x4fc7, 0x4fd6,0x4fba,0x4fc0,0x4fb9,
  0x4fec,0x5244,0x5249,0x52c0, 0x52c2,0x533d,0x537c,0x5397,
  0x5396,0x5399,0x5398,0x54ba, 0x54a1,0x54ad,0x54a5,0x54cf,
  0x54c3,0x830d,0x54b7,0x54ae, 0x54d6,0x54b6,0x54c5,0x54c6,
  0x54a0,0x5470,0x54bc,0x54a2, 0x54be,0x5472,0x54de,0x54b0,
  0x57b5,0x579e,0x579f,0x57a4, 0x578c,0x5797,0x579d,0x579b,
  0x5794,0x5798,0x578f,0x5799, 0x57a5,0x579a,0x5795,0x58f4,
  0x590d,0x5953,0x59e1,0x59de, 0x59ee,0x5a00,0x59f1,0x59dd,
  0x59fa,0x59fd,0x59fc,0x59f6, 0x59e4,0x59f2,0x59f7,0x59db,
  0x59e9,0x59f3,0x59f5,0x59e0, 0x59fe,0x59f4,0x59ed,0x5ba8,
  0x5c4c,0x5cd0,0x5cd8,0x5ccc, 0x5cd7,0x5ccb,0x5cdb,0x5cde,
  0x5cda,0x5cc9,0x5cc7,0x5cca, 0x5cd6,0x5cd3,0x5cd4,0x5ccf,
  0x5cc8,0x5cc6,0x5cce,0x5cdf, 0x5cf8,0x5df9,0x5e21,0x5e22,
  0x5e23,0x5e20,0x5e24,0x5eb0, 0x5ea4,0x5ea2,0x5e9b,0x5ea3,
  0x5ea5,0x5f07,0x5f2e,0x5f56, 0x5f86,0x6037,0x6039,0x6054,
  0x6072,0x605e,0x6045,0x6053, 0x6047,0x6049,0x605b,0x604c,
  0x6040,0x6042,0x605f,0x6024, 0x6044,0x6058,0x6066,0x606e,
  0x6242,0x6243,0x62cf,0x630d, 0x630b,0x62f5,0x630e,0x6303,
  0x62eb,0x62f9,0x630f,0x630c, 0x62f8,0x62f6,0x6300,0x6313,
  0x6314,0x62fa,0x6315,0x62fb, 0x62f0,0x6541,0x6543,0x65aa,
  0x65bf,0x6636,0x6621,0x6632, 0x6635,0x661c,0x6626,0x6622,
  0x6633,0x662b,0x663a,0x661d, 0x6634,0x6639,0x662e,0x670f,
  0x6710,0x67c1,0x67f2,0x67c8, 0x67ba,0x67dc,0x67bb,0x67f8,
  0x67d8,0x67c0,0x67b7,0x67c5, 0x67eb,0x67e4,0x67df,0x67b5,
  0x67cd,0x67b3,0x67f7,0x67f6, 0x67ee,0x67e3,0x67c2,0x67b9,
  0x67ce,0x67e7,0x67f0,0x67b2, 0x67fc,0x67c6,0x67ed,0x67cc,
  0x67ae,0x67e6,0x67db,0x67fa, 0x67c9,0x67ca,0x67c3,0x67ea,
  0x67cb,0x6b28,0x6b82,0x6b84, 0x6bb6,0x6bd6,0x6bd8,0x6be0,
  0x6c20,0x6c21,0x6d28,0x6d34, 0x6d2d,0x6d1f,0x6d3c,0x6d3f,
  0x6d12,0x6d0a,0x6cda,0x6d33, 0x6d04,0x6d19,0x6d3a,0x6d1a,
  0x6d11,0x6d00,0x6d1d,0x6d42, 0x6d01,0x6d18,0x6d37,0x6d03,
  0x6d0f,0x6d40,0x6d07,0x6d20, 0x6d2c,0x6d08,0x6d22,0x6d09,
  0x6d10,0x70b7,0x709f,0x70be, 0x70b1,0x70b0,0x70a1,0x70b4,
  0x70b5,0x70a9,0x7241,0x7249, 0x724a,0x726c,0x7270,0x7273,
  0x726e,0x72ca,0x72e4,0x72e8, 0x72eb,0x72df,0x72ea,0x72e6,
  0x72e3,0x7385,0x73cc,0x73c2, 0x73c8,0x73c5,0x73b9,0x73b6,
  0x73b5,0x73b4,0x73eb,0x73bf, 0x73c7,0x73be,0x73c3,0x73c6,
  0x73b8,0x73cb,0x74ec,0x74ee, 0x752e,0x7547,0x7548,0x75a7,
  0x75aa,0x7679,0x76c4,0x7708, 0x7703,0x7704,0x7705,0x770a,
  0x76f7,0x76fb,0x76fa,0x77e7, 0x77e8,0x7806,0x7811,0x7812,
  0x7805,0x7810,0x780f,0x780e, 0x7809,0x7803,0x7813,0x794a,
  0x794c,0x794b,0x7945,0x7944, 0x79d5,0x79cd,0x79cf,0x79d6,
  0x79ce,0x7a80,0x7a7e,0x7ad1, 0x7b00,0x7b01,0x7c7a,0x7c78,
  0x7c79,0x7c7f,0x7c80,0x7c81, 0x7d03,0x7d08,0x7d01,0x7f58,
  0x7f91,0x7f8d,0x7fbe,0x8007, 0x800e,0x800f,0x8014,0x8037,
  0x80d8,0x80c7,0x80e0,0x80d1, 0x80c8,0x80c2,0x80d0,0x80c5,
  0x80e3,0x80d9,0x80dc,0x80ca, 0x80d5,0x80c9,0x80cf,0x80d7,
  0x80e6,0x80cd,0x81ff,0x8221, 0x8294,0x82d9,0x82fe,0x82f9,
  0x8307,0x82e8,0x8300,0x82d5, 0x833a,0x82eb,0x82d6,0x82f4,
  0x82ec,0x82e1,0x82f2,0x82f5, 0x830c,0x82fb,0x82f6,0x82f0,
  0x82ea,0x82e4,0x82e0,0x82fa, 0x82f3,0x82ed,0x8677,0x8674,
  0x867c,0x8673,0x8841,0x884e, 0x8867,0x886a,0x8869,0x89d3,
  0x8a04,0x8a07,0x8d72,0x8fe3, 0x8fe1,0x8fee,0x8fe0,0x90f1,
  0x90bd,0x90bf,0x90d5,0x90c5, 0x90be,0x90c7,0x90cb,0x90c8,
  0x91d4,0x91d3,0x9654,0x964f, 0x9651,0x9653,0x964a,0x964e,
  0x501e,0x5005,0x5007,0x5013, 0x5022,0x5030,0x501b,0x4ff5,
  0x4ff4,0x5033,0x5037,0x502c, 0x4ff6,0x4ff7,0x5017,0x501c,
  0x5020,0x5027,0x5035,0x502f, 0x5031,0x500e,0x515a,0x5194,
  0x5193,0x51ca,0x51c4,0x51c5, 0x51c8,0x51ce,0x5261,0x525a,
  0x5252,0x525e,0x525f,0x5255, 0x5262,0x52cd,0x530e,0x539e,
  0x5526,0x54e2,0x5517,0x5512, 0x54e7,0x54f3,0x54e4,0x551a,
  0x54ff,0x5504,0x5508,0x54eb, 0x5511,0x5505,0x54f1,0x550a,
  0x54fb,0x54f7,0x54f8,0x54e0, 0x550e,0x5503,0x550b,0x5701,
  0x5702,0x57cc,0x5832,0x57d5, 0x57d2,0x57ba,0x57c6,0x57bd,
  0x57bc,0x57b8,0x57b6,0x57bf, 0x57c7,0x57d0,0x57b9,0x57c1,
  0x590e,0x594a,0x5a19,0x5a16, 0x5a2d,0x5a2e,0x5a15,0x5a0f,
  0x5a17,0x5a0a,0x5a1e,0x5a33, 0x5b6c,0x5ba7,0x5bad,0x5bac,
  0x5c03,0x5c56,0x5c54,0x5cec, 0x5cff,0x5cee,0x5cf1,0x5cf7,
  0x5d00,0x5cf9,0x5e29,0x5e28, 0x5ea8,0x5eae,0x5eaa,0x5eac,
  0x5f33,0x5f30,0x5f67,0x605d, 0x605a,0x6067,0x6041,0x60a2,
  0x6088,0x6080,0x6092,0x6081, 0x609d,0x6083,0x6095,0x609b,
  0x6097,0x6087,0x609c,0x608e, 0x6219,0x6246,0x62f2,0x6310,
  0x6356,0x632c,0x6344,0x6345, 0x6336,0x6343,0x63e4,0x6339,
  0x634b,0x634a,0x633c,0x6329, 0x6341,0x6334,0x6358,0x6354,
  0x6359,0x632d,0x6347,0x6333, 0x635a,0x6351,0x6338,0x6357,
  0x6340,0x6348,0x654a,0x6546, 0x65c6,0x65c3,0x65c4,0x65c2,
  0x664a,0x665f,0x6647,0x6651, 0x6712,0x6713,0x681f,0x681a,
  0x6849,0x6832,0x6833,0x683b, 0x684b,0x684f,0x6816,0x6831,
  0x681c,0x6835,0x682b,0x682d, 0x682f,0x684e,0x6844,0x6834,
  0x681d,0x6812,0x6814,0x6826, 0x6828,0x682e,0x684d,0x683a,
  0x6825,0x6820,0x6b2c,0x6b2f, 0x6b2d,0x6b31,0x6b34,0x6b6d,
  0x8082,0x6b88,0x6be6,0x6be4, 0x6be8,0x6be3,0x6be2,0x6be7,
  0x6c25,0x6d7a,0x6d63,0x6d64, 0x6d76,0x6d0d,0x6d61,0x6d92,
  0x6d58,0x6d62,0x6d6d,0x6d6f, 0x6d91,0x6d8d,0x6def,0x6d7f,
  0x6d86,0x6d5e,0x6d67,0x6d60, 0x6d97,0x6d70,0x6d7c,0x6d5f,
  0x6d82,0x6d98,0x6d2f,0x6d68, 0x6d8b,0x6d7e,0x6d80,0x6d84,
  0x6d16,0x6d83,0x6d7b,0x6d7d, 0x6d75,0x6d90,0x70dc,0x70d3,
  0x70d1,0x70dd,0x70cb,0x7f39, 0x70e2,0x70d7,0x70d2,0x70de,
  0x70e0,0x70d4,0x70cd,0x70c5, 0x70c6,0x70c7,0x70da,0x70ce,
  0x70e1,0x7242,0x7278,0x7277, 0x7276,0x7300,0x72fa,0x72f4,
  0x72fe,0x72f6,0x72f3,0x72fb, 0x7301,0x73d3,0x73d9,0x73e5,
  0x73d6,0x73bc,0x73e7,0x73e3, 0x73e9,0x73dc,0x73d2,0x73db,
  0x73d4,0x73dd,0x73da,0x73d7, 0x73d8,0x73e8,0x74de,0x74df,
  0x74f4,0x74f5,0x7521,0x755b, 0x755f,0x75b0,0x75c1,0x75bb,
  0x75c4,0x75c0,0x75bf,0x75b6, 0x75ba,0x768a,0x76c9,0x771d,
  0x771b,0x7710,0x7713,0x7712, 0x7723,0x7711,0x7715,0x7719,
  0x771a,0x7722,0x7727,0x7823, 0x782c,0x7822,0x7835,0x782f,
  0x7828,0x782e,0x782b,0x7821, 0x7829,0x7833,0x782a,0x7831,
  0x7954,0x795b,0x794f,0x795c, 0x7953,0x7952,0x7951,0x79eb,
  0x79ec,0x79e0,0x79ee,0x79ed, 0x79ea,0x79dc,0x79de,0x79dd,
  0x7a86,0x7a89,0x7a85,0x7a8b, 0x7a8c,0x7a8a,0x7a87,0x7ad8,
  0x7b10,0x7b04,0x7b13,0x7b05, 0x7b0f,0x7b08,0x7b0a,0x7b0e,
  0x7b09,0x7b12,0x7c84,0x7c91, 0x7c8a,0x7c8c,0x7c88,0x7c8d,
  0x7c85,0x7d1e,0x7d1d,0x7d11, 0x7d0e,0x7d18,0x7d16,0x7d13,
  0x7d1f,0x7d12,0x7d0f,0x7d0c, 0x7f5c,0x7f61,0x7f5e,0x7f60,
  0x7f5d,0x7f5b,0x7f96,0x7f92, 0x7fc3,0x7fc2,0x7fc0,0x8016,
  0x803e,0x8039,0x80fa,0x80f2, 0x80f9,0x80f5,0x8101,0x80fb,
  0x8100,0x8201,0x822f,0x8225, 0x8333,0x832d,0x8344,0x8319,
  0x8351,0x8325,0x8356,0x833f, 0x8341,0x8326,0x831c,0x8322,
  0x8342,0x834e,0x831b,0x832a, 0x8308,0x833c,0x834d,0x8316,
  0x8324,0x8320,0x8337,0x832f, 0x8329,0x8347,0x8345,0x834c,
  0x8353,0x831e,0x832c,0x834b, 0x8327,0x8348,0x8653,0x8652,
  0x86a2,0x86a8,0x8696,0x868d, 0x8691,0x869e,0x8687,0x8697,
  0x8686,0x868b,0x869a,0x8685, 0x86a5,0x8699,0x86a1,0x86a7,
  0x8695,0x8698,0x868e,0x869d, 0x8690,0x8694,0x8843,0x8844,
  0x886d,0x8875,0x8876,0x8872, 0x8880,0x8871,0x887f,0x886f,
  0x8883,0x887e,0x8874,0x887c, 0x8a12,0x8c47,0x8c57,0x8c7b,
  0x8ca4,0x8ca3,0x8d76,0x8d78, 0x8db5,0x8db7,0x8db6,0x8ed1,
  0x8ed3,0x8ffe,0x8ff5,0x9002, 0x8fff,0x8ffb,0x9004,0x8ffc,
  0x8ff6,0x90d6,0x90e0,0x90d9, 0x90da,0x90e3,0x90df,0x90e5,
  0x90d8,0x90db,0x90d7,0x90dc, 0x90e4,0x9150,0x914e,0x914f,
  0x91d5,0x91e2,0x91da,0x965c, 0x965f,0x96bc,0x98e3,0x9adf,
  0x9b2f,0x4e7f,0x5070,0x506a, 0x5061,0x505e,0x5060,0x5053,
  0x504b,0x505d,0x5072,0x5048, 0x504d,0x5041,0x505b,0x504a,
  0x5062,0x5015,0x5045,0x505f, 0x5069,0x506b,0x5063,0x5064,
  0x5046,0x5040,0x506e,0x5073, 0x5057,0x5051,0x51d0,0x526b,
  0x526d,0x526c,0x526e,0x52d6, 0x52d3,0x532d,0x539c,0x5575,
  0x5576,0x553c,0x554d,0x5550, 0x5534,0x552a,0x5551,0x5562,
  0x5536,0x5535,0x5530,0x5552, 0x5545,0x550c,0x5532,0x5565,
  0x554e,0x5539,0x5548,0x552d, 0x553b,0x5540,0x554b,0x570a,
  0x5707,0x57fb,0x5814,0x57e2, 0x57f6,0x57dc,0x57f4,0x5800,
  0x57ed,0x57fd,0x5808,0x57f8, 0x580b,0x57f3,0x57cf,0x5807,
  0x57ee,0x57e3,0x57f2,0x57e5, 0x57ec,0x57e1,0x580e,0x57fc,
  0x5810,0x57e7,0x5801,0x580c, 0x57f1,0x57e9,0x57f0,0x580d,
  0x5804,0x595c,0x5a60,0x5a58, 0x5a55,0x5a67,0x5a5e,0x5a38,
  0x5a35,0x5a6d,0x5a50,0x5a5f, 0x5a65,0x5a6c,0x5a53,0x5a64,
  0x5a57,0x5a43,0x5a5d,0x5a52, 0x5a44,0x5a5b,0x5a48,0x5a8e,
  0x5a3e,0x5a4d,0x5a39,0x5a4c, 0x5a70,0x5a69,0x5a47,0x5a51,
  0x5a56,0x5a42,0x5a5c,0x5b72, 0x5b6e,0x5bc1,0x5bc0,0x5c59,
  0x5d1e,0x5d0b,0x5d1d,0x5d1a, 0x5d20,0x5d0c,0x5d28,0x5d0d,
  0x5d26,0x5d25,0x5d0f,0x5d30, 0x5d12,0x5d23,0x5d1f,0x5d2e,
  0x5e3e,0x5e34,0x5eb1,0x5eb4, 0x5eb9,0x5eb2,0x5eb3,0x5f36,
  0x5f38,0x5f9b,0x5f96,0x5f9f, 0x608a,0x6090,0x6086,0x60be,
  0x60b0,0x60ba,0x60d3,0x60d4, 0x60cf,0x60e4,0x60d9,0x60dd,
  0x60c8,0x60b1,0x60db,0x60b7, 0x60ca,0x60bf,0x60c3,0x60cd,
  0x60c0,0x6332,0x6365,0x638a, 0x6382,0x637d,0x63bd,0x639e,
  0x63ad,0x639d,0x6397,0x63ab, 0x638e,0x636f,0x6387,0x6390,
  0x636e,0x63af,0x6375,0x639c, 0x636d,0x63ae,0x637c,0x63a4,
  0x633b,0x639f,0x6378,0x6385, 0x6381,0x6391,0x638d,0x6370,
  0x6553,0x65cd,0x6665,0x6661, 0x665b,0x6659,0x665c,0x6662,
  0x6718,0x6879,0x6887,0x6890, 0x689c,0x686d,0x686e,0x68ae,
  0x68ab,0x6956,0x686f,0x68a3, 0x68ac,0x68a9,0x6875,0x6874,
  0x68b2,0x688f,0x6877,0x6892, 0x687c,0x686b,0x6872,0x68aa,
  0x6880,0x6871,0x687e,0x689b, 0x6896,0x688b,0x68a0,0x6889,
  0x68a4,0x6878,0x687b,0x6891, 0x688c,0x688a,0x687d,0x6b36,
  0x6b33,0x6b37,0x6b38,0x6b91, 0x6b8f,0x6b8d,0x6b8e,0x6b8c,
  0x6c2a,0x6dc0,0x6dab,0x6db4, 0x6db3,0x6e74,0x6dac,0x6de9,
  0x6de2,0x6db7,0x6df6,0x6dd4, 0x6e00,0x6dc8,0x6de0,0x6ddf,
  0x6dd6,0x6dbe,0x6de5,0x6ddc, 0x6ddd,0x6ddb,0x6df4,0x6dca,
  0x6dbd,0x6ded,0x6df0,0x6dba, 0x6dd5,0x6dc2,0x6dcf,0x6dc9,
  0x6dd0,0x6df2,0x6dd3,0x6dfd, 0x6dd7,0x6dcd,0x6de3,0x6dbb,
  0x70fa,0x710d,0x70f7,0x7117, 0x70f4,0x710c,0x70f0,0x7104,
  0x70f3,0x7110,0x70fc,0x70ff, 0x7106,0x7113,0x7100,0x70f8,
  0x70f6,0x710b,0x7102,0x710e, 0x727e,0x727b,0x727c,0x727f,
  0x731d,0x7317,0x7307,0x7311, 0x7318,0x730a,0x7308,0x72ff,
  0x730f,0x731e,0x7388,0x73f6, 0x73f8,0x73f5,0x7404,0x7401,
  0x73fd,0x7407,0x7400,0x73fa, 0x73fc,0x73ff,0x740c,0x740b,
  0x73f4,0x7408,0x7564,0x7563, 0x75ce,0x75d2,0x75cf,0x75cb,
  0x75cc,0x75d1,0x75d0,0x768f, 0x7689,0x76d3,0x7739,0x772f,
  0x772d,0x7731,0x7732,0x7734, 0x7733,0x773d,0x7725,0x773b,
  0x7735,0x7848,0x7852,0x7849, 0x784d,0x784a,0x784c,0x7826,
  0x7845,0x7850,0x7964,0x7967, 0x7969,0x796a,0x7963,0x796b,
  0x7961,0x79bb,0x79fa,0x79f8, 0x79f6,0x79f7,0x7a8f,0x7a94,
  0x7a90,0x7b35,0x7b3b,0x7b34, 0x7b25,0x7b30,0x7b22,0x7b24,
  0x7b33,0x7b18,0x7b2a,0x7b1d, 0x7b31,0x7b2b,0x7b2d,0x7b2f,
  0x7b32,0x7b38,0x7b1a,0x7b23, 0x7c94,0x7c98,0x7c96,0x7ca3,
  0x7d35,0x7d3d,0x7d38,0x7d36, 0x7d3a,0x7d45,0x7d2c,0x7d29,
  0x7d41,0x7d47,0x7d3e,0x7d3f, 0x7d4a,0x7d3b,0x7d28,0x7f63,
  0x7f95,0x7f9c,0x7f9d,0x7f9b, 0x7fca,0x7fcb,0x7fcd,0x7fd0,
  0x7fd1,0x7fc7,0x7fcf,0x7fc9, 0x801f,0x801e,0x801b,0x8047,
  0x8043,0x8048,0x8118,0x8125, 0x8119,0x811b,0x812d,0x811f,
  0x812c,0x811e,0x8121,0x8115, 0x8127,0x811d,0x8122,0x8211,
  0x8238,0x8233,0x823a,0x8234, 0x8232,0x8274,0x8390,0x83a3,
  0x83a8,0x838d,0x837a,0x8373, 0x83a4,0x8374,0x838f,0x8381,
  0x8395,0x8399,0x8375,0x8394, 0x83a9,0x837d,0x8383,0x838c,
  0x839d,0x839b,0x83aa,0x838b, 0x837e,0x83a5,0x83af,0x8388,
  0x8397,0x83b0,0x837f,0x83a6, 0x8387,0x83ae,0x8376,0x8659,
  0x8656,0x86bf,0x86b7,0x86c2, 0x86c1,0x86c5,0x86ba,0x86b0,
  0x86c8,0x86b9,0x86b3,0x86b8, 0x86cc,0x86b4,0x86bb,0x86bc,
  0x86c3,0x86bd,0x86be,0x8852, 0x8889,0x8895,0x88a8,0x88a2,
  0x88aa,0x889a,0x8891,0x88a1, 0x889f,0x8898,0x88a7,0x8899,
  0x889b,0x8897,0x88a4,0x88ac, 0x888c,0x8893,0x888e,0x8982,
  0x89d6,0x89d9,0x89d5,0x8a30, 0x8a27,0x8a2c,0x8a1e,0x8c39,
  0x8c3b,0x8c5c,0x8c5d,0x8c7d, 0x8ca5,0x8d7d,0x8d7b,0x8d79,
  0x8dbc,0x8dc2,0x8db9,0x8dbf, 0x8dc1,0x8ed8,0x8ede,0x8edd,
  0x8edc,0x8ed7,0x8ee0,0x8ee1, 0x9024,0x900b,0x9011,0x901c,
  0x900c,0x9021,0x90ef,0x90ea, 0x90f0,0x90f4,0x90f2,0x90f3,
  0x90d4,0x90eb,0x90ec,0x90e9, 0x9156,0x9158,0x915a,0x9153,
  0x9155,0x91ec,0x91f4,0x91f1, 0x91f3,0x91f8,0x91e4,0x91f9,
  0x91ea,0x91eb,0x91f7,0x91e8, 0x91ee,0x957a,0x9586,0x9588,
  0x967c,0x966d,0x966b,0x9671, 0x966f,0x96bf,0x976a,0x9804,
  0x98e5,0x9997,0x509b,0x5095, 0x5094,0x509e,0x508b,0x50a3,
  0x5083,0x508c,0x508e,0x509d, 0x5068,0x509c,0x5092,0x5082,
  0x5087,0x515f,0x51d4,0x5312, 0x5311,0x53a4,0x53a7,0x5591,
  0x55a8,0x55a5,0x55ad,0x5577, 0x5645,0x55a2,0x5593,0x5588,
  0x558f,0x55b5,0x5581,0x55a3, 0x5592,0x55a4,0x557d,0x558c,
  0x55a6,0x557f,0x5595,0x55a1, 0x558e,0x570c,0x5829,0x5837,
  0x5819,0x581e,0x5827,0x5823, 0x5828,0x57f5,0x5848,0x5825,
  0x581c,0x581b,0x5833,0x583f, 0x5836,0x582e,0x5839,0x5838,
  0x582d,0x582c,0x583b,0x5961, 0x5aaf,0x5a94,0x5a9f,0x5a7a,
  0x5aa2,0x5a9e,0x5a78,0x5aa6, 0x5a7c,0x5aa5,0x5aac,0x5a95,
  0x5aae,0x5a37,0x5a84,0x5a8a, 0x5a97,0x5a83,0x5a8b,0x5aa9,
  0x5a7b,0x5a7d,0x5a8c,0x5a9c, 0x5a8f,0x5a93,0x5a9d,0x5bea,
  0x5bcd,0x5bcb,0x5bd4,0x5bd1, 0x5bca,0x5bce,0x5c0c,0x5c30,
  0x5d37,0x5d43,0x5d6b,0x5d41, 0x5d4b,0x5d3f,0x5d35,0x5d51,
  0x5d4e,0x5d55,0x5d33,0x5d3a, 0x5d52,0x5d3d,0x5d31,0x5d59,
  0x5d42,0x5d39,0x5d49,0x5d38, 0x5d3c,0x5d32,0x5d36,0x5d40,
  0x5d45,0x5e44,0x5e41,0x5f58, 0x5fa6,0x5fa5,0x5fab,0x60c9,
  0x60b9,0x60cc,0x60e2,0x60ce, 0x60c4,0x6114,0x60f2,0x610a,
  0x6116,0x6105,0x60f5,0x6113, 0x60f8,0x60fc,0x60fe,0x60c1,
  0x6103,0x6118,0x611d,0x6110, 0x60ff,0x6104,0x610b,0x624a,
  0x6394,0x63b1,0x63b0,0x63ce, 0x63e5,0x63e8,0x63ef,0x63c3,
  0x649d,0x63f3,0x63ca,0x63e0, 0x63f6,0x63d5,0x63f2,0x63f5,
  0x6461,0x63df,0x63be,0x63dd, 0x63dc,0x63c4,0x63d8,0x63d3,
  0x63c2,0x63c7,0x63cc,0x63cb, 0x63c8,0x63f0,0x63d7,0x63d9,
  0x6532,0x6567,0x656a,0x6564, 0x655c,0x6568,0x6565,0x658c,
  0x659d,0x659e,0x65ae,0x65d0, 0x65d2,0x667c,0x666c,0x667b,
  0x6680,0x6671,0x6679,0x666a, 0x6672,0x6701,0x690c,0x68d3,
  0x6904,0x68dc,0x692a,0x68ec, 0x68ea,0x68f1,0x690f,0x68d6,
  0x68f7,0x68eb,0x68e4,0x68f6, 0x6913,0x6910,0x68f3,0x68e1,
  0x6907,0x68cc,0x6908,0x6970, 0x68b4,0x6911,0x68ef,0x68c6,
  0x6914,0x68f8,0x68d0,0x68fd, 0x68fc,0x68e8,0x690b,0x690a,
  0x6917,0x68ce,0x68c8,0x68dd, 0x68de,0x68e6,0x68f4,0x68d1,
  0x6906,0x68d4,0x68e9,0x6915, 0x6925,0x68c7,0x6b39,0x6b3b,
  0x6b3f,0x6b3c,0x6b94,0x6b97, 0x6b99,0x6b95,0x6bbd,0x6bf0,
  0x6bf2,0x6bf3,0x6c30,0x6dfc, 0x6e46,0x6e47,0x6e1f,0x6e49,
  0x6e88,0x6e3c,0x6e3d,0x6e45, 0x6e62,0x6e2b,0x6e3f,0x6e41,
  0x6e5d,0x6e73,0x6e1c,0x6e33, 0x6e4b,0x6e40,0x6e51,0x6e3b,
  0x6e03,0x6e2e,0x6e5e,0x6e68, 0x6e5c,0x6e61,0x6e31,0x6e28,
  0x6e60,0x6e71,0x6e6b,0x6e39, 0x6e22,0x6e30,0x6e53,0x6e65,
  0x6e27,0x6e78,0x6e64,0x6e77, 0x6e55,0x6e79,0x6e52,0x6e66,
  0x6e35,0x6e36,0x6e5a,0x7120, 0x711e,0x712f,0x70fb,0x712e,
  0x7131,0x7123,0x7125,0x7122, 0x7132,0x711f,0x7128,0x713a,
  0x711b,0x724b,0x725a,0x7288, 0x7289,0x7286,0x7285,0x728b,
  0x7312,0x730b,0x7330,0x7322, 0x7331,0x7333,0x7327,0x7332,
  0x732d,0x7326,0x7323,0x7335, 0x730c,0x742e,0x742c,0x7430,
  0x742b,0x7416,0x741a,0x7421, 0x742d,0x7431,0x7424,0x7423,
  0x741d,0x7429,0x7420,0x7432, 0x74fb,0x752f,0x756f,0x756c,
  0x75e7,0x75da,0x75e1,0x75e6, 0x75dd,0x75df,0x75e4,0x75d7,
  0x7695,0x7692,0x76da,0x7746, 0x7747,0x7744,0x774d,0x7745,
  0x774a,0x774e,0x774b,0x774c, 0x77de,0x77ec,0x7860,0x7864,
  0x7865,0x785c,0x786d,0x7871, 0x786a,0x786e,0x7870,0x7869,
  0x7868,0x785e,0x7862,0x7974, 0x7973,0x7972,0x7970,0x7a02,
  0x7a0a,0x7a03,0x7a0c,0x7a04, 0x7a99,0x7ae6,0x7ae4,0x7b4a,
  0x7b47,0x7b44,0x7b48,0x7b4c, 0x7b4e,0x7b40,0x7b58,0x7b45,
  0x7ca2,0x7c9e,0x7ca8,0x7ca1, 0x7d58,0x7d6f,0x7d63,0x7d53,
  0x7d56,0x7d67,0x7d6a,0x7d4f, 0x7d6d,0x7d5c,0x7d6b,0x7d52,
  0x7d54,0x7d69,0x7d51,0x7d5f, 0x7d4e,0x7f3e,0x7f3f,0x7f65,
  0x7f66,0x7fa2,0x7fa0,0x7fa1, 0x7fd7,0x8051,0x804f,0x8050,
  0x80fe,0x80d4,0x8143,0x814a, 0x8152,0x814f,0x8147,0x813d,
  0x814d,0x813a,0x81e6,0x81ee, 0x81f7,0x81f8,0x81f9,0x8204,
  0x823c,0x823d,0x823f,0x8275, 0x833b,0x83cf,0x83f9,0x8423,
  0x83c0,0x83e8,0x8412,0x83e7, 0x83e4,0x83fc,0x83f6,0x8410,
  0x83c6,0x83c8,0x83eb,0x83e3, 0x83bf,0x8401,0x83dd,0x83e5,
  0x83d8,0x83ff,0x83e1,0x83cb, 0x83ce,0x83d6,0x83f5,0x83c9,
  0x8409,0x840f,0x83de,0x8411, 0x8406,0x83c2,0x83f3,0x83d5,
  0x83fa,0x83c7,0x83d1,0x83ea, 0x8413,0x839a,0x83c3,0x83ec,
  0x83ee,0x83c4,0x83fb,0x83d7, 0x83e2,0x841b,0x83db,0x83fe,
  0x86d8,0x86e2,0x86e6,0x86d3, 0x86e3,0x86da,0x86ea,0x86dd,
  0x86eb,0x86dc,0x86ec,0x86e9, 0x86d7,0x86e8,0x86d1,0x8848,
  0x8856,0x8855,0x88ba,0x88d7, 0x88b9,0x88b8,0x88c0,0x88be,
  0x88b6,0x88bc,0x88b7,0x88bd, 0x88b2,0x8901,0x88c9,0x8995,
  0x8998,0x8997,0x89dd,0x89da, 0x89db,0x8a4e,0x8a4d,0x8a39,
  0x8a59,0x8a40,0x8a57,0x8a58, 0x8a44,0x8a45,0x8a52,0x8a48,
  0x8a51,0x8a4a,0x8a4c,0x8a4f, 0x8c5f,0x8c81,0x8c80,0x8cba,
  0x8cbe,0x8cb0,0x8cb9,0x8cb5, 0x8d84,0x8d80,0x8d89,0x8dd8,
  0x8dd3,0x8dcd,0x8dc7,0x8dd6, 0x8ddc,0x8dcf,0x8dd5,0x8dd9,
  0x8dc8,0x8dd7,0x8dc5,0x8eef, 0x8ef7,0x8efa,0x8ef9,0x8ee6,
  0x8eee,0x8ee5,0x8ef5,0x8ee7, 0x8ee8,0x8ef6,0x8eeb,0x8ef1,
  0x8eec,0x8ef4,0x8ee9,0x902d, 0x9034,0x902f,0x9106,0x912c,
  0x9104,0x90ff,0x90fc,0x9108, 0x90f9,0x90fb,0x9101,0x9100,
  0x9107,0x9105,0x9103,0x9161, 0x9164,0x915f,0x9162,0x9160,
  0x9201,0x920a,0x9225,0x9203, 0x921a,0x9226,0x920f,0x920c,
  0x9200,0x9212,0x91ff,0x91fd, 0x9206,0x9204,0x9227,0x9202,
  0x921c,0x9224,0x9219,0x9217, 0x9205,0x9216,0x957b,0x958d,
  0x958c,0x9590,0x9687,0x967e, 0x9688,0x9689,0x9683,0x9680,
  0x96c2,0x96c8,0x96c3,0x96f1, 0x96f0,0x976c,0x9770,0x976e,
  0x9807,0x98a9,0x98eb,0x9ce6, 0x9ef9,0x4e83,0x4e84,0x4eb6,
  0x50bd,0x50bf,0x50c6,0x50ae, 0x50c4,0x50ca,0x50b4,0x50c8,
  0x50c2,0x50b0,0x50c1,0x50ba, 0x50b1,0x50cb,0x50c9,0x50b6,
  0x50b8,0x51d7,0x527a,0x5278, 0x527b,0x527c,0x55c3,0x55db,
  0x55cc,0x55d0,0x55cb,0x55ca, 0x55dd,0x55c0,0x55d4,0x55c4,
  0x55e9,0x55bf,0x55d2,0x558d, 0x55cf,0x55d5,0x55e2,0x55d6,
  0x55c8,0x55f2,0x55cd,0x55d9, 0x55c2,0x5714,0x5853,0x5868,
  0x5864,0x584f,0x584d,0x5849, 0x586f,0x5855,0x584e,0x585d,
  0x5859,0x5865,0x585b,0x583d, 0x5863,0x5871,0x58fc,0x5ac7,
  0x5ac4,0x5acb,0x5aba,0x5ab8, 0x5ab1,0x5ab5,0x5ab0,0x5abf,
  0x5ac8,0x5abb,0x5ac6,0x5ab7, 0x5ac0,0x5aca,0x5ab4,0x5ab6,
  0x5acd,0x5ab9,0x5a90,0x5bd6, 0x5bd8,0x5bd9,0x5c1f,0x5c33,
  0x5d71,0x5d63,0x5d4a,0x5d65, 0x5d72,0x5d6c,0x5d5e,0x5d68,
  0x5d67,0x5d62,0x5df0,0x5e4f, 0x5e4e,0x5e4a,0x5e4d,0x5e4b,
  0x5ec5,0x5ecc,0x5ec6,0x5ecb, 0x5ec7,0x5f40,0x5faf,0x5fad,
  0x60f7,0x6149,0x614a,0x612b, 0x6145,0x6136,0x6132,0x612e,
  0x6146,0x612f,0x614f,0x6129, 0x6140,0x6220,0x9168,0x6223,
  0x6225,0x6224,0x63c5,0x63f1, 0x63eb,0x6410,0x6412,0x6409,
  0x6420,0x6424,0x6433,0x6443, 0x641f,0x6415,0x6418,0x6439,
  0x6437,0x6422,0x6423,0x640c, 0x6426,0x6430,0x6428,0x6441,
  0x6435,0x642f,0x640a,0x641a, 0x6440,0x6425,0x6427,0x640b,
  0x63e7,0x641b,0x642e,0x6421, 0x640e,0x656f,0x6592,0x65d3,
  0x6686,0x668c,0x6695,0x6690, 0x668b,0x668a,0x6699,0x6694,
  0x6678,0x6720,0x6966,0x695f, 0x6938,0x694e,0x6962,0x6971,
  0x693f,0x6945,0x696a,0x6939, 0x6942,0x6957,0x6959,0x697a,
  0x6948,0x6949,0x6935,0x696c, 0x6933,0x693d,0x6965,0x68f0,
  0x6978,0x6934,0x6969,0x6940, 0x696f,0x6944,0x6976,0x6958,
  0x6941,0x6974,0x694c,0x693b, 0x694b,0x6937,0x695c,0x694f,
  0x6951,0x6932,0x6952,0x692f, 0x697b,0x693c,0x6b46,0x6b45,
  0x6b43,0x6b42,0x6b48,0x6b41, 0x6b9b,0x6bfb,0x6bfc,0x6bf9,
  0x6bf7,0x6bf8,0x6e9b,0x6ed6, 0x6ec8,0x6e8f,0x6ec0,0x6e9f,
  0x6e93,0x6e94,0x6ea0,0x6eb1, 0x6eb9,0x6ec6,0x6ed2,0x6ebd,
  0x6ec1,0x6e9e,0x6ec9,0x6eb7, 0x6eb0,0x6ecd,0x6ea6,0x6ecf,
  0x6eb2,0x6ebe,0x6ec3,0x6edc, 0x6ed8,0x6e99,0x6e92,0x6e8e,
  0x6e8d,0x6ea4,0x6ea1,0x6ebf, 0x6eb3,0x6ed0,0x6eca,0x6e97,
  0x6eae,0x6ea3,0x7147,0x7154, 0x7152,0x7163,0x7160,0x7141,
  0x715d,0x7162,0x7172,0x7178, 0x716a,0x7161,0x7142,0x7158,
  0x7143,0x714b,0x7170,0x715f, 0x7150,0x7153,0x7144,0x714d,
  0x715a,0x724f,0x728d,0x728c, 0x7291,0x7290,0x728e,0x733c,
  0x7342,0x733b,0x733a,0x7340, 0x734a,0x7349,0x7444,0x744a,
  0x744b,0x7452,0x7451,0x7457, 0x7440,0x744f,0x7450,0x744e,
  0x7442,0x7446,0x744d,0x7454, 0x74e1,0x74ff,0x74fe,0x74fd,
  0x751d,0x7579,0x7577,0x6983, 0x75ef,0x760f,0x7603,0x75f7,
  0x75fe,0x75fc,0x75f9,0x75f8, 0x7610,0x75fb,0x75f6,0x75ed,
  0x75f5,0x75fd,0x7699,0x76b5, 0x76dd,0x7755,0x775f,0x7760,
  0x7752,0x7756,0x775a,0x7769, 0x7767,0x7754,0x7759,0x776d,
  0x77e0,0x7887,0x789a,0x7894, 0x788f,0x7884,0x7895,0x7885,
  0x7886,0x78a1,0x7883,0x7879, 0x7899,0x7880,0x7896,0x787b,
  0x797c,0x7982,0x797d,0x7979, 0x7a11,0x7a18,0x7a19,0x7a12,
  0x7a17,0x7a15,0x7a22,0x7a13, 0x7a1b,0x7a10,0x7aa3,0x7aa2,
  0x7a9e,0x7aeb,0x7b66,0x7b64, 0x7b6d,0x7b74,0x7b69,0x7b72,
  0x7b65,0x7b73,0x7b71,0x7b70, 0x7b61,0x7b78,0x7b76,0x7b63,
  0x7cb2,0x7cb4,0x7caf,0x7d88, 0x7d86,0x7d80,0x7d8d,0x7d7f,
  0x7d85,0x7d7a,0x7d8e,0x7d7b, 0x7d83,0x7d7c,0x7d8c,0x7d94,
  0x7d84,0x7d7d,0x7d92,0x7f6d, 0x7f6b,0x7f67,0x7f68,0x7f6c,
  0x7fa6,0x7fa5,0x7fa7,0x7fdb, 0x7fdc,0x8021,0x8164,0x8160,
  0x8177,0x815c,0x8169,0x815b, 0x8162,0x8172,0x6721,0x815e,
  0x8176,0x8167,0x816f,0x8144, 0x8161,0x821d,0x8249,0x8244,
  0x8240,0x8242,0x8245,0x84f1, 0x843f,0x8456,0x8476,0x8479,
  0x848f,0x848d,0x8465,0x8451, 0x8440,0x8486,0x8467,0x8430,
  0x844d,0x847d,0x845a,0x8459, 0x8474,0x8473,0x845d,0x8507,
  0x845e,0x8437,0x843a,0x8434, 0x847a,0x8443,0x8478,0x8432,
  0x8445,0x8429,0x83d9,0x844b, 0x842f,0x8442,0x842d,0x845f,
  0x8470,0x8439,0x844e,0x844c, 0x8452,0x846f,0x84c5,0x848e,
  0x843b,0x8447,0x8436,0x8433, 0x8468,0x847e,0x8444,0x842b,
  0x8460,0x8454,0x846e,0x8450, 0x870b,0x8704,0x86f7,0x870c,
  0x86fa,0x86d6,0x86f5,0x874d, 0x86f8,0x870e,0x8709,0x8701,
  0x86f6,0x870d,0x8705,0x88d6, 0x88cb,0x88cd,0x88ce,0x88de,
  0x88db,0x88da,0x88cc,0x88d0, 0x8985,0x899b,0x89df,0x89e5,
  0x89e4,0x89e1,0x89e0,0x89e2, 0x89dc,0x89e6,0x8a76,0x8a86,
  0x8a7f,0x8a61,0x8a3f,0x8a77, 0x8a82,0x8a84,0x8a75,0x8a83,
  0x8a81,0x8a74,0x8a7a,0x8c3c, 0x8c4b,0x8c4a,0x8c65,0x8c64,
  0x8c66,0x8c86,0x8c84,0x8c85, 0x8ccc,0x8d68,0x8d69,0x8d91,
  0x8d8c,0x8d8e,0x8d8f,0x8d8d, 0x8d93,0x8d94,0x8d90,0x8d92,
  0x8df0,0x8de0,0x8dec,0x8df1, 0x8dee,0x8dd0,0x8de9,0x8de3,
  0x8de2,0x8de7,0x8df2,0x8deb, 0x8df4,0x8f06,0x8eff,0x8f01,
  0x8f00,0x8f05,0x8f07,0x8f08, 0x8f02,0x8f0b,0x9052,0x903f,
  0x9044,0x9049,0x903d,0x9110, 0x910d,0x910f,0x9111,0x9116,
  0x9114,0x910b,0x910e,0x916e, 0x916f,0x9248,0x9252,0x9230,
  0x923a,0x9266,0x9233,0x9265, 0x925e,0x9283,0x922e,0x924a,
  0x9246,0x926d,0x926c,0x924f, 0x9260,0x9267,0x926f,0x9236,
  0x9261,0x9270,0x9231,0x9254, 0x9263,0x9250,0x9272,0x924e,
  0x9253,0x924c,0x9256,0x9232, 0x959f,0x959c,0x959e,0x959b,
  0x9692,0x9693,0x9691,0x9697, 0x96ce,0x96fa,0x96fd,0x96f8,
  0x96f5,0x9773,0x9777,0x9778, 0x9772,0x980f,0x980d,0x980e,
  0x98ac,0x98f6,0x98f9,0x99af, 0x99b2,0x99b0,0x99b5,0x9aad,
  0x9aab,0x9b5b,0x9cea,0x9ced, 0x9ce7,0x9e80,0x9efd,0x50e6,
  0x50d4,0x50d7,0x50e8,0x50f3, 0x50db,0x50ea,0x50dd,0x50e4,
  0x50d3,0x50ec,0x50f0,0x50ef, 0x50e3,0x50e0,0x51d8,0x5280,
  0x5281,0x52e9,0x52eb,0x5330, 0x53ac,0x5627,0x5615,0x560c,
  0x5612,0x55fc,0x560f,0x561c, 0x5601,0x5613,0x5602,0x55fa,
  0x561d,0x5604,0x55ff,0x55f9, 0x5889,0x587c,0x5890,0x5898,
  0x5886,0x5881,0x587f,0x5874, 0x588b,0x587a,0x5887,0x5891,
  0x588e,0x5876,0x5882,0x5888, 0x587b,0x5894,0x588f,0x58fe,
  0x596b,0x5adc,0x5aee,0x5ae5, 0x5ad5,0x5aea,0x5ada,0x5aed,
  0x5aeb,0x5af3,0x5ae2,0x5ae0, 0x5adb,0x5aec,0x5ade,0x5add,
  0x5ad9,0x5ae8,0x5adf,0x5b77, 0x5be0,0x5be3,0x5c63,0x5d82,
  0x5d80,0x5d7d,0x5d86,0x5d7a, 0x5d81,0x5d77,0x5d8a,0x5d89,
  0x5d88,0x5d7e,0x5d7c,0x5d8d, 0x5d79,0x5d7f,0x5e58,0x5e59,
  0x5e53,0x5ed8,0x5ed1,0x5ed7, 0x5ece,0x5edc,0x5ed5,0x5ed9,
  0x5ed2,0x5ed4,0x5f44,0x5f43, 0x5f6f,0x5fb6,0x612c,0x6128,
  0x6141,0x615e,0x6171,0x6173, 0x6152,0x6153,0x6172,0x616c,
  0x6180,0x6174,0x6154,0x617a, 0x615b,0x6165,0x613b,0x616a,
  0x6161,0x6156,0x6229,0x6227, 0x622b,0x642b,0x644d,0x645b,
  0x645d,0x6474,0x6476,0x6472, 0x6473,0x647d,0x6475,0x6466,
  0x64a6,0x644e,0x6482,0x645e, 0x645c,0x644b,0x6453,0x6460,
  0x6450,0x647f,0x643f,0x646c, 0x646b,0x6459,0x6465,0x6477,
  0x6573,0x65a0,0x66a1,0x66a0, 0x669f,0x6705,0x6704,0x6722,
  0x69b1,0x69b6,0x69c9,0x69a0, 0x69ce,0x6996,0x69b0,0x69ac,
  0x69bc,0x6991,0x6999,0x698e, 0x69a7,0x698d,0x69a9,0x69be,
  0x69af,0x69bf,0x69c4,0x69bd, 0x69a4,0x69d4,0x69b9,0x69ca,
  0x699a,0x69cf,0x69b3,0x6993, 0x69aa,0x69a1,0x699e,0x69d9,
  0x6997,0x6990,0x69c2,0x69b5, 0x69a5,0x69c6,0x6b4a,0x6b4d,
  0x6b4b,0x6b9e,0x6b9f,0x6ba0, 0x6bc3,0x6bc4,0x6bfe,0x6ece,
  0x6ef5,0x6ef1,0x6f03,0x6f25, 0x6ef8,0x6f37,0x6efb,0x6f2e,
  0x6f09,0x6f4e,0x6f19,0x6f1a, 0x6f27,0x6f18,0x6f3b,0x6f12,
  0x6eed,0x6f0a,0x6f36,0x6f73, 0x6ef9,0x6eee,0x6f2d,0x6f40,
  0x6f30,0x6f3c,0x6f35,0x6eeb, 0x6f07,0x6f0e,0x6f43,0x6f05,
  0x6efd,0x6ef6,0x6f39,0x6f1c, 0x6efc,0x6f3a,0x6f1f,0x6f0d,
  0x6f1e,0x6f08,0x6f21,0x7187, 0x7190,0x7189,0x7180,0x7185,
  0x7182,0x718f,0x717b,0x7186, 0x7181,0x7197,0x7244,0x7253,
  0x7297,0x7295,0x7293,0x7343, 0x734d,0x7351,0x734c,0x7462,
  0x7473,0x7471,0x7475,0x7472, 0x7467,0x746e,0x7500,0x7502,
  0x7503,0x757d,0x7590,0x7616, 0x7608,0x760c,0x7615,0x7611,
  0x760a,0x7614,0x76b8,0x7781, 0x777c,0x7785,0x7782,0x776e,
  0x7780,0x776f,0x777e,0x7783, 0x78b2,0x78aa,0x78b4,0x78ad,
  0x78a8,0x787e,0x78ab,0x789e, 0x78a5,0x78a0,0x78ac,0x78a2,
  0x78a4,0x7998,0x798a,0x798b, 0x7996,0x7995,0x7994,0x7993,
  0x7997,0x7988,0x7992,0x7990, 0x7a2b,0x7a4a,0x7a30,0x7a2f,
  0x7a28,0x7a26,0x7aa8,0x7aab, 0x7aac,0x7aee,0x7b88,0x7b9c,
  0x7b8a,0x7b91,0x7b90,0x7b96, 0x7b8d,0x7b8c,0x7b9b,0x7b8e,
  0x7b85,0x7b98,0x5284,0x7b99, 0x7ba4,0x7b82,0x7cbb,0x7cbf,
  0x7cbc,0x7cba,0x7da7,0x7db7, 0x7dc2,0x7da3,0x7daa,0x7dc1,
  0x7dc0,0x7dc5,0x7d9d,0x7dce, 0x7dc4,0x7dc6,0x7dcb,0x7dcc,
  0x7daf,0x7db9,0x7d96,0x7dbc, 0x7d9f,0x7da6,0x7dae,0x7da9,
  0x7da1,0x7dc9,0x7f73,0x7fe2, 0x7fe3,0x7fe5,0x7fde,0x8024,
  0x805d,0x805c,0x8189,0x8186, 0x8183,0x8187,0x818d,0x818c,
  0x818b,0x8215,0x8497,0x84a4, 0x84a1,0x849f,0x84ba,0x84ce,
  0x84c2,0x84ac,0x84ae,0x84ab, 0x84b9,0x84b4,0x84c1,0x84cd,
  0x84aa,0x849a,0x84b1,0x84d0, 0x849d,0x84a7,0x84bb,0x84a2,
  0x8494,0x84c7,0x84cc,0x849b, 0x84a9,0x84af,0x84a8,0x84d6,
  0x8498,0x84b6,0x84cf,0x84a0, 0x84d7,0x84d4,0x84d2,0x84db,
  0x84b0,0x8491,0x8661,0x8733, 0x8723,0x8728,0x876b,0x8740,
  0x872e,0x871e,0x8721,0x8719, 0x871b,0x8743,0x872c,0x8741,
  0x873e,0x8746,0x8720,0x8732, 0x872a,0x872d,0x873c,0x8712,
  0x873a,0x8731,0x8735,0x8742, 0x8726,0x8727,0x8738,0x8724,
  0x871a,0x8730,0x8711,0x88f7, 0x88e7,0x88f1,0x88f2,0x88fa,
  0x88fe,0x88ee,0x88fc,0x88f6, 0x88fb,0x88f0,0x88ec,0x88eb,
  0x899d,0x89a1,0x899f,0x899e, 0x89e9,0x89eb,0x89e8,0x8aab,
  0x8a99,0x8a8b,0x8a92,0x8a8f, 0x8a96,0x8c3d,0x8c68,0x8c69,
  0x8cd5,0x8ccf,0x8cd7,0x8d96, 0x8e09,0x8e02,0x8dff,0x8e0d,
  0x8dfd,0x8e0a,0x8e03,0x8e07, 0x8e06,0x8e05,0x8dfe,0x8e00,
  0x8e04,0x8f10,0x8f11,0x8f0e, 0x8f0d,0x9123,0x911c,0x9120,
  0x9122,0x911f,0x911d,0x911a, 0x9124,0x9121,0x911b,0x917a,
  0x9172,0x9179,0x9173,0x92a5, 0x92a4,0x9276,0x929b,0x927a,
  0x92a0,0x9294,0x92aa,0x928d, 0x92a6,0x929a,0x92ab,0x9279,
  0x9297,0x927f,0x92a3,0x92ee, 0x928e,0x9282,0x9295,0x92a2,
  0x927d,0x9288,0x92a1,0x928a, 0x9286,0x928c,0x9299,0x92a7,
  0x927e,0x9287,0x92a9,0x929d, 0x928b,0x922d,0x969e,0x96a1,
  0x96ff,0x9758,0x977d,0x977a, 0x977e,0x9783,0x9780,0x9782,
  0x977b,0x9784,0x9781,0x977f, 0x97ce,0x97cd,0x9816,0x98ad,
  0x98ae,0x9902,0x9900,0x9907, 0x999d,0x999c,0x99c3,0x99b9,
  0x99bb,0x99ba,0x99c2,0x99bd, 0x99c7,0x9ab1,0x9ae3,0x9ae7,
  0x9b3e,0x9b3f,0x9b60,0x9b61, 0x9b5f,0x9cf1,0x9cf2,0x9cf5,
  0x9ea7,0x50ff,0x5103,0x5130, 0x50f8,0x5106,0x5107,0x50f6,
  0x50fe,0x510b,0x510c,0x50fd, 0x510a,0x528b,0x528c,0x52f1,
  0x52ef,0x5648,0x5642,0x564c, 0x5635,0x5641,0x564a,0x5649,
  0x5646,0x5658,0x565a,0x5640, 0x5633,0x563d,0x562c,0x563e,
  0x5638,0x562a,0x563a,0x571a, 0x58ab,0x589d,0x58b1,0x58a0,
  0x58a3,0x58af,0x58ac,0x58a5, 0x58a1,0x58ff,0x5aff,0x5af4,
  0x5afd,0x5af7,0x5af6,0x5b03, 0x5af8,0x5b02,0x5af9,0x5b01,
  0x5b07,0x5b05,0x5b0f,0x5c67, 0x5d99,0x5d97,0x5d9f,0x5d92,
  0x5da2,0x5d93,0x5d95,0x5da0, 0x5d9c,0x5da1,0x5d9a,0x5d9e,
  0x5e69,0x5e5d,0x5e60,0x5e5c, 0x7df3,0x5edb,0x5ede,0x5ee1,
  0x5f49,0x5fb2,0x618b,0x6183, 0x6179,0x61b1,0x61b0,0x61a2,
  0x6189,0x619b,0x6193,0x61af, 0x61ad,0x619f,0x6192,0x61aa,
  0x61a1,0x618d,0x6166,0x61b3, 0x622d,0x646e,0x6470,0x6496,
  0x64a0,0x6485,0x6497,0x649c, 0x648f,0x648b,0x648a,0x648c,
  0x64a3,0x649f,0x6468,0x64b1, 0x6498,0x6576,0x657a,0x6579,
  0x657b,0x65b2,0x65b3,0x66b5, 0x66b0,0x66a9,0x66b2,0x66b7,
  0x66aa,0x66af,0x6a00,0x6a06, 0x6a17,0x69e5,0x69f8,0x6a15,
  0x69f1,0x69e4,0x6a20,0x69ff, 0x69ec,0x69e2,0x6a1b,0x6a1d,
  0x69fe,0x6a27,0x69f2,0x69ee, 0x6a14,0x69f7,0x69e7,0x6a40,
  0x6a08,0x69e6,0x69fb,0x6a0d, 0x69fc,0x69eb,0x6a09,0x6a04,
  0x6a18,0x6a25,0x6a0f,0x69f6, 0x6a26,0x6a07,0x69f4,0x6a16,
  0x6b51,0x6ba5,0x6ba3,0x6ba2, 0x6ba6,0x6c01,0x6c00,0x6bff,
  0x6c02,0x6f41,0x6f26,0x6f7e, 0x6f87,0x6fc6,0x6f92,0x6f8d,
  0x6f89,0x6f8c,0x6f62,0x6f4f, 0x6f85,0x6f5a,0x6f96,0x6f76,
  0x6f6c,0x6f82,0x6f55,0x6f72, 0x6f52,0x6f50,0x6f57,0x6f94,
  0x6f93,0x6f5d,0x6f00,0x6f61, 0x6f6b,0x6f7d,0x6f67,0x6f90,
  0x6f53,0x6f8b,0x6f69,0x6f7f, 0x6f95,0x6f63,0x6f77,0x6f6a,
  0x6f7b,0x71b2,0x71af,0x719b, 0x71b0,0x71a0,0x719a,0x71a9,
  0x71b5,0x719d,0x71a5,0x719e, 0x71a4,0x71a1,0x71aa,0x719c,
  0x71a7,0x71b3,0x7298,0x729a, 0x7358,0x7352,0x735e,0x735f,
  0x7360,0x735d,0x735b,0x7361, 0x735a,0x7359,0x7362,0x7487,
  0x7489,0x748a,0x7486,0x7481, 0x747d,0x7485,0x7488,0x747c,
  0x7479,0x7508,0x7507,0x757e, 0x7625,0x761e,0x7619,0x761d,
  0x761c,0x7623,0x761a,0x7628, 0x761b,0x769c,0x769d,0x769e,
  0x769b,0x778d,0x778f,0x7789, 0x7788,0x78cd,0x78bb,0x78cf,
  0x78cc,0x78d1,0x78ce,0x78d4, 0x78c8,0x78c3,0x78c4,0x78c9,
  0x799a,0x79a1,0x79a0,0x799c, 0x79a2,0x799b,0x6b76,0x7a39,
  0x7ab2,0x7ab4,0x7ab3,0x7bb7, 0x7bcb,0x7bbe,0x7bac,0x7bce,
  0x7baf,0x7bb9,0x7bca,0x7bb5, 0x7cc5,0x7cc8,0x7ccc,0x7ccb,
  0x7df7,0x7ddb,0x7dea,0x7de7, 0x7dd7,0x7de1,0x7e03,0x7dfa,
  0x7de6,0x7df6,0x7df1,0x7df0, 0x7dee,0x7ddf,0x7f76,0x7fac,
  0x7fb0,0x7fad,0x7fed,0x7feb, 0x7fea,0x7fec,0x7fe6,0x7fe8,
  0x8064,0x8067,0x81a3,0x819f, 0x819e,0x8195,0x81a2,0x8199,
  0x8197,0x8216,0x824f,0x8253, 0x8252,0x8250,0x824e,0x8251,
  0x8524,0x853b,0x850f,0x8500, 0x8529,0x850e,0x8509,0x850d,
  0x851f,0x850a,0x8527,0x851c, 0x84fb,0x852b,0x84fa,0x8508,
  0x850c,0x84f4,0x852a,0x84f2, 0x8515,0x84f7,0x84eb,0x84f3,
  0x84fc,0x8512,0x84ea,0x84e9, 0x8516,0x84fe,0x8528,0x851d,
  0x852e,0x8502,0x84fd,0x851e, 0x84f6,0x8531,0x8526,0x84e7,
  0x84e8,0x84f0,0x84ef,0x84f9, 0x8518,0x8520,0x8530,0x850b,
  0x8519,0x852f,0x8662,0x8756, 0x8763,0x8764,0x8777,0x87e1,
  0x8773,0x8758,0x8754,0x875b, 0x8752,0x8761,0x875a,0x8751,
  0x875e,0x876d,0x876a,0x8750, 0x874e,0x875f,0x875d,0x876f,
  0x876c,0x877a,0x876e,0x875c, 0x8765,0x874f,0x877b,0x8775,
  0x8762,0x8767,0x8769,0x885a, 0x8905,0x890c,0x8914,0x890b,
  0x8917,0x8918,0x8919,0x8906, 0x8916,0x8911,0x890e,0x8909,
  0x89a2,0x89a4,0x89a3,0x89ed, 0x89f0,0x89ec,0x8acf,0x8ac6,
  0x8ab8,0x8ad3,0x8ad1,0x8ad4, 0x8ad5,0x8abb,0x8ad7,0x8abe,
  0x8ac0,0x8ac5,0x8ad8,0x8ac3, 0x8aba,0x8abd,0x8ad9,0x8c3e,
  0x8c4d,0x8c8f,0x8ce5,0x8cdf, 0x8cd9,0x8ce8,0x8cda,0x8cdd,
  0x8ce7,0x8da0,0x8d9c,0x8da1, 0x8d9b,0x8e20,0x8e23,0x8e25,
  0x8e24,0x8e2e,0x8e15,0x8e1b, 0x8e16,0x8e11,0x8e19,0x8e26,
  0x8e27,0x8e14,0x8e12,0x8e18, 0x8e13,0x8e1c,0x8e17,0x8e1a,
  0x8f2c,0x8f24,0x8f18,0x8f1a, 0x8f20,0x8f23,0x8f16,0x8f17,
  0x9073,0x9070,0x906f,0x9067, 0x906b,0x912f,0x912b,0x9129,
  0x912a,0x9132,0x9126,0x912e, 0x9185,0x9186,0x918a,0x9181,
  0x9182,0x9184,0x9180,0x92d0, 0x92c3,0x92c4,0x92c0,0x92d9,
  0x92b6,0x92cf,0x92f1,0x92df, 0x92d8,0x92e9,0x92d7,0x92dd,
  0x92cc,0x92ef,0x92c2,0x92e8, 0x92ca,0x92c8,0x92ce,0x92e6,
  0x92cd,0x92d5,0x92c9,0x92e0, 0x92de,0x92e7,0x92d1,0x92d3,
  0x92b5,0x92e1,0x9325,0x92c6, 0x92b4,0x957c,0x95ac,0x95ab,
  0x95ae,0x95b0,0x96a4,0x96a2, 0x96d3,0x9705,0x9708,0x9702,
  0x975a,0x978a,0x978e,0x9788, 0x97d0,0x97cf,0x981e,0x981d,
  0x9826,0x9829,0x9828,0x9820, 0x981b,0x9827,0x98b2,0x9908,
  0x98fa,0x9911,0x9914,0x9916, 0x9917,0x9915,0x99dc,0x99cd,
  0x99cf,0x99d3,0x99d4,0x99ce, 0x99c9,0x99d6,0x99d8,0x99cb,
  0x99d7,0x99cc,0x9ab3,0x9aec, 0x9aeb,0x9af3,0x9af2,0x9af1,
  0x9b46,0x9b43,0x9b67,0x9b74, 0x9b71,0x9b66,0x9b76,0x9b75,
  0x9b70,0x9b68,0x9b64,0x9b6c, 0x9cfc,0x9cfa,0x9cfd,0x9cff,
  0x9cf7,0x9d07,0x9d00,0x9cf9, 0x9cfb,0x9d08,0x9d05,0x9d04,
  0x9e83,0x9ed3,0x9f0f,0x9f10, 0x511c,0x5113,0x5117,0x511a,
  0x5111,0x51de,0x5334,0x53e1, 0x5670,0x5660,0x566e,0x5673,
  0x5666,0x5663,0x566d,0x5672, 0x565e,0x5677,0x571c,0x571b,
  0x58c8,0x58bd,0x58c9,0x58bf, 0x58ba,0x58c2,0x58bc,0x58c6,
  0x5b17,0x5b19,0x5b1b,0x5b21, 0x5b14,0x5b13,0x5b10,0x5b16,
  0x5b28,0x5b1a,0x5b20,0x5b1e, 0x5bef,0x5dac,0x5db1,0x5da9,
  0x5da7,0x5db5,0x5db0,0x5dae, 0x5daa,0x5da8,0x5db2,0x5dad,
  0x5daf,0x5db4,0x5e67,0x5e68, 0x5e66,0x5e6f,0x5ee9,0x5ee7,
  0x5ee6,0x5ee8,0x5ee5,0x5f4b, 0x5fbc,0x5fbb,0x619d,0x61a8,
  0x6196,0x61c5,0x61b4,0x61c6, 0x61c1,0x61cc,0x61ba,0x61bf,
  0x61b8,0x618c,0x64d7,0x64d6, 0x64d0,0x64cf,0x64c9,0x64bd,
  0x6489,0x64c3,0x64db,0x64f3, 0x64d9,0x6533,0x657f,0x657c,
  0x65a2,0x66c8,0x66be,0x66c0, 0x66ca,0x66cb,0x66cf,0x66bd,
  0x66bb,0x66ba,0x66cc,0x6723, 0x6a34,0x6a66,0x6a49,0x6a67,
  0x6a32,0x6a68,0x6a3e,0x6a5d, 0x6a6d,0x6a76,0x6a5b,0x6a51,
  0x6a28,0x6a5a,0x6a3b,0x6a3f, 0x6a41,0x6a6a,0x6a64,0x6a50,
  0x6a4f,0x6a54,0x6a6f,0x6a69, 0x6a60,0x6a3c,0x6a5e,0x6a56,
  0x6a55,0x6a4d,0x6a4e,0x6a46, 0x6b55,0x6b54,0x6b56,0x6ba7,
  0x6baa,0x6bab,0x6bc8,0x6bc7, 0x6c04,0x6c03,0x6c06,0x6fad,
  0x6fcb,0x6fa3,0x6fc7,0x6fbc, 0x6fce,0x6fc8,0x6f5e,0x6fc4,
  0x6fbd,0x6f9e,0x6fca,0x6fa8, 0x7004,0x6fa5,0x6fae,0x6fba,
  0x6fac,0x6faa,0x6fcf,0x6fbf, 0x6fb8,0x6fa2,0x6fc9,0x6fab,
  0x6fcd,0x6faf,0x6fb2,0x6fb0, 0x71c5,0x71c2,0x71bf,0x71b8,
  0x71d6,0x71c0,0x71c1,0x71cb, 0x71d4,0x71ca,0x71c7,0x71cf,
  0x71bd,0x71d8,0x71bc,0x71c6, 0x71da,0x71db,0x729d,0x729e,
  0x7369,0x7366,0x7367,0x736c, 0x7365,0x736b,0x736a,0x747f,
  0x749a,0x74a0,0x7494,0x7492, 0x7495,0x74a1,0x750b,0x7580,
  0x762f,0x762d,0x7631,0x763d, 0x7633,0x763c,0x7635,0x7632,
  0x7630,0x76bb,0x76e6,0x779a, 0x779d,0x77a1,0x779c,0x779b,
  0x77a2,0x77a3,0x7795,0x7799, 0x7797,0x78dd,0x78e9,0x78e5,
  0x78ea,0x78de,0x78e3,0x78db, 0x78e1,0x78e2,0x78ed,0x78df,
  0x78e0,0x79a4,0x7a44,0x7a48, 0x7a47,0x7ab6,0x7ab8,0x7ab5,
  0x7ab1,0x7ab7,0x7bde,0x7be3, 0x7be7,0x7bdd,0x7bd5,0x7be5,
  0x7bda,0x7be8,0x7bf9,0x7bd4, 0x7bea,0x7be2,0x7bdc,0x7beb,
  0x7bd8,0x7bdf,0x7cd2,0x7cd4, 0x7cd7,0x7cd0,0x7cd1,0x7e12,
  0x7e21,0x7e17,0x7e0c,0x7e1f, 0x7e20,0x7e13,0x7e0e,0x7e1c,
  0x7e15,0x7e1a,0x7e22,0x7e0b, 0x7e0f,0x7e16,0x7e0d,0x7e14,
  0x7e25,0x7e24,0x7f43,0x7f7b, 0x7f7c,0x7f7a,0x7fb1,0x7fef,
  0x802a,0x8029,0x806c,0x81b1, 0x81a6,0x81ae,0x81b9,0x81b5,
  0x81ab,0x81b0,0x81ac,0x81b4, 0x81b2,0x81b7,0x81a7,0x81f2,
  0x8255,0x8256,0x8257,0x8556, 0x8545,0x856b,0x854d,0x8553,
  0x8561,0x8558,0x8540,0x8546, 0x8564,0x8541,0x8562,0x8544,
  0x8551,0x8547,0x8563,0x853e, 0x855b,0x8571,0x854e,0x856e,
  0x8575,0x8555,0x8567,0x8560, 0x858c,0x8566,0x855d,0x8554,
  0x8565,0x856c,0x8663,0x8665, 0x8664,0x87a4,0x879b,0x878f,
  0x8797,0x8793,0x8792,0x8788, 0x8781,0x8796,0x8798,0x8779,
  0x8787,0x87a3,0x8785,0x8790, 0x8791,0x879d,0x8784,0x8794,
  0x879c,0x879a,0x8789,0x891e, 0x8926,0x8930,0x892d,0x892e,
  0x8927,0x8931,0x8922,0x8929, 0x8923,0x892f,0x892c,0x891f,
  0x89f1,0x8ae0,0x8ae2,0x8af2, 0x8af4,0x8af5,0x8add,0x8b14,
  0x8ae4,0x8adf,0x8af0,0x8ac8, 0x8ade,0x8ae1,0x8ae8,0x8aff,
  0x8aef,0x8afb,0x8c91,0x8c92, 0x8c90,0x8cf5,0x8cee,0x8cf1,
  0x8cf0,0x8cf3,0x8d6c,0x8d6e, 0x8da5,0x8da7,0x8e33,0x8e3e,
  0x8e38,0x8e40,0x8e45,0x8e36, 0x8e3c,0x8e3d,0x8e41,0x8e30,
  0x8e3f,0x8ebd,0x8f36,0x8f2e, 0x8f35,0x8f32,0x8f39,0x8f37,
  0x8f34,0x9076,0x9079,0x907b, 0x9086,0x90fa,0x9133,0x9135,
  0x9136,0x9193,0x9190,0x9191, 0x918d,0x918f,0x9327,0x931e,
  0x9308,0x931f,0x9306,0x930f, 0x937a,0x9338,0x933c,0x931b,
  0x9323,0x9312,0x9301,0x9346, 0x932d,0x930e,0x930d,0x92cb,
  0x931d,0x92fa,0x9313,0x92f9, 0x92f7,0x9334,0x9302,0x9324,
  0x92ff,0x9329,0x9339,0x9335, 0x932a,0x9314,0x930c,0x930b,
  0x92fe,0x9309,0x9300,0x92fb, 0x9316,0x95bc,0x95cd,0x95be,
  0x95b9,0x95ba,0x95b6,0x95bf, 0x95b5,0x95bd,0x96a9,0x96d4,
  0x970b,0x9712,0x9710,0x9799, 0x9797,0x9794,0x97f0,0x97f8,
  0x9835,0x982f,0x9832,0x9924, 0x991f,0x9927,0x9929,0x999e,
  0x99ee,0x99ec,0x99e5,0x99e4, 0x99f0,0x99e3,0x99ea,0x99e9,
  0x99e7,0x9ab9,0x9abf,0x9ab4, 0x9abb,0x9af6,0x9afa,0x9af9,
  0x9af7,0x9b33,0x9b80,0x9b85, 0x9b87,0x9b7c,0x9b7e,0x9b7b,
  0x9b82,0x9b93,0x9b92,0x9b90, 0x9b7a,0x9b95,0x9b7d,0x9b88,
  0x9d25,0x9d17,0x9d20,0x9d1e, 0x9d14,0x9d29,0x9d1d,0x9d18,
  0x9d22,0x9d10,0x9d19,0x9d1f, 0x9e88,0x9e86,0x9e87,0x9eae,
  0x9ead,0x9ed5,0x9ed6,0x9efa, 0x9f12,0x9f3d,0x5126,0x5125,
  0x5122,0x5124,0x5120,0x5129, 0x52f4,0x5693,0x568c,0x568d,
  0x5686,0x5684,0x5683,0x567e, 0x5682,0x567f,0x5681,0x58d6,
  0x58d4,0x58cf,0x58d2,0x5b2d, 0x5b25,0x5b32,0x5b23,0x5b2c,
  0x5b27,0x5b26,0x5b2f,0x5b2e, 0x5b7b,0x5bf1,0x5bf2,0x5db7,
  0x5e6c,0x5e6a,0x5fbe,0x61c3, 0x61b5,0x61bc,0x61e7,0x61e0,
  0x61e5,0x61e4,0x61e8,0x61de, 0x64ef,0x64e9,0x64e3,0x64eb,
  0x64e4,0x64e8,0x6581,0x6580, 0x65b6,0x65da,0x66d2,0x6a8d,
  0x6a96,0x6a81,0x6aa5,0x6a89, 0x6a9f,0x6a9b,0x6aa1,0x6a9e,
  0x6a87,0x6a93,0x6a8e,0x6a95, 0x6a83,0x6aa8,0x6aa4,0x6a91,
  0x6a7f,0x6aa6,0x6a9a,0x6a85, 0x6a8c,0x6a92,0x6b5b,0x6bad,
  0x6c09,0x6fcc,0x6fa9,0x6ff4, 0x6fd4,0x6fe3,0x6fdc,0x6fed,
  0x6fe7,0x6fe6,0x6fde,0x6ff2, 0x6fdd,0x6fe2,0x6fe8,0x71e1,
  0x71f1,0x71e8,0x71f2,0x71e4, 0x71f0,0x71e2,0x7373,0x736e,
  0x736f,0x7497,0x74b2,0x74ab, 0x7490,0x74aa,0x74ad,0x74b1,
  0x74a5,0x74af,0x7510,0x7511, 0x7512,0x750f,0x7584,0x7643,
  0x7648,0x7649,0x7647,0x76a4, 0x76e9,0x77b5,0x77ab,0x77b2,
  0x77b7,0x77b6,0x77b4,0x77b1, 0x77a8,0x77f0,0x78f3,0x78fd,
  0x7902,0x78fb,0x78fc,0x78ff, 0x78f2,0x7905,0x78f9,0x78fe,
  0x7904,0x79ab,0x79a8,0x7a5c, 0x7a5b,0x7a56,0x7a58,0x7a54,
  0x7a5a,0x7abe,0x7ac0,0x7ac1, 0x7c05,0x7c0f,0x7bf2,0x7c00,
  0x7bff,0x7bfb,0x7c0e,0x7bf4, 0x7c0b,0x7bf3,0x7c02,0x7c09,
  0x7c03,0x7c01,0x7bf8,0x7bfd, 0x7c06,0x7bf0,0x7bf1,0x7c10,
  0x7c0a,0x7ce8,0x7e2d,0x7e3c, 0x7e42,0x7e33,0x9848,0x7e38,
  0x7e2a,0x7e49,0x7e40,0x7e47, 0x7e29,0x7e4c,0x7e30,0x7e3b,
  0x7e36,0x7e44,0x7e3a,0x7f45, 0x7f7f,0x7f7e,0x7f7d,0x7ff4,
  0x7ff2,0x802c,0x81bb,0x81c4, 0x81cc,0x81ca,0x81c5,0x81c7,
  0x81bc,0x81e9,0x825b,0x825a, 0x825c,0x8583,0x8580,0x858f,
  0x85a7,0x8595,0x85a0,0x858b, 0x85a3,0x857b,0x85a4,0x859a,
  0x859e,0x8577,0x857c,0x8589, 0x85a1,0x857a,0x8578,0x8557,
  0x858e,0x8596,0x8586,0x858d, 0x8599,0x859d,0x8581,0x85a2,
  0x8582,0x8588,0x8585,0x8579, 0x8576,0x8598,0x8590,0x859f,
  0x8668,0x87be,0x87aa,0x87ad, 0x87c5,0x87b0,0x87ac,0x87b9,
  0x87b5,0x87bc,0x87ae,0x87c9, 0x87c3,0x87c2,0x87cc,0x87b7,
  0x87af,0x87c4,0x87ca,0x87b4, 0x87b6,0x87bf,0x87b8,0x87bd,
  0x87de,0x87b2,0x8935,0x8933, 0x893c,0x893e,0x8941,0x8952,
  0x8937,0x8942,0x89ad,0x89af, 0x89ae,0x89f2,0x89f3,0x8b1e,
  0x8b18,0x8b16,0x8b11,0x8b05, 0x8b0b,0x8b22,0x8b0f,0x8b12,
  0x8b15,0x8b07,0x8b0d,0x8b08, 0x8b06,0x8b1c,0x8b13,0x8b1a,
  0x8c4f,0x8c70,0x8c72,0x8c71, 0x8c6f,0x8c95,0x8c94,0x8cf9,
  0x8d6f,0x8e4e,0x8e4d,0x8e53, 0x8e50,0x8e4c,0x8e47,0x8f43,
  0x8f40,0x9085,0x907e,0x9138, 0x919a,0x91a2,0x919b,0x9199,
  0x919f,0x91a1,0x919d,0x91a0, 0x93a1,0x9383,0x93af,0x9364,
  0x9356,0x9347,0x937c,0x9358, 0x935c,0x9376,0x9349,0x9350,
  0x9351,0x9360,0x936d,0x938f, 0x934c,0x936a,0x9379,0x9357,
  0x9355,0x9352,0x934f,0x9371, 0x9377,0x937b,0x9361,0x935e,
  0x9363,0x9367,0x934e,0x9359, 0x95c7,0x95c0,0x95c9,0x95c3,
  0x95c5,0x95b7,0x96ae,0x96b0, 0x96ac,0x9720,0x971f,0x9718,
  0x971d,0x9719,0x979a,0x97a1, 0x979c,0x979e,0x979d,0x97d5,
  0x97d4,0x97f1,0x9841,0x9844, 0x984a,0x9849,0x9845,0x9843,
  0x9925,0x992b,0x992c,0x992a, 0x9933,0x9932,0x992f,0x992d,
  0x9931,0x9930,0x9998,0x99a3, 0x99a1,0x9a02,0x99fa,0x99f4,
  0x99f7,0x99f9,0x99f8,0x99f6, 0x99fb,0x99fd,0x99fe,0x99fc,
  0x9a03,0x9abe,0x9afe,0x9afd, 0x9b01,0x9afc,0x9b48,0x9b9a,
  0x9ba8,0x9b9e,0x9b9b,0x9ba6, 0x9ba1,0x9ba5,0x9ba4,0x9b86,
  0x9ba2,0x9ba0,0x9baf,0x9d33, 0x9d41,0x9d67,0x9d36,0x9d2e,
  0x9d2f,0x9d31,0x9d38,0x9d30, 0x9d45,0x9d42,0x9d43,0x9d3e,
  0x9d37,0x9d40,0x9d3d,0x7ff5, 0x9d2d,0x9e8a,0x9e89,0x9e8d,
  0x9eb0,0x9ec8,0x9eda,0x9efb, 0x9eff,0x9f24,0x9f23,0x9f22,
  0x9f54,0x9fa0,0x5131,0x512d, 0x512e,0x5698,0x569c,0x5697,
  0x569a,0x569d,0x5699,0x5970, 0x5b3c,0x5c69,0x5c6a,0x5dc0,
  0x5e6d,0x5e6e,0x61d8,0x61df, 0x61ed,0x61ee,0x61f1,0x61ea,
  0x61f0,0x61eb,0x61d6,0x61e9, 0x64ff,0x6504,0x64fd,0x64f8,
  0x6501,0x6503,0x64fc,0x6594, 0x65db,0x66da,0x66db,0x66d8,
  0x6ac5,0x6ab9,0x6abd,0x6ae1, 0x6ac6,0x6aba,0x6ab6,0x6ab7,
  0x6ac7,0x6ab4,0x6aad,0x6b5e, 0x6bc9,0x6c0b,0x7007,0x700c,
  0x700d,0x7001,0x7005,0x7014, 0x700e,0x6fff,0x7000,0x6ffb,
  0x7026,0x6ffc,0x6ff7,0x700a, 0x7201,0x71ff,0x71f9,0x7203,
  0x71fd,0x7376,0x74b8,0x74c0, 0x74b5,0x74c1,0x74be,0x74b6,
  0x74bb,0x74c2,0x7514,0x7513, 0x765c,0x7664,0x7659,0x7650,
  0x7653,0x7657,0x765a,0x76a6, 0x76bd,0x76ec,0x77c2,0x77ba,
  0x790c,0x7913,0x7914,0x7909, 0x7910,0x7912,0x7911,0x79ad,
  0x79ac,0x7a5f,0x7c1c,0x7c29, 0x7c19,0x7c20,0x7c1f,0x7c2d,
  0x7c1d,0x7c26,0x7c28,0x7c22, 0x7c25,0x7c30,0x7e5c,0x7e50,
  0x7e56,0x7e63,0x7e58,0x7e62, 0x7e5f,0x7e51,0x7e60,0x7e57,
  0x7e53,0x7fb5,0x7fb3,0x7ff7, 0x7ff8,0x8075,0x81d1,0x81d2,
  0x81d0,0x825f,0x825e,0x85b4, 0x85c6,0x85c0,0x85c3,0x85c2,
  0x85b3,0x85b5,0x85bd,0x85c7, 0x85c4,0x85bf,0x85cb,0x85ce,
  0x85c8,0x85c5,0x85b1,0x85b6, 0x85d2,0x8624,0x85b8,0x85b7,
  0x85be,0x8669,0x87e7,0x87e6, 0x87e2,0x87db,0x87eb,0x87ea,
  0x87e5,0x87df,0x87f3,0x87e4, 0x87d4,0x87dc,0x87d3,0x87ed,
  0x87d8,0x87e3,0x87d7,0x87d9, 0x8801,0x87f4,0x87e8,0x87dd,
  0x8953,0x894b,0x894f,0x894c, 0x8946,0x8950,0x8951,0x8949,
  0x8b2a,0x8b27,0x8b23,0x8b33, 0x8b30,0x8b35,0x8b47,0x8b2f,
  0x8b3c,0x8b3e,0x8b31,0x8b25, 0x8b37,0x8b26,0x8b36,0x8b2e,
  0x8b24,0x8b3b,0x8b3d,0x8b3a, 0x8c42,0x8c75,0x8c99,0x8c98,
  0x8c97,0x8cfe,0x8d04,0x8d02, 0x8d00,0x8e5c,0x8e62,0x8e60,
  0x8e57,0x8e56,0x8e5e,0x8e65, 0x8e67,0x8e5b,0x8e5a,0x8e61,
  0x8e5d,0x8e69,0x8e54,0x8f46, 0x8f47,0x8f48,0x8f4b,0x9128,
  0x913a,0x913b,0x913e,0x91a8, 0x91a5,0x91a7,0x91af,0x91aa,
  0x93b5,0x938c,0x9392,0x93b7, 0x939b,0x939d,0x9389,0x93a7,
  0x938e,0x93aa,0x939e,0x93a6, 0x9395,0x9388,0x9399,0x939f,
  0x9380,0x938d,0x93b1,0x9391, 0x93b2,0x93a4,0x93a8,0x93b4,
  0x93a3,0x95d2,0x95d3,0x95d1, 0x96b3,0x96d7,0x96da,0x5dc2,
  0x96df,0x96d8,0x96dd,0x9723, 0x9722,0x9725,0x97ac,0x97ae,
  0x97a8,0x97ab,0x97a4,0x97aa, 0x97a2,0x97a5,0x97d7,0x97d9,
  0x97d6,0x97d8,0x97fa,0x9850, 0x9851,0x9852,0x98b8,0x9941,
  0x993c,0x993a,0x9a0f,0x9a0b, 0x9a09,0x9a0d,0x9a04,0x9a11,
  0x9a0a,0x9a05,0x9a07,0x9a06, 0x9ac0,0x9adc,0x9b08,0x9b04,
  0x9b05,0x9b29,0x9b35,0x9b4a, 0x9b4c,0x9b4b,0x9bc7,0x9bc6,
  0x9bc3,0x9bbf,0x9bc1,0x9bb5, 0x9bb8,0x9bd3,0x9bb6,0x9bc4,
  0x9bb9,0x9bbd,0x9d5c,0x9d53, 0x9d4f,0x9d4a,0x9d5b,0x9d4b,
  0x9d59,0x9d56,0x9d4c,0x9d57, 0x9d52,0x9d54,0x9d5f,0x9d58,
  0x9d5a,0x9e8e,0x9e8c,0x9edf, 0x9f01,0x9f00,0x9f16,0x9f25,
  0x9f2b,0x9f2a,0x9f29,0x9f28, 0x9f4c,0x9f55,0x5134,0x5135,
  0x5296,0x52f7,0x53b4,0x56ab, 0x56ad,0x56a6,0x56a7,0x56aa,
  0x56ac,0x58da,0x58dd,0x58db, 0x5912,0x5b3d,0x5b3e,0x5b3f,
  0x5dc3,0x5e70,0x5fbf,0x61fb, 0x6507,0x6510,0x650d,0x6509,
  0x650c,0x650e,0x6584,0x65de, 0x65dd,0x66de,0x6ae7,0x6ae0,
  0x6acc,0x6ad1,0x6ad9,0x6acb, 0x6adf,0x6adc,0x6ad0,0x6aeb,
  0x6acf,0x6acd,0x6ade,0x6b60, 0x6bb0,0x6c0c,0x7019,0x7027,
  0x7020,0x7016,0x702b,0x7021, 0x7022,0x7023,0x7029,0x7017,
  0x7024,0x701c,0x720c,0x720a, 0x7207,0x7202,0x7205,0x72a5,
  0x72a6,0x72a4,0x72a3,0x72a1, 0x74cb,0x74c5,0x74b7,0x74c3,
  0x7516,0x7660,0x77c9,0x77ca, 0x77c4,0x77f1,0x791d,0x791b,
  0x7921,0x791c,0x7917,0x791e, 0x79b0,0x7a67,0x7a68,0x7c33,
  0x7c3c,0x7c39,0x7c2c,0x7c3b, 0x7cec,0x7cea,0x7e76,0x7e75,
  0x7e78,0x7e70,0x7e77,0x7e6f, 0x7e7a,0x7e72,0x7e74,0x7e68,
  0x7f4b,0x7f4a,0x7f83,0x7f86, 0x7fb7,0x7ffd,0x7ffe,0x8078,
  0x81d7,0x81d5,0x820b,0x8264, 0x8261,0x8263,0x85eb,0x85f1,
  0x85ed,0x85d9,0x85e1,0x85e8, 0x85da,0x85d7,0x85ec,0x85f2,
  0x85f8,0x85d8,0x85df,0x85e3, 0x85dc,0x85d1,0x85f0,0x85e6,
  0x85ef,0x85de,0x85e2,0x8800, 0x87fa,0x8803,0x87f6,0x87f7,
  0x8809,0x880c,0x880b,0x8806, 0x87fc,0x8808,0x87ff,0x880a,
  0x8802,0x8962,0x895a,0x895b, 0x8957,0x8961,0x895c,0x8958,
  0x895d,0x8959,0x8988,0x89b7, 0x89b6,0x89f6,0x8b50,0x8b48,
  0x8b4a,0x8b40,0x8b53,0x8b56, 0x8b54,0x8b4b,0x8b55,0x8b51,
  0x8b42,0x8b52,0x8b57,0x8c43, 0x8c77,0x8c76,0x8c9a,0x8d06,
  0x8d07,0x8d09,0x8dac,0x8daa, 0x8dad,0x8dab,0x8e6d,0x8e78,
  0x8e73,0x8e6a,0x8e6f,0x8e7b, 0x8ec2,0x8f52,0x8f51,0x8f4f,
  0x8f50,0x8f53,0x8fb4,0x9140, 0x913f,0x91b0,0x91ad,0x93de,
  0x93c7,0x93cf,0x93c2,0x93da, 0x93d0,0x93f9,0x93ec,0x93cc,
  0x93d9,0x93a9,0x93e6,0x93ca, 0x93d4,0x93ee,0x93e3,0x93d5,
  0x93c4,0x93ce,0x93c0,0x93d2, 0x93a5,0x93e7,0x957d,0x95da,
  0x95db,0x96e1,0x9729,0x972b, 0x972c,0x9728,0x9726,0x97b3,
  0x97b7,0x97b6,0x97dd,0x97de, 0x97df,0x985c,0x9859,0x985d,
  0x9857,0x98bf,0x98bd,0x98bb, 0x98be,0x9948,0x9947,0x9943,
  0x99a6,0x99a7,0x9a1a,0x9a15, 0x9a25,0x9a1d,0x9a24,0x9a1b,
  0x9a22,0x9a20,0x9a27,0x9a23, 0x9a1e,0x9a1c,0x9a14,0x9ac2,
  0x9b0b,0x9b0a,0x9b0e,0x9b0c, 0x9b37,0x9bea,0x9beb,0x9be0,
  0x9bde,0x9be4,0x9be6,0x9be2, 0x9bf0,0x9bd4,0x9bd7,0x9bec,
  0x9bdc,0x9bd9,0x9be5,0x9bd5, 0x9be1,0x9bda,0x9d77,0x9d81,
  0x9d8a,0x9d84,0x9d88,0x9d71, 0x9d80,0x9d78,0x9d86,0x9d8b,
  0x9d8c,0x9d7d,0x9d6b,0x9d74, 0x9d75,0x9d70,0x9d69,0x9d85,
  0x9d73,0x9d7b,0x9d82,0x9d6f, 0x9d79,0x9d7f,0x9d87,0x9d68,
  0x9e94,0x9e91,0x9ec0,0x9efc, 0x9f2d,0x9f40,0x9f41,0x9f4d,
  0x9f56,0x9f57,0x9f58,0x5337, 0x56b2,0x56b5,0x56b3,0x58e3,
  0x5b45,0x5dc6,0x5dc7,0x5eee, 0x5eef,0x5fc0,0x5fc1,0x61f9,
  0x6517,0x6516,0x6515,0x6513, 0x65df,0x66e8,0x66e3,0x66e4,
  0x6af3,0x6af0,0x6aea,0x6ae8, 0x6af9,0x6af1,0x6aee,0x6aef,
  0x703c,0x7035,0x702f,0x7037, 0x7034,0x7031,0x7042,0x7038,
  0x703f,0x703a,0x7039,0x702a, 0x7040,0x703b,0x7033,0x7041,
  0x7213,0x7214,0x72a8,0x737d, 0x737c,0x74ba,0x76ab,0x76aa,
  0x76be,0x76ed,0x77cc,0x77ce, 0x77cf,0x77cd,0x77f2,0x7925,
  0x7923,0x7927,0x7928,0x7924, 0x7929,0x79b2,0x7a6e,0x7a6c,
  0x7a6d,0x7af7,0x7c49,0x7c48, 0x7c4a,0x7c47,0x7c45,0x7cee,
  0x7e7b,0x7e7e,0x7e81,0x7e80, 0x7fba,0x7fff,0x8079,0x81db,
  0x81d9,0x8268,0x8269,0x8622, 0x85ff,0x8601,0x85fe,0x861b,
  0x8600,0x85f6,0x8604,0x8609, 0x8605,0x860c,0x85fd,0x8819,
  0x8810,0x8811,0x8817,0x8813, 0x8816,0x8963,0x8966,0x89b9,
  0x89f7,0x8b60,0x8b6a,0x8b5d, 0x8b68,0x8b63,0x8b65,0x8b67,
  0x8b6d,0x8dae,0x8e86,0x8e88, 0x8e84,0x8f59,0x8f56,0x8f57,
  0x8f55,0x8f58,0x8f5a,0x908d, 0x9143,0x9141,0x91b7,0x91b5,
  0x91b2,0x91b3,0x940b,0x9413, 0x93fb,0x9420,0x940f,0x9414,
  0x93fe,0x9415,0x9410,0x9428, 0x9419,0x940d,0x93f5,0x9400,
  0x93f7,0x9407,0x940e,0x9416, 0x9412,0x93fa,0x9409,0x93f8,
  0x943c,0x940a,0x93ff,0x93fc, 0x940c,0x93f6,0x9411,0x9406,
  0x95de,0x95e0,0x95df,0x972e, 0x972f,0x97b9,0x97bb,0x97fd,
  0x97fe,0x9860,0x9862,0x9863, 0x985f,0x98c1,0x98c2,0x9950,
  0x994e,0x9959,0x994c,0x994b, 0x9953,0x9a32,0x9a34,0x9a31,
  0x9a2c,0x9a2a,0x9a36,0x9a29, 0x9a2e,0x9a38,0x9a2d,0x9ac7,
  0x9aca,0x9ac6,0x9b10,0x9b12, 0x9b11,0x9c0b,0x9c08,0x9bf7,
  0x9c05,0x9c12,0x9bf8,0x9c40, 0x9c07,0x9c0e,0x9c06,0x9c17,
  0x9c14,0x9c09,0x9d9f,0x9d99, 0x9da4,0x9d9d,0x9d92,0x9d98,
  0x9d90,0x9d9b,0x9da0,0x9d94, 0x9d9c,0x9daa,0x9d97,0x9da1,
  0x9d9a,0x9da2,0x9da8,0x9d9e, 0x9da3,0x9dbf,0x9da9,0x9d96,
  0x9da6,0x9da7,0x9e99,0x9e9b, 0x9e9a,0x9ee5,0x9ee4,0x9ee7,
  0x9ee6,0x9f30,0x9f2e,0x9f5b, 0x9f60,0x9f5e,0x9f5d,0x9f59,
  0x9f91,0x513a,0x5139,0x5298, 0x5297,0x56c3,0x56bd,0x56be,
  0x5b48,0x5b47,0x5dcb,0x5dcf, 0x5ef1,0x61fd,0x651b,0x6b02,
  0x6afc,0x6b03,0x6af8,0x6b00, 0x7043,0x7044,0x704a,0x7048,
  0x7049,0x7045,0x7046,0x721d, 0x721a,0x7219,0x737e,0x7517,
  0x766a,0x77d0,0x792d,0x7931, 0x792f,0x7c54,0x7c53,0x7cf2,
  0x7e8a,0x7e87,0x7e88,0x7e8b, 0x7e86,0x7e8d,0x7f4d,0x7fbb,
  0x8030,0x81dd,0x8618,0x862a, 0x8626,0x861f,0x8623,0x861c,
  0x8619,0x8627,0x862e,0x8621, 0x8620,0x8629,0x861e,0x8625,
  0x8829,0x881d,0x881b,0x8820, 0x8824,0x881c,0x882b,0x884a,
  0x896d,0x8969,0x896e,0x896b, 0x89fa,0x8b79,0x8b78,0x8b45,
  0x8b7a,0x8b7b,0x8d10,0x8d14, 0x8daf,0x8e8e,0x8e8c,0x8f5e,
  0x8f5b,0x8f5d,0x9146,0x9144, 0x9145,0x91b9,0x943f,0x943b,
  0x9436,0x9429,0x943d,0x9430, 0x9439,0x942a,0x9437,0x942c,
  0x9440,0x9431,0x95e5,0x95e4, 0x95e3,0x9735,0x973a,0x97bf,
  0x97e1,0x9864,0x98c9,0x98c6, 0x98c0,0x9958,0x9956,0x9a39,
  0x9a3d,0x9a46,0x9a44,0x9a42, 0x9a41,0x9a3a,0x9a3f,0x9acd,
  0x9b15,0x9b17,0x9b18,0x9b16, 0x9b3a,0x9b52,0x9c2b,0x9c1d,
  0x9c1c,0x9c2c,0x9c23,0x9c28, 0x9c29,0x9c24,0x9c21,0x9db7,
  0x9db6,0x9dbc,0x9dc1,0x9dc7, 0x9dca,0x9dcf,0x9dbe,0x9dc5,
  0x9dc3,0x9dbb,0x9db5,0x9dce, 0x9db9,0x9dba,0x9dac,0x9dc8,
  0x9db1,0x9dad,0x9dcc,0x9db3, 0x9dcd,0x9db2,0x9e7a,0x9e9c,
  0x9eeb,0x9eee,0x9eed,0x9f1b, 0x9f18,0x9f1a,0x9f31,0x9f4e,
  0x9f65,0x9f64,0x9f92,0x4eb9, 0x56c6,0x56c5,0x56cb,0x5971,
  0x5b4b,0x5b4c,0x5dd5,0x5dd1, 0x5ef2,0x6521,0x6520,0x6526,
  0x6522,0x6b0b,0x6b08,0x6b09, 0x6c0d,0x7055,0x7056,0x7057,
  0x7052,0x721e,0x721f,0x72a9, 0x737f,0x74d8,0x74d5,0x74d9,
  0x74d7,0x766d,0x76ad,0x7935, 0x79b4,0x7a70,0x7a71,0x7c57,
  0x7c5c,0x7c59,0x7c5b,0x7c5a, 0x7cf4,0x7cf1,0x7e91,0x7f4f,
  0x7f87,0x81de,0x826b,0x8634, 0x8635,0x8633,0x862c,0x8632,
  0x8636,0x882c,0x8828,0x8826, 0x882a,0x8825,0x8971,0x89bf,
  0x89be,0x89fb,0x8b7e,0x8b84, 0x8b82,0x8b86,0x8b85,0x8b7f,
  0x8d15,0x8e95,0x8e94,0x8e9a, 0x8e92,0x8e90,0x8e96,0x8e97,
  0x8f60,0x8f62,0x9147,0x944c, 0x9450,0x944a,0x944b,0x944f,
  0x9447,0x9445,0x9448,0x9449, 0x9446,0x973f,0x97e3,0x986a,
  0x9869,0x98cb,0x9954,0x995b, 0x9a4e,0x9a53,0x9a54,0x9a4c,
  0x9a4f,0x9a48,0x9a4a,0x9a49, 0x9a52,0x9a50,0x9ad0,0x9b19,
  0x9b2b,0x9b3b,0x9b56,0x9b55, 0x9c46,0x9c48,0x9c3f,0x9c44,
  0x9c39,0x9c33,0x9c41,0x9c3c, 0x9c37,0x9c34,0x9c32,0x9c3d,
  0x9c36,0x9ddb,0x9dd2,0x9dde, 0x9dda,0x9dcb,0x9dd0,0x9ddc,
  0x9dd1,0x9ddf,0x9de9,0x9dd9, 0x9dd8,0x9dd6,0x9df5,0x9dd5,
  0x9ddd,0x9eb6,0x9ef0,0x9f35, 0x9f33,0x9f32,0x9f42,0x9f6b,
  0x9f95,0x9fa2,0x513d,0x5299, 0x58e8,0x58e7,0x5972,0x5b4d,
  0x5dd8,0x882f,0x5f4f,0x6201, 0x6203,0x6204,0x6529,0x6525,
  0x6596,0x66eb,0x6b11,0x6b12, 0x6b0f,0x6bca,0x705b,0x705a,
  0x7222,0x7382,0x7381,0x7383, 0x7670,0x77d4,0x7c67,0x7c66,
  0x7e95,0x826c,0x863a,0x8640, 0x8639,0x863c,0x8631,0x863b,
  0x863e,0x8830,0x8832,0x882e, 0x8833,0x8976,0x8974,0x8973,
  0x89fe,0x8b8c,0x8b8e,0x8b8b, 0x8b88,0x8c45,0x8d19,0x8e98,
  0x8f64,0x8f63,0x91bc,0x9462, 0x9455,0x945d,0x9457,0x945e,
  0x97c4,0x97c5,0x9800,0x9a56, 0x9a59,0x9b1e,0x9b1f,0x9b20,
  0x9c52,0x9c58,0x9c50,0x9c4a, 0x9c4d,0x9c4b,0x9c55,0x9c59,
  0x9c4c,0x9c4e,0x9dfb,0x9df7, 0x9def,0x9de3,0x9deb,0x9df8,
  0x9de4,0x9df6,0x9de1,0x9dee, 0x9de6,0x9df2,0x9df0,0x9de2,
  0x9dec,0x9df4,0x9df3,0x9de8, 0x9ded,0x9ec2,0x9ed0,0x9ef2,
  0x9ef3,0x9f06,0x9f1c,0x9f38, 0x9f37,0x9f36,0x9f43,0x9f4f,
  0x9f71,0x9f70,0x9f6e,0x9f6f, 0x56d3,0x56cd,0x5b4e,0x5c6d,
  0x652d,0x66ed,0x66ee,0x6b13, 0x705f,0x7061,0x705d,0x7060,
  0x7223,0x74db,0x74e5,0x77d5, 0x7938,0x79b7,0x79b6,0x7c6a,
  0x7e97,0x7f89,0x826d,0x8643, 0x8838,0x8837,0x8835,0x884b,
  0x8b94,0x8b95,0x8e9e,0x8e9f, 0x8ea0,0x8e9d,0x91be,0x91bd,
  0x91c2,0x946b,0x9468,0x9469, 0x96e5,0x9746,0x9743,0x9747,
  0x97c7,0x97e5,0x9a5e,0x9ad5, 0x9b59,0x9c63,0x9c67,0x9c66,
  0x9c62,0x9c5e,0x9c60,0x9e02, 0x9dfe,0x9e07,0x9e03,0x9e06,
  0x9e05,0x9e00,0x9e01,0x9e09, 0x9dff,0x9dfd,0x9e04,0x9ea0,
  0x9f1e,0x9f46,0x9f74,0x9f75, 0x9f76,0x56d4,0x652e,0x65b8,
  0x6b18,0x6b19,0x6b17,0x6b1a, 0x7062,0x7226,0x72aa,0x77d8,
  0x77d9,0x7939,0x7c69,0x7c6b, 0x7cf6,0x7e9a,0x7e98,0x7e9b,
  0x7e99,0x81e0,0x81e1,0x8646, 0x8647,0x8648,0x8979,0x897a,
  0x897c,0x897b,0x89ff,0x8b98, 0x8b99,0x8ea5,0x8ea4,0x8ea3,
  0x946e,0x946d,0x946f,0x9471, 0x9473,0x9749,0x9872,0x995f,
  0x9c68,0x9c6e,0x9c6d,0x9e0b, 0x9e0d,0x9e10,0x9e0f,0x9e12,
  0x9e11,0x9ea1,0x9ef5,0x9f09, 0x9f47,0x9f78,0x9f7b,0x9f7a,
  0x9f79,0x571e,0x7066,0x7c6f, 0x883c,0x8db2,0x8ea6,0x91c3,
  0x9474,0x9478,0x9476,0x9475, 0x9a60,0x9b2e,0x9c74,0x9c73,
  0x9c71,0x9c75,0x9e14,0x9e13, 0x9ef6,0x9f0a,0x9fa4,0x7068,
  0x7065,0x7cf7,0x866a,0x883e, 0x883d,0x883f,0x8b9e,0x8c9c,
  0x8ea9,0x8ec9,0x974b,0x9873, 0x9874,0x98cc,0x9961,0x99ab,
  0x9a64,0x9a66,0x9a67,0x9b24, 0x9e15,0x9e17,0x9f48,0x6207,
  0x6b1e,0x7227,0x864c,0x8ea8, 0x9482,0x9480,0x9481,0x9a69,
  0x9a68,0x9e19,0x864b,0x8b9f, 0x9483,0x9c79,0x9eb7,0x7675,
  0x9a6b,0x9c7a,0x9e1d,0x7069, 0x706a,0x7229,0x9ea4,0x9f7e,
  0x9f49,0x9f98,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000
};
unsigned short uni_t_cns11643_3[ISOMB_CODE_END] = {
/* codelimit: 8836 */
  0x4e28,0x4e36,0x4e3f,0x4e85, 0x4e05,0x4e04,0x5182,0x5196,
  0x5338,0x5369,0x53b6,0x4e2a, 0x4e87,0x4e49,0x51e2,0x4e46,
  0x4e8f,0x4ebc,0x4ebe,0x5166, 0x51e3,0x5204,0x529c,0x3039,
  0x5902,0x590a,0x5b80,0x5ddb, 0x5e7a,0x5e7f,0x5ef4,0x5f50,
  0x5f51,0x5f61,0x961d,0x0000, 0x4e63,0x4e62,0x4ea3,0x5185,
  0x4ec5,0x4ecf,0x4ece,0x4ecc, 0x5184,0x5186,0x34c1,0x34c5,
  0x51e4,0x5205,0x529e,0x529d, 0x52fd,0x5300,0x533a,0x3539,
  0x5346,0x535d,0x5386,0x53b7, 0x3555,0x53cc,0x355b,0x53ce,
  0x5721,0x0000,0x5e00,0x5f0c, 0x6237,0x6238,0x6534,0x6535,
  0x65e0,0x0000,0x738d,0x4e97, 0x4ee0,0x0000,0x0000,0x4ee7,
  0x0000,0x4ee6,0x0000,0x0000, 0x0000,0x0000,0x56d8,0x518b,
  0x518c,0x5199,0x51e5,0x0000, 0x520b,0x0000,0x0000,0x5304,
  0x5303,0x5307,0x0000,0x531e, 0x535f,0x536d,0x5389,0x53ba,
  0x53d0,0x0000,0x53f6,0x53f7, 0x53f9,0x0000,0x53f4,0x0000,
  0x0000,0x5724,0x5904,0x5918, 0x5932,0x5930,0x5934,0x0000,
  0x5975,0x0000,0x5b82,0x5bf9, 0x5c14,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x5e81,0x5e83,0x5f0d,0x5f52,
  0x0000,0x5fca,0x5fc7,0x6239, 0x0000,0x624f,0x65e7,0x672f,
  0x6b7a,0x6c39,0x0000,0x0000, 0x6c37,0x6c44,0x6c45,0x738c,
  0x7592,0x7676,0x9093,0x9092, 0x0000,0x0000,0x4e21,0x4e20,
  0x4e22,0x4e68,0x4e89,0x4e98, 0x4ef9,0x4eef,0x0000,0x0000,
  0x4ef8,0x4f06,0x4f03,0x4efc, 0x4eee,0x4f16,0x0000,0x4f28,
  0x4f1c,0x4f07,0x4f1a,0x4efa, 0x4f17,0x514a,0x0000,0x5172,
  0x0000,0x51b4,0x51b3,0x51b2, 0x0000,0x51e8,0x0000,0x5214,
  0x520f,0x5215,0x5218,0x52a8, 0x0000,0x534b,0x534f,0x0000,
  0x5350,0x0000,0x538b,0x0000, 0x53be,0x0000,0x53d2,0x5416,
  0x53ff,0x0000,0x5400,0x0000, 0x5405,0x5413,0x5415,0x0000,
  0x0000,0x56e3,0x5735,0x5736, 0x5731,0x5732,0x58ee,0x5905,
  0x4e54,0x0000,0x5936,0x0000, 0x0000,0x0000,0x597a,0x0000,
  0x5986,0x0000,0x0000,0x5b86, 0x5f53,0x5c18,0x0000,0x5c3d,
  0x5c78,0x0000,0x0000,0x0000, 0x0000,0x5c80,0x0000,0x5e08,
  0x0000,0x0000,0x0000,0x0000, 0x5ef5,0x5f0e,0x0000,0x0000,
  0x0000,0x5fd3,0x5fda,0x0000, 0x5fdb,0x0000,0x620f,0x625d,
  0x625f,0x6267,0x6257,0x9f50, 0x0000,0x65eb,0x65ea,0x0000,
  0x6737,0x0000,0x6732,0x6736, 0x6b22,0x6bce,0x0000,0x6c58,
  0x6c51,0x6c77,0x6c3c,0x0000, 0x6c5a,0x0000,0x6c53,0x706f,
  0x7072,0x706e,0x0000,0x0000, 0x7073,0x72b1,0x72b2,0x0000,
  0x738f,0x0000,0x0000,0x0000, 0x793c,0x0000,0x808d,0x808e,
  0x0000,0x827b,0x0000,0x8d71, 0x8fb9,0x9096,0x909a,0x0000,
  0x4e24,0x4e71,0x0000,0x4e9c, 0x4f45,0x4f4a,0x4f39,0x4f37,
  0x0000,0x4f32,0x4f42,0x0000, 0x4f44,0x4f4b,0x0000,0x4f40,
  0x4f35,0x4f31,0x5151,0x0000, 0x5150,0x514e,0x0000,0x0000,
  0x519d,0x0000,0x51b5,0x51b8, 0x51ec,0x5223,0x5227,0x5226,
  0x521f,0x522b,0x5220,0x52b4, 0x52b3,0x0000,0x5325,0x533b,
  0x5374,0x0000,0x0000,0x0000, 0x0000,0x0000,0x544d,0x0000,
  0x0000,0x543a,0x0000,0x0000, 0x5444,0x544c,0x5423,0x541a,
  0x5432,0x544b,0x5421,0x0000, 0x5434,0x5449,0x5450,0x5422,
  0x543f,0x5451,0x545a,0x542f, 0x0000,0x56e9,0x56f2,0x56f3,
  0x56ef,0x56ed,0x56ec,0x56e6, 0x5748,0x0000,0x5744,0x573f,
  0x573c,0x5753,0x5756,0x0000, 0x575f,0x5743,0x5758,0x5757,
  0x0000,0x0000,0x0000,0x5746, 0x0000,0x573d,0x0000,0x5742,
  0x5754,0x5755,0x58f1,0x58f2, 0x58f0,0x590b,0x9ea6,0x56f1,
  0x593d,0x0000,0x5994,0x598c, 0x0000,0x599c,0x0000,0x0000,
  0x599f,0x0000,0x599b,0x0000, 0x5989,0x599a,0x0000,0x6588,
  0x0000,0x5b8d,0x0000,0x5bfe, 0x5bff,0x5bfd,0x5c2b,0x0000,
  0x5c84,0x5c8e,0x5c9c,0x0000, 0x0000,0x5c85,0x5df5,0x5e09,
  0x0000,0x0000,0x5e0b,0x0000, 0x5e92,0x5e90,0x5f03,0x0000,
  0x5f1e,0x5f63,0x0000,0x5fe7, 0x5ffe,0x5fe6,0x5fdc,0x5fce,
  0x0000,0x5ffc,0x5fdf,0x5fec, 0x5ff6,0x0000,0x5ff2,0x5ff0,
  0x5ff9,0x0000,0x6213,0x0000, 0x0000,0x623b,0x623c,0x6282,
  0x0000,0x0000,0x0000,0x6278, 0x628b,0x0000,0x629e,0x62a5,
  0x629b,0x629c,0x6299,0x628d, 0x6285,0x629d,0x6275,0x0000,
  0x0000,0x0000,0x65f6,0x0000, 0x0000,0x0000,0x66f5,0x675b,
  0x0000,0x6754,0x6752,0x0000, 0x6758,0x6744,0x674a,0x6761,
  0x0000,0x6c7f,0x6c91,0x6c9e, 0x0000,0x6c6e,0x6c7c,0x6c9f,
  0x6c75,0x0000,0x6c56,0x6ca2, 0x6c79,0x0000,0x6ca1,0x0000,
  0x6caa,0x6ca0,0x0000,0x7079, 0x7077,0x707e,0x0000,0x7075,
  0x707b,0x7264,0x0000,0x72bb, 0x72bc,0x72c7,0x72b9,0x72be,
  0x72b6,0x0000,0x0000,0x7398, 0x0000,0x0000,0x0000,0x0000,
  0x7593,0x7680,0x0000,0x7683, 0x76c0,0x76c1,0x0000,0x0000,
  0x77f4,0x77f5,0x0000,0x7acc, 0x7acd,0x7cfa,0x809f,0x8091,
  0x8097,0x8094,0x0000,0x8286, 0x828c,0x0000,0x8295,0x0000,
  0x866c,0x0000,0x8fb5,0x8fbe, 0x8fc7,0x0000,0x8fc1,0x90a9,
  0x90a4,0x0000,0x0000,0x0000, 0x90a8,0x9627,0x9626,0x962b,
  0x9633,0x9634,0x9629,0x4e3d, 0x0000,0x4e9d,0x4f93,0x4f8a,
  0x0000,0x0000,0x4f6d,0x4f8e, 0x4fa0,0x4fa2,0x4fa1,0x4f9f,
  0x4fa3,0x0000,0x4f72,0x0000, 0x4f8c,0x5156,0x0000,0x0000,
  0x5190,0x0000,0x0000,0x0000, 0x51ed,0x51fe,0x522f,0x0000,
  0x523c,0x5234,0x5239,0x52b9, 0x52b5,0x52bf,0x5355,0x0000,
  0x5376,0x537a,0x5393,0x0000, 0x53c1,0x53c2,0x53d5,0x5485,
  0x0000,0x545f,0x5493,0x5489, 0x5479,0x9efe,0x548f,0x5469,
  0x546d,0x0000,0x5494,0x546a, 0x548a,0x0000,0x56fd,0x56fb,
  0x56f8,0x0000,0x56fc,0x56f6, 0x5765,0x5781,0x5763,0x5767,
  0x0000,0x576e,0x5778,0x577f, 0x0000,0x0000,0x58f3,0x594b,
  0x594c,0x0000,0x0000,0x0000, 0x59ad,0x0000,0x59c4,0x0000,
  0x59c2,0x59b0,0x0000,0x0000, 0x0000,0x0000,0x59bf,0x0000,
  0x59c9,0x59b8,0x59ac,0x0000, 0x0000,0x0000,0x59b7,0x59d7,
  0x0000,0x5b60,0x0000,0x5b96, 0x5b9e,0x5b94,0x5b9f,0x5b9d,
  0x0000,0x5c00,0x5c19,0x0000, 0x0000,0x5c49,0x5c4a,0x0000,
  0x5cbb,0x5cc1,0x0000,0x0000, 0x0000,0x5cb9,0x5c9e,0x5cb4,
  0x5cba,0x5df6,0x5e13,0x5e12, 0x5e77,0x0000,0x5e98,0x0000,
  0x5e99,0x5e9d,0x5ef8,0x0000, 0x5ef9,0x0000,0x5f06,0x5f21,
  0x0000,0x5f25,0x5f55,0x0000, 0x0000,0x0000,0x5f84,0x5f83,
  0x6030,0x6007,0x0000,0x6036, 0x0000,0x0000,0x0000,0x5fe9,
  0x603d,0x6008,0x0000,0x0000, 0x62ba,0x62b2,0x0000,0x62b7,
  0x62e4,0x62a7,0x0000,0x0000, 0x0000,0x62d5,0x62e1,0x62dd,
  0x62a6,0x62c1,0x62c5,0x62c0, 0x62df,0x62e0,0x62de,0x0000,
  0x6589,0x0000,0x65a6,0x65ba, 0x0000,0x65ff,0x0000,0x6617,
  0x6618,0x6601,0x65fe,0x0000, 0x670c,0x0000,0x676b,0x6796,
  0x6782,0x678a,0x0000,0x67a3, 0x0000,0x67a2,0x678f,0x0000,
  0x67f9,0x6780,0x6b26,0x6b27, 0x6b68,0x6b69,0x0000,0x6b81,
  0x6bb4,0x6bd1,0x0000,0x0000, 0x6c1c,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x6c97,0x6c6c, 0x6cdf,0x0000,0x6cea,0x0000,
  0x6ce4,0x6cd8,0x6cb2,0x6cce, 0x6cc8,0x0000,0x708b,0x7088,
  0x7090,0x708f,0x0000,0x7087, 0x7089,0x708d,0x7081,0x0000,
  0x708c,0x0000,0x0000,0x7240, 0x0000,0x0000,0x7265,0x7266,
  0x7268,0x0000,0x0000,0x72cd, 0x72d3,0x72db,0x0000,0x72cf,
  0x73a7,0x73a3,0x739e,0x0000, 0x73af,0x0000,0x0000,0x73aa,
  0x739c,0x0000,0x7542,0x7544, 0x753b,0x7541,0x0000,0x759b,
  0x759e,0x0000,0x79c4,0x79c3, 0x79c6,0x0000,0x0000,0x79c7,
  0x0000,0x79ca,0x0000,0x0000, 0x7acf,0x7c76,0x7c74,0x7cff,
  0x7cfc,0x0000,0x0000,0x7f59, 0x80a8,0x0000,0x0000,0x80b0,
  0x0000,0x80b3,0x0000,0x80a4, 0x80b6,0x80a7,0x80ac,0x0000,
  0x80a6,0x5367,0x820e,0x82c4, 0x833e,0x829c,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x82aa, 0x0000,0x82c9,0x0000,0x0000,
  0x82a6,0x82b2,0x0000,0x0000, 0x0000,0x8fcc,0x8fd9,0x8fca,
  0x8fd8,0x8fcf,0x90b7,0x0000, 0x90ad,0x90b9,0x9637,0x0000,
  0x9641,0x963e,0x96b6,0x9751, 0x9763,0x4e57,0x4e79,0x4eb2,
  0x4eb0,0x4eaf,0x4eb1,0x4fd2, 0x4fd5,0x0000,0x4fbe,0x4fb8,
  0x4fb0,0x4fb1,0x4fc8,0x0000, 0x0000,0x4fc6,0x4fcc,0x4fe5,
  0x4fe3,0x4fb4,0x516a,0x0000, 0x519f,0x0000,0x51c1,0x0000,
  0x51c2,0x51c3,0x5245,0x5248, 0x0000,0x0000,0x524f,0x0000,
  0x0000,0x52c5,0x52ca,0x52c4, 0x5327,0x5358,0x537d,0x0000,
  0x53dd,0x53dc,0x53da,0x53d9, 0x54b9,0x0000,0x54d0,0x54b4,
  0x54ca,0x0000,0x54a3,0x54da, 0x54a4,0x0000,0x54b2,0x549e,
  0x549f,0x54b5,0x0000,0x0000, 0x54cd,0x0000,0x54cc,0x0000,
  0x5700,0x57ac,0x5791,0x578e, 0x578d,0x5792,0x57a1,0x5790,
  0x57a6,0x57a8,0x0000,0x579c, 0x5796,0x57a7,0x0000,0x0000,
  0x0000,0x0000,0x58f5,0x0000, 0x5909,0x5908,0x0000,0x5952,
  0x0000,0x0000,0x59df,0x0000, 0x59eb,0x59ef,0x59f0,0x59d5,
  0x5a0d,0x5a04,0x59f9,0x5a02, 0x59f8,0x59e2,0x59d9,0x59e7,
  0x5b6a,0x0000,0x0000,0x5bab, 0x0000,0x5c1b,0x5c2f,0x0000,
  0x663c,0x0000,0x0000,0x0000, 0x5cd1,0x5cdc,0x5ce6,0x5ce1,
  0x5ccd,0x0000,0x5ce2,0x5cdd, 0x5ce5,0x5dfb,0x5dfa,0x5e1e,
  0x0000,0x5ea1,0x0000,0x0000, 0x5efc,0x5efb,0x5f2f,0x0000,
  0x0000,0x5f66,0x0000,0x0000, 0x0000,0x605c,0x0000,0x604e,
  0x6051,0x0000,0x0000,0x6023, 0x6031,0x607c,0x6052,0x0000,
  0x6060,0x604a,0x6061,0x0000, 0x6218,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x631f,0x6317,0x62ea,0x6321,
  0x6304,0x6305,0x0000,0x6531, 0x6544,0x6540,0x0000,0x6542,
  0x65be,0x0000,0x6629,0x661b, 0x0000,0x6623,0x662c,0x661a,
  0x6630,0x663b,0x661e,0x6637, 0x6638,0x0000,0x670e,0x0000,
  0x0000,0x67e8,0x67d6,0x0000, 0x67c7,0x67bc,0x6852,0x67bf,
  0x67d5,0x67fe,0x8363,0x67fb, 0x0000,0x67b1,0x6801,0x6805,
  0x6800,0x67d7,0x0000,0x6b2a, 0x6b6b,0x0000,0x0000,0x0000,
  0x0000,0x6be1,0x0000,0x0000, 0x6d23,0x6cff,0x6d14,0x6d05,
  0x6d13,0x6d06,0x6d21,0x0000, 0x6d15,0x6caf,0x6cf4,0x6d02,
  0x6d45,0x0000,0x6d26,0x0000, 0x6d44,0x0000,0x6d24,0x70a5,
  0x0000,0x70a3,0x0000,0x70a2, 0x70bb,0x70a0,0x70aa,0x0000,
  0x0000,0x70a8,0x70b6,0x70b2, 0x70a7,0x0000,0x0000,0x70b9,
  0x722e,0x0000,0x723c,0x0000, 0x726d,0x0000,0x0000,0x72e7,
  0x72ed,0x0000,0x72ec,0x72e5, 0x72e2,0x0000,0x73c4,0x73bd,
  0x73cf,0x73c9,0x73c1,0x73d0, 0x0000,0x73ce,0x74ed,0x74eb,
  0x0000,0x74ef,0x7549,0x7550, 0x7546,0x754a,0x0000,0x754d,
  0x75a6,0x0000,0x0000,0x0000, 0x75a8,0x0000,0x0000,0x76c7,
  0x76ff,0x0000,0x76fd,0x77e6, 0x780a,0x0000,0x7804,0x780b,
  0x7807,0x0000,0x7815,0x7808, 0x0000,0x79d3,0x79d4,0x79d0,
  0x79d7,0x7a7c,0x0000,0x0000, 0x7a7d,0x7a83,0x7a82,0x0000,
  0x7ad4,0x7ad5,0x7ad3,0x7ad0, 0x7ad2,0x7afe,0x7afc,0x7c77,
  0x7c7c,0x7c7b,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x7f8f,0x80d3, 0x0000,0x80cb,0x80d2,0x0000,
  0x8109,0x80e2,0x80df,0x80c6, 0x0000,0x8224,0x82f7,0x82d8,
  0x82dd,0x0000,0x0000,0x82f8, 0x82fc,0x0000,0x0000,0x82e9,
  0x0000,0x82ee,0x0000,0x82d0, 0x830e,0x82e2,0x830b,0x82fd,
  0x5179,0x8676,0x0000,0x8678, 0x0000,0x0000,0x8675,0x867d,
  0x0000,0x8842,0x8866,0x0000, 0x898c,0x8a05,0x0000,0x8a06,
  0x0000,0x8c9f,0x0000,0x8ff1, 0x8fe7,0x8fe9,0x8fef,0x90c2,
  0x90bc,0x0000,0x90c6,0x90c0, 0x0000,0x0000,0x90cd,0x90c9,
  0x0000,0x90c4,0x0000,0x9581, 0x0000,0x9cec,0x5032,0x4ff9,
  0x501d,0x4fff,0x5004,0x4ff0, 0x5003,0x0000,0x5002,0x4ffc,
  0x4ff2,0x5024,0x5008,0x5036, 0x502e,0x0000,0x5010,0x5038,
  0x5039,0x4ffd,0x5056,0x4ffb, 0x51a3,0x51a6,0x51a1,0x0000,
  0x0000,0x51c7,0x51c9,0x5260, 0x5264,0x5259,0x5265,0x5267,
  0x5257,0x5263,0x0000,0x5253, 0x0000,0x52cf,0x0000,0x52ce,
  0x52d0,0x52d1,0x52cc,0x0000, 0x0000,0x0000,0x550d,0x54f4,
  0x0000,0x5513,0x54ef,0x54f5, 0x54f9,0x5502,0x5500,0x0000,
  0x0000,0x5518,0x54f0,0x54f6, 0x0000,0x0000,0x5519,0x0000,
  0x5705,0x57c9,0x0000,0x57b7, 0x57cd,0x0000,0x0000,0x0000,
  0x57be,0x57bb,0x0000,0x57db, 0x57c8,0x57c4,0x57c5,0x57d1,
  0x57ca,0x57c0,0x0000,0x0000, 0x5a21,0x5a2a,0x0000,0x5a1d,
  0x0000,0x5a0b,0x0000,0x0000, 0x0000,0x0000,0x5a22,0x0000,
  0x0000,0x5a24,0x0000,0x5a14, 0x5a31,0x0000,0x5a2f,0x5a1a,
  0x5a12,0x0000,0x0000,0x5a26, 0x0000,0x0000,0x5bbc,0x5bbb,
  0x5bb7,0x5c05,0x5c06,0x5c52, 0x5c53,0x0000,0x0000,0x5cfa,
  0x5ceb,0x0000,0x5cf3,0x5cf5, 0x5ce9,0x5cef,0x0000,0x5e2a,
  0x5e30,0x5e2e,0x5e2c,0x5e2f, 0x5eaf,0x5ea9,0x0000,0x5efd,
  0x5f32,0x5f8e,0x5f93,0x5f8f, 0x604f,0x6099,0x0000,0x607e,
  0x0000,0x6074,0x604b,0x6073, 0x6075,0x0000,0x0000,0x6056,
  0x60a9,0x608b,0x60a6,0x0000, 0x6093,0x60ae,0x609e,0x60a7,
  0x6245,0x0000,0x0000,0x632e, 0x0000,0x6352,0x6330,0x635b,
  0x0000,0x6319,0x631b,0x0000, 0x6331,0x635d,0x6337,0x6335,
  0x6353,0x0000,0x635c,0x633f, 0x654b,0x0000,0x0000,0x658b,
  0x0000,0x659a,0x6650,0x6646, 0x664e,0x6640,0x0000,0x664b,
  0x6648,0x0000,0x6660,0x6644, 0x664d,0x0000,0x6837,0x6824,
  0x0000,0x0000,0x681b,0x6836, 0x0000,0x682c,0x6819,0x6856,
  0x6847,0x683e,0x681e,0x0000, 0x6815,0x6822,0x6827,0x6859,
  0x6858,0x6855,0x6830,0x6823, 0x6b2e,0x6b2b,0x6b30,0x6b6c,
  0x0000,0x6b8b,0x0000,0x6be9, 0x6bea,0x6be5,0x6d6b,0x0000,
  0x0000,0x6d73,0x6d57,0x0000, 0x0000,0x6d5d,0x6d56,0x6d8f,
  0x6d5b,0x6d1c,0x6d9a,0x6d9b, 0x6d99,0x0000,0x6d81,0x6d71,
  0x0000,0x0000,0x6d72,0x6d5c, 0x6d96,0x70c4,0x70db,0x70cc,
  0x70d0,0x70e3,0x70df,0x0000, 0x70d6,0x70ee,0x70d5,0x0000,
  0x0000,0x0000,0x0000,0x727a, 0x0000,0x72f5,0x7302,0x0000,
  0x0000,0x73e2,0x73ec,0x73d5, 0x73f9,0x73df,0x73e6,0x0000,
  0x0000,0x0000,0x0000,0x73e4, 0x73e1,0x74f3,0x0000,0x0000,
  0x0000,0x0000,0x7556,0x7555, 0x7558,0x7557,0x755e,0x75c3,
  0x0000,0x0000,0x75b4,0x0000, 0x75b1,0x0000,0x0000,0x76cb,
  0x76cc,0x772a,0x0000,0x7716, 0x770f,0x0000,0x0000,0x773f,
  0x772b,0x770e,0x7724,0x0000, 0x7721,0x7718,0x77dd,0x0000,
  0x0000,0x7824,0x7836,0x0000, 0x7958,0x7959,0x0000,0x7962,
  0x79da,0x79d9,0x0000,0x79e1, 0x79e5,0x79e8,0x79db,0x0000,
  0x79e2,0x79f0,0x0000,0x0000, 0x0000,0x0000,0x7ada,0x7add,
  0x0000,0x7adb,0x7adc,0x0000, 0x0000,0x7b0d,0x7b0b,0x7b14,
  0x7c8e,0x7c86,0x0000,0x7c87, 0x7c83,0x7c8b,0x0000,0x0000,
  0x0000,0x0000,0x7d24,0x0000, 0x0000,0x0000,0x7d25,0x7f62,
  0x7f93,0x7f99,0x7f97,0x0000, 0x0000,0x7fc4,0x7fc6,0x800a,
  0x0000,0x0000,0x8040,0x803c, 0x803b,0x80f6,0x80ff,0x80ee,
  0x8104,0x8103,0x8107,0x0000, 0x0000,0x80f7,0x0000,0x0000,
  0x822d,0x0000,0x8227,0x8229, 0x831f,0x8357,0x0000,0x0000,
  0x0000,0x0000,0x8321,0x0000, 0x0000,0x8318,0x8358,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x8684,0x869f,0x869b,0x8689,
  0x86a6,0x8692,0x868f,0x86a0, 0x884f,0x8878,0x887a,0x886e,
  0x887b,0x8884,0x8873,0x0000, 0x0000,0x8a0d,0x8a0b,0x8a19,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x8ff9,0x9009,
  0x9008,0x0000,0x90de,0x9151, 0x0000,0x0000,0x91db,0x91df,
  0x91de,0x91d6,0x91e0,0x9585, 0x9660,0x9659,0x0000,0x9656,
  0x0000,0x0000,0x96bd,0x0000, 0x0000,0x5042,0x5059,0x0000,
  0x5044,0x5066,0x5052,0x5054, 0x5071,0x5050,0x507b,0x507c,
  0x5058,0x0000,0x0000,0x5079, 0x506c,0x5078,0x51a8,0x51d1,
  0x51cf,0x5268,0x5276,0x52d4, 0x0000,0x53a0,0x53c4,0x0000,
  0x5558,0x554c,0x5568,0x0000, 0x5549,0x0000,0x0000,0x555d,
  0x5529,0x0000,0x5554,0x5553, 0x0000,0x555a,0x0000,0x553a,
  0x553f,0x552b,0x57ea,0x0000, 0x57ef,0x0000,0x0000,0x57dd,
  0x57fe,0x0000,0x57de,0x57e6, 0x0000,0x57e8,0x57ff,0x5803,
  0x58f7,0x68a6,0x591f,0x0000, 0x595b,0x595d,0x595e,0x0000,
  0x0000,0x5a2b,0x0000,0x5a3b, 0x0000,0x0000,0x5a61,0x5a3a,
  0x5a6e,0x5a4b,0x5a6b,0x0000, 0x0000,0x5a45,0x5a4e,0x5a68,
  0x5a3d,0x5a71,0x5a3f,0x5a6f, 0x5a75,0x0000,0x5a73,0x5a2c,
  0x5a59,0x5a54,0x5a4f,0x5a63, 0x0000,0x0000,0x5bc8,0x0000,
  0x5bc3,0x0000,0x5c5b,0x5c61, 0x0000,0x5d21,0x5d0a,0x5d09,
  0x0000,0x5d2c,0x5d08,0x0000, 0x0000,0x5d2a,0x5d15,0x0000,
  0x5d10,0x5d13,0x0000,0x5d2f, 0x5d18,0x0000,0x5de3,0x5e39,
  0x5e35,0x5e3a,0x5e32,0x0000, 0x0000,0x0000,0x0000,0x5ebb,
  0x5eba,0x5f34,0x5f39,0x0000, 0x0000,0x0000,0x0000,0x6098,
  0x0000,0x60d0,0x0000,0x0000, 0x0000,0x60d7,0x60aa,0x0000,
  0x60a1,0x60a4,0x0000,0x60ee, 0x0000,0x60e7,0x0000,0x0000,
  0x60de,0x0000,0x0000,0x637e, 0x638b,0x0000,0x0000,0x6379,
  0x6386,0x6393,0x0000,0x6373, 0x636a,0x0000,0x636c,0x0000,
  0x637f,0x0000,0x63b2,0x63ba, 0x0000,0x0000,0x6366,0x6374,
  0x0000,0x655a,0x0000,0x654e, 0x654d,0x658d,0x658e,0x65ad,
  0x0000,0x65c7,0x65ca,0x0000, 0x65c9,0x0000,0x65e3,0x6657,
  0x0000,0x6663,0x6667,0x671a, 0x6719,0x6716,0x0000,0x0000,
  0x689e,0x68b6,0x6898,0x6873, 0x0000,0x689a,0x688e,0x68b7,
  0x68db,0x68a5,0x686c,0x68c1, 0x6884,0x0000,0x0000,0x6895,
  0x687a,0x6899,0x0000,0x68b8, 0x68b9,0x6870,0x0000,0x6b35,
  0x0000,0x6b90,0x6bbb,0x6bed, 0x0000,0x0000,0x0000,0x6dc1,
  0x6dc3,0x6dce,0x0000,0x0000, 0x6dad,0x6e04,0x0000,0x6db9,
  0x0000,0x6de7,0x0000,0x6e08, 0x6e06,0x0000,0x6e0a,0x6db0,
  0x0000,0x6df8,0x6e0c,0x0000, 0x6db1,0x0000,0x6e02,0x6e07,
  0x6e09,0x6e01,0x6e17,0x6dff, 0x6e12,0x0000,0x0000,0x7103,
  0x7107,0x7101,0x70f5,0x70f1, 0x7108,0x70f2,0x710f,0x0000,
  0x70fe,0x0000,0x0000,0x0000, 0x731a,0x7310,0x730e,0x7402,
  0x73f3,0x0000,0x0000,0x73fb, 0x0000,0x0000,0x0000,0x751b,
  0x7523,0x7561,0x7568,0x0000, 0x7567,0x75d3,0x0000,0x0000,
  0x7690,0x0000,0x0000,0x76d5, 0x76d7,0x76d6,0x7730,0x0000,
  0x7726,0x0000,0x7740,0x0000, 0x771e,0x0000,0x0000,0x0000,
  0x7847,0x0000,0x784b,0x7851, 0x784f,0x7842,0x7846,0x0000,
  0x796e,0x796c,0x79f2,0x0000, 0x79f1,0x79f5,0x79f3,0x79f9,
  0x0000,0x0000,0x0000,0x7a9a, 0x7a93,0x7a91,0x7ae1,0x0000,
  0x0000,0x7b21,0x7b1c,0x7b16, 0x7b17,0x7b36,0x7b1f,0x0000,
  0x7c93,0x7c99,0x7c9a,0x7c9c, 0x0000,0x7d49,0x0000,0x7d34,
  0x7d37,0x0000,0x7d2d,0x0000, 0x7d4c,0x0000,0x0000,0x7d48,
  0x0000,0x0000,0x7f3b,0x0000, 0x0000,0x0000,0x0000,0x8008,
  0x801a,0x0000,0x801d,0x0000, 0x8049,0x8045,0x8044,0x7c9b,
  0x0000,0x0000,0x812a,0x812e, 0x0000,0x0000,0x8131,0x0000,
  0x811a,0x8134,0x8117,0x0000, 0x0000,0x0000,0x831d,0x8371,
  0x8384,0x8380,0x8372,0x83a1, 0x0000,0x8379,0x8391,0x0000,
  0x839f,0x83ad,0x0000,0x0000, 0x8323,0x0000,0x8385,0x839c,
  0x83b7,0x8658,0x865a,0x0000, 0x8657,0x86b2,0x0000,0x86ae,
  0x0000,0x0000,0x0000,0x8845, 0x889c,0x8894,0x88a3,0x888f,
  0x88a5,0x88a9,0x88a6,0x888a, 0x88a0,0x8890,0x8992,0x8991,
  0x8994,0x0000,0x8a26,0x8a32, 0x8a28,0x0000,0x0000,0x8a1c,
  0x0000,0x8a2b,0x8a20,0x0000, 0x8a29,0x0000,0x0000,0x0000,
  0x8a21,0x8c3a,0x0000,0x8c5b, 0x8c58,0x8c7c,0x0000,0x8ca6,
  0x8cae,0x8cad,0x8d65,0x0000, 0x8d7e,0x0000,0x8d7c,0x8d7f,
  0x8d7a,0x8dbd,0x0000,0x0000, 0x8dc0,0x8dbb,0x8ead,0x8eaf,
  0x8ed6,0x0000,0x0000,0x0000, 0x0000,0x0000,0x8ed9,0x0000,
  0x0000,0x9012,0x900e,0x9025, 0x0000,0x9013,0x90ee,0x0000,
  0x90ab,0x90f7,0x0000,0x9159, 0x9154,0x91f2,0x91f0,0x91e5,
  0x91f6,0x0000,0x0000,0x9587, 0x0000,0x965a,0x0000,0x0000,
  0x966e,0x0000,0x0000,0x0000, 0x9679,0x0000,0x98e1,0x98e6,
  0x0000,0x9ec4,0x9ed2,0x4e80, 0x0000,0x4e81,0x508f,0x5097,
  0x5088,0x5089,0x0000,0x0000, 0x5081,0x5160,0x0000,0x0000,
  0x5e42,0x51d3,0x0000,0x0000, 0x51d2,0x51d6,0x5273,0x0000,
  0x5270,0x0000,0x0000,0x0000, 0x53a8,0x53a6,0x53c5,0x5597,
  0x55de,0x0000,0x0000,0x5596, 0x55b4,0x0000,0x5585,0x0000,
  0x559b,0x55a0,0x0000,0x5559, 0x0000,0x5586,0x0000,0x0000,
  0x55af,0x557a,0x0000,0x0000, 0x0000,0x559e,0x0000,0x55a9,
  0x570f,0x570e,0x581a,0x0000, 0x581f,0x0000,0x583c,0x5818,
  0x583e,0x5826,0x0000,0x583a, 0x0000,0x5822,0x0000,0x58fb,
  0x5963,0x5964,0x0000,0x5aa8, 0x5aa3,0x5a82,0x5a88,0x5aa1,
  0x5a85,0x5a98,0x0000,0x5a99, 0x0000,0x5a89,0x5a81,0x5a96,
  0x5a80,0x0000,0x0000,0x5a91, 0x0000,0x0000,0x0000,0x0000,
  0x5acf,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x5a87,
  0x5aa0,0x0000,0x5a79,0x0000, 0x5a86,0x5aab,0x5aaa,0x5aa4,
  0x5a8d,0x5a7e,0x0000,0x5bd5, 0x0000,0x0000,0x0000,0x5c1e,
  0x5c5f,0x5c5e,0x5d44,0x5d3e, 0x0000,0x5d48,0x5d1c,0x0000,
  0x5d5b,0x5d4d,0x0000,0x0000, 0x5d57,0x0000,0x5d53,0x5d4f,
  0x0000,0x5d3b,0x5d46,0x0000, 0x0000,0x5e46,0x5e47,0x0000,
  0x5e48,0x5ec0,0x5ebd,0x5ebf, 0x0000,0x5f11,0x0000,0x5f3e,
  0x5f3b,0x0000,0x5f3a,0x0000, 0x0000,0x0000,0x5fa7,0x0000,
  0x60ea,0x0000,0x6107,0x6122, 0x610c,0x0000,0x0000,0x60b3,
  0x60d6,0x60d2,0x0000,0x60e3, 0x60e5,0x60e9,0x0000,0x0000,
  0x6111,0x60fd,0x0000,0x0000, 0x611e,0x6120,0x6121,0x621e,
  0x0000,0x63e2,0x63de,0x63e6, 0x0000,0x0000,0x0000,0x0000,
  0x63f8,0x0000,0x63fe,0x63c1, 0x63bf,0x63f7,0x63d1,0x655f,
  0x6560,0x6561,0x0000,0x0000, 0x65d1,0x0000,0x0000,0x667d,
  0x666b,0x667f,0x0000,0x0000, 0x6673,0x6681,0x666d,0x6669,
  0x0000,0x0000,0x671e,0x68ed, 0x0000,0x0000,0x0000,0x0000,
  0x6903,0x0000,0x68fe,0x68e5, 0x691e,0x6902,0x0000,0x0000,
  0x6909,0x68ca,0x6900,0x0000, 0x6901,0x6918,0x68e2,0x68cf,
  0x0000,0x692e,0x68c5,0x68ff, 0x0000,0x691c,0x68c3,0x0000,
  0x6b6f,0x0000,0x6b6e,0x0000, 0x6bbe,0x0000,0x6bf4,0x6c2d,
  0x0000,0x6db6,0x6e75,0x6e1e, 0x0000,0x6e18,0x0000,0x6e48,
  0x0000,0x6e4f,0x0000,0x6e42, 0x6e6a,0x6e70,0x6dfe,0x0000,
  0x0000,0x6e6d,0x0000,0x6e7b, 0x6e7e,0x6e59,0x0000,0x6e57,
  0x0000,0x6e80,0x6e50,0x0000, 0x6e29,0x6e76,0x6e2a,0x6e4c,
  0x712a,0x0000,0x7135,0x712c, 0x7137,0x711d,0x0000,0x0000,
  0x7138,0x0000,0x7134,0x712b, 0x7133,0x7127,0x7124,0x0000,
  0x712d,0x7232,0x7283,0x7282, 0x7287,0x7306,0x7324,0x7338,
  0x732a,0x732c,0x732b,0x0000, 0x732f,0x7328,0x7417,0x0000,
  0x0000,0x7419,0x7438,0x0000, 0x741f,0x7414,0x743c,0x73f7,
  0x741c,0x7415,0x7418,0x7439, 0x74f9,0x7524,0x0000,0x0000,
  0x0000,0x756e,0x756d,0x7571, 0x758e,0x0000,0x75e5,0x0000,
  0x0000,0x0000,0x0000,0x7694, 0x76b3,0x0000,0x76d9,0x0000,
  0x7748,0x7749,0x7743,0x0000, 0x0000,0x7742,0x77df,0x0000,
  0x7863,0x7876,0x0000,0x785f, 0x7866,0x7966,0x7971,0x0000,
  0x0000,0x7976,0x7984,0x7975, 0x79ff,0x7a07,0x0000,0x7a0e,
  0x7a09,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x7ae7,
  0x7ae2,0x7b55,0x0000,0x0000, 0x7b43,0x7b57,0x7b6c,0x7b42,
  0x7b53,0x0000,0x7b41,0x0000, 0x0000,0x7ca7,0x7ca0,0x7ca6,
  0x7ca4,0x7d74,0x0000,0x7d59, 0x0000,0x7d60,0x7d57,0x7d6c,
  0x7d7e,0x7d64,0x0000,0x7d5a, 0x7d5d,0x0000,0x0000,0x0000,
  0x7d76,0x7d4d,0x7d75,0x0000, 0x7fd3,0x7fd6,0x0000,0x0000,
  0x8060,0x804e,0x8145,0x813b, 0x0000,0x8148,0x8142,0x8149,
  0x8140,0x8114,0x8141,0x0000, 0x81ef,0x81f6,0x8203,0x0000,
  0x83ed,0x0000,0x83da,0x8418, 0x83d2,0x8408,0x0000,0x8400,
  0x0000,0x0000,0x0000,0x8417, 0x8346,0x8414,0x83d3,0x8405,
  0x841f,0x8402,0x8416,0x83cd, 0x83e6,0x0000,0x865d,0x86d5,
  0x86e1,0x0000,0x0000,0x0000, 0x0000,0x86ee,0x8847,0x8846,
  0x0000,0x0000,0x88bb,0x0000, 0x88bf,0x88b4,0x0000,0x88b5,
  0x0000,0x899a,0x8a43,0x0000, 0x0000,0x8a5a,0x0000,0x0000,
  0x0000,0x8a35,0x8a38,0x8a42, 0x8a49,0x8a5d,0x8a4b,0x8a3d,
  0x0000,0x0000,0x0000,0x0000, 0x8c60,0x8c5e,0x8c7f,0x8c7e,
  0x8c83,0x0000,0x8cb1,0x8d87, 0x0000,0x0000,0x8d88,0x8d83,
  0x0000,0x0000,0x8d86,0x8d8b, 0x8d82,0x8dca,0x8dd2,0x0000,
  0x0000,0x8dd4,0x8dc9,0x8eb0, 0x0000,0x0000,0x0000,0x8ef2,
  0x8ee4,0x8ef3,0x8eea,0x0000, 0x8efd,0x0000,0x8f9d,0x902b,
  0x902a,0x0000,0x9028,0x9029, 0x902c,0x0000,0x0000,0x903a,
  0x9030,0x9037,0x903b,0x0000, 0x910a,0x0000,0x0000,0x0000,
  0x91fe,0x9220,0x0000,0x920b, 0x0000,0x9218,0x9222,0x0000,
  0x921b,0x9208,0x0000,0x920e, 0x9213,0x0000,0x0000,0x9595,
  0x0000,0x0000,0x0000,0x968c, 0x967b,0x967f,0x9681,0x0000,
  0x9682,0x0000,0x0000,0x0000, 0x0000,0x0000,0x96ee,0x96ed,
  0x0000,0x96ec,0x975f,0x976f, 0x0000,0x976d,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x98f0,0x0000,0x0000,0x0000,
  0x9aa9,0x0000,0x0000,0x9ae0, 0x4eb7,0x0000,0x0000,0x50cc,
  0x50bc,0x0000,0x50aa,0x50b9, 0x0000,0x50ab,0x50c3,0x50cd,
  0x517e,0x527e,0x5279,0x0000, 0x0000,0x52e1,0x52e0,0x52e7,
  0x5380,0x53ab,0x53aa,0x53a9, 0x53e0,0x55ea,0x0000,0x55d7,
  0x0000,0x0000,0x55c1,0x5715, 0x0000,0x586c,0x0000,0x585c,
  0x5850,0x5861,0x586a,0x5869, 0x5856,0x5860,0x5866,0x585f,
  0x5923,0x5966,0x5968,0x0000, 0x0000,0x5ace,0x0000,0x5ac5,
  0x5ac3,0x0000,0x0000,0x5ad0, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x5b74,0x5b76, 0x5bdc,0x5bd7,0x5bda,0x5bdb,
  0x0000,0x5c20,0x5d6d,0x5d66, 0x0000,0x5d64,0x5d6e,0x0000,
  0x5d60,0x5f42,0x5f5a,0x5f6e, 0x0000,0x0000,0x6130,0x613a,
  0x612a,0x6143,0x6119,0x6131, 0x0000,0x613d,0x0000,0x0000,
  0x0000,0x6408,0x6432,0x6438, 0x0000,0x6431,0x0000,0x6419,
  0x0000,0x6411,0x0000,0x0000, 0x6429,0x641d,0x0000,0x0000,
  0x0000,0x643c,0x0000,0x6446, 0x6447,0x0000,0x0000,0x643a,
  0x6407,0x0000,0x656b,0x0000, 0x6570,0x656d,0x0000,0x65e4,
  0x6693,0x0000,0x0000,0x0000, 0x0000,0x668f,0x0000,0x0000,
  0x6692,0x0000,0x668e,0x0000, 0x6946,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x6931,0x0000,0x0000,0x693e,
  0x0000,0x697c,0x6943,0x0000, 0x6973,0x0000,0x6955,0x0000,
  0x0000,0x6985,0x694d,0x6950, 0x6947,0x6967,0x6936,0x6964,
  0x6961,0x0000,0x697d,0x6b44, 0x6b40,0x6b71,0x6b73,0x6b9c,
  0x0000,0x0000,0x0000,0x6bc1, 0x0000,0x6bfa,0x6c31,0x6c32,
  0x0000,0x0000,0x6eb8,0x6ea8, 0x0000,0x6e91,0x6ebb,0x0000,
  0x6e9a,0x0000,0x0000,0x6ea9, 0x0000,0x0000,0x6eb5,0x6e6c,
  0x6ee8,0x0000,0x6edd,0x6eda, 0x6ee6,0x6eac,0x0000,0x0000,
  0x0000,0x6ed9,0x6ee3,0x6ee9, 0x6edb,0x0000,0x716f,0x0000,
  0x0000,0x7148,0x0000,0x714a, 0x716b,0x0000,0x714f,0x7157,
  0x7174,0x0000,0x0000,0x0000, 0x7145,0x7151,0x716d,0x0000,
  0x7251,0x7250,0x724e,0x0000, 0x7341,0x0000,0x732e,0x7346,
  0x0000,0x7427,0x0000,0x7448, 0x7453,0x743d,0x0000,0x745d,
  0x7456,0x0000,0x741e,0x7447, 0x7443,0x7458,0x7449,0x0000,
  0x744c,0x7445,0x743e,0x0000, 0x7501,0x751e,0x0000,0x0000,
  0x757a,0x75ee,0x7602,0x7697, 0x7698,0x0000,0x0000,0x0000,
  0x775d,0x7764,0x7753,0x7758, 0x7882,0x7890,0x788a,0x0000,
  0x787a,0x787d,0x0000,0x788b, 0x7878,0x0000,0x0000,0x788d,
  0x7888,0x7892,0x7881,0x797e, 0x7983,0x0000,0x0000,0x0000,
  0x7980,0x0000,0x0000,0x0000, 0x7a0f,0x0000,0x0000,0x7a1d,
  0x0000,0x7aa1,0x7aa4,0x0000, 0x7ae9,0x7aea,0x0000,0x7b62,
  0x7b6b,0x0000,0x7b5e,0x0000, 0x7b79,0x0000,0x0000,0x7b6f,
  0x7b68,0x0000,0x0000,0x7cae, 0x0000,0x0000,0x0000,0x7cb0,
  0x0000,0x7d90,0x0000,0x7d8a, 0x0000,0x7d8b,0x7d99,0x7d95,
  0x0000,0x7d87,0x7d78,0x7d97, 0x7d89,0x7d98,0x0000,0x0000,
  0x0000,0x7fa3,0x0000,0x0000, 0x0000,0x7fdd,0x8057,0x0000,
  0x8163,0x816a,0x816c,0x0000, 0x0000,0x0000,0x815d,0x8175,
  0x0000,0x815f,0x0000,0x817d, 0x816d,0x0000,0x0000,0x8241,
  0x844f,0x8484,0x0000,0x847f, 0x0000,0x8448,0x842a,0x847b,
  0x8472,0x8464,0x842e,0x845c, 0x8453,0x0000,0x8441,0x84c8,
  0x0000,0x8462,0x8480,0x843e, 0x8483,0x8471,0x0000,0x844a,
  0x8455,0x8458,0x0000,0x0000, 0x0000,0x86fc,0x86fd,0x8715,
  0x0000,0x8716,0x86ff,0x0000, 0x0000,0x0000,0x8858,0x88cf,
  0x88e0,0x0000,0x0000,0x0000, 0x0000,0x89e7,0x8a6a,0x8a80,
  0x0000,0x8a6f,0x8a65,0x0000, 0x8a78,0x8a7d,0x8a88,0x0000,
  0x0000,0x8a64,0x8a7e,0x0000, 0x8a67,0x8c63,0x8c88,0x0000,
  0x8ccd,0x0000,0x8cc9,0x0000, 0x8ded,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x8eb1,0x0000,0x0000,0x8f04,
  0x8f9e,0x8fa0,0x9043,0x9046, 0x9048,0x9045,0x9040,0x904c,
  0x0000,0x0000,0x910c,0x9113, 0x9115,0x0000,0x916b,0x9167,
  0x925d,0x9255,0x9235,0x0000, 0x9259,0x922f,0x923c,0x928f,
  0x925c,0x926a,0x9262,0x925f, 0x926b,0x926e,0x923b,0x9244,
  0x9241,0x959a,0x0000,0x9599, 0x0000,0x0000,0x0000,0x968f,
  0x0000,0x9696,0x0000,0x0000, 0x0000,0x96f4,0x96fc,0x0000,
  0x9755,0x0000,0x9779,0x0000, 0x0000,0x0000,0x97ee,0x97f5,
  0x0000,0x980b,0x0000,0x98f3, 0x0000,0x0000,0x98f7,0x98ff,
  0x98f5,0x0000,0x98ec,0x98f1, 0x0000,0x0000,0x999a,0x0000,
  0x9ae2,0x9b3d,0x9b5d,0x9ce8, 0x0000,0x9ceb,0x9cef,0x9cee,
  0x9e81,0x9f14,0x50d0,0x50d9, 0x50dc,0x50d8,0x0000,0x50e1,
  0x50eb,0x0000,0x0000,0x50f4, 0x50e2,0x50de,0x0000,0x0000,
  0x0000,0x51f4,0x0000,0x0000, 0x0000,0x52ed,0x52ea,0x0000,
  0x5332,0x0000,0x53ae,0x53b0, 0x0000,0x55fb,0x5603,0x560b,
  0x0000,0x5607,0x0000,0x55f8, 0x0000,0x5628,0x561e,0x0000,
  0x5618,0x5611,0x5651,0x5605, 0x5717,0x5892,0x0000,0x588c,
  0x0000,0x5878,0x5884,0x5873, 0x58ad,0x5897,0x5895,0x5877,
  0x5872,0x5896,0x588d,0x5910, 0x0000,0x596c,0x0000,0x5ae7,
  0x0000,0x5ae4,0x0000,0x0000, 0x5aef,0x5626,0x0000,0x0000,
  0x5af0,0x5d7b,0x0000,0x5d83, 0x0000,0x0000,0x5d8b,0x5d8c,
  0x0000,0x5d78,0x5e52,0x0000, 0x0000,0x5ed0,0x5ecf,0x0000,
  0x5fb3,0x5fb4,0x0000,0x0000, 0x0000,0x617b,0x0000,0x616f,
  0x6181,0x613c,0x6142,0x6138, 0x6133,0x0000,0x6160,0x6169,
  0x617d,0x6186,0x622c,0x6228, 0x0000,0x644c,0x0000,0x6457,
  0x647c,0x0000,0x0000,0x6455, 0x6462,0x6471,0x646a,0x6456,
  0x643b,0x6481,0x0000,0x644f, 0x647e,0x6464,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x6571, 0x0000,0x0000,0x66a5,0x669a,
  0x669c,0x0000,0x66a6,0x0000, 0x66a4,0x698f,0x69c5,0x69c8,
  0x6992,0x69b2,0x0000,0x0000, 0x0000,0x69e3,0x69c0,0x69d6,
  0x69d1,0x699f,0x69a2,0x69d2, 0x0000,0x0000,0x0000,0x69e1,
  0x69d5,0x699d,0x0000,0x0000, 0x6998,0x0000,0x6b74,0x6ba1,
  0x0000,0x6ef0,0x6ef3,0x0000, 0x0000,0x6f1b,0x6f0c,0x6f1d,
  0x6f34,0x6f28,0x6f17,0x0000, 0x6f44,0x6f42,0x6f04,0x6f11,
  0x6efa,0x6f4a,0x7191,0x718e, 0x0000,0x718b,0x718d,0x717f,
  0x718c,0x717e,0x717c,0x7183, 0x0000,0x7188,0x0000,0x0000,
  0x7294,0x0000,0x7355,0x7353, 0x734f,0x7354,0x746c,0x7465,
  0x7466,0x7461,0x746b,0x7468, 0x7476,0x0000,0x7460,0x0000,
  0x7474,0x7506,0x760e,0x0000, 0x7607,0x0000,0x0000,0x76b9,
  0x0000,0x76b7,0x76e2,0x0000, 0x7774,0x7777,0x7776,0x7775,
  0x0000,0x7778,0x7771,0x0000, 0x777a,0x715b,0x777b,0x78a6,
  0x78ae,0x78b8,0x0000,0x0000, 0x0000,0x78b1,0x78af,0x0000,
  0x7989,0x7987,0x0000,0x0000, 0x7a29,0x0000,0x7a2a,0x0000,
  0x7a2d,0x7a2c,0x0000,0x7a32, 0x0000,0x7aec,0x7af0,0x7b81,
  0x7b9e,0x7b83,0x0000,0x7b92, 0x0000,0x7ba3,0x7b9f,0x7b93,
  0x0000,0x7b86,0x7cb8,0x7cb7, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x7dc8,0x7db6,0x0000, 0x7dd1,0x0000,0x7da8,0x7dab,
  0x0000,0x7db3,0x7dcd,0x0000, 0x7dcf,0x7da4,0x0000,0x0000,
  0x7f41,0x7f6f,0x7f71,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x8023,0x805b,0x0000, 0x8061,0x805f,0x8181,0x0000,
  0x0000,0x8184,0x8213,0x0000, 0x824a,0x824c,0x0000,0x0000,
  0x0000,0x84bd,0x8495,0x0000, 0x8492,0x84c3,0x0000,0x8496,
  0x84a5,0x84b5,0x84b3,0x84a3, 0x84e4,0x84d8,0x84d5,0x0000,
  0x84b7,0x84ad,0x84da,0x8493, 0x8736,0x0000,0x0000,0x0000,
  0x873d,0x872b,0x8747,0x8739, 0x0000,0x8745,0x871d,0x0000,
  0x88ff,0x88ea,0x0000,0x88f5, 0x0000,0x8900,0x88ed,0x8903,
  0x88e9,0x0000,0x0000,0x89ea, 0x0000,0x8a9b,0x8a8e,0x8aa2,
  0x0000,0x8a9c,0x8a94,0x8a90, 0x8aa9,0x8aac,0x0000,0x8a9f,
  0x0000,0x0000,0x8a9d,0x0000, 0x8c67,0x0000,0x0000,0x8cd0,
  0x8cd6,0x8cd4,0x8d98,0x8d9a, 0x8d97,0x0000,0x0000,0x0000,
  0x8e0b,0x8e08,0x8e01,0x8eb4, 0x8eb3,0x0000,0x8fa1,0x8fa2,
  0x0000,0x905a,0x0000,0x9061, 0x905f,0x0000,0x0000,0x9125,
  0x917b,0x9176,0x917c,0x0000, 0x9289,0x92f6,0x92b1,0x92ad,
  0x9292,0x9281,0x9284,0x0000, 0x92ae,0x9290,0x929e,0x0000,
  0x0000,0x0000,0x95a2,0x95a7, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x96a0,0x969d,0x969f, 0x96d0,0x0000,0x96d1,0x0000,
  0x0000,0x9759,0x0000,0x9764, 0x0000,0x0000,0x0000,0x9819,
  0x0000,0x9814,0x9815,0x981a, 0x0000,0x0000,0x0000,0x0000,
  0x9906,0x0000,0x98f8,0x9901, 0x0000,0x99be,0x99bc,0x99b7,
  0x99b6,0x99c0,0x0000,0x99b8, 0x0000,0x0000,0x0000,0x99c4,
  0x0000,0x99bf,0x0000,0x9ada, 0x9ae4,0x9ae9,0x9ae8,0x9aea,
  0x9ae5,0x0000,0x9b26,0x0000, 0x0000,0x9b40,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x9ebd,0x0000,0x0000,
  0x0000,0x0000,0x510e,0x0000, 0x50f7,0x0000,0x50fc,0x510d,
  0x5101,0x51da,0x51d9,0x51db, 0x5286,0x528e,0x52ee,0x5333,
  0x53b1,0x0000,0x5647,0x562d, 0x5654,0x0000,0x564b,0x5652,
  0x5631,0x5644,0x5656,0x5650, 0x562b,0x0000,0x564d,0x5637,
  0x564f,0x58a2,0x58b7,0x0000, 0x58b2,0x0000,0x58aa,0x58b5,
  0x58b0,0x0000,0x58b4,0x58a4, 0x58a7,0x0000,0x5926,0x5afe,
  0x0000,0x5b04,0x0000,0x5afc, 0x0000,0x5b06,0x5b0a,0x5afa,
  0x5b0d,0x5b00,0x5b0e,0x0000, 0x0000,0x0000,0x5d91,0x0000,
  0x5d8f,0x5d90,0x5d98,0x5da4, 0x5d9b,0x5da3,0x5d96,0x5de4,
  0x5e5a,0x0000,0x0000,0x5e5e, 0x0000,0x5fb8,0x6157,0x615c,
  0x61a6,0x6195,0x6188,0x0000, 0x61a3,0x618f,0x0000,0x6164,
  0x0000,0x6159,0x6178,0x0000, 0x6185,0x6187,0x619e,0x0000,
  0x0000,0x6198,0x619c,0x0000, 0x0000,0x622f,0x6480,0x649b,
  0x648e,0x648d,0x6494,0x64c6, 0x0000,0x64a8,0x6483,0x0000,
  0x64b9,0x6486,0x64b4,0x64af, 0x6491,0x0000,0x64aa,0x64a1,
  0x64a7,0x66b6,0x66b3,0x0000, 0x66bc,0x66ac,0x0000,0x66ad,
  0x6a0e,0x0000,0x6a1c,0x6a1a, 0x0000,0x0000,0x6a0b,0x0000,
  0x69ef,0x6a0c,0x69f0,0x6a22, 0x0000,0x69d8,0x0000,0x6a12,
  0x69fa,0x0000,0x6a2a,0x0000, 0x6a10,0x0000,0x0000,0x6a29,
  0x69f9,0x69ea,0x6a2c,0x6a24, 0x0000,0x69e9,0x6b52,0x6b4f,
  0x6b53,0x0000,0x0000,0x6f10, 0x6f65,0x6f75,0x0000,0x0000,
  0x0000,0x0000,0x6fd0,0x0000, 0x6f5c,0x6f3d,0x6f71,0x0000,
  0x6f91,0x6f0b,0x6f79,0x6f81, 0x6f8f,0x0000,0x6f59,0x6f74,
  0x0000,0x71ae,0x0000,0x71a3, 0x71ad,0x0000,0x0000,0x71ab,
  0x71a6,0x71a2,0x0000,0x52f2, 0x7257,0x7255,0x7299,0x734b,
  0x747a,0x0000,0x0000,0x0000, 0x748c,0x7484,0x0000,0x0000,
  0x7482,0x7493,0x747b,0x0000, 0x7509,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x778a, 0x0000,0x7790,0x0000,0x78c6,
  0x78d3,0x78c0,0x78d2,0x78c7, 0x78c2,0x0000,0x799f,0x799d,
  0x799e,0x0000,0x7a41,0x0000, 0x7a38,0x7a3a,0x7a42,0x0000,
  0x0000,0x7a3e,0x7ab0,0x7bae, 0x7bb3,0x0000,0x0000,0x7bbf,
  0x0000,0x0000,0x7bcd,0x0000, 0x7bb2,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x7cc4,0x7ccd,0x7cc2,0x7cc6,
  0x7cc3,0x7cc9,0x7cc7,0x0000, 0x7df8,0x0000,0x7ded,0x7de2,
  0x0000,0x0000,0x0000,0x7ddc, 0x7e02,0x7e01,0x0000,0x7dd6,
  0x0000,0x7de4,0x7dfe,0x0000, 0x7e00,0x7dfc,0x7dfd,0x0000,
  0x7df5,0x7dff,0x0000,0x7deb, 0x7de5,0x7f78,0x7fae,0x7fe7,
  0x0000,0x8065,0x806a,0x8066, 0x8068,0x806b,0x8194,0x81a1,
  0x8192,0x8196,0x8193,0x0000, 0x0000,0x8501,0x0000,0x84f8,
  0x0000,0x84f5,0x0000,0x8504, 0x0000,0x0000,0x0000,0x0000,
  0x851b,0x8503,0x8533,0x8534, 0x84ed,0x0000,0x0000,0x8535,
  0x0000,0x8505,0x0000,0x0000, 0x0000,0x0000,0x877d,0x0000,
  0x0000,0x0000,0x8771,0x0000, 0x885c,0x88e6,0x890f,0x891b,
  0x0000,0x89a9,0x89a5,0x89ee, 0x8ab1,0x0000,0x8acc,0x8ace,
  0x0000,0x8ab7,0x0000,0x8ab5, 0x8ae9,0x8ab4,0x0000,0x8ab3,
  0x8ac1,0x8aaf,0x8aca,0x8ad0, 0x0000,0x0000,0x0000,0x8c8e,
  0x0000,0x0000,0x8ce9,0x8cdb, 0x0000,0x8ceb,0x8da4,0x0000,
  0x8da2,0x8d9d,0x0000,0x0000, 0x0000,0x0000,0x8e2a,0x8e28,
  0x0000,0x0000,0x8eb8,0x8eb6, 0x8eb9,0x8eb7,0x8f22,0x8f2b,
  0x8f27,0x8f19,0x8fa4,0x0000, 0x8fb3,0x0000,0x9071,0x906a,
  0x0000,0x0000,0x9188,0x918c, 0x92bf,0x92b8,0x92be,0x92dc,
  0x92e5,0x0000,0x0000,0x92d4, 0x92d6,0x0000,0x92da,0x92ed,
  0x92f3,0x92db,0x0000,0x92b9, 0x92e2,0x92eb,0x95af,0x0000,
  0x95b2,0x95b3,0x0000,0x0000, 0x0000,0x96a3,0x96a5,0x0000,
  0x0000,0x0000,0x0000,0x970a, 0x0000,0x9787,0x9789,0x978c,
  0x97ef,0x982a,0x9822,0x0000, 0x981f,0x0000,0x9919,0x0000,
  0x99ca,0x99da,0x0000,0x0000, 0x0000,0x99de,0x99c8,0x99e0,
  0x0000,0x9ab6,0x9ab5,0x0000, 0x9af4,0x0000,0x9b6b,0x9b69,
  0x9b72,0x9b63,0x0000,0x9d0d, 0x0000,0x9d01,0x9d0c,0x0000,
  0x9cf8,0x0000,0x0000,0x9cfe, 0x9d02,0x9e84,0x0000,0x9eab,
  0x9eaa,0x511d,0x5116,0x0000, 0x512b,0x511e,0x511b,0x5290,
  0x5294,0x5314,0x0000,0x0000, 0x5667,0x0000,0x567b,0x0000,
  0x565f,0x5661,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x58c3,0x58ca,0x58bb, 0x58c0,0x58c4,0x5901,0x5b1f,
  0x5b18,0x5b11,0x5b15,0x0000, 0x5b12,0x5b1c,0x0000,0x5b22,
  0x5b79,0x5da6,0x0000,0x5db3, 0x5dab,0x5eea,0x0000,0x5f5b,
  0x0000,0x0000,0x61b7,0x61ce, 0x61b9,0x61bd,0x61cf,0x61c0,
  0x6199,0x6197,0x0000,0x61bb, 0x61d0,0x61c4,0x6231,0x0000,
  0x64d3,0x64c0,0x0000,0x0000, 0x0000,0x0000,0x64dc,0x64d1,
  0x64c8,0x0000,0x64d5,0x66c3, 0x0000,0x0000,0x66bf,0x66c5,
  0x0000,0x66cd,0x66c1,0x6706, 0x0000,0x6724,0x6a63,0x6a42,
  0x6a52,0x0000,0x6a43,0x6a33, 0x0000,0x6a6c,0x6a57,0x0000,
  0x6a4c,0x6a6e,0x0000,0x0000, 0x0000,0x0000,0x0000,0x6a37,
  0x0000,0x6a71,0x6a4a,0x6a36, 0x0000,0x6a53,0x0000,0x6a45,
  0x6a70,0x0000,0x0000,0x6a5c, 0x6b58,0x6b57,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x6fbb,0x0000,0x0000,0x6fbe,
  0x0000,0x0000,0x0000,0x6fb5, 0x6fd3,0x6f9f,0x0000,0x6fb7,
  0x6ff5,0x71b7,0x0000,0x71bb, 0x0000,0x71d1,0x0000,0x71ba,
  0x0000,0x71b6,0x71cc,0x0000, 0x0000,0x71d3,0x749b,0x0000,
  0x0000,0x7496,0x74a2,0x749d, 0x750a,0x750e,0x0000,0x7581,
  0x762c,0x7637,0x7636,0x763b, 0x0000,0x76a1,0x0000,0x0000,
  0x7798,0x0000,0x7796,0x0000, 0x0000,0x0000,0x78d6,0x78eb,
  0x0000,0x78dc,0x0000,0x79a5, 0x79a9,0x9834,0x7a53,0x7a45,
  0x0000,0x7a4f,0x0000,0x7abd, 0x7abb,0x7af1,0x0000,0x0000,
  0x7bec,0x7bed,0x0000,0x0000, 0x7cd3,0x0000,0x7ce1,0x0000,
  0x7e19,0x0000,0x0000,0x0000, 0x7e27,0x7e26,0x0000,0x0000,
  0x806e,0x81af,0x0000,0x0000, 0x81ad,0x0000,0x81aa,0x8218,
  0x0000,0x0000,0x0000,0x0000, 0x856f,0x854c,0x0000,0x8542,
  0x0000,0x855c,0x8570,0x855f, 0x0000,0x855a,0x854b,0x853f,
  0x878a,0x0000,0x878b,0x87a1, 0x878e,0x0000,0x0000,0x8799,
  0x885e,0x885f,0x8924,0x89a7, 0x8aea,0x8afd,0x8af9,0x8ae3,
  0x8ae5,0x0000,0x0000,0x8aec, 0x0000,0x0000,0x0000,0x0000,
  0x8cf2,0x0000,0x8cef,0x0000, 0x8da6,0x0000,0x0000,0x0000,
  0x8e3b,0x8e43,0x0000,0x8e32, 0x8f31,0x8f30,0x0000,0x8f2d,
  0x8f3c,0x8fa7,0x8fa5,0x0000, 0x0000,0x0000,0x9137,0x9195,
  0x918e,0x0000,0x9196,0x0000, 0x9345,0x930a,0x0000,0x0000,
  0x92fd,0x9317,0x931c,0x9307, 0x9331,0x9332,0x932c,0x9330,
  0x9303,0x9305,0x0000,0x95c2, 0x0000,0x95b8,0x0000,0x95c1,
  0x0000,0x0000,0x0000,0x96ab, 0x96b7,0x0000,0x0000,0x9715,
  0x9714,0x0000,0x0000,0x970c, 0x9717,0x0000,0x9793,0x0000,
  0x97d2,0x0000,0x0000,0x9836, 0x9831,0x9833,0x983c,0x982e,
  0x983a,0x0000,0x983d,0x0000, 0x98b5,0x9922,0x9923,0x9920,
  0x991c,0x991d,0x0000,0x99a0, 0x0000,0x99ef,0x99e8,0x99eb,
  0x0000,0x0000,0x0000,0x99e1, 0x99e6,0x0000,0x0000,0x9af8,
  0x9af5,0x0000,0x0000,0x9b83, 0x9b94,0x9b84,0x0000,0x9b8b,
  0x9b8f,0x0000,0x9b8c,0x0000, 0x9b89,0x0000,0x9b8e,0x0000,
  0x0000,0x0000,0x9d24,0x9d0f, 0x0000,0x9d13,0x9d0a,0x0000,
  0x0000,0x0000,0x0000,0x9d2a, 0x9d1a,0x0000,0x9d27,0x9d16,
  0x9d21,0x0000,0x9e85,0x9eac, 0x9ec6,0x9ec5,0x9ed7,0x9f53,
  0x0000,0x5128,0x5127,0x51df, 0x0000,0x5335,0x53b3,0x0000,
  0x568a,0x567d,0x5689,0x0000, 0x58cd,0x58d0,0x0000,0x5b2b,
  0x5b33,0x5b29,0x5b35,0x5b31, 0x5b37,0x5c36,0x5dbe,0x0000,
  0x5db9,0x0000,0x5dbb,0x0000, 0x61e2,0x61db,0x61dd,0x61dc,
  0x61da,0x0000,0x61d9,0x0000, 0x0000,0x64df,0x0000,0x0000,
  0x64e1,0x0000,0x64ee,0x0000, 0x65b5,0x66d4,0x66d5,0x0000,
  0x66d0,0x66d1,0x66ce,0x66d7, 0x0000,0x0000,0x6a7d,0x6a8a,
  0x0000,0x6aa7,0x0000,0x6a99, 0x6a82,0x6a88,0x0000,0x0000,
  0x6a86,0x0000,0x6a98,0x6a9d, 0x0000,0x0000,0x6a8f,0x0000,
  0x6aaa,0x0000,0x6b5d,0x0000, 0x6c0a,0x0000,0x6fd7,0x6fd6,
  0x6fe5,0x0000,0x0000,0x0000, 0x6fd9,0x6fda,0x6fea,0x0000,
  0x6ff6,0x0000,0x0000,0x71e3, 0x0000,0x71e9,0x0000,0x71eb,
  0x71ef,0x71f3,0x71ea,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x7371,0x0000,0x74ae,0x0000, 0x74b3,0x0000,0x74ac,0x0000,
  0x0000,0x7583,0x7645,0x764e, 0x7644,0x76a3,0x76a5,0x77a6,
  0x77a4,0x0000,0x77a9,0x77af, 0x0000,0x0000,0x0000,0x78f0,
  0x78f8,0x78f1,0x0000,0x7a49, 0x0000,0x0000,0x0000,0x7ac2,
  0x7af2,0x7af3,0x7bfa,0x0000, 0x7bf6,0x7bfc,0x7c18,0x7c08,
  0x7c12,0x0000,0x0000,0x7cdb, 0x7cda,0x0000,0x0000,0x0000,
  0x7e2c,0x7e4d,0x0000,0x0000, 0x7f46,0x7ff6,0x802b,0x8074,
  0x81b8,0x81c8,0x0000,0x0000, 0x0000,0x8592,0x8593,0x0000,
  0x857f,0x85ab,0x8597,0x0000, 0x0000,0x85ac,0x0000,0x0000,
  0x0000,0x87ce,0x0000,0x87cd, 0x0000,0x0000,0x87c1,0x87b1,
  0x87c7,0x0000,0x8940,0x0000, 0x893f,0x8939,0x0000,0x8943,
  0x0000,0x0000,0x0000,0x89ab, 0x0000,0x8b1f,0x8b09,0x8b0c,
  0x0000,0x0000,0x8c40,0x0000, 0x8c96,0x0000,0x8cf6,0x8cf7,
  0x0000,0x8e46,0x8e4f,0x0000, 0x0000,0x0000,0x8f3d,0x8f41,
  0x9366,0x9378,0x935d,0x9369, 0x9374,0x937d,0x936e,0x9372,
  0x9373,0x9362,0x9348,0x9353, 0x935f,0x9368,0x0000,0x937f,
  0x936b,0x0000,0x95c4,0x0000, 0x96af,0x96ad,0x96b2,0x0000,
  0x0000,0x971a,0x971b,0x0000, 0x0000,0x0000,0x0000,0x979b,
  0x979f,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x9840,0x0000,0x9847, 0x0000,0x98b7,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x99a2, 0x0000,0x0000,0x9a00,0x99f3,
  0x0000,0x0000,0x99f5,0x0000, 0x0000,0x9abd,0x9b00,0x9b02,
  0x0000,0x9b34,0x9b49,0x9b9f, 0x0000,0x9ba3,0x9bcd,0x9b99,
  0x9b9d,0x0000,0x0000,0x9d39, 0x0000,0x9d44,0x0000,0x0000,
  0x9d35,0x0000,0x0000,0x9eaf, 0x0000,0x512f,0x0000,0x0000,
  0x9f8e,0x0000,0x569f,0x569b, 0x569e,0x5696,0x5694,0x56a0,
  0x0000,0x5b3b,0x0000,0x0000, 0x5b3a,0x5dc1,0x5f4d,0x5f5d,
  0x61f3,0x0000,0x0000,0x0000, 0x0000,0x64f6,0x64e5,0x64ea,
  0x64e7,0x6505,0x0000,0x64f9, 0x0000,0x0000,0x0000,0x6aab,
  0x6aed,0x6ab2,0x6ab0,0x6ab5, 0x6abe,0x6ac1,0x6ac8,0x0000,
  0x6ac0,0x6abc,0x6ab1,0x6ac4, 0x6abf,0x0000,0x0000,0x7008,
  0x7003,0x6ffd,0x7010,0x7002, 0x7013,0x0000,0x71fa,0x7200,
  0x74b9,0x74bc,0x0000,0x765b, 0x7651,0x764f,0x76eb,0x77b8,
  0x0000,0x77b9,0x77c1,0x77c0, 0x77be,0x790b,0x0000,0x7907,
  0x790a,0x7908,0x0000,0x790d, 0x7906,0x7915,0x79af,0x0000,
  0x0000,0x0000,0x7af5,0x0000, 0x0000,0x7c2e,0x0000,0x7c1b,
  0x0000,0x7c1a,0x7c24,0x0000, 0x0000,0x7ce6,0x7ce3,0x0000,
  0x0000,0x7e5d,0x7e4f,0x7e66, 0x7e5b,0x7f47,0x7fb4,0x0000,
  0x0000,0x0000,0x7ffa,0x802e, 0x0000,0x0000,0x81ce,0x0000,
  0x0000,0x8219,0x0000,0x0000, 0x85cc,0x85b2,0x0000,0x85bb,
  0x85c1,0x0000,0x0000,0x0000, 0x87e9,0x87ee,0x87f0,0x87d6,
  0x880e,0x87da,0x8948,0x894a, 0x894e,0x894d,0x89b1,0x89b0,
  0x89b3,0x0000,0x8b38,0x8b32, 0x0000,0x8b2d,0x0000,0x8b34,
  0x0000,0x8b29,0x8c74,0x0000, 0x0000,0x8d03,0x0000,0x0000,
  0x8da9,0x8e58,0x0000,0x0000, 0x8ebf,0x8ec1,0x8f4a,0x8fac,
  0x0000,0x9089,0x913d,0x913c, 0x91a9,0x93a0,0x0000,0x9390,
  0x0000,0x9393,0x938b,0x93ad, 0x93bb,0x93b8,0x0000,0x0000,
  0x939c,0x95d8,0x95d7,0x0000, 0x0000,0x0000,0x975d,0x97a9,
  0x97da,0x0000,0x0000,0x0000, 0x0000,0x9854,0x0000,0x9855,
  0x984b,0x0000,0x983f,0x98b9, 0x0000,0x0000,0x0000,0x0000,
  0x9938,0x9936,0x9940,0x0000, 0x993b,0x9939,0x99a4,0x0000,
  0x0000,0x9a08,0x9a0c,0x0000, 0x9a10,0x0000,0x9b07,0x0000,
  0x9bd2,0x0000,0x9bc2,0x9bbb, 0x9bcc,0x9bcb,0x0000,0x0000,
  0x9d4d,0x9d63,0x9d4e,0x0000, 0x9d50,0x9d55,0x0000,0x9d5e,
  0x0000,0x9e90,0x9eb2,0x9eb1, 0x0000,0x9eca,0x9f02,0x9f27,
  0x9f26,0x0000,0x56af,0x58e0, 0x58dc,0x0000,0x5b39,0x0000,
  0x0000,0x5b7c,0x5bf3,0x0000, 0x0000,0x5c6b,0x5dc4,0x650b,
  0x6508,0x650a,0x0000,0x0000, 0x65dc,0x0000,0x0000,0x66e1,
  0x66df,0x6ace,0x6ad4,0x6ae3, 0x6ad7,0x6ae2,0x0000,0x0000,
  0x0000,0x0000,0x6ad8,0x6ad5, 0x6ad2,0x0000,0x0000,0x701e,
  0x702c,0x7025,0x6ff3,0x7204, 0x7208,0x7215,0x0000,0x74c4,
  0x74c9,0x74c7,0x74c8,0x76a9, 0x77c6,0x77c5,0x7918,0x791a,
  0x7920,0x0000,0x7a66,0x7a64, 0x7a6a,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x7c35, 0x7c34,0x0000,0x0000,0x7e6c,
  0x0000,0x7e6e,0x7e71,0x0000, 0x81d4,0x81d6,0x821a,0x8262,
  0x8265,0x8276,0x85db,0x85d6, 0x0000,0x85e7,0x0000,0x0000,
  0x85f4,0x0000,0x87fd,0x87d5, 0x8807,0x0000,0x880f,0x87f8,
  0x0000,0x0000,0x8987,0x0000, 0x89b5,0x89f5,0x0000,0x8b3f,
  0x8b43,0x8b4c,0x0000,0x8d0b, 0x8e6b,0x8e68,0x8e70,0x8e75,
  0x8e77,0x0000,0x8ec3,0x0000, 0x93e9,0x93ea,0x93cb,0x93c5,
  0x93c6,0x0000,0x93ed,0x93d3, 0x0000,0x93e5,0x0000,0x0000,
  0x93db,0x93eb,0x93e0,0x93c1, 0x0000,0x0000,0x95dd,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x97b2,0x97b4,0x97b1,0x97b5, 0x97f2,0x0000,0x0000,0x0000,
  0x9856,0x0000,0x0000,0x0000, 0x9944,0x0000,0x9a26,0x9a1f,
  0x9a18,0x9a21,0x9a17,0x0000, 0x9b09,0x0000,0x0000,0x9bc5,
  0x9bdf,0x0000,0x9be3,0x0000, 0x9be9,0x9bee,0x0000,0x0000,
  0x9d66,0x9d7a,0x0000,0x9d6e, 0x9d91,0x9d83,0x9d76,0x9d7e,
  0x9d6d,0x0000,0x9e95,0x9ee3, 0x0000,0x0000,0x9f03,0x9f04,
  0x0000,0x9f17,0x0000,0x5136, 0x0000,0x5336,0x0000,0x5b42,
  0x0000,0x0000,0x5b44,0x5b46, 0x5b7e,0x5dca,0x5dc8,0x5dcc,
  0x5ef0,0x0000,0x6585,0x66e5, 0x66e7,0x0000,0x0000,0x0000,
  0x6af4,0x0000,0x6ae9,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x703d,0x0000,0x7036,0x0000, 0x7216,0x0000,0x7212,0x720f,
  0x7217,0x7211,0x720b,0x0000, 0x0000,0x74cd,0x74d0,0x74cc,
  0x74ce,0x74d1,0x0000,0x7589, 0x0000,0x7a6f,0x7c4b,0x7c44,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x7e7f,0x8b71,0x0000,
  0x802f,0x807a,0x807b,0x807c, 0x0000,0x0000,0x0000,0x85fc,
  0x8610,0x8602,0x0000,0x0000, 0x85ee,0x8603,0x0000,0x860d,
  0x8613,0x8608,0x860f,0x8818, 0x8812,0x0000,0x0000,0x8967,
  0x8965,0x89bb,0x8b69,0x8b62, 0x0000,0x8b6e,0x0000,0x8b61,
  0x0000,0x8b64,0x8b4d,0x8c51, 0x0000,0x0000,0x8e83,0x8ec6,
  0x0000,0x941f,0x0000,0x9404, 0x9417,0x9408,0x9405,0x0000,
  0x93f3,0x941e,0x9402,0x941a, 0x941b,0x9427,0x941c,0x0000,
  0x96b5,0x0000,0x0000,0x9733, 0x0000,0x9734,0x9731,0x97b8,
  0x97ba,0x0000,0x97fc,0x0000, 0x0000,0x98c3,0x0000,0x994d,
  0x0000,0x9a2f,0x0000,0x0000, 0x0000,0x9ac9,0x0000,0x9ac8,
  0x9ac4,0x9b2a,0x9b38,0x9b50, 0x0000,0x9c0a,0x9bfb,0x9c04,
  0x9bfc,0x9bfe,0x0000,0x0000, 0x0000,0x9c02,0x9bf6,0x9c1b,
  0x9bf9,0x9c15,0x9c10,0x9bff, 0x9c00,0x9c0c,0x0000,0x0000,
  0x9d95,0x9da5,0x0000,0x0000, 0x0000,0x0000,0x9e98,0x9ec1,
  0x0000,0x9f5a,0x5164,0x56bb, 0x0000,0x58e6,0x5b49,0x5bf7,
  0x0000,0x0000,0x5dd0,0x0000, 0x5fc2,0x0000,0x6511,0x0000,
  0x6aff,0x6afe,0x6afd,0x0000, 0x6b01,0x0000,0x0000,0x704b,
  0x704d,0x7047,0x74d3,0x7668, 0x7667,0x0000,0x0000,0x77d1,
  0x7930,0x7932,0x792e,0x0000, 0x9f9d,0x7ac9,0x7ac8,0x0000,
  0x7c56,0x7c51,0x0000,0x0000, 0x0000,0x7e85,0x7e89,0x7e8e,
  0x7e84,0x0000,0x826a,0x862b, 0x862f,0x8628,0x0000,0x8616,
  0x8615,0x861d,0x881a,0x0000, 0x0000,0x0000,0x89bc,0x8b75,
  0x8b7c,0x0000,0x8d11,0x8d12, 0x8f5c,0x91bb,0x0000,0x93f4,
  0x0000,0x0000,0x942d,0x0000, 0x0000,0x96e4,0x9737,0x9736,
  0x9767,0x97be,0x97bd,0x97e2, 0x9868,0x9866,0x98c8,0x98ca,
  0x98c7,0x98dc,0x0000,0x994f, 0x99a9,0x9a3c,0x0000,0x9a3b,
  0x9ace,0x0000,0x9b14,0x9b53, 0x0000,0x9c2e,0x0000,0x9c1f,
  0x0000,0x0000,0x0000,0x0000, 0x9db0,0x9dbd,0x0000,0x0000,
  0x9dae,0x9dc4,0x9e7b,0x0000, 0x0000,0x9e9e,0x0000,0x9f05,
  0x0000,0x9f69,0x9fa1,0x56c7, 0x571d,0x5b4a,0x5dd3,0x0000,
  0x5f72,0x6202,0x0000,0x6235, 0x6527,0x651e,0x651f,0x0000,
  0x0000,0x6b07,0x6b06,0x0000, 0x0000,0x7054,0x721c,0x7220,
  0x7af8,0x0000,0x7c5d,0x7c58, 0x0000,0x7e92,0x7f4e,0x0000,
  0x0000,0x0000,0x8827,0x0000, 0x8b81,0x8b83,0x0000,0x8c44,
  0x0000,0x0000,0x0000,0x0000, 0x9442,0x944d,0x9454,0x944e,
  0x0000,0x9443,0x0000,0x0000, 0x973c,0x9740,0x97c0,0x0000,
  0x0000,0x0000,0x0000,0x995a, 0x9a51,0x0000,0x9add,0x0000,
  0x0000,0x9c38,0x0000,0x9c45, 0x9c3a,0x0000,0x9c35,0x0000,
  0x0000,0x0000,0x9ef1,0x0000, 0x9f93,0x529a,0x0000,0x0000,
  0x8641,0x5dd7,0x0000,0x6528, 0x0000,0x0000,0x0000,0x7053,
  0x7059,0x0000,0x7221,0x0000, 0x766f,0x7937,0x79b5,0x7c62,
  0x7c5e,0x7cf5,0x0000,0x0000, 0x863d,0x0000,0x882d,0x8989,
  0x8b8d,0x8b87,0x8b90,0x8d1a, 0x8e99,0x0000,0x0000,0x0000,
  0x945f,0x0000,0x0000,0x9456, 0x9461,0x945b,0x945a,0x945c,
  0x9465,0x0000,0x9741,0x0000, 0x0000,0x986e,0x986c,0x986d,
  0x0000,0x99aa,0x9a5c,0x9a58, 0x9ade,0x0000,0x9c4f,0x9c51,
  0x0000,0x9c53,0x0000,0x0000, 0x0000,0x9dfc,0x9f39,0x0000,
  0x513e,0x0000,0x56d2,0x0000, 0x5b4f,0x6b14,0x0000,0x7a72,
  0x7a73,0x0000,0x0000,0x0000, 0x8b91,0x0000,0x0000,0x91bf,
  0x0000,0x946c,0x0000,0x0000, 0x96e6,0x9745,0x0000,0x97c8,
  0x97e4,0x995d,0x0000,0x9b21, 0x0000,0x9b2c,0x9b57,0x0000,
  0x0000,0x9c5d,0x9c61,0x9c65, 0x9e08,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x9f45,0x0000, 0x0000,0x6205,0x66ef,0x6b1b,
  0x6b1d,0x7225,0x7224,0x7c6d, 0x0000,0x8642,0x8649,0x0000,
  0x8978,0x898a,0x8b97,0x0000, 0x8c9b,0x8d1c,0x0000,0x8ea2,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x9c6c,0x0000,0x9c6f,0x0000, 0x9e0e,0x0000,0x9f08,0x9f1d,
  0x9fa3,0x0000,0x0000,0x5f60, 0x6b1c,0x0000,0x0000,0x0000,
  0x7cf3,0x0000,0x8b9b,0x8ea7, 0x91c4,0x0000,0x947a,0x0000,
  0x0000,0x9a61,0x9a63,0x9ad7, 0x9c76,0x0000,0x9fa5,0x0000,
  0x7067,0x0000,0x72ab,0x864a, 0x897d,0x8b9d,0x8c53,0x8f65,
  0x947b,0x0000,0x98cd,0x98dd, 0x0000,0x9b30,0x9e16,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x96e7,0x9e18,0x9ea2,0x0000,
  0x9f7c,0x0000,0x7e9e,0x9484, 0x0000,0x9e1c,0x0000,0x7c71,
  0x97ca,0x0000,0x0000,0x0000, 0x9ea3,0x0000,0x9c7b,0x9f97,
  0x4d12,0x4a3a,0x9750,0x4a3b, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000
};
#endif

unsigned short gb2k_a_tbl[GB2K_A_LEN] = {
/* codelimit: 32760 */
/* 0x8100(i:0) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x00a0,0x00a1,0x00a2,0x00a3, 0x00a5,0x00a6,0x00a9,0x00aa,
  0x00ab,0x00ac,0x00ad,0x00ae, 0x00af,0x00b2,0x00b3,0x00b4,
  0x00b5,0x00b6,0x00b8,0x00b9, 0x00ba,0x00bb,0x00bc,0x00bd,
  0x00be,0x00bf,0x00c0,0x00c1, 0x00c2,0x00c3,0x00c4,0x00c5,
  0x00c6,0x00c7,0x00c8,0x00c9, 0x00ca,0x00cb,0x00cc,0x00cd,
  0x00ce,0x00cf,0x00d0,0x00d1, 0x00d2,0x00d3,0x00d4,0x00d5,
  0x00d6,0x00d8,0x00d9,0x00da, 0x00db,0x00dc,0x00dd,0x00de,
  0x00df,0x00e2,0x00e3,0x00e4, 0x00e5,0x00e6,0x00e7,0x00eb,
  0x00ee,0x00ef,0x00f0,0x00f1, 0x00f4,0x00f5,0x00f6,0x00f8,
  0x00fb,0x00fd,0x00fe,0x00ff, 0x0100,0x0102,0x0103,0x0104,
  0x0105,0x0106,0x0107,0x0108, 0x0109,0x010a,0x010b,0x010c,
  0x010d,0x010e,0x010f,0x0110, 0x0111,0x0112,0x0114,0x0115,
  0x0116,0x0117,0x0118,0x0119, 0x011a,0x011c,0x011d,0x011e,
  0x011f,0x0120,0x0121,0x0122, 0x0123,0x0124,0x0125,0x0126,
  0x0127,0x0128,0x0129,0x012a, 0x012c,0x012d,0x012e,0x012f,
  0x0130,0x0131,0x0132,0x0133, 0x0134,0x0135,0x0136,0x0137,
  0x0138,0x0139,0x013a,0x013b, 0x013c,0x013d,0x013e,0x013f,
  0x0140,0x0141,0x0142,0x0143, 0x0145,0x0146,0x0147,0x0149,
  0x014a,0x014b,0x014c,0x014e, 
/* 0x8281(i:180) */
  0x014f,0x0150,0x0151,0x0152, 0x0153,0x0154,0x0155,0x0156,
  0x0157,0x0158,0x0159,0x015a, 0x015b,0x015c,0x015d,0x015e,
  0x015f,0x0160,0x0161,0x0162, 0x0163,0x0164,0x0165,0x0166,
  0x0167,0x0168,0x0169,0x016a, 0x016c,0x016d,0x016e,0x016f,
  0x0170,0x0171,0x0172,0x0173, 0x0174,0x0175,0x0176,0x0177,
  0x0178,0x0179,0x017a,0x017b, 0x017c,0x017d,0x017e,0x017f,
  0x0180,0x0181,0x0182,0x0183, 0x0184,0x0185,0x0186,0x0187,
  0x0188,0x0189,0x018a,0x018b, 0x018c,0x018d,0x018e,0x018f,
  0x0190,0x0191,0x0192,0x0193, 0x0194,0x0195,0x0196,0x0197,
  0x0198,0x0199,0x019a,0x019b, 0x019c,0x019d,0x019e,0x019f,
  0x01a0,0x01a1,0x01a2,0x01a3, 0x01a4,0x01a5,0x01a6,0x01a7,
  0x01a8,0x01a9,0x01aa,0x01ab, 0x01ac,0x01ad,0x01ae,0x01af,
  0x01b0,0x01b1,0x01b2,0x01b3, 0x01b4,0x01b5,0x01b6,0x01b7,
  0x01b8,0x01b9,0x01ba,0x01bb, 0x01bc,0x01bd,0x01be,0x01bf,
  0x01c0,0x01c1,0x01c2,0x01c3, 0x01c4,0x01c5,0x01c6,0x01c7,
  0x01c8,0x01c9,0x01ca,0x01cb, 0x01cc,0x01cd,0x01cf,0x01d1,
  0x01d3,0x01d5,0x01d7,0x01d9, 0x01db,0x01dd,0x01de,0x01df,
  0x01e0,0x01e1,0x01e2,0x01e3, 0x01e4,0x01e5,0x01e6,0x01e7,
  0x01e8,0x01e9,0x01ea,0x01eb, 0x01ec,0x01ed,0x01ee,0x01ef,
  0x01f0,0x01f1,0x01f2,0x01f3, 0x01f4,0x01f5,0x01f6,0x01f7,
  0x01f8,0x01fa,0x01fb,0x01fc, 0x01fd,0x01fe,0x01ff,0x0200,
  0x0201,0x0202,0x0203,0x0204, 0x0205,0x0206,0x0207,0x0208,
  0x0209,0x020a,0x020b,0x020c, 
/* 0x8381(i:360) */
  0x020d,0x020e,0x020f,0x0210, 0x0211,0x0212,0x0213,0x0214,
  0x0215,0x0216,0x0217,0x0218, 0x0219,0x021a,0x021b,0x021c,
  0x021d,0x021e,0x021f,0x0220, 0x0221,0x0222,0x0223,0x0224,
  0x0225,0x0226,0x0227,0x0228, 0x0229,0x022a,0x022b,0x022c,
  0x022d,0x022e,0x022f,0x0230, 0x0231,0x0232,0x0233,0x0234,
  0x0235,0x0236,0x0237,0x0238, 0x0239,0x023a,0x023b,0x023c,
  0x023d,0x023e,0x023f,0x0240, 0x0241,0x0242,0x0243,0x0244,
  0x0245,0x0246,0x0247,0x0248, 0x0249,0x024a,0x024b,0x024c,
  0x024d,0x024e,0x024f,0x0250, 0x0252,0x0253,0x0254,0x0255,
  0x0256,0x0257,0x0258,0x0259, 0x025a,0x025b,0x025c,0x025d,
  0x025e,0x025f,0x0260,0x0262, 0x0263,0x0264,0x0265,0x0266,
  0x0267,0x0268,0x0269,0x026a, 0x026b,0x026c,0x026d,0x026e,
  0x026f,0x0270,0x0271,0x0272, 0x0273,0x0274,0x0275,0x0276,
  0x0277,0x0278,0x0279,0x027a, 0x027b,0x027c,0x027d,0x027e,
  0x027f,0x0280,0x0281,0x0282, 0x0283,0x0284,0x0285,0x0286,
  0x0287,0x0288,0x0289,0x028a, 0x028b,0x028c,0x028d,0x028e,
  0x028f,0x0290,0x0291,0x0292, 0x0293,0x0294,0x0295,0x0296,
  0x0297,0x0298,0x0299,0x029a, 0x029b,0x029c,0x029d,0x029e,
  0x029f,0x02a0,0x02a1,0x02a2, 0x02a3,0x02a4,0x02a5,0x02a6,
  0x02a7,0x02a8,0x02a9,0x02aa, 0x02ab,0x02ac,0x02ad,0x02ae,
  0x02af,0x02b0,0x02b1,0x02b2, 0x02b3,0x02b4,0x02b5,0x02b6,
  0x02b7,0x02b8,0x02b9,0x02ba, 0x02bb,0x02bc,0x02bd,0x02be,
  0x02bf,0x02c0,0x02c1,0x02c2, 
/* 0x8481(i:540) */
  0x02c3,0x02c4,0x02c5,0x02c6, 0x02c8,0x02cc,0x02cd,0x02ce,
  0x02cf,0x02d0,0x02d1,0x02d2, 0x02d3,0x02d4,0x02d5,0x02d6,
  0x02d7,0x02d8,0x02da,0x02db, 0x02dc,0x02dd,0x02de,0x02df,
  0x02e0,0x02e1,0x02e2,0x02e3, 0x02e4,0x02e5,0x02e6,0x02e7,
  0x02e8,0x02e9,0x02ea,0x02eb, 0x02ec,0x02ed,0x02ee,0x02ef,
  0x02f0,0x02f1,0x02f2,0x02f3, 0x02f4,0x02f5,0x02f6,0x02f7,
  0x02f8,0x02f9,0x02fa,0x02fb, 0x02fc,0x02fd,0x02fe,0x02ff,
  0x0300,0x0301,0x0302,0x0303, 0x0304,0x0305,0x0306,0x0307,
  0x0308,0x0309,0x030a,0x030b, 0x030c,0x030d,0x030e,0x030f,
  0x0310,0x0311,0x0312,0x0313, 0x0314,0x0315,0x0316,0x0317,
  0x0318,0x0319,0x031a,0x031b, 0x031c,0x031d,0x031e,0x031f,
  0x0320,0x0321,0x0322,0x0323, 0x0324,0x0325,0x0326,0x0327,
  0x0328,0x0329,0x032a,0x032b, 0x032c,0x032d,0x032e,0x032f,
  0x0330,0x0331,0x0332,0x0333, 0x0334,0x0335,0x0336,0x0337,
  0x0338,0x0339,0x033a,0x033b, 0x033c,0x033d,0x033e,0x033f,
  0x0340,0x0341,0x0342,0x0343, 0x0344,0x0345,0x0346,0x0347,
  0x0348,0x0349,0x034a,0x034b, 0x034c,0x034d,0x034e,0x034f,
  0x0350,0x0351,0x0352,0x0353, 0x0354,0x0355,0x0356,0x0357,
  0x0358,0x0359,0x035a,0x035b, 0x035c,0x035d,0x035e,0x035f,
  0x0360,0x0361,0x0362,0x0363, 0x0364,0x0365,0x0366,0x0367,
  0x0368,0x0369,0x036a,0x036b, 0x036c,0x036d,0x036e,0x036f,
  0x0370,0x0371,0x0372,0x0373, 0x0374,0x0375,0x0376,0x0377,
  0x0378,0x0379,0x037a,0x037b, 
/* 0x8581(i:720) */
  0x037c,0x037d,0x037e,0x037f, 0x0380,0x0381,0x0382,0x0383,
  0x0384,0x0385,0x0386,0x0387, 0x0388,0x0389,0x038a,0x038b,
  0x038c,0x038d,0x038e,0x038f, 0x0390,0x03a2,0x03aa,0x03ab,
  0x03ac,0x03ad,0x03ae,0x03af, 0x03b0,0x03c2,0x03ca,0x03cb,
  0x03cc,0x03cd,0x03ce,0x03cf, 0x03d0,0x03d1,0x03d2,0x03d3,
  0x03d4,0x03d5,0x03d6,0x03d7, 0x03d8,0x03d9,0x03da,0x03db,
  0x03dc,0x03dd,0x03de,0x03df, 0x03e0,0x03e1,0x03e2,0x03e3,
  0x03e4,0x03e5,0x03e6,0x03e7, 0x03e8,0x03e9,0x03ea,0x03eb,
  0x03ec,0x03ed,0x03ee,0x03ef, 0x03f0,0x03f1,0x03f2,0x03f3,
  0x03f4,0x03f5,0x03f6,0x03f7, 0x03f8,0x03f9,0x03fa,0x03fb,
  0x03fc,0x03fd,0x03fe,0x03ff, 0x0400,0x0402,0x0403,0x0404,
  0x0405,0x0406,0x0407,0x0408, 0x0409,0x040a,0x040b,0x040c,
  0x040d,0x040e,0x040f,0x0450, 0x0452,0x0453,0x0454,0x0455,
  0x0456,0x0457,0x0458,0x0459, 0x045a,0x045b,0x045c,0x045d,
  0x045e,0x045f,0x0460,0x0461, 0x0462,0x0463,0x0464,0x0465,
  0x0466,0x0467,0x0468,0x0469, 0x046a,0x046b,0x046c,0x046d,
  0x046e,0x046f,0x0470,0x0471, 0x0472,0x0473,0x0474,0x0475,
  0x0476,0x0477,0x0478,0x0479, 0x047a,0x047b,0x047c,0x047d,
  0x047e,0x047f,0x0480,0x0481, 0x0482,0x0483,0x0484,0x0485,
  0x0486,0x0487,0x0488,0x0489, 0x048a,0x048b,0x048c,0x048d,
  0x048e,0x048f,0x0490,0x0491, 0x0492,0x0493,0x0494,0x0495,
  0x0496,0x0497,0x0498,0x0499, 0x049a,0x049b,0x049c,0x049d,
  0x049e,0x049f,0x04a0,0x04a1,
/* 0x8681(i:900) */
  0x04a2,0x04a3,0x04a4,0x04a5, 0x04a6,0x04a7,0x04a8,0x04a9,
  0x04aa,0x04ab,0x04ac,0x04ad, 0x04ae,0x04af,0x04b0,0x04b1,
  0x04b2,0x04b3,0x04b4,0x04b5, 0x04b6,0x04b7,0x04b8,0x04b9,
  0x04ba,0x04bb,0x04bc,0x04bd, 0x04be,0x04bf,0x04c0,0x04c1,
  0x04c2,0x04c3,0x04c4,0x04c5, 0x04c6,0x04c7,0x04c8,0x04c9,
  0x04ca,0x04cb,0x04cc,0x04cd, 0x04ce,0x04cf,0x04d0,0x04d1,
  0x04d2,0x04d3,0x04d4,0x04d5, 0x04d6,0x04d7,0x04d8,0x04d9,
  0x04da,0x04db,0x04dc,0x04dd, 0x04de,0x04df,0x04e0,0x04e1,
  0x04e2,0x04e3,0x04e4,0x04e5, 0x04e6,0x04e7,0x04e8,0x04e9,
  0x04ea,0x04eb,0x04ec,0x04ed, 0x04ee,0x04ef,0x04f0,0x04f1,
  0x04f2,0x04f3,0x04f4,0x04f5, 0x04f6,0x04f7,0x04f8,0x04f9,
  0x04fa,0x04fb,0x04fc,0x04fd, 0x04fe,0x04ff,0x0500,0x0501,
  0x0502,0x0503,0x0504,0x0505, 0x0506,0x0507,0x0508,0x0509,
  0x050a,0x050b,0x050c,0x050d, 0x050e,0x050f,0x0510,0x0511,
  0x0512,0x0513,0x0514,0x0515, 0x0516,0x0517,0x0518,0x0519,
  0x051a,0x051b,0x051c,0x051d, 0x051e,0x051f,0x0520,0x0521,
  0x0522,0x0523,0x0524,0x0525, 0x0526,0x0527,0x0528,0x0529,
  0x052a,0x052b,0x052c,0x052d, 0x052e,0x052f,0x0530,0x0531,
  0x0532,0x0533,0x0534,0x0535, 0x0536,0x0537,0x0538,0x0539,
  0x053a,0x053b,0x053c,0x053d, 0x053e,0x053f,0x0540,0x0541,
  0x0542,0x0543,0x0544,0x0545, 0x0546,0x0547,0x0548,0x0549,
  0x054a,0x054b,0x054c,0x054d, 0x054e,0x054f,0x0550,0x0551,
  0x0552,0x0553,0x0554,0x0555,
/* 0x8781(i:1080) */
  0x0556,0x0557,0x0558,0x0559, 0x055a,0x055b,0x055c,0x055d,
  0x055e,0x055f,0x0560,0x0561, 0x0562,0x0563,0x0564,0x0565,
  0x0566,0x0567,0x0568,0x0569, 0x056a,0x056b,0x056c,0x056d,
  0x056e,0x056f,0x0570,0x0571, 0x0572,0x0573,0x0574,0x0575,
  0x0576,0x0577,0x0578,0x0579, 0x057a,0x057b,0x057c,0x057d,
  0x057e,0x057f,0x0580,0x0581, 0x0582,0x0583,0x0584,0x0585,
  0x0586,0x0587,0x0588,0x0589, 0x058a,0x058b,0x058c,0x058d,
  0x058e,0x058f,0x0590,0x0591, 0x0592,0x0593,0x0594,0x0595,
  0x0596,0x0597,0x0598,0x0599, 0x059a,0x059b,0x059c,0x059d,
  0x059e,0x059f,0x05a0,0x05a1, 0x05a2,0x05a3,0x05a4,0x05a5,
  0x05a6,0x05a7,0x05a8,0x05a9, 0x05aa,0x05ab,0x05ac,0x05ad,
  0x05ae,0x05af,0x05b0,0x05b1, 0x05b2,0x05b3,0x05b4,0x05b5,
  0x05b6,0x05b7,0x05b8,0x05b9, 0x05ba,0x05bb,0x05bc,0x05bd,
  0x05be,0x05bf,0x05c0,0x05c1, 0x05c2,0x05c3,0x05c4,0x05c5,
  0x05c6,0x05c7,0x05c8,0x05c9, 0x05ca,0x05cb,0x05cc,0x05cd,
  0x05ce,0x05cf,0x05d0,0x05d1, 0x05d2,0x05d3,0x05d4,0x05d5,
  0x05d6,0x05d7,0x05d8,0x05d9, 0x05da,0x05db,0x05dc,0x05dd,
  0x05de,0x05df,0x05e0,0x05e1, 0x05e2,0x05e3,0x05e4,0x05e5,
  0x05e6,0x05e7,0x05e8,0x05e9, 0x05ea,0x05eb,0x05ec,0x05ed,
  0x05ee,0x05ef,0x05f0,0x05f1, 0x05f2,0x05f3,0x05f4,0x05f5,
  0x05f6,0x05f7,0x05f8,0x05f9, 0x05fa,0x05fb,0x05fc,0x05fd,
  0x05fe,0x05ff,0x0600,0x0601, 0x0602,0x0603,0x0604,0x0605,
  0x0606,0x0607,0x0608,0x0609,
/* 0x8881(i:1260) */
  0x060a,0x060b,0x060c,0x060d, 0x060e,0x060f,0x0610,0x0611,
  0x0612,0x0613,0x0614,0x0615, 0x0616,0x0617,0x0618,0x0619,
  0x061a,0x061b,0x061c,0x061d, 0x061e,0x061f,0x0620,0x0621,
  0x0622,0x0623,0x0624,0x0625, 0x0626,0x0627,0x0628,0x0629,
  0x062a,0x062b,0x062c,0x062d, 0x062e,0x062f,0x0630,0x0631,
  0x0632,0x0633,0x0634,0x0635, 0x0636,0x0637,0x0638,0x0639,
  0x063a,0x063b,0x063c,0x063d, 0x063e,0x063f,0x0640,0x0641,
  0x0642,0x0643,0x0644,0x0645, 0x0646,0x0647,0x0648,0x0649,
  0x064a,0x064b,0x064c,0x064d, 0x064e,0x064f,0x0650,0x0651,
  0x0652,0x0653,0x0654,0x0655, 0x0656,0x0657,0x0658,0x0659,
  0x065a,0x065b,0x065c,0x065d, 0x065e,0x065f,0x0660,0x0661,
  0x0662,0x0663,0x0664,0x0665, 0x0666,0x0667,0x0668,0x0669,
  0x066a,0x066b,0x066c,0x066d, 0x066e,0x066f,0x0670,0x0671,
  0x0672,0x0673,0x0674,0x0675, 0x0676,0x0677,0x0678,0x0679,
  0x067a,0x067b,0x067c,0x067d, 0x067e,0x067f,0x0680,0x0681,
  0x0682,0x0683,0x0684,0x0685, 0x0686,0x0687,0x0688,0x0689,
  0x068a,0x068b,0x068c,0x068d, 0x068e,0x068f,0x0690,0x0691,
  0x0692,0x0693,0x0694,0x0695, 0x0696,0x0697,0x0698,0x0699,
  0x069a,0x069b,0x069c,0x069d, 0x069e,0x069f,0x06a0,0x06a1,
  0x06a2,0x06a3,0x06a4,0x06a5, 0x06a6,0x06a7,0x06a8,0x06a9,
  0x06aa,0x06ab,0x06ac,0x06ad, 0x06ae,0x06af,0x06b0,0x06b1,
  0x06b2,0x06b3,0x06b4,0x06b5, 0x06b6,0x06b7,0x06b8,0x06b9,
  0x06ba,0x06bb,0x06bc,0x06bd,
/* 0x8981(i:1440) */
  0x06be,0x06bf,0x06c0,0x06c1, 0x06c2,0x06c3,0x06c4,0x06c5,
  0x06c6,0x06c7,0x06c8,0x06c9, 0x06ca,0x06cb,0x06cc,0x06cd,
  0x06ce,0x06cf,0x06d0,0x06d1, 0x06d2,0x06d3,0x06d4,0x06d5,
  0x06d6,0x06d7,0x06d8,0x06d9, 0x06da,0x06db,0x06dc,0x06dd,
  0x06de,0x06df,0x06e0,0x06e1, 0x06e2,0x06e3,0x06e4,0x06e5,
  0x06e6,0x06e7,0x06e8,0x06e9, 0x06ea,0x06eb,0x06ec,0x06ed,
  0x06ee,0x06ef,0x06f0,0x06f1, 0x06f2,0x06f3,0x06f4,0x06f5,
  0x06f6,0x06f7,0x06f8,0x06f9, 0x06fa,0x06fb,0x06fc,0x06fd,
  0x06fe,0x06ff,0x0700,0x0701, 0x0702,0x0703,0x0704,0x0705,
  0x0706,0x0707,0x0708,0x0709, 0x070a,0x070b,0x070c,0x070d,
  0x070e,0x070f,0x0710,0x0711, 0x0712,0x0713,0x0714,0x0715,
  0x0716,0x0717,0x0718,0x0719, 0x071a,0x071b,0x071c,0x071d,
  0x071e,0x071f,0x0720,0x0721, 0x0722,0x0723,0x0724,0x0725,
  0x0726,0x0727,0x0728,0x0729, 0x072a,0x072b,0x072c,0x072d,
  0x072e,0x072f,0x0730,0x0731, 0x0732,0x0733,0x0734,0x0735,
  0x0736,0x0737,0x0738,0x0739, 0x073a,0x073b,0x073c,0x073d,
  0x073e,0x073f,0x0740,0x0741, 0x0742,0x0743,0x0744,0x0745,
  0x0746,0x0747,0x0748,0x0749, 0x074a,0x074b,0x074c,0x074d,
  0x074e,0x074f,0x0750,0x0751, 0x0752,0x0753,0x0754,0x0755,
  0x0756,0x0757,0x0758,0x0759, 0x075a,0x075b,0x075c,0x075d,
  0x075e,0x075f,0x0760,0x0761, 0x0762,0x0763,0x0764,0x0765,
  0x0766,0x0767,0x0768,0x0769, 0x076a,0x076b,0x076c,0x076d,
  0x076e,0x076f,0x0770,0x0771,
/* 0x8a81(i:1620) */
  0x0772,0x0773,0x0774,0x0775, 0x0776,0x0777,0x0778,0x0779,
  0x077a,0x077b,0x077c,0x077d, 0x077e,0x077f,0x0780,0x0781,
  0x0782,0x0783,0x0784,0x0785, 0x0786,0x0787,0x0788,0x0789,
  0x078a,0x078b,0x078c,0x078d, 0x078e,0x078f,0x0790,0x0791,
  0x0792,0x0793,0x0794,0x0795, 0x0796,0x0797,0x0798,0x0799,
  0x079a,0x079b,0x079c,0x079d, 0x079e,0x079f,0x07a0,0x07a1,
  0x07a2,0x07a3,0x07a4,0x07a5, 0x07a6,0x07a7,0x07a8,0x07a9,
  0x07aa,0x07ab,0x07ac,0x07ad, 0x07ae,0x07af,0x07b0,0x07b1,
  0x07b2,0x07b3,0x07b4,0x07b5, 0x07b6,0x07b7,0x07b8,0x07b9,
  0x07ba,0x07bb,0x07bc,0x07bd, 0x07be,0x07bf,0x07c0,0x07c1,
  0x07c2,0x07c3,0x07c4,0x07c5, 0x07c6,0x07c7,0x07c8,0x07c9,
  0x07ca,0x07cb,0x07cc,0x07cd, 0x07ce,0x07cf,0x07d0,0x07d1,
  0x07d2,0x07d3,0x07d4,0x07d5, 0x07d6,0x07d7,0x07d8,0x07d9,
  0x07da,0x07db,0x07dc,0x07dd, 0x07de,0x07df,0x07e0,0x07e1,
  0x07e2,0x07e3,0x07e4,0x07e5, 0x07e6,0x07e7,0x07e8,0x07e9,
  0x07ea,0x07eb,0x07ec,0x07ed, 0x07ee,0x07ef,0x07f0,0x07f1,
  0x07f2,0x07f3,0x07f4,0x07f5, 0x07f6,0x07f7,0x07f8,0x07f9,
  0x07fa,0x07fb,0x07fc,0x07fd, 0x07fe,0x07ff,0x0800,0x0801,
  0x0802,0x0803,0x0804,0x0805, 0x0806,0x0807,0x0808,0x0809,
  0x080a,0x080b,0x080c,0x080d, 0x080e,0x080f,0x0810,0x0811,
  0x0812,0x0813,0x0814,0x0815, 0x0816,0x0817,0x0818,0x0819,
  0x081a,0x081b,0x081c,0x081d, 0x081e,0x081f,0x0820,0x0821,
  0x0822,0x0823,0x0824,0x0825,
/* 0x8b81(i:1800) */
  0x0826,0x0827,0x0828,0x0829, 0x082a,0x082b,0x082c,0x082d,
  0x082e,0x082f,0x0830,0x0831, 0x0832,0x0833,0x0834,0x0835,
  0x0836,0x0837,0x0838,0x0839, 0x083a,0x083b,0x083c,0x083d,
  0x083e,0x083f,0x0840,0x0841, 0x0842,0x0843,0x0844,0x0845,
  0x0846,0x0847,0x0848,0x0849, 0x084a,0x084b,0x084c,0x084d,
  0x084e,0x084f,0x0850,0x0851, 0x0852,0x0853,0x0854,0x0855,
  0x0856,0x0857,0x0858,0x0859, 0x085a,0x085b,0x085c,0x085d,
  0x085e,0x085f,0x0860,0x0861, 0x0862,0x0863,0x0864,0x0865,
  0x0866,0x0867,0x0868,0x0869, 0x086a,0x086b,0x086c,0x086d,
  0x086e,0x086f,0x0870,0x0871, 0x0872,0x0873,0x0874,0x0875,
  0x0876,0x0877,0x0878,0x0879, 0x087a,0x087b,0x087c,0x087d,
  0x087e,0x087f,0x0880,0x0881, 0x0882,0x0883,0x0884,0x0885,
  0x0886,0x0887,0x0888,0x0889, 0x088a,0x088b,0x088c,0x088d,
  0x088e,0x088f,0x0890,0x0891, 0x0892,0x0893,0x0894,0x0895,
  0x0896,0x0897,0x0898,0x0899, 0x089a,0x089b,0x089c,0x089d,
  0x089e,0x089f,0x08a0,0x08a1, 0x08a2,0x08a3,0x08a4,0x08a5,
  0x08a6,0x08a7,0x08a8,0x08a9, 0x08aa,0x08ab,0x08ac,0x08ad,
  0x08ae,0x08af,0x08b0,0x08b1, 0x08b2,0x08b3,0x08b4,0x08b5,
  0x08b6,0x08b7,0x08b8,0x08b9, 0x08ba,0x08bb,0x08bc,0x08bd,
  0x08be,0x08bf,0x08c0,0x08c1, 0x08c2,0x08c3,0x08c4,0x08c5,
  0x08c6,0x08c7,0x08c8,0x08c9, 0x08ca,0x08cb,0x08cc,0x08cd,
  0x08ce,0x08cf,0x08d0,0x08d1, 0x08d2,0x08d3,0x08d4,0x08d5,
  0x08d6,0x08d7,0x08d8,0x08d9,
/* 0x8c81(i:1980) */
  0x08da,0x08db,0x08dc,0x08dd, 0x08de,0x08df,0x08e0,0x08e1,
  0x08e2,0x08e3,0x08e4,0x08e5, 0x08e6,0x08e7,0x08e8,0x08e9,
  0x08ea,0x08eb,0x08ec,0x08ed, 0x08ee,0x08ef,0x08f0,0x08f1,
  0x08f2,0x08f3,0x08f4,0x08f5, 0x08f6,0x08f7,0x08f8,0x08f9,
  0x08fa,0x08fb,0x08fc,0x08fd, 0x08fe,0x08ff,0x0900,0x0901,
  0x0902,0x0903,0x0904,0x0905, 0x0906,0x0907,0x0908,0x0909,
  0x090a,0x090b,0x090c,0x090d, 0x090e,0x090f,0x0910,0x0911,
  0x0912,0x0913,0x0914,0x0915, 0x0916,0x0917,0x0918,0x0919,
  0x091a,0x091b,0x091c,0x091d, 0x091e,0x091f,0x0920,0x0921,
  0x0922,0x0923,0x0924,0x0925, 0x0926,0x0927,0x0928,0x0929,
  0x092a,0x092b,0x092c,0x092d, 0x092e,0x092f,0x0930,0x0931,
  0x0932,0x0933,0x0934,0x0935, 0x0936,0x0937,0x0938,0x0939,
  0x093a,0x093b,0x093c,0x093d, 0x093e,0x093f,0x0940,0x0941,
  0x0942,0x0943,0x0944,0x0945, 0x0946,0x0947,0x0948,0x0949,
  0x094a,0x094b,0x094c,0x094d, 0x094e,0x094f,0x0950,0x0951,
  0x0952,0x0953,0x0954,0x0955, 0x0956,0x0957,0x0958,0x0959,
  0x095a,0x095b,0x095c,0x095d, 0x095e,0x095f,0x0960,0x0961,
  0x0962,0x0963,0x0964,0x0965, 0x0966,0x0967,0x0968,0x0969,
  0x096a,0x096b,0x096c,0x096d, 0x096e,0x096f,0x0970,0x0971,
  0x0972,0x0973,0x0974,0x0975, 0x0976,0x0977,0x0978,0x0979,
  0x097a,0x097b,0x097c,0x097d, 0x097e,0x097f,0x0980,0x0981,
  0x0982,0x0983,0x0984,0x0985, 0x0986,0x0987,0x0988,0x0989,
  0x098a,0x098b,0x098c,0x098d,
/* 0x8d81(i:2160) */
  0x098e,0x098f,0x0990,0x0991, 0x0992,0x0993,0x0994,0x0995,
  0x0996,0x0997,0x0998,0x0999, 0x099a,0x099b,0x099c,0x099d,
  0x099e,0x099f,0x09a0,0x09a1, 0x09a2,0x09a3,0x09a4,0x09a5,
  0x09a6,0x09a7,0x09a8,0x09a9, 0x09aa,0x09ab,0x09ac,0x09ad,
  0x09ae,0x09af,0x09b0,0x09b1, 0x09b2,0x09b3,0x09b4,0x09b5,
  0x09b6,0x09b7,0x09b8,0x09b9, 0x09ba,0x09bb,0x09bc,0x09bd,
  0x09be,0x09bf,0x09c0,0x09c1, 0x09c2,0x09c3,0x09c4,0x09c5,
  0x09c6,0x09c7,0x09c8,0x09c9, 0x09ca,0x09cb,0x09cc,0x09cd,
  0x09ce,0x09cf,0x09d0,0x09d1, 0x09d2,0x09d3,0x09d4,0x09d5,
  0x09d6,0x09d7,0x09d8,0x09d9, 0x09da,0x09db,0x09dc,0x09dd,
  0x09de,0x09df,0x09e0,0x09e1, 0x09e2,0x09e3,0x09e4,0x09e5,
  0x09e6,0x09e7,0x09e8,0x09e9, 0x09ea,0x09eb,0x09ec,0x09ed,
  0x09ee,0x09ef,0x09f0,0x09f1, 0x09f2,0x09f3,0x09f4,0x09f5,
  0x09f6,0x09f7,0x09f8,0x09f9, 0x09fa,0x09fb,0x09fc,0x09fd,
  0x09fe,0x09ff,0x0a00,0x0a01, 0x0a02,0x0a03,0x0a04,0x0a05,
  0x0a06,0x0a07,0x0a08,0x0a09, 0x0a0a,0x0a0b,0x0a0c,0x0a0d,
  0x0a0e,0x0a0f,0x0a10,0x0a11, 0x0a12,0x0a13,0x0a14,0x0a15,
  0x0a16,0x0a17,0x0a18,0x0a19, 0x0a1a,0x0a1b,0x0a1c,0x0a1d,
  0x0a1e,0x0a1f,0x0a20,0x0a21, 0x0a22,0x0a23,0x0a24,0x0a25,
  0x0a26,0x0a27,0x0a28,0x0a29, 0x0a2a,0x0a2b,0x0a2c,0x0a2d,
  0x0a2e,0x0a2f,0x0a30,0x0a31, 0x0a32,0x0a33,0x0a34,0x0a35,
  0x0a36,0x0a37,0x0a38,0x0a39, 0x0a3a,0x0a3b,0x0a3c,0x0a3d,
  0x0a3e,0x0a3f,0x0a40,0x0a41,
/* 0x8e81(i:2340) */
  0x0a42,0x0a43,0x0a44,0x0a45, 0x0a46,0x0a47,0x0a48,0x0a49,
  0x0a4a,0x0a4b,0x0a4c,0x0a4d, 0x0a4e,0x0a4f,0x0a50,0x0a51,
  0x0a52,0x0a53,0x0a54,0x0a55, 0x0a56,0x0a57,0x0a58,0x0a59,
  0x0a5a,0x0a5b,0x0a5c,0x0a5d, 0x0a5e,0x0a5f,0x0a60,0x0a61,
  0x0a62,0x0a63,0x0a64,0x0a65, 0x0a66,0x0a67,0x0a68,0x0a69,
  0x0a6a,0x0a6b,0x0a6c,0x0a6d, 0x0a6e,0x0a6f,0x0a70,0x0a71,
  0x0a72,0x0a73,0x0a74,0x0a75, 0x0a76,0x0a77,0x0a78,0x0a79,
  0x0a7a,0x0a7b,0x0a7c,0x0a7d, 0x0a7e,0x0a7f,0x0a80,0x0a81,
  0x0a82,0x0a83,0x0a84,0x0a85, 0x0a86,0x0a87,0x0a88,0x0a89,
  0x0a8a,0x0a8b,0x0a8c,0x0a8d, 0x0a8e,0x0a8f,0x0a90,0x0a91,
  0x0a92,0x0a93,0x0a94,0x0a95, 0x0a96,0x0a97,0x0a98,0x0a99,
  0x0a9a,0x0a9b,0x0a9c,0x0a9d, 0x0a9e,0x0a9f,0x0aa0,0x0aa1,
  0x0aa2,0x0aa3,0x0aa4,0x0aa5, 0x0aa6,0x0aa7,0x0aa8,0x0aa9,
  0x0aaa,0x0aab,0x0aac,0x0aad, 0x0aae,0x0aaf,0x0ab0,0x0ab1,
  0x0ab2,0x0ab3,0x0ab4,0x0ab5, 0x0ab6,0x0ab7,0x0ab8,0x0ab9,
  0x0aba,0x0abb,0x0abc,0x0abd, 0x0abe,0x0abf,0x0ac0,0x0ac1,
  0x0ac2,0x0ac3,0x0ac4,0x0ac5, 0x0ac6,0x0ac7,0x0ac8,0x0ac9,
  0x0aca,0x0acb,0x0acc,0x0acd, 0x0ace,0x0acf,0x0ad0,0x0ad1,
  0x0ad2,0x0ad3,0x0ad4,0x0ad5, 0x0ad6,0x0ad7,0x0ad8,0x0ad9,
  0x0ada,0x0adb,0x0adc,0x0add, 0x0ade,0x0adf,0x0ae0,0x0ae1,
  0x0ae2,0x0ae3,0x0ae4,0x0ae5, 0x0ae6,0x0ae7,0x0ae8,0x0ae9,
  0x0aea,0x0aeb,0x0aec,0x0aed, 0x0aee,0x0aef,0x0af0,0x0af1,
  0x0af2,0x0af3,0x0af4,0x0af5,
/* 0x8f81(i:2520) */
  0x0af6,0x0af7,0x0af8,0x0af9, 0x0afa,0x0afb,0x0afc,0x0afd,
  0x0afe,0x0aff,0x0b00,0x0b01, 0x0b02,0x0b03,0x0b04,0x0b05,
  0x0b06,0x0b07,0x0b08,0x0b09, 0x0b0a,0x0b0b,0x0b0c,0x0b0d,
  0x0b0e,0x0b0f,0x0b10,0x0b11, 0x0b12,0x0b13,0x0b14,0x0b15,
  0x0b16,0x0b17,0x0b18,0x0b19, 0x0b1a,0x0b1b,0x0b1c,0x0b1d,
  0x0b1e,0x0b1f,0x0b20,0x0b21, 0x0b22,0x0b23,0x0b24,0x0b25,
  0x0b26,0x0b27,0x0b28,0x0b29, 0x0b2a,0x0b2b,0x0b2c,0x0b2d,
  0x0b2e,0x0b2f,0x0b30,0x0b31, 0x0b32,0x0b33,0x0b34,0x0b35,
  0x0b36,0x0b37,0x0b38,0x0b39, 0x0b3a,0x0b3b,0x0b3c,0x0b3d,
  0x0b3e,0x0b3f,0x0b40,0x0b41, 0x0b42,0x0b43,0x0b44,0x0b45,
  0x0b46,0x0b47,0x0b48,0x0b49, 0x0b4a,0x0b4b,0x0b4c,0x0b4d,
  0x0b4e,0x0b4f,0x0b50,0x0b51, 0x0b52,0x0b53,0x0b54,0x0b55,
  0x0b56,0x0b57,0x0b58,0x0b59, 0x0b5a,0x0b5b,0x0b5c,0x0b5d,
  0x0b5e,0x0b5f,0x0b60,0x0b61, 0x0b62,0x0b63,0x0b64,0x0b65,
  0x0b66,0x0b67,0x0b68,0x0b69, 0x0b6a,0x0b6b,0x0b6c,0x0b6d,
  0x0b6e,0x0b6f,0x0b70,0x0b71, 0x0b72,0x0b73,0x0b74,0x0b75,
  0x0b76,0x0b77,0x0b78,0x0b79, 0x0b7a,0x0b7b,0x0b7c,0x0b7d,
  0x0b7e,0x0b7f,0x0b80,0x0b81, 0x0b82,0x0b83,0x0b84,0x0b85,
  0x0b86,0x0b87,0x0b88,0x0b89, 0x0b8a,0x0b8b,0x0b8c,0x0b8d,
  0x0b8e,0x0b8f,0x0b90,0x0b91, 0x0b92,0x0b93,0x0b94,0x0b95,
  0x0b96,0x0b97,0x0b98,0x0b99, 0x0b9a,0x0b9b,0x0b9c,0x0b9d,
  0x0b9e,0x0b9f,0x0ba0,0x0ba1, 0x0ba2,0x0ba3,0x0ba4,0x0ba5,
  0x0ba6,0x0ba7,0x0ba8,0x0ba9,
/* 0x9081(i:2700) */
  0x0baa,0x0bab,0x0bac,0x0bad, 0x0bae,0x0baf,0x0bb0,0x0bb1,
  0x0bb2,0x0bb3,0x0bb4,0x0bb5, 0x0bb6,0x0bb7,0x0bb8,0x0bb9,
  0x0bba,0x0bbb,0x0bbc,0x0bbd, 0x0bbe,0x0bbf,0x0bc0,0x0bc1,
  0x0bc2,0x0bc3,0x0bc4,0x0bc5, 0x0bc6,0x0bc7,0x0bc8,0x0bc9,
  0x0bca,0x0bcb,0x0bcc,0x0bcd, 0x0bce,0x0bcf,0x0bd0,0x0bd1,
  0x0bd2,0x0bd3,0x0bd4,0x0bd5, 0x0bd6,0x0bd7,0x0bd8,0x0bd9,
  0x0bda,0x0bdb,0x0bdc,0x0bdd, 0x0bde,0x0bdf,0x0be0,0x0be1,
  0x0be2,0x0be3,0x0be4,0x0be5, 0x0be6,0x0be7,0x0be8,0x0be9,
  0x0bea,0x0beb,0x0bec,0x0bed, 0x0bee,0x0bef,0x0bf0,0x0bf1,
  0x0bf2,0x0bf3,0x0bf4,0x0bf5, 0x0bf6,0x0bf7,0x0bf8,0x0bf9,
  0x0bfa,0x0bfb,0x0bfc,0x0bfd, 0x0bfe,0x0bff,0x0c00,0x0c01,
  0x0c02,0x0c03,0x0c04,0x0c05, 0x0c06,0x0c07,0x0c08,0x0c09,
  0x0c0a,0x0c0b,0x0c0c,0x0c0d, 0x0c0e,0x0c0f,0x0c10,0x0c11,
  0x0c12,0x0c13,0x0c14,0x0c15, 0x0c16,0x0c17,0x0c18,0x0c19,
  0x0c1a,0x0c1b,0x0c1c,0x0c1d, 0x0c1e,0x0c1f,0x0c20,0x0c21,
  0x0c22,0x0c23,0x0c24,0x0c25, 0x0c26,0x0c27,0x0c28,0x0c29,
  0x0c2a,0x0c2b,0x0c2c,0x0c2d, 0x0c2e,0x0c2f,0x0c30,0x0c31,
  0x0c32,0x0c33,0x0c34,0x0c35, 0x0c36,0x0c37,0x0c38,0x0c39,
  0x0c3a,0x0c3b,0x0c3c,0x0c3d, 0x0c3e,0x0c3f,0x0c40,0x0c41,
  0x0c42,0x0c43,0x0c44,0x0c45, 0x0c46,0x0c47,0x0c48,0x0c49,
  0x0c4a,0x0c4b,0x0c4c,0x0c4d, 0x0c4e,0x0c4f,0x0c50,0x0c51,
  0x0c52,0x0c53,0x0c54,0x0c55, 0x0c56,0x0c57,0x0c58,0x0c59,
  0x0c5a,0x0c5b,0x0c5c,0x0c5d,
/* 0x9181(i:2880) */
  0x0c5e,0x0c5f,0x0c60,0x0c61, 0x0c62,0x0c63,0x0c64,0x0c65,
  0x0c66,0x0c67,0x0c68,0x0c69, 0x0c6a,0x0c6b,0x0c6c,0x0c6d,
  0x0c6e,0x0c6f,0x0c70,0x0c71, 0x0c72,0x0c73,0x0c74,0x0c75,
  0x0c76,0x0c77,0x0c78,0x0c79, 0x0c7a,0x0c7b,0x0c7c,0x0c7d,
  0x0c7e,0x0c7f,0x0c80,0x0c81, 0x0c82,0x0c83,0x0c84,0x0c85,
  0x0c86,0x0c87,0x0c88,0x0c89, 0x0c8a,0x0c8b,0x0c8c,0x0c8d,
  0x0c8e,0x0c8f,0x0c90,0x0c91, 0x0c92,0x0c93,0x0c94,0x0c95,
  0x0c96,0x0c97,0x0c98,0x0c99, 0x0c9a,0x0c9b,0x0c9c,0x0c9d,
  0x0c9e,0x0c9f,0x0ca0,0x0ca1, 0x0ca2,0x0ca3,0x0ca4,0x0ca5,
  0x0ca6,0x0ca7,0x0ca8,0x0ca9, 0x0caa,0x0cab,0x0cac,0x0cad,
  0x0cae,0x0caf,0x0cb0,0x0cb1, 0x0cb2,0x0cb3,0x0cb4,0x0cb5,
  0x0cb6,0x0cb7,0x0cb8,0x0cb9, 0x0cba,0x0cbb,0x0cbc,0x0cbd,
  0x0cbe,0x0cbf,0x0cc0,0x0cc1, 0x0cc2,0x0cc3,0x0cc4,0x0cc5,
  0x0cc6,0x0cc7,0x0cc8,0x0cc9, 0x0cca,0x0ccb,0x0ccc,0x0ccd,
  0x0cce,0x0ccf,0x0cd0,0x0cd1, 0x0cd2,0x0cd3,0x0cd4,0x0cd5,
  0x0cd6,0x0cd7,0x0cd8,0x0cd9, 0x0cda,0x0cdb,0x0cdc,0x0cdd,
  0x0cde,0x0cdf,0x0ce0,0x0ce1, 0x0ce2,0x0ce3,0x0ce4,0x0ce5,
  0x0ce6,0x0ce7,0x0ce8,0x0ce9, 0x0cea,0x0ceb,0x0cec,0x0ced,
  0x0cee,0x0cef,0x0cf0,0x0cf1, 0x0cf2,0x0cf3,0x0cf4,0x0cf5,
  0x0cf6,0x0cf7,0x0cf8,0x0cf9, 0x0cfa,0x0cfb,0x0cfc,0x0cfd,
  0x0cfe,0x0cff,0x0d00,0x0d01, 0x0d02,0x0d03,0x0d04,0x0d05,
  0x0d06,0x0d07,0x0d08,0x0d09, 0x0d0a,0x0d0b,0x0d0c,0x0d0d,
  0x0d0e,0x0d0f,0x0d10,0x0d11,
/* 0x9281(i:3060) */
  0x0d12,0x0d13,0x0d14,0x0d15, 0x0d16,0x0d17,0x0d18,0x0d19,
  0x0d1a,0x0d1b,0x0d1c,0x0d1d, 0x0d1e,0x0d1f,0x0d20,0x0d21,
  0x0d22,0x0d23,0x0d24,0x0d25, 0x0d26,0x0d27,0x0d28,0x0d29,
  0x0d2a,0x0d2b,0x0d2c,0x0d2d, 0x0d2e,0x0d2f,0x0d30,0x0d31,
  0x0d32,0x0d33,0x0d34,0x0d35, 0x0d36,0x0d37,0x0d38,0x0d39,
  0x0d3a,0x0d3b,0x0d3c,0x0d3d, 0x0d3e,0x0d3f,0x0d40,0x0d41,
  0x0d42,0x0d43,0x0d44,0x0d45, 0x0d46,0x0d47,0x0d48,0x0d49,
  0x0d4a,0x0d4b,0x0d4c,0x0d4d, 0x0d4e,0x0d4f,0x0d50,0x0d51,
  0x0d52,0x0d53,0x0d54,0x0d55, 0x0d56,0x0d57,0x0d58,0x0d59,
  0x0d5a,0x0d5b,0x0d5c,0x0d5d, 0x0d5e,0x0d5f,0x0d60,0x0d61,
  0x0d62,0x0d63,0x0d64,0x0d65, 0x0d66,0x0d67,0x0d68,0x0d69,
  0x0d6a,0x0d6b,0x0d6c,0x0d6d, 0x0d6e,0x0d6f,0x0d70,0x0d71,
  0x0d72,0x0d73,0x0d74,0x0d75, 0x0d76,0x0d77,0x0d78,0x0d79,
  0x0d7a,0x0d7b,0x0d7c,0x0d7d, 0x0d7e,0x0d7f,0x0d80,0x0d81,
  0x0d82,0x0d83,0x0d84,0x0d85, 0x0d86,0x0d87,0x0d88,0x0d89,
  0x0d8a,0x0d8b,0x0d8c,0x0d8d, 0x0d8e,0x0d8f,0x0d90,0x0d91,
  0x0d92,0x0d93,0x0d94,0x0d95, 0x0d96,0x0d97,0x0d98,0x0d99,
  0x0d9a,0x0d9b,0x0d9c,0x0d9d, 0x0d9e,0x0d9f,0x0da0,0x0da1,
  0x0da2,0x0da3,0x0da4,0x0da5, 0x0da6,0x0da7,0x0da8,0x0da9,
  0x0daa,0x0dab,0x0dac,0x0dad, 0x0dae,0x0daf,0x0db0,0x0db1,
  0x0db2,0x0db3,0x0db4,0x0db5, 0x0db6,0x0db7,0x0db8,0x0db9,
  0x0dba,0x0dbb,0x0dbc,0x0dbd, 0x0dbe,0x0dbf,0x0dc0,0x0dc1,
  0x0dc2,0x0dc3,0x0dc4,0x0dc5,
/* 0x9381(i:3240) */
  0x0dc6,0x0dc7,0x0dc8,0x0dc9, 0x0dca,0x0dcb,0x0dcc,0x0dcd,
  0x0dce,0x0dcf,0x0dd0,0x0dd1, 0x0dd2,0x0dd3,0x0dd4,0x0dd5,
  0x0dd6,0x0dd7,0x0dd8,0x0dd9, 0x0dda,0x0ddb,0x0ddc,0x0ddd,
  0x0dde,0x0ddf,0x0de0,0x0de1, 0x0de2,0x0de3,0x0de4,0x0de5,
  0x0de6,0x0de7,0x0de8,0x0de9, 0x0dea,0x0deb,0x0dec,0x0ded,
  0x0dee,0x0def,0x0df0,0x0df1, 0x0df2,0x0df3,0x0df4,0x0df5,
  0x0df6,0x0df7,0x0df8,0x0df9, 0x0dfa,0x0dfb,0x0dfc,0x0dfd,
  0x0dfe,0x0dff,0x0e00,0x0e01, 0x0e02,0x0e03,0x0e04,0x0e05,
  0x0e06,0x0e07,0x0e08,0x0e09, 0x0e0a,0x0e0b,0x0e0c,0x0e0d,
  0x0e0e,0x0e0f,0x0e10,0x0e11, 0x0e12,0x0e13,0x0e14,0x0e15,
  0x0e16,0x0e17,0x0e18,0x0e19, 0x0e1a,0x0e1b,0x0e1c,0x0e1d,
  0x0e1e,0x0e1f,0x0e20,0x0e21, 0x0e22,0x0e23,0x0e24,0x0e25,
  0x0e26,0x0e27,0x0e28,0x0e29, 0x0e2a,0x0e2b,0x0e2c,0x0e2d,
  0x0e2e,0x0e2f,0x0e30,0x0e31, 0x0e32,0x0e33,0x0e34,0x0e35,
  0x0e36,0x0e37,0x0e38,0x0e39, 0x0e3a,0x0e3b,0x0e3c,0x0e3d,
  0x0e3e,0x0e3f,0x0e40,0x0e41, 0x0e42,0x0e43,0x0e44,0x0e45,
  0x0e46,0x0e47,0x0e48,0x0e49, 0x0e4a,0x0e4b,0x0e4c,0x0e4d,
  0x0e4e,0x0e4f,0x0e50,0x0e51, 0x0e52,0x0e53,0x0e54,0x0e55,
  0x0e56,0x0e57,0x0e58,0x0e59, 0x0e5a,0x0e5b,0x0e5c,0x0e5d,
  0x0e5e,0x0e5f,0x0e60,0x0e61, 0x0e62,0x0e63,0x0e64,0x0e65,
  0x0e66,0x0e67,0x0e68,0x0e69, 0x0e6a,0x0e6b,0x0e6c,0x0e6d,
  0x0e6e,0x0e6f,0x0e70,0x0e71, 0x0e72,0x0e73,0x0e74,0x0e75,
  0x0e76,0x0e77,0x0e78,0x0e79,
/* 0x9481(i:3420) */
  0x0e7a,0x0e7b,0x0e7c,0x0e7d, 0x0e7e,0x0e7f,0x0e80,0x0e81,
  0x0e82,0x0e83,0x0e84,0x0e85, 0x0e86,0x0e87,0x0e88,0x0e89,
  0x0e8a,0x0e8b,0x0e8c,0x0e8d, 0x0e8e,0x0e8f,0x0e90,0x0e91,
  0x0e92,0x0e93,0x0e94,0x0e95, 0x0e96,0x0e97,0x0e98,0x0e99,
  0x0e9a,0x0e9b,0x0e9c,0x0e9d, 0x0e9e,0x0e9f,0x0ea0,0x0ea1,
  0x0ea2,0x0ea3,0x0ea4,0x0ea5, 0x0ea6,0x0ea7,0x0ea8,0x0ea9,
  0x0eaa,0x0eab,0x0eac,0x0ead, 0x0eae,0x0eaf,0x0eb0,0x0eb1,
  0x0eb2,0x0eb3,0x0eb4,0x0eb5, 0x0eb6,0x0eb7,0x0eb8,0x0eb9,
  0x0eba,0x0ebb,0x0ebc,0x0ebd, 0x0ebe,0x0ebf,0x0ec0,0x0ec1,
  0x0ec2,0x0ec3,0x0ec4,0x0ec5, 0x0ec6,0x0ec7,0x0ec8,0x0ec9,
  0x0eca,0x0ecb,0x0ecc,0x0ecd, 0x0ece,0x0ecf,0x0ed0,0x0ed1,
  0x0ed2,0x0ed3,0x0ed4,0x0ed5, 0x0ed6,0x0ed7,0x0ed8,0x0ed9,
  0x0eda,0x0edb,0x0edc,0x0edd, 0x0ede,0x0edf,0x0ee0,0x0ee1,
  0x0ee2,0x0ee3,0x0ee4,0x0ee5, 0x0ee6,0x0ee7,0x0ee8,0x0ee9,
  0x0eea,0x0eeb,0x0eec,0x0eed, 0x0eee,0x0eef,0x0ef0,0x0ef1,
  0x0ef2,0x0ef3,0x0ef4,0x0ef5, 0x0ef6,0x0ef7,0x0ef8,0x0ef9,
  0x0efa,0x0efb,0x0efc,0x0efd, 0x0efe,0x0eff,0x0f00,0x0f01,
  0x0f02,0x0f03,0x0f04,0x0f05, 0x0f06,0x0f07,0x0f08,0x0f09,
  0x0f0a,0x0f0b,0x0f0c,0x0f0d, 0x0f0e,0x0f0f,0x0f10,0x0f11,
  0x0f12,0x0f13,0x0f14,0x0f15, 0x0f16,0x0f17,0x0f18,0x0f19,
  0x0f1a,0x0f1b,0x0f1c,0x0f1d, 0x0f1e,0x0f1f,0x0f20,0x0f21,
  0x0f22,0x0f23,0x0f24,0x0f25, 0x0f26,0x0f27,0x0f28,0x0f29,
  0x0f2a,0x0f2b,0x0f2c,0x0f2d,
/* 0x9581(i:3600) */
  0x0f2e,0x0f2f,0x0f30,0x0f31, 0x0f32,0x0f33,0x0f34,0x0f35,
  0x0f36,0x0f37,0x0f38,0x0f39, 0x0f3a,0x0f3b,0x0f3c,0x0f3d,
  0x0f3e,0x0f3f,0x0f40,0x0f41, 0x0f42,0x0f43,0x0f44,0x0f45,
  0x0f46,0x0f47,0x0f48,0x0f49, 0x0f4a,0x0f4b,0x0f4c,0x0f4d,
  0x0f4e,0x0f4f,0x0f50,0x0f51, 0x0f52,0x0f53,0x0f54,0x0f55,
  0x0f56,0x0f57,0x0f58,0x0f59, 0x0f5a,0x0f5b,0x0f5c,0x0f5d,
  0x0f5e,0x0f5f,0x0f60,0x0f61, 0x0f62,0x0f63,0x0f64,0x0f65,
  0x0f66,0x0f67,0x0f68,0x0f69, 0x0f6a,0x0f6b,0x0f6c,0x0f6d,
  0x0f6e,0x0f6f,0x0f70,0x0f71, 0x0f72,0x0f73,0x0f74,0x0f75,
  0x0f76,0x0f77,0x0f78,0x0f79, 0x0f7a,0x0f7b,0x0f7c,0x0f7d,
  0x0f7e,0x0f7f,0x0f80,0x0f81, 0x0f82,0x0f83,0x0f84,0x0f85,
  0x0f86,0x0f87,0x0f88,0x0f89, 0x0f8a,0x0f8b,0x0f8c,0x0f8d,
  0x0f8e,0x0f8f,0x0f90,0x0f91, 0x0f92,0x0f93,0x0f94,0x0f95,
  0x0f96,0x0f97,0x0f98,0x0f99, 0x0f9a,0x0f9b,0x0f9c,0x0f9d,
  0x0f9e,0x0f9f,0x0fa0,0x0fa1, 0x0fa2,0x0fa3,0x0fa4,0x0fa5,
  0x0fa6,0x0fa7,0x0fa8,0x0fa9, 0x0faa,0x0fab,0x0fac,0x0fad,
  0x0fae,0x0faf,0x0fb0,0x0fb1, 0x0fb2,0x0fb3,0x0fb4,0x0fb5,
  0x0fb6,0x0fb7,0x0fb8,0x0fb9, 0x0fba,0x0fbb,0x0fbc,0x0fbd,
  0x0fbe,0x0fbf,0x0fc0,0x0fc1, 0x0fc2,0x0fc3,0x0fc4,0x0fc5,
  0x0fc6,0x0fc7,0x0fc8,0x0fc9, 0x0fca,0x0fcb,0x0fcc,0x0fcd,
  0x0fce,0x0fcf,0x0fd0,0x0fd1, 0x0fd2,0x0fd3,0x0fd4,0x0fd5,
  0x0fd6,0x0fd7,0x0fd8,0x0fd9, 0x0fda,0x0fdb,0x0fdc,0x0fdd,
  0x0fde,0x0fdf,0x0fe0,0x0fe1,
/* 0x9681(i:3780) */
  0x0fe2,0x0fe3,0x0fe4,0x0fe5, 0x0fe6,0x0fe7,0x0fe8,0x0fe9,
  0x0fea,0x0feb,0x0fec,0x0fed, 0x0fee,0x0fef,0x0ff0,0x0ff1,
  0x0ff2,0x0ff3,0x0ff4,0x0ff5, 0x0ff6,0x0ff7,0x0ff8,0x0ff9,
  0x0ffa,0x0ffb,0x0ffc,0x0ffd, 0x0ffe,0x0fff,0x1000,0x1001,
  0x1002,0x1003,0x1004,0x1005, 0x1006,0x1007,0x1008,0x1009,
  0x100a,0x100b,0x100c,0x100d, 0x100e,0x100f,0x1010,0x1011,
  0x1012,0x1013,0x1014,0x1015, 0x1016,0x1017,0x1018,0x1019,
  0x101a,0x101b,0x101c,0x101d, 0x101e,0x101f,0x1020,0x1021,
  0x1022,0x1023,0x1024,0x1025, 0x1026,0x1027,0x1028,0x1029,
  0x102a,0x102b,0x102c,0x102d, 0x102e,0x102f,0x1030,0x1031,
  0x1032,0x1033,0x1034,0x1035, 0x1036,0x1037,0x1038,0x1039,
  0x103a,0x103b,0x103c,0x103d, 0x103e,0x103f,0x1040,0x1041,
  0x1042,0x1043,0x1044,0x1045, 0x1046,0x1047,0x1048,0x1049,
  0x104a,0x104b,0x104c,0x104d, 0x104e,0x104f,0x1050,0x1051,
  0x1052,0x1053,0x1054,0x1055, 0x1056,0x1057,0x1058,0x1059,
  0x105a,0x105b,0x105c,0x105d, 0x105e,0x105f,0x1060,0x1061,
  0x1062,0x1063,0x1064,0x1065, 0x1066,0x1067,0x1068,0x1069,
  0x106a,0x106b,0x106c,0x106d, 0x106e,0x106f,0x1070,0x1071,
  0x1072,0x1073,0x1074,0x1075, 0x1076,0x1077,0x1078,0x1079,
  0x107a,0x107b,0x107c,0x107d, 0x107e,0x107f,0x1080,0x1081,
  0x1082,0x1083,0x1084,0x1085, 0x1086,0x1087,0x1088,0x1089,
  0x108a,0x108b,0x108c,0x108d, 0x108e,0x108f,0x1090,0x1091,
  0x1092,0x1093,0x1094,0x1095,
/* 0x9781(i:3960) */
  0x1096,0x1097,0x1098,0x1099, 0x109a,0x109b,0x109c,0x109d,
  0x109e,0x109f,0x10a0,0x10a1, 0x10a2,0x10a3,0x10a4,0x10a5,
  0x10a6,0x10a7,0x10a8,0x10a9, 0x10aa,0x10ab,0x10ac,0x10ad,
  0x10ae,0x10af,0x10b0,0x10b1, 0x10b2,0x10b3,0x10b4,0x10b5,
  0x10b6,0x10b7,0x10b8,0x10b9, 0x10ba,0x10bb,0x10bc,0x10bd,
  0x10be,0x10bf,0x10c0,0x10c1, 0x10c2,0x10c3,0x10c4,0x10c5,
  0x10c6,0x10c7,0x10c8,0x10c9, 0x10ca,0x10cb,0x10cc,0x10cd,
  0x10ce,0x10cf,0x10d0,0x10d1, 0x10d2,0x10d3,0x10d4,0x10d5,
  0x10d6,0x10d7,0x10d8,0x10d9, 0x10da,0x10db,0x10dc,0x10dd,
  0x10de,0x10df,0x10e0,0x10e1, 0x10e2,0x10e3,0x10e4,0x10e5,
  0x10e6,0x10e7,0x10e8,0x10e9, 0x10ea,0x10eb,0x10ec,0x10ed,
  0x10ee,0x10ef,0x10f0,0x10f1, 0x10f2,0x10f3,0x10f4,0x10f5,
  0x10f6,0x10f7,0x10f8,0x10f9, 0x10fa,0x10fb,0x10fc,0x10fd,
  0x10fe,0x10ff,0x1100,0x1101, 0x1102,0x1103,0x1104,0x1105,
  0x1106,0x1107,0x1108,0x1109, 0x110a,0x110b,0x110c,0x110d,
  0x110e,0x110f,0x1110,0x1111, 0x1112,0x1113,0x1114,0x1115,
  0x1116,0x1117,0x1118,0x1119, 0x111a,0x111b,0x111c,0x111d,
  0x111e,0x111f,0x1120,0x1121, 0x1122,0x1123,0x1124,0x1125,
  0x1126,0x1127,0x1128,0x1129, 0x112a,0x112b,0x112c,0x112d,
  0x112e,0x112f,0x1130,0x1131, 0x1132,0x1133,0x1134,0x1135,
  0x1136,0x1137,0x1138,0x1139, 0x113a,0x113b,0x113c,0x113d,
  0x113e,0x113f,0x1140,0x1141, 0x1142,0x1143,0x1144,0x1145,
  0x1146,0x1147,0x1148,0x1149,
/* 0x9881(i:4140) */
  0x114a,0x114b,0x114c,0x114d, 0x114e,0x114f,0x1150,0x1151,
  0x1152,0x1153,0x1154,0x1155, 0x1156,0x1157,0x1158,0x1159,
  0x115a,0x115b,0x115c,0x115d, 0x115e,0x115f,0x1160,0x1161,
  0x1162,0x1163,0x1164,0x1165, 0x1166,0x1167,0x1168,0x1169,
  0x116a,0x116b,0x116c,0x116d, 0x116e,0x116f,0x1170,0x1171,
  0x1172,0x1173,0x1174,0x1175, 0x1176,0x1177,0x1178,0x1179,
  0x117a,0x117b,0x117c,0x117d, 0x117e,0x117f,0x1180,0x1181,
  0x1182,0x1183,0x1184,0x1185, 0x1186,0x1187,0x1188,0x1189,
  0x118a,0x118b,0x118c,0x118d, 0x118e,0x118f,0x1190,0x1191,
  0x1192,0x1193,0x1194,0x1195, 0x1196,0x1197,0x1198,0x1199,
  0x119a,0x119b,0x119c,0x119d, 0x119e,0x119f,0x11a0,0x11a1,
  0x11a2,0x11a3,0x11a4,0x11a5, 0x11a6,0x11a7,0x11a8,0x11a9,
  0x11aa,0x11ab,0x11ac,0x11ad, 0x11ae,0x11af,0x11b0,0x11b1,
  0x11b2,0x11b3,0x11b4,0x11b5, 0x11b6,0x11b7,0x11b8,0x11b9,
  0x11ba,0x11bb,0x11bc,0x11bd, 0x11be,0x11bf,0x11c0,0x11c1,
  0x11c2,0x11c3,0x11c4,0x11c5, 0x11c6,0x11c7,0x11c8,0x11c9,
  0x11ca,0x11cb,0x11cc,0x11cd, 0x11ce,0x11cf,0x11d0,0x11d1,
  0x11d2,0x11d3,0x11d4,0x11d5, 0x11d6,0x11d7,0x11d8,0x11d9,
  0x11da,0x11db,0x11dc,0x11dd, 0x11de,0x11df,0x11e0,0x11e1,
  0x11e2,0x11e3,0x11e4,0x11e5, 0x11e6,0x11e7,0x11e8,0x11e9,
  0x11ea,0x11eb,0x11ec,0x11ed, 0x11ee,0x11ef,0x11f0,0x11f1,
  0x11f2,0x11f3,0x11f4,0x11f5, 0x11f6,0x11f7,0x11f8,0x11f9,
  0x11fa,0x11fb,0x11fc,0x11fd,
/* 0x9981(i:4320) */
  0x11fe,0x11ff,0x1200,0x1201, 0x1202,0x1203,0x1204,0x1205,
  0x1206,0x1207,0x1208,0x1209, 0x120a,0x120b,0x120c,0x120d,
  0x120e,0x120f,0x1210,0x1211, 0x1212,0x1213,0x1214,0x1215,
  0x1216,0x1217,0x1218,0x1219, 0x121a,0x121b,0x121c,0x121d,
  0x121e,0x121f,0x1220,0x1221, 0x1222,0x1223,0x1224,0x1225,
  0x1226,0x1227,0x1228,0x1229, 0x122a,0x122b,0x122c,0x122d,
  0x122e,0x122f,0x1230,0x1231, 0x1232,0x1233,0x1234,0x1235,
  0x1236,0x1237,0x1238,0x1239, 0x123a,0x123b,0x123c,0x123d,
  0x123e,0x123f,0x1240,0x1241, 0x1242,0x1243,0x1244,0x1245,
  0x1246,0x1247,0x1248,0x1249, 0x124a,0x124b,0x124c,0x124d,
  0x124e,0x124f,0x1250,0x1251, 0x1252,0x1253,0x1254,0x1255,
  0x1256,0x1257,0x1258,0x1259, 0x125a,0x125b,0x125c,0x125d,
  0x125e,0x125f,0x1260,0x1261, 0x1262,0x1263,0x1264,0x1265,
  0x1266,0x1267,0x1268,0x1269, 0x126a,0x126b,0x126c,0x126d,
  0x126e,0x126f,0x1270,0x1271, 0x1272,0x1273,0x1274,0x1275,
  0x1276,0x1277,0x1278,0x1279, 0x127a,0x127b,0x127c,0x127d,
  0x127e,0x127f,0x1280,0x1281, 0x1282,0x1283,0x1284,0x1285,
  0x1286,0x1287,0x1288,0x1289, 0x128a,0x128b,0x128c,0x128d,
  0x128e,0x128f,0x1290,0x1291, 0x1292,0x1293,0x1294,0x1295,
  0x1296,0x1297,0x1298,0x1299, 0x129a,0x129b,0x129c,0x129d,
  0x129e,0x129f,0x12a0,0x12a1, 0x12a2,0x12a3,0x12a4,0x12a5,
  0x12a6,0x12a7,0x12a8,0x12a9, 0x12aa,0x12ab,0x12ac,0x12ad,
  0x12ae,0x12af,0x12b0,0x12b1,
/* 0x9a81(i:4500) */
  0x12b2,0x12b3,0x12b4,0x12b5, 0x12b6,0x12b7,0x12b8,0x12b9,
  0x12ba,0x12bb,0x12bc,0x12bd, 0x12be,0x12bf,0x12c0,0x12c1,
  0x12c2,0x12c3,0x12c4,0x12c5, 0x12c6,0x12c7,0x12c8,0x12c9,
  0x12ca,0x12cb,0x12cc,0x12cd, 0x12ce,0x12cf,0x12d0,0x12d1,
  0x12d2,0x12d3,0x12d4,0x12d5, 0x12d6,0x12d7,0x12d8,0x12d9,
  0x12da,0x12db,0x12dc,0x12dd, 0x12de,0x12df,0x12e0,0x12e1,
  0x12e2,0x12e3,0x12e4,0x12e5, 0x12e6,0x12e7,0x12e8,0x12e9,
  0x12ea,0x12eb,0x12ec,0x12ed, 0x12ee,0x12ef,0x12f0,0x12f1,
  0x12f2,0x12f3,0x12f4,0x12f5, 0x12f6,0x12f7,0x12f8,0x12f9,
  0x12fa,0x12fb,0x12fc,0x12fd, 0x12fe,0x12ff,0x1300,0x1301,
  0x1302,0x1303,0x1304,0x1305, 0x1306,0x1307,0x1308,0x1309,
  0x130a,0x130b,0x130c,0x130d, 0x130e,0x130f,0x1310,0x1311,
  0x1312,0x1313,0x1314,0x1315, 0x1316,0x1317,0x1318,0x1319,
  0x131a,0x131b,0x131c,0x131d, 0x131e,0x131f,0x1320,0x1321,
  0x1322,0x1323,0x1324,0x1325, 0x1326,0x1327,0x1328,0x1329,
  0x132a,0x132b,0x132c,0x132d, 0x132e,0x132f,0x1330,0x1331,
  0x1332,0x1333,0x1334,0x1335, 0x1336,0x1337,0x1338,0x1339,
  0x133a,0x133b,0x133c,0x133d, 0x133e,0x133f,0x1340,0x1341,
  0x1342,0x1343,0x1344,0x1345, 0x1346,0x1347,0x1348,0x1349,
  0x134a,0x134b,0x134c,0x134d, 0x134e,0x134f,0x1350,0x1351,
  0x1352,0x1353,0x1354,0x1355, 0x1356,0x1357,0x1358,0x1359,
  0x135a,0x135b,0x135c,0x135d, 0x135e,0x135f,0x1360,0x1361,
  0x1362,0x1363,0x1364,0x1365,
/* 0x9b81(i:4680) */
  0x1366,0x1367,0x1368,0x1369, 0x136a,0x136b,0x136c,0x136d,
  0x136e,0x136f,0x1370,0x1371, 0x1372,0x1373,0x1374,0x1375,
  0x1376,0x1377,0x1378,0x1379, 0x137a,0x137b,0x137c,0x137d,
  0x137e,0x137f,0x1380,0x1381, 0x1382,0x1383,0x1384,0x1385,
  0x1386,0x1387,0x1388,0x1389, 0x138a,0x138b,0x138c,0x138d,
  0x138e,0x138f,0x1390,0x1391, 0x1392,0x1393,0x1394,0x1395,
  0x1396,0x1397,0x1398,0x1399, 0x139a,0x139b,0x139c,0x139d,
  0x139e,0x139f,0x13a0,0x13a1, 0x13a2,0x13a3,0x13a4,0x13a5,
  0x13a6,0x13a7,0x13a8,0x13a9, 0x13aa,0x13ab,0x13ac,0x13ad,
  0x13ae,0x13af,0x13b0,0x13b1, 0x13b2,0x13b3,0x13b4,0x13b5,
  0x13b6,0x13b7,0x13b8,0x13b9, 0x13ba,0x13bb,0x13bc,0x13bd,
  0x13be,0x13bf,0x13c0,0x13c1, 0x13c2,0x13c3,0x13c4,0x13c5,
  0x13c6,0x13c7,0x13c8,0x13c9, 0x13ca,0x13cb,0x13cc,0x13cd,
  0x13ce,0x13cf,0x13d0,0x13d1, 0x13d2,0x13d3,0x13d4,0x13d5,
  0x13d6,0x13d7,0x13d8,0x13d9, 0x13da,0x13db,0x13dc,0x13dd,
  0x13de,0x13df,0x13e0,0x13e1, 0x13e2,0x13e3,0x13e4,0x13e5,
  0x13e6,0x13e7,0x13e8,0x13e9, 0x13ea,0x13eb,0x13ec,0x13ed,
  0x13ee,0x13ef,0x13f0,0x13f1, 0x13f2,0x13f3,0x13f4,0x13f5,
  0x13f6,0x13f7,0x13f8,0x13f9, 0x13fa,0x13fb,0x13fc,0x13fd,
  0x13fe,0x13ff,0x1400,0x1401, 0x1402,0x1403,0x1404,0x1405,
  0x1406,0x1407,0x1408,0x1409, 0x140a,0x140b,0x140c,0x140d,
  0x140e,0x140f,0x1410,0x1411, 0x1412,0x1413,0x1414,0x1415,
  0x1416,0x1417,0x1418,0x1419,
/* 0x9c81(i:4860) */
  0x141a,0x141b,0x141c,0x141d, 0x141e,0x141f,0x1420,0x1421,
  0x1422,0x1423,0x1424,0x1425, 0x1426,0x1427,0x1428,0x1429,
  0x142a,0x142b,0x142c,0x142d, 0x142e,0x142f,0x1430,0x1431,
  0x1432,0x1433,0x1434,0x1435, 0x1436,0x1437,0x1438,0x1439,
  0x143a,0x143b,0x143c,0x143d, 0x143e,0x143f,0x1440,0x1441,
  0x1442,0x1443,0x1444,0x1445, 0x1446,0x1447,0x1448,0x1449,
  0x144a,0x144b,0x144c,0x144d, 0x144e,0x144f,0x1450,0x1451,
  0x1452,0x1453,0x1454,0x1455, 0x1456,0x1457,0x1458,0x1459,
  0x145a,0x145b,0x145c,0x145d, 0x145e,0x145f,0x1460,0x1461,
  0x1462,0x1463,0x1464,0x1465, 0x1466,0x1467,0x1468,0x1469,
  0x146a,0x146b,0x146c,0x146d, 0x146e,0x146f,0x1470,0x1471,
  0x1472,0x1473,0x1474,0x1475, 0x1476,0x1477,0x1478,0x1479,
  0x147a,0x147b,0x147c,0x147d, 0x147e,0x147f,0x1480,0x1481,
  0x1482,0x1483,0x1484,0x1485, 0x1486,0x1487,0x1488,0x1489,
  0x148a,0x148b,0x148c,0x148d, 0x148e,0x148f,0x1490,0x1491,
  0x1492,0x1493,0x1494,0x1495, 0x1496,0x1497,0x1498,0x1499,
  0x149a,0x149b,0x149c,0x149d, 0x149e,0x149f,0x14a0,0x14a1,
  0x14a2,0x14a3,0x14a4,0x14a5, 0x14a6,0x14a7,0x14a8,0x14a9,
  0x14aa,0x14ab,0x14ac,0x14ad, 0x14ae,0x14af,0x14b0,0x14b1,
  0x14b2,0x14b3,0x14b4,0x14b5, 0x14b6,0x14b7,0x14b8,0x14b9,
  0x14ba,0x14bb,0x14bc,0x14bd, 0x14be,0x14bf,0x14c0,0x14c1,
  0x14c2,0x14c3,0x14c4,0x14c5, 0x14c6,0x14c7,0x14c8,0x14c9,
  0x14ca,0x14cb,0x14cc,0x14cd,
/* 0x9d81(i:5040) */
  0x14ce,0x14cf,0x14d0,0x14d1, 0x14d2,0x14d3,0x14d4,0x14d5,
  0x14d6,0x14d7,0x14d8,0x14d9, 0x14da,0x14db,0x14dc,0x14dd,
  0x14de,0x14df,0x14e0,0x14e1, 0x14e2,0x14e3,0x14e4,0x14e5,
  0x14e6,0x14e7,0x14e8,0x14e9, 0x14ea,0x14eb,0x14ec,0x14ed,
  0x14ee,0x14ef,0x14f0,0x14f1, 0x14f2,0x14f3,0x14f4,0x14f5,
  0x14f6,0x14f7,0x14f8,0x14f9, 0x14fa,0x14fb,0x14fc,0x14fd,
  0x14fe,0x14ff,0x1500,0x1501, 0x1502,0x1503,0x1504,0x1505,
  0x1506,0x1507,0x1508,0x1509, 0x150a,0x150b,0x150c,0x150d,
  0x150e,0x150f,0x1510,0x1511, 0x1512,0x1513,0x1514,0x1515,
  0x1516,0x1517,0x1518,0x1519, 0x151a,0x151b,0x151c,0x151d,
  0x151e,0x151f,0x1520,0x1521, 0x1522,0x1523,0x1524,0x1525,
  0x1526,0x1527,0x1528,0x1529, 0x152a,0x152b,0x152c,0x152d,
  0x152e,0x152f,0x1530,0x1531, 0x1532,0x1533,0x1534,0x1535,
  0x1536,0x1537,0x1538,0x1539, 0x153a,0x153b,0x153c,0x153d,
  0x153e,0x153f,0x1540,0x1541, 0x1542,0x1543,0x1544,0x1545,
  0x1546,0x1547,0x1548,0x1549, 0x154a,0x154b,0x154c,0x154d,
  0x154e,0x154f,0x1550,0x1551, 0x1552,0x1553,0x1554,0x1555,
  0x1556,0x1557,0x1558,0x1559, 0x155a,0x155b,0x155c,0x155d,
  0x155e,0x155f,0x1560,0x1561, 0x1562,0x1563,0x1564,0x1565,
  0x1566,0x1567,0x1568,0x1569, 0x156a,0x156b,0x156c,0x156d,
  0x156e,0x156f,0x1570,0x1571, 0x1572,0x1573,0x1574,0x1575,
  0x1576,0x1577,0x1578,0x1579, 0x157a,0x157b,0x157c,0x157d,
  0x157e,0x157f,0x1580,0x1581,
/* 0x9e81(i:5220) */
  0x1582,0x1583,0x1584,0x1585, 0x1586,0x1587,0x1588,0x1589,
  0x158a,0x158b,0x158c,0x158d, 0x158e,0x158f,0x1590,0x1591,
  0x1592,0x1593,0x1594,0x1595, 0x1596,0x1597,0x1598,0x1599,
  0x159a,0x159b,0x159c,0x159d, 0x159e,0x159f,0x15a0,0x15a1,
  0x15a2,0x15a3,0x15a4,0x15a5, 0x15a6,0x15a7,0x15a8,0x15a9,
  0x15aa,0x15ab,0x15ac,0x15ad, 0x15ae,0x15af,0x15b0,0x15b1,
  0x15b2,0x15b3,0x15b4,0x15b5, 0x15b6,0x15b7,0x15b8,0x15b9,
  0x15ba,0x15bb,0x15bc,0x15bd, 0x15be,0x15bf,0x15c0,0x15c1,
  0x15c2,0x15c3,0x15c4,0x15c5, 0x15c6,0x15c7,0x15c8,0x15c9,
  0x15ca,0x15cb,0x15cc,0x15cd, 0x15ce,0x15cf,0x15d0,0x15d1,
  0x15d2,0x15d3,0x15d4,0x15d5, 0x15d6,0x15d7,0x15d8,0x15d9,
  0x15da,0x15db,0x15dc,0x15dd, 0x15de,0x15df,0x15e0,0x15e1,
  0x15e2,0x15e3,0x15e4,0x15e5, 0x15e6,0x15e7,0x15e8,0x15e9,
  0x15ea,0x15eb,0x15ec,0x15ed, 0x15ee,0x15ef,0x15f0,0x15f1,
  0x15f2,0x15f3,0x15f4,0x15f5, 0x15f6,0x15f7,0x15f8,0x15f9,
  0x15fa,0x15fb,0x15fc,0x15fd, 0x15fe,0x15ff,0x1600,0x1601,
  0x1602,0x1603,0x1604,0x1605, 0x1606,0x1607,0x1608,0x1609,
  0x160a,0x160b,0x160c,0x160d, 0x160e,0x160f,0x1610,0x1611,
  0x1612,0x1613,0x1614,0x1615, 0x1616,0x1617,0x1618,0x1619,
  0x161a,0x161b,0x161c,0x161d, 0x161e,0x161f,0x1620,0x1621,
  0x1622,0x1623,0x1624,0x1625, 0x1626,0x1627,0x1628,0x1629,
  0x162a,0x162b,0x162c,0x162d, 0x162e,0x162f,0x1630,0x1631,
  0x1632,0x1633,0x1634,0x1635,
/* 0x9f81(i:5400) */
  0x1636,0x1637,0x1638,0x1639, 0x163a,0x163b,0x163c,0x163d,
  0x163e,0x163f,0x1640,0x1641, 0x1642,0x1643,0x1644,0x1645,
  0x1646,0x1647,0x1648,0x1649, 0x164a,0x164b,0x164c,0x164d,
  0x164e,0x164f,0x1650,0x1651, 0x1652,0x1653,0x1654,0x1655,
  0x1656,0x1657,0x1658,0x1659, 0x165a,0x165b,0x165c,0x165d,
  0x165e,0x165f,0x1660,0x1661, 0x1662,0x1663,0x1664,0x1665,
  0x1666,0x1667,0x1668,0x1669, 0x166a,0x166b,0x166c,0x166d,
  0x166e,0x166f,0x1670,0x1671, 0x1672,0x1673,0x1674,0x1675,
  0x1676,0x1677,0x1678,0x1679, 0x167a,0x167b,0x167c,0x167d,
  0x167e,0x167f,0x1680,0x1681, 0x1682,0x1683,0x1684,0x1685,
  0x1686,0x1687,0x1688,0x1689, 0x168a,0x168b,0x168c,0x168d,
  0x168e,0x168f,0x1690,0x1691, 0x1692,0x1693,0x1694,0x1695,
  0x1696,0x1697,0x1698,0x1699, 0x169a,0x169b,0x169c,0x169d,
  0x169e,0x169f,0x16a0,0x16a1, 0x16a2,0x16a3,0x16a4,0x16a5,
  0x16a6,0x16a7,0x16a8,0x16a9, 0x16aa,0x16ab,0x16ac,0x16ad,
  0x16ae,0x16af,0x16b0,0x16b1, 0x16b2,0x16b3,0x16b4,0x16b5,
  0x16b6,0x16b7,0x16b8,0x16b9, 0x16ba,0x16bb,0x16bc,0x16bd,
  0x16be,0x16bf,0x16c0,0x16c1, 0x16c2,0x16c3,0x16c4,0x16c5,
  0x16c6,0x16c7,0x16c8,0x16c9, 0x16ca,0x16cb,0x16cc,0x16cd,
  0x16ce,0x16cf,0x16d0,0x16d1, 0x16d2,0x16d3,0x16d4,0x16d5,
  0x16d6,0x16d7,0x16d8,0x16d9, 0x16da,0x16db,0x16dc,0x16dd,
  0x16de,0x16df,0x16e0,0x16e1, 0x16e2,0x16e3,0x16e4,0x16e5,
  0x16e6,0x16e7,0x16e8,0x16e9,
/* 0xa081(i:5580) */
  0x16ea,0x16eb,0x16ec,0x16ed, 0x16ee,0x16ef,0x16f0,0x16f1,
  0x16f2,0x16f3,0x16f4,0x16f5, 0x16f6,0x16f7,0x16f8,0x16f9,
  0x16fa,0x16fb,0x16fc,0x16fd, 0x16fe,0x16ff,0x1700,0x1701,
  0x1702,0x1703,0x1704,0x1705, 0x1706,0x1707,0x1708,0x1709,
  0x170a,0x170b,0x170c,0x170d, 0x170e,0x170f,0x1710,0x1711,
  0x1712,0x1713,0x1714,0x1715, 0x1716,0x1717,0x1718,0x1719,
  0x171a,0x171b,0x171c,0x171d, 0x171e,0x171f,0x1720,0x1721,
  0x1722,0x1723,0x1724,0x1725, 0x1726,0x1727,0x1728,0x1729,
  0x172a,0x172b,0x172c,0x172d, 0x172e,0x172f,0x1730,0x1731,
  0x1732,0x1733,0x1734,0x1735, 0x1736,0x1737,0x1738,0x1739,
  0x173a,0x173b,0x173c,0x173d, 0x173e,0x173f,0x1740,0x1741,
  0x1742,0x1743,0x1744,0x1745, 0x1746,0x1747,0x1748,0x1749,
  0x174a,0x174b,0x174c,0x174d, 0x174e,0x174f,0x1750,0x1751,
  0x1752,0x1753,0x1754,0x1755, 0x1756,0x1757,0x1758,0x1759,
  0x175a,0x175b,0x175c,0x175d, 0x175e,0x175f,0x1760,0x1761,
  0x1762,0x1763,0x1764,0x1765, 0x1766,0x1767,0x1768,0x1769,
  0x176a,0x176b,0x176c,0x176d, 0x176e,0x176f,0x1770,0x1771,
  0x1772,0x1773,0x1774,0x1775, 0x1776,0x1777,0x1778,0x1779,
  0x177a,0x177b,0x177c,0x177d, 0x177e,0x177f,0x1780,0x1781,
  0x1782,0x1783,0x1784,0x1785, 0x1786,0x1787,0x1788,0x1789,
  0x178a,0x178b,0x178c,0x178d, 0x178e,0x178f,0x1790,0x1791,
  0x1792,0x1793,0x1794,0x1795, 0x1796,0x1797,0x1798,0x1799,
  0x179a,0x179b,0x179c,0x179d,
/* 0xa181(i:5760) */
  0x179e,0x179f,0x17a0,0x17a1, 0x17a2,0x17a3,0x17a4,0x17a5,
  0x17a6,0x17a7,0x17a8,0x17a9, 0x17aa,0x17ab,0x17ac,0x17ad,
  0x17ae,0x17af,0x17b0,0x17b1, 0x17b2,0x17b3,0x17b4,0x17b5,
  0x17b6,0x17b7,0x17b8,0x17b9, 0x17ba,0x17bb,0x17bc,0x17bd,
  0x17be,0x17bf,0x17c0,0x17c1, 0x17c2,0x17c3,0x17c4,0x17c5,
  0x17c6,0x17c7,0x17c8,0x17c9, 0x17ca,0x17cb,0x17cc,0x17cd,
  0x17ce,0x17cf,0x17d0,0x17d1, 0x17d2,0x17d3,0x17d4,0x17d5,
  0x17d6,0x17d7,0x17d8,0x17d9, 0x17da,0x17db,0x17dc,0x17dd,
  0x17de,0x17df,0x17e0,0x17e1, 0x17e2,0x17e3,0x17e4,0x17e5,
  0x17e6,0x17e7,0x17e8,0x17e9, 0x17ea,0x17eb,0x17ec,0x17ed,
  0x17ee,0x17ef,0x17f0,0x17f1, 0x17f2,0x17f3,0x17f4,0x17f5,
  0x17f6,0x17f7,0x17f8,0x17f9, 0x17fa,0x17fb,0x17fc,0x17fd,
  0x17fe,0x17ff,0x1800,0x1801, 0x1802,0x1803,0x1804,0x1805,
  0x1806,0x1807,0x1808,0x1809, 0x180a,0x180b,0x180c,0x180d,
  0x180e,0x180f,0x1810,0x1811, 0x1812,0x1813,0x1814,0x1815,
  0x1816,0x1817,0x1818,0x1819, 0x181a,0x181b,0x181c,0x181d,
  0x181e,0x181f,0x1820,0x1821, 0x1822,0x1823,0x1824,0x1825,
  0x1826,0x1827,0x1828,0x1829, 0x182a,0x182b,0x182c,0x182d,
  0x182e,0x182f,0x1830,0x1831, 0x1832,0x1833,0x1834,0x1835,
  0x1836,0x1837,0x1838,0x1839, 0x183a,0x183b,0x183c,0x183d,
  0x183e,0x183f,0x1840,0x1841, 0x1842,0x1843,0x1844,0x1845,
  0x1846,0x1847,0x1848,0x1849, 0x184a,0x184b,0x184c,0x184d,
  0x184e,0x184f,0x1850,0x1851,
/* 0xa281(i:5940) */
  0x1852,0x1853,0x1854,0x1855, 0x1856,0x1857,0x1858,0x1859,
  0x185a,0x185b,0x185c,0x185d, 0x185e,0x185f,0x1860,0x1861,
  0x1862,0x1863,0x1864,0x1865, 0x1866,0x1867,0x1868,0x1869,
  0x186a,0x186b,0x186c,0x186d, 0x186e,0x186f,0x1870,0x1871,
  0x1872,0x1873,0x1874,0x1875, 0x1876,0x1877,0x1878,0x1879,
  0x187a,0x187b,0x187c,0x187d, 0x187e,0x187f,0x1880,0x1881,
  0x1882,0x1883,0x1884,0x1885, 0x1886,0x1887,0x1888,0x1889,
  0x188a,0x188b,0x188c,0x188d, 0x188e,0x188f,0x1890,0x1891,
  0x1892,0x1893,0x1894,0x1895, 0x1896,0x1897,0x1898,0x1899,
  0x189a,0x189b,0x189c,0x189d, 0x189e,0x189f,0x18a0,0x18a1,
  0x18a2,0x18a3,0x18a4,0x18a5, 0x18a6,0x18a7,0x18a8,0x18a9,
  0x18aa,0x18ab,0x18ac,0x18ad, 0x18ae,0x18af,0x18b0,0x18b1,
  0x18b2,0x18b3,0x18b4,0x18b5, 0x18b6,0x18b7,0x18b8,0x18b9,
  0x18ba,0x18bb,0x18bc,0x18bd, 0x18be,0x18bf,0x18c0,0x18c1,
  0x18c2,0x18c3,0x18c4,0x18c5, 0x18c6,0x18c7,0x18c8,0x18c9,
  0x18ca,0x18cb,0x18cc,0x18cd, 0x18ce,0x18cf,0x18d0,0x18d1,
  0x18d2,0x18d3,0x18d4,0x18d5, 0x18d6,0x18d7,0x18d8,0x18d9,
  0x18da,0x18db,0x18dc,0x18dd, 0x18de,0x18df,0x18e0,0x18e1,
  0x18e2,0x18e3,0x18e4,0x18e5, 0x18e6,0x18e7,0x18e8,0x18e9,
  0x18ea,0x18eb,0x18ec,0x18ed, 0x18ee,0x18ef,0x18f0,0x18f1,
  0x18f2,0x18f3,0x18f4,0x18f5, 0x18f6,0x18f7,0x18f8,0x18f9,
  0x18fa,0x18fb,0x18fc,0x18fd, 0x18fe,0x18ff,0x1900,0x1901,
  0x1902,0x1903,0x1904,0x1905,
/* 0xa381(i:6120) */
  0x1906,0x1907,0x1908,0x1909, 0x190a,0x190b,0x190c,0x190d,
  0x190e,0x190f,0x1910,0x1911, 0x1912,0x1913,0x1914,0x1915,
  0x1916,0x1917,0x1918,0x1919, 0x191a,0x191b,0x191c,0x191d,
  0x191e,0x191f,0x1920,0x1921, 0x1922,0x1923,0x1924,0x1925,
  0x1926,0x1927,0x1928,0x1929, 0x192a,0x192b,0x192c,0x192d,
  0x192e,0x192f,0x1930,0x1931, 0x1932,0x1933,0x1934,0x1935,
  0x1936,0x1937,0x1938,0x1939, 0x193a,0x193b,0x193c,0x193d,
  0x193e,0x193f,0x1940,0x1941, 0x1942,0x1943,0x1944,0x1945,
  0x1946,0x1947,0x1948,0x1949, 0x194a,0x194b,0x194c,0x194d,
  0x194e,0x194f,0x1950,0x1951, 0x1952,0x1953,0x1954,0x1955,
  0x1956,0x1957,0x1958,0x1959, 0x195a,0x195b,0x195c,0x195d,
  0x195e,0x195f,0x1960,0x1961, 0x1962,0x1963,0x1964,0x1965,
  0x1966,0x1967,0x1968,0x1969, 0x196a,0x196b,0x196c,0x196d,
  0x196e,0x196f,0x1970,0x1971, 0x1972,0x1973,0x1974,0x1975,
  0x1976,0x1977,0x1978,0x1979, 0x197a,0x197b,0x197c,0x197d,
  0x197e,0x197f,0x1980,0x1981, 0x1982,0x1983,0x1984,0x1985,
  0x1986,0x1987,0x1988,0x1989, 0x198a,0x198b,0x198c,0x198d,
  0x198e,0x198f,0x1990,0x1991, 0x1992,0x1993,0x1994,0x1995,
  0x1996,0x1997,0x1998,0x1999, 0x199a,0x199b,0x199c,0x199d,
  0x199e,0x199f,0x19a0,0x19a1, 0x19a2,0x19a3,0x19a4,0x19a5,
  0x19a6,0x19a7,0x19a8,0x19a9, 0x19aa,0x19ab,0x19ac,0x19ad,
  0x19ae,0x19af,0x19b0,0x19b1, 0x19b2,0x19b3,0x19b4,0x19b5,
  0x19b6,0x19b7,0x19b8,0x19b9,
/* 0xa481(i:6300) */
  0x19ba,0x19bb,0x19bc,0x19bd, 0x19be,0x19bf,0x19c0,0x19c1,
  0x19c2,0x19c3,0x19c4,0x19c5, 0x19c6,0x19c7,0x19c8,0x19c9,
  0x19ca,0x19cb,0x19cc,0x19cd, 0x19ce,0x19cf,0x19d0,0x19d1,
  0x19d2,0x19d3,0x19d4,0x19d5, 0x19d6,0x19d7,0x19d8,0x19d9,
  0x19da,0x19db,0x19dc,0x19dd, 0x19de,0x19df,0x19e0,0x19e1,
  0x19e2,0x19e3,0x19e4,0x19e5, 0x19e6,0x19e7,0x19e8,0x19e9,
  0x19ea,0x19eb,0x19ec,0x19ed, 0x19ee,0x19ef,0x19f0,0x19f1,
  0x19f2,0x19f3,0x19f4,0x19f5, 0x19f6,0x19f7,0x19f8,0x19f9,
  0x19fa,0x19fb,0x19fc,0x19fd, 0x19fe,0x19ff,0x1a00,0x1a01,
  0x1a02,0x1a03,0x1a04,0x1a05, 0x1a06,0x1a07,0x1a08,0x1a09,
  0x1a0a,0x1a0b,0x1a0c,0x1a0d, 0x1a0e,0x1a0f,0x1a10,0x1a11,
  0x1a12,0x1a13,0x1a14,0x1a15, 0x1a16,0x1a17,0x1a18,0x1a19,
  0x1a1a,0x1a1b,0x1a1c,0x1a1d, 0x1a1e,0x1a1f,0x1a20,0x1a21,
  0x1a22,0x1a23,0x1a24,0x1a25, 0x1a26,0x1a27,0x1a28,0x1a29,
  0x1a2a,0x1a2b,0x1a2c,0x1a2d, 0x1a2e,0x1a2f,0x1a30,0x1a31,
  0x1a32,0x1a33,0x1a34,0x1a35, 0x1a36,0x1a37,0x1a38,0x1a39,
  0x1a3a,0x1a3b,0x1a3c,0x1a3d, 0x1a3e,0x1a3f,0x1a40,0x1a41,
  0x1a42,0x1a43,0x1a44,0x1a45, 0x1a46,0x1a47,0x1a48,0x1a49,
  0x1a4a,0x1a4b,0x1a4c,0x1a4d, 0x1a4e,0x1a4f,0x1a50,0x1a51,
  0x1a52,0x1a53,0x1a54,0x1a55, 0x1a56,0x1a57,0x1a58,0x1a59,
  0x1a5a,0x1a5b,0x1a5c,0x1a5d, 0x1a5e,0x1a5f,0x1a60,0x1a61,
  0x1a62,0x1a63,0x1a64,0x1a65, 0x1a66,0x1a67,0x1a68,0x1a69,
  0x1a6a,0x1a6b,0x1a6c,0x1a6d,
/* 0xa581(i:6480) */
  0x1a6e,0x1a6f,0x1a70,0x1a71, 0x1a72,0x1a73,0x1a74,0x1a75,
  0x1a76,0x1a77,0x1a78,0x1a79, 0x1a7a,0x1a7b,0x1a7c,0x1a7d,
  0x1a7e,0x1a7f,0x1a80,0x1a81, 0x1a82,0x1a83,0x1a84,0x1a85,
  0x1a86,0x1a87,0x1a88,0x1a89, 0x1a8a,0x1a8b,0x1a8c,0x1a8d,
  0x1a8e,0x1a8f,0x1a90,0x1a91, 0x1a92,0x1a93,0x1a94,0x1a95,
  0x1a96,0x1a97,0x1a98,0x1a99, 0x1a9a,0x1a9b,0x1a9c,0x1a9d,
  0x1a9e,0x1a9f,0x1aa0,0x1aa1, 0x1aa2,0x1aa3,0x1aa4,0x1aa5,
  0x1aa6,0x1aa7,0x1aa8,0x1aa9, 0x1aaa,0x1aab,0x1aac,0x1aad,
  0x1aae,0x1aaf,0x1ab0,0x1ab1, 0x1ab2,0x1ab3,0x1ab4,0x1ab5,
  0x1ab6,0x1ab7,0x1ab8,0x1ab9, 0x1aba,0x1abb,0x1abc,0x1abd,
  0x1abe,0x1abf,0x1ac0,0x1ac1, 0x1ac2,0x1ac3,0x1ac4,0x1ac5,
  0x1ac6,0x1ac7,0x1ac8,0x1ac9, 0x1aca,0x1acb,0x1acc,0x1acd,
  0x1ace,0x1acf,0x1ad0,0x1ad1, 0x1ad2,0x1ad3,0x1ad4,0x1ad5,
  0x1ad6,0x1ad7,0x1ad8,0x1ad9, 0x1ada,0x1adb,0x1adc,0x1add,
  0x1ade,0x1adf,0x1ae0,0x1ae1, 0x1ae2,0x1ae3,0x1ae4,0x1ae5,
  0x1ae6,0x1ae7,0x1ae8,0x1ae9, 0x1aea,0x1aeb,0x1aec,0x1aed,
  0x1aee,0x1aef,0x1af0,0x1af1, 0x1af2,0x1af3,0x1af4,0x1af5,
  0x1af6,0x1af7,0x1af8,0x1af9, 0x1afa,0x1afb,0x1afc,0x1afd,
  0x1afe,0x1aff,0x1b00,0x1b01, 0x1b02,0x1b03,0x1b04,0x1b05,
  0x1b06,0x1b07,0x1b08,0x1b09, 0x1b0a,0x1b0b,0x1b0c,0x1b0d,
  0x1b0e,0x1b0f,0x1b10,0x1b11, 0x1b12,0x1b13,0x1b14,0x1b15,
  0x1b16,0x1b17,0x1b18,0x1b19, 0x1b1a,0x1b1b,0x1b1c,0x1b1d,
  0x1b1e,0x1b1f,0x1b20,0x1b21,
/* 0xa681(i:6660) */
  0x1b22,0x1b23,0x1b24,0x1b25, 0x1b26,0x1b27,0x1b28,0x1b29,
  0x1b2a,0x1b2b,0x1b2c,0x1b2d, 0x1b2e,0x1b2f,0x1b30,0x1b31,
  0x1b32,0x1b33,0x1b34,0x1b35, 0x1b36,0x1b37,0x1b38,0x1b39,
  0x1b3a,0x1b3b,0x1b3c,0x1b3d, 0x1b3e,0x1b3f,0x1b40,0x1b41,
  0x1b42,0x1b43,0x1b44,0x1b45, 0x1b46,0x1b47,0x1b48,0x1b49,
  0x1b4a,0x1b4b,0x1b4c,0x1b4d, 0x1b4e,0x1b4f,0x1b50,0x1b51,
  0x1b52,0x1b53,0x1b54,0x1b55, 0x1b56,0x1b57,0x1b58,0x1b59,
  0x1b5a,0x1b5b,0x1b5c,0x1b5d, 0x1b5e,0x1b5f,0x1b60,0x1b61,
  0x1b62,0x1b63,0x1b64,0x1b65, 0x1b66,0x1b67,0x1b68,0x1b69,
  0x1b6a,0x1b6b,0x1b6c,0x1b6d, 0x1b6e,0x1b6f,0x1b70,0x1b71,
  0x1b72,0x1b73,0x1b74,0x1b75, 0x1b76,0x1b77,0x1b78,0x1b79,
  0x1b7a,0x1b7b,0x1b7c,0x1b7d, 0x1b7e,0x1b7f,0x1b80,0x1b81,
  0x1b82,0x1b83,0x1b84,0x1b85, 0x1b86,0x1b87,0x1b88,0x1b89,
  0x1b8a,0x1b8b,0x1b8c,0x1b8d, 0x1b8e,0x1b8f,0x1b90,0x1b91,
  0x1b92,0x1b93,0x1b94,0x1b95, 0x1b96,0x1b97,0x1b98,0x1b99,
  0x1b9a,0x1b9b,0x1b9c,0x1b9d, 0x1b9e,0x1b9f,0x1ba0,0x1ba1,
  0x1ba2,0x1ba3,0x1ba4,0x1ba5, 0x1ba6,0x1ba7,0x1ba8,0x1ba9,
  0x1baa,0x1bab,0x1bac,0x1bad, 0x1bae,0x1baf,0x1bb0,0x1bb1,
  0x1bb2,0x1bb3,0x1bb4,0x1bb5, 0x1bb6,0x1bb7,0x1bb8,0x1bb9,
  0x1bba,0x1bbb,0x1bbc,0x1bbd, 0x1bbe,0x1bbf,0x1bc0,0x1bc1,
  0x1bc2,0x1bc3,0x1bc4,0x1bc5, 0x1bc6,0x1bc7,0x1bc8,0x1bc9,
  0x1bca,0x1bcb,0x1bcc,0x1bcd, 0x1bce,0x1bcf,0x1bd0,0x1bd1,
  0x1bd2,0x1bd3,0x1bd4,0x1bd5,
/* 0xa781(i:6840) */
  0x1bd6,0x1bd7,0x1bd8,0x1bd9, 0x1bda,0x1bdb,0x1bdc,0x1bdd,
  0x1bde,0x1bdf,0x1be0,0x1be1, 0x1be2,0x1be3,0x1be4,0x1be5,
  0x1be6,0x1be7,0x1be8,0x1be9, 0x1bea,0x1beb,0x1bec,0x1bed,
  0x1bee,0x1bef,0x1bf0,0x1bf1, 0x1bf2,0x1bf3,0x1bf4,0x1bf5,
  0x1bf6,0x1bf7,0x1bf8,0x1bf9, 0x1bfa,0x1bfb,0x1bfc,0x1bfd,
  0x1bfe,0x1bff,0x1c00,0x1c01, 0x1c02,0x1c03,0x1c04,0x1c05,
  0x1c06,0x1c07,0x1c08,0x1c09, 0x1c0a,0x1c0b,0x1c0c,0x1c0d,
  0x1c0e,0x1c0f,0x1c10,0x1c11, 0x1c12,0x1c13,0x1c14,0x1c15,
  0x1c16,0x1c17,0x1c18,0x1c19, 0x1c1a,0x1c1b,0x1c1c,0x1c1d,
  0x1c1e,0x1c1f,0x1c20,0x1c21, 0x1c22,0x1c23,0x1c24,0x1c25,
  0x1c26,0x1c27,0x1c28,0x1c29, 0x1c2a,0x1c2b,0x1c2c,0x1c2d,
  0x1c2e,0x1c2f,0x1c30,0x1c31, 0x1c32,0x1c33,0x1c34,0x1c35,
  0x1c36,0x1c37,0x1c38,0x1c39, 0x1c3a,0x1c3b,0x1c3c,0x1c3d,
  0x1c3e,0x1c3f,0x1c40,0x1c41, 0x1c42,0x1c43,0x1c44,0x1c45,
  0x1c46,0x1c47,0x1c48,0x1c49, 0x1c4a,0x1c4b,0x1c4c,0x1c4d,
  0x1c4e,0x1c4f,0x1c50,0x1c51, 0x1c52,0x1c53,0x1c54,0x1c55,
  0x1c56,0x1c57,0x1c58,0x1c59, 0x1c5a,0x1c5b,0x1c5c,0x1c5d,
  0x1c5e,0x1c5f,0x1c60,0x1c61, 0x1c62,0x1c63,0x1c64,0x1c65,
  0x1c66,0x1c67,0x1c68,0x1c69, 0x1c6a,0x1c6b,0x1c6c,0x1c6d,
  0x1c6e,0x1c6f,0x1c70,0x1c71, 0x1c72,0x1c73,0x1c74,0x1c75,
  0x1c76,0x1c77,0x1c78,0x1c79, 0x1c7a,0x1c7b,0x1c7c,0x1c7d,
  0x1c7e,0x1c7f,0x1c80,0x1c81, 0x1c82,0x1c83,0x1c84,0x1c85,
  0x1c86,0x1c87,0x1c88,0x1c89,
/* 0xa881(i:7020) */
  0x1c8a,0x1c8b,0x1c8c,0x1c8d, 0x1c8e,0x1c8f,0x1c90,0x1c91,
  0x1c92,0x1c93,0x1c94,0x1c95, 0x1c96,0x1c97,0x1c98,0x1c99,
  0x1c9a,0x1c9b,0x1c9c,0x1c9d, 0x1c9e,0x1c9f,0x1ca0,0x1ca1,
  0x1ca2,0x1ca3,0x1ca4,0x1ca5, 0x1ca6,0x1ca7,0x1ca8,0x1ca9,
  0x1caa,0x1cab,0x1cac,0x1cad, 0x1cae,0x1caf,0x1cb0,0x1cb1,
  0x1cb2,0x1cb3,0x1cb4,0x1cb5, 0x1cb6,0x1cb7,0x1cb8,0x1cb9,
  0x1cba,0x1cbb,0x1cbc,0x1cbd, 0x1cbe,0x1cbf,0x1cc0,0x1cc1,
  0x1cc2,0x1cc3,0x1cc4,0x1cc5, 0x1cc6,0x1cc7,0x1cc8,0x1cc9,
  0x1cca,0x1ccb,0x1ccc,0x1ccd, 0x1cce,0x1ccf,0x1cd0,0x1cd1,
  0x1cd2,0x1cd3,0x1cd4,0x1cd5, 0x1cd6,0x1cd7,0x1cd8,0x1cd9,
  0x1cda,0x1cdb,0x1cdc,0x1cdd, 0x1cde,0x1cdf,0x1ce0,0x1ce1,
  0x1ce2,0x1ce3,0x1ce4,0x1ce5, 0x1ce6,0x1ce7,0x1ce8,0x1ce9,
  0x1cea,0x1ceb,0x1cec,0x1ced, 0x1cee,0x1cef,0x1cf0,0x1cf1,
  0x1cf2,0x1cf3,0x1cf4,0x1cf5, 0x1cf6,0x1cf7,0x1cf8,0x1cf9,
  0x1cfa,0x1cfb,0x1cfc,0x1cfd, 0x1cfe,0x1cff,0x1d00,0x1d01,
  0x1d02,0x1d03,0x1d04,0x1d05, 0x1d06,0x1d07,0x1d08,0x1d09,
  0x1d0a,0x1d0b,0x1d0c,0x1d0d, 0x1d0e,0x1d0f,0x1d10,0x1d11,
  0x1d12,0x1d13,0x1d14,0x1d15, 0x1d16,0x1d17,0x1d18,0x1d19,
  0x1d1a,0x1d1b,0x1d1c,0x1d1d, 0x1d1e,0x1d1f,0x1d20,0x1d21,
  0x1d22,0x1d23,0x1d24,0x1d25, 0x1d26,0x1d27,0x1d28,0x1d29,
  0x1d2a,0x1d2b,0x1d2c,0x1d2d, 0x1d2e,0x1d2f,0x1d30,0x1d31,
  0x1d32,0x1d33,0x1d34,0x1d35, 0x1d36,0x1d37,0x1d38,0x1d39,
  0x1d3a,0x1d3b,0x1d3c,0x1d3d,
/* 0xa981(i:7200) */
  0x1d3e,0x1d3f,0x1d40,0x1d41, 0x1d42,0x1d43,0x1d44,0x1d45,
  0x1d46,0x1d47,0x1d48,0x1d49, 0x1d4a,0x1d4b,0x1d4c,0x1d4d,
  0x1d4e,0x1d4f,0x1d50,0x1d51, 0x1d52,0x1d53,0x1d54,0x1d55,
  0x1d56,0x1d57,0x1d58,0x1d59, 0x1d5a,0x1d5b,0x1d5c,0x1d5d,
  0x1d5e,0x1d5f,0x1d60,0x1d61, 0x1d62,0x1d63,0x1d64,0x1d65,
  0x1d66,0x1d67,0x1d68,0x1d69, 0x1d6a,0x1d6b,0x1d6c,0x1d6d,
  0x1d6e,0x1d6f,0x1d70,0x1d71, 0x1d72,0x1d73,0x1d74,0x1d75,
  0x1d76,0x1d77,0x1d78,0x1d79, 0x1d7a,0x1d7b,0x1d7c,0x1d7d,
  0x1d7e,0x1d7f,0x1d80,0x1d81, 0x1d82,0x1d83,0x1d84,0x1d85,
  0x1d86,0x1d87,0x1d88,0x1d89, 0x1d8a,0x1d8b,0x1d8c,0x1d8d,
  0x1d8e,0x1d8f,0x1d90,0x1d91, 0x1d92,0x1d93,0x1d94,0x1d95,
  0x1d96,0x1d97,0x1d98,0x1d99, 0x1d9a,0x1d9b,0x1d9c,0x1d9d,
  0x1d9e,0x1d9f,0x1da0,0x1da1, 0x1da2,0x1da3,0x1da4,0x1da5,
  0x1da6,0x1da7,0x1da8,0x1da9, 0x1daa,0x1dab,0x1dac,0x1dad,
  0x1dae,0x1daf,0x1db0,0x1db1, 0x1db2,0x1db3,0x1db4,0x1db5,
  0x1db6,0x1db7,0x1db8,0x1db9, 0x1dba,0x1dbb,0x1dbc,0x1dbd,
  0x1dbe,0x1dbf,0x1dc0,0x1dc1, 0x1dc2,0x1dc3,0x1dc4,0x1dc5,
  0x1dc6,0x1dc7,0x1dc8,0x1dc9, 0x1dca,0x1dcb,0x1dcc,0x1dcd,
  0x1dce,0x1dcf,0x1dd0,0x1dd1, 0x1dd2,0x1dd3,0x1dd4,0x1dd5,
  0x1dd6,0x1dd7,0x1dd8,0x1dd9, 0x1dda,0x1ddb,0x1ddc,0x1ddd,
  0x1dde,0x1ddf,0x1de0,0x1de1, 0x1de2,0x1de3,0x1de4,0x1de5,
  0x1de6,0x1de7,0x1de8,0x1de9, 0x1dea,0x1deb,0x1dec,0x1ded,
  0x1dee,0x1def,0x1df0,0x1df1,
/* 0xaa81(i:7380) */
  0x1df2,0x1df3,0x1df4,0x1df5, 0x1df6,0x1df7,0x1df8,0x1df9,
  0x1dfa,0x1dfb,0x1dfc,0x1dfd, 0x1dfe,0x1dff,0x1e00,0x1e01,
  0x1e02,0x1e03,0x1e04,0x1e05, 0x1e06,0x1e07,0x1e08,0x1e09,
  0x1e0a,0x1e0b,0x1e0c,0x1e0d, 0x1e0e,0x1e0f,0x1e10,0x1e11,
  0x1e12,0x1e13,0x1e14,0x1e15, 0x1e16,0x1e17,0x1e18,0x1e19,
  0x1e1a,0x1e1b,0x1e1c,0x1e1d, 0x1e1e,0x1e1f,0x1e20,0x1e21,
  0x1e22,0x1e23,0x1e24,0x1e25, 0x1e26,0x1e27,0x1e28,0x1e29,
  0x1e2a,0x1e2b,0x1e2c,0x1e2d, 0x1e2e,0x1e2f,0x1e30,0x1e31,
  0x1e32,0x1e33,0x1e34,0x1e35, 0x1e36,0x1e37,0x1e38,0x1e39,
  0x1e3a,0x1e3b,0x1e3c,0x1e3d, 0x1e3e,0x1e3f,0x1e40,0x1e41,
  0x1e42,0x1e43,0x1e44,0x1e45, 0x1e46,0x1e47,0x1e48,0x1e49,
  0x1e4a,0x1e4b,0x1e4c,0x1e4d, 0x1e4e,0x1e4f,0x1e50,0x1e51,
  0x1e52,0x1e53,0x1e54,0x1e55, 0x1e56,0x1e57,0x1e58,0x1e59,
  0x1e5a,0x1e5b,0x1e5c,0x1e5d, 0x1e5e,0x1e5f,0x1e60,0x1e61,
  0x1e62,0x1e63,0x1e64,0x1e65, 0x1e66,0x1e67,0x1e68,0x1e69,
  0x1e6a,0x1e6b,0x1e6c,0x1e6d, 0x1e6e,0x1e6f,0x1e70,0x1e71,
  0x1e72,0x1e73,0x1e74,0x1e75, 0x1e76,0x1e77,0x1e78,0x1e79,
  0x1e7a,0x1e7b,0x1e7c,0x1e7d, 0x1e7e,0x1e7f,0x1e80,0x1e81,
  0x1e82,0x1e83,0x1e84,0x1e85, 0x1e86,0x1e87,0x1e88,0x1e89,
  0x1e8a,0x1e8b,0x1e8c,0x1e8d, 0x1e8e,0x1e8f,0x1e90,0x1e91,
  0x1e92,0x1e93,0x1e94,0x1e95, 0x1e96,0x1e97,0x1e98,0x1e99,
  0x1e9a,0x1e9b,0x1e9c,0x1e9d, 0x1e9e,0x1e9f,0x1ea0,0x1ea1,
  0x1ea2,0x1ea3,0x1ea4,0x1ea5,
/* 0xab81(i:7560) */
  0x1ea6,0x1ea7,0x1ea8,0x1ea9, 0x1eaa,0x1eab,0x1eac,0x1ead,
  0x1eae,0x1eaf,0x1eb0,0x1eb1, 0x1eb2,0x1eb3,0x1eb4,0x1eb5,
  0x1eb6,0x1eb7,0x1eb8,0x1eb9, 0x1eba,0x1ebb,0x1ebc,0x1ebd,
  0x1ebe,0x1ebf,0x1ec0,0x1ec1, 0x1ec2,0x1ec3,0x1ec4,0x1ec5,
  0x1ec6,0x1ec7,0x1ec8,0x1ec9, 0x1eca,0x1ecb,0x1ecc,0x1ecd,
  0x1ece,0x1ecf,0x1ed0,0x1ed1, 0x1ed2,0x1ed3,0x1ed4,0x1ed5,
  0x1ed6,0x1ed7,0x1ed8,0x1ed9, 0x1eda,0x1edb,0x1edc,0x1edd,
  0x1ede,0x1edf,0x1ee0,0x1ee1, 0x1ee2,0x1ee3,0x1ee4,0x1ee5,
  0x1ee6,0x1ee7,0x1ee8,0x1ee9, 0x1eea,0x1eeb,0x1eec,0x1eed,
  0x1eee,0x1eef,0x1ef0,0x1ef1, 0x1ef2,0x1ef3,0x1ef4,0x1ef5,
  0x1ef6,0x1ef7,0x1ef8,0x1ef9, 0x1efa,0x1efb,0x1efc,0x1efd,
  0x1efe,0x1eff,0x1f00,0x1f01, 0x1f02,0x1f03,0x1f04,0x1f05,
  0x1f06,0x1f07,0x1f08,0x1f09, 0x1f0a,0x1f0b,0x1f0c,0x1f0d,
  0x1f0e,0x1f0f,0x1f10,0x1f11, 0x1f12,0x1f13,0x1f14,0x1f15,
  0x1f16,0x1f17,0x1f18,0x1f19, 0x1f1a,0x1f1b,0x1f1c,0x1f1d,
  0x1f1e,0x1f1f,0x1f20,0x1f21, 0x1f22,0x1f23,0x1f24,0x1f25,
  0x1f26,0x1f27,0x1f28,0x1f29, 0x1f2a,0x1f2b,0x1f2c,0x1f2d,
  0x1f2e,0x1f2f,0x1f30,0x1f31, 0x1f32,0x1f33,0x1f34,0x1f35,
  0x1f36,0x1f37,0x1f38,0x1f39, 0x1f3a,0x1f3b,0x1f3c,0x1f3d,
  0x1f3e,0x1f3f,0x1f40,0x1f41, 0x1f42,0x1f43,0x1f44,0x1f45,
  0x1f46,0x1f47,0x1f48,0x1f49, 0x1f4a,0x1f4b,0x1f4c,0x1f4d,
  0x1f4e,0x1f4f,0x1f50,0x1f51, 0x1f52,0x1f53,0x1f54,0x1f55,
  0x1f56,0x1f57,0x1f58,0x1f59,
/* 0xac81(i:7740) */
  0x1f5a,0x1f5b,0x1f5c,0x1f5d, 0x1f5e,0x1f5f,0x1f60,0x1f61,
  0x1f62,0x1f63,0x1f64,0x1f65, 0x1f66,0x1f67,0x1f68,0x1f69,
  0x1f6a,0x1f6b,0x1f6c,0x1f6d, 0x1f6e,0x1f6f,0x1f70,0x1f71,
  0x1f72,0x1f73,0x1f74,0x1f75, 0x1f76,0x1f77,0x1f78,0x1f79,
  0x1f7a,0x1f7b,0x1f7c,0x1f7d, 0x1f7e,0x1f7f,0x1f80,0x1f81,
  0x1f82,0x1f83,0x1f84,0x1f85, 0x1f86,0x1f87,0x1f88,0x1f89,
  0x1f8a,0x1f8b,0x1f8c,0x1f8d, 0x1f8e,0x1f8f,0x1f90,0x1f91,
  0x1f92,0x1f93,0x1f94,0x1f95, 0x1f96,0x1f97,0x1f98,0x1f99,
  0x1f9a,0x1f9b,0x1f9c,0x1f9d, 0x1f9e,0x1f9f,0x1fa0,0x1fa1,
  0x1fa2,0x1fa3,0x1fa4,0x1fa5, 0x1fa6,0x1fa7,0x1fa8,0x1fa9,
  0x1faa,0x1fab,0x1fac,0x1fad, 0x1fae,0x1faf,0x1fb0,0x1fb1,
  0x1fb2,0x1fb3,0x1fb4,0x1fb5, 0x1fb6,0x1fb7,0x1fb8,0x1fb9,
  0x1fba,0x1fbb,0x1fbc,0x1fbd, 0x1fbe,0x1fbf,0x1fc0,0x1fc1,
  0x1fc2,0x1fc3,0x1fc4,0x1fc5, 0x1fc6,0x1fc7,0x1fc8,0x1fc9,
  0x1fca,0x1fcb,0x1fcc,0x1fcd, 0x1fce,0x1fcf,0x1fd0,0x1fd1,
  0x1fd2,0x1fd3,0x1fd4,0x1fd5, 0x1fd6,0x1fd7,0x1fd8,0x1fd9,
  0x1fda,0x1fdb,0x1fdc,0x1fdd, 0x1fde,0x1fdf,0x1fe0,0x1fe1,
  0x1fe2,0x1fe3,0x1fe4,0x1fe5, 0x1fe6,0x1fe7,0x1fe8,0x1fe9,
  0x1fea,0x1feb,0x1fec,0x1fed, 0x1fee,0x1fef,0x1ff0,0x1ff1,
  0x1ff2,0x1ff3,0x1ff4,0x1ff5, 0x1ff6,0x1ff7,0x1ff8,0x1ff9,
  0x1ffa,0x1ffb,0x1ffc,0x1ffd, 0x1ffe,0x1fff,0x2000,0x2001,
  0x2002,0x2003,0x2004,0x2005, 0x2006,0x2007,0x2008,0x2009,
  0x200a,0x200b,0x200c,0x200d,
/* 0xad81(i:7920) */
  0x200e,0x200f,0x2011,0x2012, 0x2017,0x201a,0x201b,0x201e,
  0x201f,0x2020,0x2021,0x2022, 0x2023,0x2024,0x2027,0x2028,
  0x2029,0x202a,0x202b,0x202c, 0x202d,0x202e,0x202f,0x2031,
  0x2034,0x2036,0x2037,0x2038, 0x2039,0x203a,0x203c,0x203d,
  0x203e,0x203f,0x2040,0x2041, 0x2042,0x2043,0x2044,0x2045,
  0x2046,0x2047,0x2048,0x2049, 0x204a,0x204b,0x204c,0x204d,
  0x204e,0x204f,0x2050,0x2051, 0x2052,0x2053,0x2054,0x2055,
  0x2056,0x2057,0x2058,0x2059, 0x205a,0x205b,0x205c,0x205d,
  0x205e,0x205f,0x2060,0x2061, 0x2062,0x2063,0x2064,0x2065,
  0x2066,0x2067,0x2068,0x2069, 0x206a,0x206b,0x206c,0x206d,
  0x206e,0x206f,0x2070,0x2071, 0x2072,0x2073,0x2074,0x2075,
  0x2076,0x2077,0x2078,0x2079, 0x207a,0x207b,0x207c,0x207d,
  0x207e,0x207f,0x2080,0x2081, 0x2082,0x2083,0x2084,0x2085,
  0x2086,0x2087,0x2088,0x2089, 0x208a,0x208b,0x208c,0x208d,
  0x208e,0x208f,0x2090,0x2091, 0x2092,0x2093,0x2094,0x2095,
  0x2096,0x2097,0x2098,0x2099, 0x209a,0x209b,0x209c,0x209d,
  0x209e,0x209f,0x20a0,0x20a1, 0x20a2,0x20a3,0x20a4,0x20a5,
  0x20a6,0x20a7,0x20a8,0x20a9, 0x20aa,0x20ab,0x20ad,0x20ae,
  0x20af,0x20b0,0x20b1,0x20b2, 0x20b3,0x20b4,0x20b5,0x20b6,
  0x20b7,0x20b8,0x20b9,0x20ba, 0x20bb,0x20bc,0x20bd,0x20be,
  0x20bf,0x20c0,0x20c1,0x20c2, 0x20c3,0x20c4,0x20c5,0x20c6,
  0x20c7,0x20c8,0x20c9,0x20ca, 0x20cb,0x20cc,0x20cd,0x20ce,
  0x20cf,0x20d0,0x20d1,0x20d2, 
/* 0xae81(i:8100) */
  0x20d3,0x20d4,0x20d5,0x20d6, 0x20d7,0x20d8,0x20d9,0x20da,
  0x20db,0x20dc,0x20dd,0x20de, 0x20df,0x20e0,0x20e1,0x20e2,
  0x20e3,0x20e4,0x20e5,0x20e6, 0x20e7,0x20e8,0x20e9,0x20ea,
  0x20eb,0x20ec,0x20ed,0x20ee, 0x20ef,0x20f0,0x20f1,0x20f2,
  0x20f3,0x20f4,0x20f5,0x20f6, 0x20f7,0x20f8,0x20f9,0x20fa,
  0x20fb,0x20fc,0x20fd,0x20fe, 0x20ff,0x2100,0x2101,0x2102,
  0x2104,0x2106,0x2107,0x2108, 0x210a,0x210b,0x210c,0x210d,
  0x210e,0x210f,0x2110,0x2111, 0x2112,0x2113,0x2114,0x2115,
  0x2117,0x2118,0x2119,0x211a, 0x211b,0x211c,0x211d,0x211e,
  0x211f,0x2120,0x2122,0x2123, 0x2124,0x2125,0x2126,0x2127,
  0x2128,0x2129,0x212a,0x212b, 0x212c,0x212d,0x212e,0x212f,
  0x2130,0x2131,0x2132,0x2133, 0x2134,0x2135,0x2136,0x2137,
  0x2138,0x2139,0x213a,0x213b, 0x213c,0x213d,0x213e,0x213f,
  0x2140,0x2141,0x2142,0x2143, 0x2144,0x2145,0x2146,0x2147,
  0x2148,0x2149,0x214a,0x214b, 0x214c,0x214d,0x214e,0x214f,
  0x2150,0x2151,0x2152,0x2153, 0x2154,0x2155,0x2156,0x2157,
  0x2158,0x2159,0x215a,0x215b, 0x215c,0x215d,0x215e,0x215f,
  0x216c,0x216d,0x216e,0x216f, 0x217a,0x217b,0x217c,0x217d,
  0x217e,0x217f,0x2180,0x2181, 0x2182,0x2183,0x2184,0x2185,
  0x2186,0x2187,0x2188,0x2189, 0x218a,0x218b,0x218c,0x218d,
  0x218e,0x218f,0x2194,0x2195, 0x219a,0x219b,0x219c,0x219d,
  0x219e,0x219f,0x21a0,0x21a1, 0x21a2,0x21a3,0x21a4,0x21a5,
  0x21a6,0x21a7,0x21a8,0x21a9, 
/* 0xaf81(i:8280) */
  0x21aa,0x21ab,0x21ac,0x21ad, 0x21ae,0x21af,0x21b0,0x21b1,
  0x21b2,0x21b3,0x21b4,0x21b5, 0x21b6,0x21b7,0x21b8,0x21b9,
  0x21ba,0x21bb,0x21bc,0x21bd, 0x21be,0x21bf,0x21c0,0x21c1,
  0x21c2,0x21c3,0x21c4,0x21c5, 0x21c6,0x21c7,0x21c8,0x21c9,
  0x21ca,0x21cb,0x21cc,0x21cd, 0x21ce,0x21cf,0x21d0,0x21d1,
  0x21d2,0x21d3,0x21d4,0x21d5, 0x21d6,0x21d7,0x21d8,0x21d9,
  0x21da,0x21db,0x21dc,0x21dd, 0x21de,0x21df,0x21e0,0x21e1,
  0x21e2,0x21e3,0x21e4,0x21e5, 0x21e6,0x21e7,0x21e8,0x21e9,
  0x21ea,0x21eb,0x21ec,0x21ed, 0x21ee,0x21ef,0x21f0,0x21f1,
  0x21f2,0x21f3,0x21f4,0x21f5, 0x21f6,0x21f7,0x21f8,0x21f9,
  0x21fa,0x21fb,0x21fc,0x21fd, 0x21fe,0x21ff,0x2200,0x2201,
  0x2202,0x2203,0x2204,0x2205, 0x2206,0x2207,0x2209,0x220a,
  0x220b,0x220c,0x220d,0x220e, 0x2210,0x2212,0x2213,0x2214,
  0x2216,0x2217,0x2218,0x2219, 0x221b,0x221c,0x2221,0x2222,
  0x2224,0x2226,0x222c,0x222d, 0x222f,0x2230,0x2231,0x2232,
  0x2233,0x2238,0x2239,0x223a, 0x223b,0x223c,0x223e,0x223f,
  0x2240,0x2241,0x2242,0x2243, 0x2244,0x2245,0x2246,0x2247,
  0x2249,0x224a,0x224b,0x224d, 0x224e,0x224f,0x2250,0x2251,
  0x2253,0x2254,0x2255,0x2256, 0x2257,0x2258,0x2259,0x225a,
  0x225b,0x225c,0x225d,0x225e, 0x225f,0x2262,0x2263,0x2268,
  0x2269,0x226a,0x226b,0x226c, 0x226d,0x2270,0x2271,0x2272,
  0x2273,0x2274,0x2275,0x2276, 0x2277,0x2278,0x2279,0x227a,
  0x227b,0x227c,0x227d,0x227e, 
/* 0xb081(i:8460) */
  0x227f,0x2280,0x2281,0x2282, 0x2283,0x2284,0x2285,0x2286,
  0x2287,0x2288,0x2289,0x228a, 0x228b,0x228c,0x228d,0x228e,
  0x228f,0x2290,0x2291,0x2292, 0x2293,0x2294,0x2296,0x2297,
  0x2298,0x229a,0x229b,0x229c, 0x229d,0x229e,0x229f,0x22a0,
  0x22a1,0x22a2,0x22a3,0x22a4, 0x22a6,0x22a7,0x22a8,0x22a9,
  0x22aa,0x22ab,0x22ac,0x22ad, 0x22ae,0x22af,0x22b0,0x22b1,
  0x22b2,0x22b3,0x22b4,0x22b5, 0x22b6,0x22b7,0x22b8,0x22b9,
  0x22ba,0x22bb,0x22bc,0x22bd, 0x22be,0x22c0,0x22c1,0x22c2,
  0x22c3,0x22c4,0x22c5,0x22c6, 0x22c7,0x22c8,0x22c9,0x22ca,
  0x22cb,0x22cc,0x22cd,0x22ce, 0x22cf,0x22d0,0x22d1,0x22d2,
  0x22d3,0x22d4,0x22d5,0x22d6, 0x22d7,0x22d8,0x22d9,0x22da,
  0x22db,0x22dc,0x22dd,0x22de, 0x22df,0x22e0,0x22e1,0x22e2,
  0x22e3,0x22e4,0x22e5,0x22e6, 0x22e7,0x22e8,0x22e9,0x22ea,
  0x22eb,0x22ec,0x22ed,0x22ee, 0x22ef,0x22f0,0x22f1,0x22f2,
  0x22f3,0x22f4,0x22f5,0x22f6, 0x22f7,0x22f8,0x22f9,0x22fa,
  0x22fb,0x22fc,0x22fd,0x22fe, 0x22ff,0x2300,0x2301,0x2302,
  0x2303,0x2304,0x2305,0x2306, 0x2307,0x2308,0x2309,0x230a,
  0x230b,0x230c,0x230d,0x230e, 0x230f,0x2310,0x2311,0x2313,
  0x2314,0x2315,0x2316,0x2317, 0x2318,0x2319,0x231a,0x231b,
  0x231c,0x231d,0x231e,0x231f, 0x2320,0x2321,0x2322,0x2323,
  0x2324,0x2325,0x2326,0x2327, 0x2328,0x2329,0x232a,0x232b,
  0x232c,0x232d,0x232e,0x232f, 0x2330,0x2331,0x2332,0x2333,
  0x2334,0x2335,0x2336,0x2337, 
/* 0xb181(i:8640) */
  0x2338,0x2339,0x233a,0x233b, 0x233c,0x233d,0x233e,0x233f,
  0x2340,0x2341,0x2342,0x2343, 0x2344,0x2345,0x2346,0x2347,
  0x2348,0x2349,0x234a,0x234b, 0x234c,0x234d,0x234e,0x234f,
  0x2350,0x2351,0x2352,0x2353, 0x2354,0x2355,0x2356,0x2357,
  0x2358,0x2359,0x235a,0x235b, 0x235c,0x235d,0x235e,0x235f,
  0x2360,0x2361,0x2362,0x2363, 0x2364,0x2365,0x2366,0x2367,
  0x2368,0x2369,0x236a,0x236b, 0x236c,0x236d,0x236e,0x236f,
  0x2370,0x2371,0x2372,0x2373, 0x2374,0x2375,0x2376,0x2377,
  0x2378,0x2379,0x237a,0x237b, 0x237c,0x237d,0x237e,0x237f,
  0x2380,0x2381,0x2382,0x2383, 0x2384,0x2385,0x2386,0x2387,
  0x2388,0x2389,0x238a,0x238b, 0x238c,0x238d,0x238e,0x238f,
  0x2390,0x2391,0x2392,0x2393, 0x2394,0x2395,0x2396,0x2397,
  0x2398,0x2399,0x239a,0x239b, 0x239c,0x239d,0x239e,0x239f,
  0x23a0,0x23a1,0x23a2,0x23a3, 0x23a4,0x23a5,0x23a6,0x23a7,
  0x23a8,0x23a9,0x23aa,0x23ab, 0x23ac,0x23ad,0x23ae,0x23af,
  0x23b0,0x23b1,0x23b2,0x23b3, 0x23b4,0x23b5,0x23b6,0x23b7,
  0x23b8,0x23b9,0x23ba,0x23bb, 0x23bc,0x23bd,0x23be,0x23bf,
  0x23c0,0x23c1,0x23c2,0x23c3, 0x23c4,0x23c5,0x23c6,0x23c7,
  0x23c8,0x23c9,0x23ca,0x23cb, 0x23cc,0x23cd,0x23ce,0x23cf,
  0x23d0,0x23d1,0x23d2,0x23d3, 0x23d4,0x23d5,0x23d6,0x23d7,
  0x23d8,0x23d9,0x23da,0x23db, 0x23dc,0x23dd,0x23de,0x23df,
  0x23e0,0x23e1,0x23e2,0x23e3, 0x23e4,0x23e5,0x23e6,0x23e7,
  0x23e8,0x23e9,0x23ea,0x23eb, 
/* 0xb281(i:8820) */
  0x23ec,0x23ed,0x23ee,0x23ef, 0x23f0,0x23f1,0x23f2,0x23f3,
  0x23f4,0x23f5,0x23f6,0x23f7, 0x23f8,0x23f9,0x23fa,0x23fb,
  0x23fc,0x23fd,0x23fe,0x23ff, 0x2400,0x2401,0x2402,0x2403,
  0x2404,0x2405,0x2406,0x2407, 0x2408,0x2409,0x240a,0x240b,
  0x240c,0x240d,0x240e,0x240f, 0x2410,0x2411,0x2412,0x2413,
  0x2414,0x2415,0x2416,0x2417, 0x2418,0x2419,0x241a,0x241b,
  0x241c,0x241d,0x241e,0x241f, 0x2420,0x2421,0x2422,0x2423,
  0x2424,0x2425,0x2426,0x2427, 0x2428,0x2429,0x242a,0x242b,
  0x242c,0x242d,0x242e,0x242f, 0x2430,0x2431,0x2432,0x2433,
  0x2434,0x2435,0x2436,0x2437, 0x2438,0x2439,0x243a,0x243b,
  0x243c,0x243d,0x243e,0x243f, 0x2440,0x2441,0x2442,0x2443,
  0x2444,0x2445,0x2446,0x2447, 0x2448,0x2449,0x244a,0x244b,
  0x244c,0x244d,0x244e,0x244f, 0x2450,0x2451,0x2452,0x2453,
  0x2454,0x2455,0x2456,0x2457, 0x2458,0x2459,0x245a,0x245b,
  0x245c,0x245d,0x245e,0x245f, 0x246a,0x246b,0x246c,0x246d,
  0x246e,0x246f,0x2470,0x2471, 0x2472,0x2473,0x249c,0x249d,
  0x249e,0x249f,0x24a0,0x24a1, 0x24a2,0x24a3,0x24a4,0x24a5,
  0x24a6,0x24a7,0x24a8,0x24a9, 0x24aa,0x24ab,0x24ac,0x24ad,
  0x24ae,0x24af,0x24b0,0x24b1, 0x24b2,0x24b3,0x24b4,0x24b5,
  0x24b6,0x24b7,0x24b8,0x24b9, 0x24ba,0x24bb,0x24bc,0x24bd,
  0x24be,0x24bf,0x24c0,0x24c1, 0x24c2,0x24c3,0x24c4,0x24c5,
  0x24c6,0x24c7,0x24c8,0x24c9, 0x24ca,0x24cb,0x24cc,0x24cd,
  0x24ce,0x24cf,0x24d0,0x24d1, 
/* 0xb381(i:9000) */
  0x24d2,0x24d3,0x24d4,0x24d5, 0x24d6,0x24d7,0x24d8,0x24d9,
  0x24da,0x24db,0x24dc,0x24dd, 0x24de,0x24df,0x24e0,0x24e1,
  0x24e2,0x24e3,0x24e4,0x24e5, 0x24e6,0x24e7,0x24e8,0x24e9,
  0x24ea,0x24eb,0x24ec,0x24ed, 0x24ee,0x24ef,0x24f0,0x24f1,
  0x24f2,0x24f3,0x24f4,0x24f5, 0x24f6,0x24f7,0x24f8,0x24f9,
  0x24fa,0x24fb,0x24fc,0x24fd, 0x24fe,0x24ff,0x254c,0x254d,
  0x254e,0x254f,0x2574,0x2575, 0x2576,0x2577,0x2578,0x2579,
  0x257a,0x257b,0x257c,0x257d, 0x257e,0x257f,0x2580,0x2590,
  0x2591,0x2592,0x2596,0x2597, 0x2598,0x2599,0x259a,0x259b,
  0x259c,0x259d,0x259e,0x259f, 0x25a2,0x25a3,0x25a4,0x25a5,
  0x25a6,0x25a7,0x25a8,0x25a9, 0x25aa,0x25ab,0x25ac,0x25ad,
  0x25ae,0x25af,0x25b0,0x25b1, 0x25b4,0x25b5,0x25b6,0x25b7,
  0x25b8,0x25b9,0x25ba,0x25bb, 0x25be,0x25bf,0x25c0,0x25c1,
  0x25c2,0x25c3,0x25c4,0x25c5, 0x25c8,0x25c9,0x25ca,0x25cc,
  0x25cd,0x25d0,0x25d1,0x25d2, 0x25d3,0x25d4,0x25d5,0x25d6,
  0x25d7,0x25d8,0x25d9,0x25da, 0x25db,0x25dc,0x25dd,0x25de,
  0x25df,0x25e0,0x25e1,0x25e6, 0x25e7,0x25e8,0x25e9,0x25ea,
  0x25eb,0x25ec,0x25ed,0x25ee, 0x25ef,0x25f0,0x25f1,0x25f2,
  0x25f3,0x25f4,0x25f5,0x25f6, 0x25f7,0x25f8,0x25f9,0x25fa,
  0x25fb,0x25fc,0x25fd,0x25fe, 0x25ff,0x2600,0x2601,0x2602,
  0x2603,0x2604,0x2607,0x2608, 0x260a,0x260b,0x260c,0x260d,
  0x260e,0x260f,0x2610,0x2611, 0x2612,0x2613,0x2614,0x2615,
  0x2616,0x2617,0x2618,0x2619, 
/* 0xb481(i:9180) */
  0x261a,0x261b,0x261c,0x261d, 0x261e,0x261f,0x2620,0x2621,
  0x2622,0x2623,0x2624,0x2625, 0x2626,0x2627,0x2628,0x2629,
  0x262a,0x262b,0x262c,0x262d, 0x262e,0x262f,0x2630,0x2631,
  0x2632,0x2633,0x2634,0x2635, 0x2636,0x2637,0x2638,0x2639,
  0x263a,0x263b,0x263c,0x263d, 0x263e,0x263f,0x2641,0x2643,
  0x2644,0x2645,0x2646,0x2647, 0x2648,0x2649,0x264a,0x264b,
  0x264c,0x264d,0x264e,0x264f, 0x2650,0x2651,0x2652,0x2653,
  0x2654,0x2655,0x2656,0x2657, 0x2658,0x2659,0x265a,0x265b,
  0x265c,0x265d,0x265e,0x265f, 0x2660,0x2661,0x2662,0x2663,
  0x2664,0x2665,0x2666,0x2667, 0x2668,0x2669,0x266a,0x266b,
  0x266c,0x266d,0x266e,0x266f, 0x2670,0x2671,0x2672,0x2673,
  0x2674,0x2675,0x2676,0x2677, 0x2678,0x2679,0x267a,0x267b,
  0x267c,0x267d,0x267e,0x267f, 0x2680,0x2681,0x2682,0x2683,
  0x2684,0x2685,0x2686,0x2687, 0x2688,0x2689,0x268a,0x268b,
  0x268c,0x268d,0x268e,0x268f, 0x2690,0x2691,0x2692,0x2693,
  0x2694,0x2695,0x2696,0x2697, 0x2698,0x2699,0x269a,0x269b,
  0x269c,0x269d,0x269e,0x269f, 0x26a0,0x26a1,0x26a2,0x26a3,
  0x26a4,0x26a5,0x26a6,0x26a7, 0x26a8,0x26a9,0x26aa,0x26ab,
  0x26ac,0x26ad,0x26ae,0x26af, 0x26b0,0x26b1,0x26b2,0x26b3,
  0x26b4,0x26b5,0x26b6,0x26b7, 0x26b8,0x26b9,0x26ba,0x26bb,
  0x26bc,0x26bd,0x26be,0x26bf, 0x26c0,0x26c1,0x26c2,0x26c3,
  0x26c4,0x26c5,0x26c6,0x26c7, 0x26c8,0x26c9,0x26ca,0x26cb,
  0x26cc,0x26cd,0x26ce,0x26cf,
/* 0xb581(i:9360) */
  0x26d0,0x26d1,0x26d2,0x26d3, 0x26d4,0x26d5,0x26d6,0x26d7,
  0x26d8,0x26d9,0x26da,0x26db, 0x26dc,0x26dd,0x26de,0x26df,
  0x26e0,0x26e1,0x26e2,0x26e3, 0x26e4,0x26e5,0x26e6,0x26e7,
  0x26e8,0x26e9,0x26ea,0x26eb, 0x26ec,0x26ed,0x26ee,0x26ef,
  0x26f0,0x26f1,0x26f2,0x26f3, 0x26f4,0x26f5,0x26f6,0x26f7,
  0x26f8,0x26f9,0x26fa,0x26fb, 0x26fc,0x26fd,0x26fe,0x26ff,
  0x2700,0x2701,0x2702,0x2703, 0x2704,0x2705,0x2706,0x2707,
  0x2708,0x2709,0x270a,0x270b, 0x270c,0x270d,0x270e,0x270f,
  0x2710,0x2711,0x2712,0x2713, 0x2714,0x2715,0x2716,0x2717,
  0x2718,0x2719,0x271a,0x271b, 0x271c,0x271d,0x271e,0x271f,
  0x2720,0x2721,0x2722,0x2723, 0x2724,0x2725,0x2726,0x2727,
  0x2728,0x2729,0x272a,0x272b, 0x272c,0x272d,0x272e,0x272f,
  0x2730,0x2731,0x2732,0x2733, 0x2734,0x2735,0x2736,0x2737,
  0x2738,0x2739,0x273a,0x273b, 0x273c,0x273d,0x273e,0x273f,
  0x2740,0x2741,0x2742,0x2743, 0x2744,0x2745,0x2746,0x2747,
  0x2748,0x2749,0x274a,0x274b, 0x274c,0x274d,0x274e,0x274f,
  0x2750,0x2751,0x2752,0x2753, 0x2754,0x2755,0x2756,0x2757,
  0x2758,0x2759,0x275a,0x275b, 0x275c,0x275d,0x275e,0x275f,
  0x2760,0x2761,0x2762,0x2763, 0x2764,0x2765,0x2766,0x2767,
  0x2768,0x2769,0x276a,0x276b, 0x276c,0x276d,0x276e,0x276f,
  0x2770,0x2771,0x2772,0x2773, 0x2774,0x2775,0x2776,0x2777,
  0x2778,0x2779,0x277a,0x277b, 0x277c,0x277d,0x277e,0x277f,
  0x2780,0x2781,0x2782,0x2783,
/* 0xb681(i:9540) */
  0x2784,0x2785,0x2786,0x2787, 0x2788,0x2789,0x278a,0x278b,
  0x278c,0x278d,0x278e,0x278f, 0x2790,0x2791,0x2792,0x2793,
  0x2794,0x2795,0x2796,0x2797, 0x2798,0x2799,0x279a,0x279b,
  0x279c,0x279d,0x279e,0x279f, 0x27a0,0x27a1,0x27a2,0x27a3,
  0x27a4,0x27a5,0x27a6,0x27a7, 0x27a8,0x27a9,0x27aa,0x27ab,
  0x27ac,0x27ad,0x27ae,0x27af, 0x27b0,0x27b1,0x27b2,0x27b3,
  0x27b4,0x27b5,0x27b6,0x27b7, 0x27b8,0x27b9,0x27ba,0x27bb,
  0x27bc,0x27bd,0x27be,0x27bf, 0x27c0,0x27c1,0x27c2,0x27c3,
  0x27c4,0x27c5,0x27c6,0x27c7, 0x27c8,0x27c9,0x27ca,0x27cb,
  0x27cc,0x27cd,0x27ce,0x27cf, 0x27d0,0x27d1,0x27d2,0x27d3,
  0x27d4,0x27d5,0x27d6,0x27d7, 0x27d8,0x27d9,0x27da,0x27db,
  0x27dc,0x27dd,0x27de,0x27df, 0x27e0,0x27e1,0x27e2,0x27e3,
  0x27e4,0x27e5,0x27e6,0x27e7, 0x27e8,0x27e9,0x27ea,0x27eb,
  0x27ec,0x27ed,0x27ee,0x27ef, 0x27f0,0x27f1,0x27f2,0x27f3,
  0x27f4,0x27f5,0x27f6,0x27f7, 0x27f8,0x27f9,0x27fa,0x27fb,
  0x27fc,0x27fd,0x27fe,0x27ff, 0x2800,0x2801,0x2802,0x2803,
  0x2804,0x2805,0x2806,0x2807, 0x2808,0x2809,0x280a,0x280b,
  0x280c,0x280d,0x280e,0x280f, 0x2810,0x2811,0x2812,0x2813,
  0x2814,0x2815,0x2816,0x2817, 0x2818,0x2819,0x281a,0x281b,
  0x281c,0x281d,0x281e,0x281f, 0x2820,0x2821,0x2822,0x2823,
  0x2824,0x2825,0x2826,0x2827, 0x2828,0x2829,0x282a,0x282b,
  0x282c,0x282d,0x282e,0x282f, 0x2830,0x2831,0x2832,0x2833,
  0x2834,0x2835,0x2836,0x2837,
/* 0xb781(i:9720) */
  0x2838,0x2839,0x283a,0x283b, 0x283c,0x283d,0x283e,0x283f,
  0x2840,0x2841,0x2842,0x2843, 0x2844,0x2845,0x2846,0x2847,
  0x2848,0x2849,0x284a,0x284b, 0x284c,0x284d,0x284e,0x284f,
  0x2850,0x2851,0x2852,0x2853, 0x2854,0x2855,0x2856,0x2857,
  0x2858,0x2859,0x285a,0x285b, 0x285c,0x285d,0x285e,0x285f,
  0x2860,0x2861,0x2862,0x2863, 0x2864,0x2865,0x2866,0x2867,
  0x2868,0x2869,0x286a,0x286b, 0x286c,0x286d,0x286e,0x286f,
  0x2870,0x2871,0x2872,0x2873, 0x2874,0x2875,0x2876,0x2877,
  0x2878,0x2879,0x287a,0x287b, 0x287c,0x287d,0x287e,0x287f,
  0x2880,0x2881,0x2882,0x2883, 0x2884,0x2885,0x2886,0x2887,
  0x2888,0x2889,0x288a,0x288b, 0x288c,0x288d,0x288e,0x288f,
  0x2890,0x2891,0x2892,0x2893, 0x2894,0x2895,0x2896,0x2897,
  0x2898,0x2899,0x289a,0x289b, 0x289c,0x289d,0x289e,0x289f,
  0x28a0,0x28a1,0x28a2,0x28a3, 0x28a4,0x28a5,0x28a6,0x28a7,
  0x28a8,0x28a9,0x28aa,0x28ab, 0x28ac,0x28ad,0x28ae,0x28af,
  0x28b0,0x28b1,0x28b2,0x28b3, 0x28b4,0x28b5,0x28b6,0x28b7,
  0x28b8,0x28b9,0x28ba,0x28bb, 0x28bc,0x28bd,0x28be,0x28bf,
  0x28c0,0x28c1,0x28c2,0x28c3, 0x28c4,0x28c5,0x28c6,0x28c7,
  0x28c8,0x28c9,0x28ca,0x28cb, 0x28cc,0x28cd,0x28ce,0x28cf,
  0x28d0,0x28d1,0x28d2,0x28d3, 0x28d4,0x28d5,0x28d6,0x28d7,
  0x28d8,0x28d9,0x28da,0x28db, 0x28dc,0x28dd,0x28de,0x28df,
  0x28e0,0x28e1,0x28e2,0x28e3, 0x28e4,0x28e5,0x28e6,0x28e7,
  0x28e8,0x28e9,0x28ea,0x28eb,
/* 0xb881(i:9900) */
  0x28ec,0x28ed,0x28ee,0x28ef, 0x28f0,0x28f1,0x28f2,0x28f3,
  0x28f4,0x28f5,0x28f6,0x28f7, 0x28f8,0x28f9,0x28fa,0x28fb,
  0x28fc,0x28fd,0x28fe,0x28ff, 0x2900,0x2901,0x2902,0x2903,
  0x2904,0x2905,0x2906,0x2907, 0x2908,0x2909,0x290a,0x290b,
  0x290c,0x290d,0x290e,0x290f, 0x2910,0x2911,0x2912,0x2913,
  0x2914,0x2915,0x2916,0x2917, 0x2918,0x2919,0x291a,0x291b,
  0x291c,0x291d,0x291e,0x291f, 0x2920,0x2921,0x2922,0x2923,
  0x2924,0x2925,0x2926,0x2927, 0x2928,0x2929,0x292a,0x292b,
  0x292c,0x292d,0x292e,0x292f, 0x2930,0x2931,0x2932,0x2933,
  0x2934,0x2935,0x2936,0x2937, 0x2938,0x2939,0x293a,0x293b,
  0x293c,0x293d,0x293e,0x293f, 0x2940,0x2941,0x2942,0x2943,
  0x2944,0x2945,0x2946,0x2947, 0x2948,0x2949,0x294a,0x294b,
  0x294c,0x294d,0x294e,0x294f, 0x2950,0x2951,0x2952,0x2953,
  0x2954,0x2955,0x2956,0x2957, 0x2958,0x2959,0x295a,0x295b,
  0x295c,0x295d,0x295e,0x295f, 0x2960,0x2961,0x2962,0x2963,
  0x2964,0x2965,0x2966,0x2967, 0x2968,0x2969,0x296a,0x296b,
  0x296c,0x296d,0x296e,0x296f, 0x2970,0x2971,0x2972,0x2973,
  0x2974,0x2975,0x2976,0x2977, 0x2978,0x2979,0x297a,0x297b,
  0x297c,0x297d,0x297e,0x297f, 0x2980,0x2981,0x2982,0x2983,
  0x2984,0x2985,0x2986,0x2987, 0x2988,0x2989,0x298a,0x298b,
  0x298c,0x298d,0x298e,0x298f, 0x2990,0x2991,0x2992,0x2993,
  0x2994,0x2995,0x2996,0x2997, 0x2998,0x2999,0x299a,0x299b,
  0x299c,0x299d,0x299e,0x299f,
/* 0xb981(i:10080) */
  0x29a0,0x29a1,0x29a2,0x29a3, 0x29a4,0x29a5,0x29a6,0x29a7,
  0x29a8,0x29a9,0x29aa,0x29ab, 0x29ac,0x29ad,0x29ae,0x29af,
  0x29b0,0x29b1,0x29b2,0x29b3, 0x29b4,0x29b5,0x29b6,0x29b7,
  0x29b8,0x29b9,0x29ba,0x29bb, 0x29bc,0x29bd,0x29be,0x29bf,
  0x29c0,0x29c1,0x29c2,0x29c3, 0x29c4,0x29c5,0x29c6,0x29c7,
  0x29c8,0x29c9,0x29ca,0x29cb, 0x29cc,0x29cd,0x29ce,0x29cf,
  0x29d0,0x29d1,0x29d2,0x29d3, 0x29d4,0x29d5,0x29d6,0x29d7,
  0x29d8,0x29d9,0x29da,0x29db, 0x29dc,0x29dd,0x29de,0x29df,
  0x29e0,0x29e1,0x29e2,0x29e3, 0x29e4,0x29e5,0x29e6,0x29e7,
  0x29e8,0x29e9,0x29ea,0x29eb, 0x29ec,0x29ed,0x29ee,0x29ef,
  0x29f0,0x29f1,0x29f2,0x29f3, 0x29f4,0x29f5,0x29f6,0x29f7,
  0x29f8,0x29f9,0x29fa,0x29fb, 0x29fc,0x29fd,0x29fe,0x29ff,
  0x2a00,0x2a01,0x2a02,0x2a03, 0x2a04,0x2a05,0x2a06,0x2a07,
  0x2a08,0x2a09,0x2a0a,0x2a0b, 0x2a0c,0x2a0d,0x2a0e,0x2a0f,
  0x2a10,0x2a11,0x2a12,0x2a13, 0x2a14,0x2a15,0x2a16,0x2a17,
  0x2a18,0x2a19,0x2a1a,0x2a1b, 0x2a1c,0x2a1d,0x2a1e,0x2a1f,
  0x2a20,0x2a21,0x2a22,0x2a23, 0x2a24,0x2a25,0x2a26,0x2a27,
  0x2a28,0x2a29,0x2a2a,0x2a2b, 0x2a2c,0x2a2d,0x2a2e,0x2a2f,
  0x2a30,0x2a31,0x2a32,0x2a33, 0x2a34,0x2a35,0x2a36,0x2a37,
  0x2a38,0x2a39,0x2a3a,0x2a3b, 0x2a3c,0x2a3d,0x2a3e,0x2a3f,
  0x2a40,0x2a41,0x2a42,0x2a43, 0x2a44,0x2a45,0x2a46,0x2a47,
  0x2a48,0x2a49,0x2a4a,0x2a4b, 0x2a4c,0x2a4d,0x2a4e,0x2a4f,
  0x2a50,0x2a51,0x2a52,0x2a53,
/* 0xba81(i:10260) */
  0x2a54,0x2a55,0x2a56,0x2a57, 0x2a58,0x2a59,0x2a5a,0x2a5b,
  0x2a5c,0x2a5d,0x2a5e,0x2a5f, 0x2a60,0x2a61,0x2a62,0x2a63,
  0x2a64,0x2a65,0x2a66,0x2a67, 0x2a68,0x2a69,0x2a6a,0x2a6b,
  0x2a6c,0x2a6d,0x2a6e,0x2a6f, 0x2a70,0x2a71,0x2a72,0x2a73,
  0x2a74,0x2a75,0x2a76,0x2a77, 0x2a78,0x2a79,0x2a7a,0x2a7b,
  0x2a7c,0x2a7d,0x2a7e,0x2a7f, 0x2a80,0x2a81,0x2a82,0x2a83,
  0x2a84,0x2a85,0x2a86,0x2a87, 0x2a88,0x2a89,0x2a8a,0x2a8b,
  0x2a8c,0x2a8d,0x2a8e,0x2a8f, 0x2a90,0x2a91,0x2a92,0x2a93,
  0x2a94,0x2a95,0x2a96,0x2a97, 0x2a98,0x2a99,0x2a9a,0x2a9b,
  0x2a9c,0x2a9d,0x2a9e,0x2a9f, 0x2aa0,0x2aa1,0x2aa2,0x2aa3,
  0x2aa4,0x2aa5,0x2aa6,0x2aa7, 0x2aa8,0x2aa9,0x2aaa,0x2aab,
  0x2aac,0x2aad,0x2aae,0x2aaf, 0x2ab0,0x2ab1,0x2ab2,0x2ab3,
  0x2ab4,0x2ab5,0x2ab6,0x2ab7, 0x2ab8,0x2ab9,0x2aba,0x2abb,
  0x2abc,0x2abd,0x2abe,0x2abf, 0x2ac0,0x2ac1,0x2ac2,0x2ac3,
  0x2ac4,0x2ac5,0x2ac6,0x2ac7, 0x2ac8,0x2ac9,0x2aca,0x2acb,
  0x2acc,0x2acd,0x2ace,0x2acf, 0x2ad0,0x2ad1,0x2ad2,0x2ad3,
  0x2ad4,0x2ad5,0x2ad6,0x2ad7, 0x2ad8,0x2ad9,0x2ada,0x2adb,
  0x2adc,0x2add,0x2ade,0x2adf, 0x2ae0,0x2ae1,0x2ae2,0x2ae3,
  0x2ae4,0x2ae5,0x2ae6,0x2ae7, 0x2ae8,0x2ae9,0x2aea,0x2aeb,
  0x2aec,0x2aed,0x2aee,0x2aef, 0x2af0,0x2af1,0x2af2,0x2af3,
  0x2af4,0x2af5,0x2af6,0x2af7, 0x2af8,0x2af9,0x2afa,0x2afb,
  0x2afc,0x2afd,0x2afe,0x2aff, 0x2b00,0x2b01,0x2b02,0x2b03,
  0x2b04,0x2b05,0x2b06,0x2b07,
/* 0xbb81(i:10440) */
  0x2b08,0x2b09,0x2b0a,0x2b0b, 0x2b0c,0x2b0d,0x2b0e,0x2b0f,
  0x2b10,0x2b11,0x2b12,0x2b13, 0x2b14,0x2b15,0x2b16,0x2b17,
  0x2b18,0x2b19,0x2b1a,0x2b1b, 0x2b1c,0x2b1d,0x2b1e,0x2b1f,
  0x2b20,0x2b21,0x2b22,0x2b23, 0x2b24,0x2b25,0x2b26,0x2b27,
  0x2b28,0x2b29,0x2b2a,0x2b2b, 0x2b2c,0x2b2d,0x2b2e,0x2b2f,
  0x2b30,0x2b31,0x2b32,0x2b33, 0x2b34,0x2b35,0x2b36,0x2b37,
  0x2b38,0x2b39,0x2b3a,0x2b3b, 0x2b3c,0x2b3d,0x2b3e,0x2b3f,
  0x2b40,0x2b41,0x2b42,0x2b43, 0x2b44,0x2b45,0x2b46,0x2b47,
  0x2b48,0x2b49,0x2b4a,0x2b4b, 0x2b4c,0x2b4d,0x2b4e,0x2b4f,
  0x2b50,0x2b51,0x2b52,0x2b53, 0x2b54,0x2b55,0x2b56,0x2b57,
  0x2b58,0x2b59,0x2b5a,0x2b5b, 0x2b5c,0x2b5d,0x2b5e,0x2b5f,
  0x2b60,0x2b61,0x2b62,0x2b63, 0x2b64,0x2b65,0x2b66,0x2b67,
  0x2b68,0x2b69,0x2b6a,0x2b6b, 0x2b6c,0x2b6d,0x2b6e,0x2b6f,
  0x2b70,0x2b71,0x2b72,0x2b73, 0x2b74,0x2b75,0x2b76,0x2b77,
  0x2b78,0x2b79,0x2b7a,0x2b7b, 0x2b7c,0x2b7d,0x2b7e,0x2b7f,
  0x2b80,0x2b81,0x2b82,0x2b83, 0x2b84,0x2b85,0x2b86,0x2b87,
  0x2b88,0x2b89,0x2b8a,0x2b8b, 0x2b8c,0x2b8d,0x2b8e,0x2b8f,
  0x2b90,0x2b91,0x2b92,0x2b93, 0x2b94,0x2b95,0x2b96,0x2b97,
  0x2b98,0x2b99,0x2b9a,0x2b9b, 0x2b9c,0x2b9d,0x2b9e,0x2b9f,
  0x2ba0,0x2ba1,0x2ba2,0x2ba3, 0x2ba4,0x2ba5,0x2ba6,0x2ba7,
  0x2ba8,0x2ba9,0x2baa,0x2bab, 0x2bac,0x2bad,0x2bae,0x2baf,
  0x2bb0,0x2bb1,0x2bb2,0x2bb3, 0x2bb4,0x2bb5,0x2bb6,0x2bb7,
  0x2bb8,0x2bb9,0x2bba,0x2bbb,
/* 0xbc81(i:10620) */
  0x2bbc,0x2bbd,0x2bbe,0x2bbf, 0x2bc0,0x2bc1,0x2bc2,0x2bc3,
  0x2bc4,0x2bc5,0x2bc6,0x2bc7, 0x2bc8,0x2bc9,0x2bca,0x2bcb,
  0x2bcc,0x2bcd,0x2bce,0x2bcf, 0x2bd0,0x2bd1,0x2bd2,0x2bd3,
  0x2bd4,0x2bd5,0x2bd6,0x2bd7, 0x2bd8,0x2bd9,0x2bda,0x2bdb,
  0x2bdc,0x2bdd,0x2bde,0x2bdf, 0x2be0,0x2be1,0x2be2,0x2be3,
  0x2be4,0x2be5,0x2be6,0x2be7, 0x2be8,0x2be9,0x2bea,0x2beb,
  0x2bec,0x2bed,0x2bee,0x2bef, 0x2bf0,0x2bf1,0x2bf2,0x2bf3,
  0x2bf4,0x2bf5,0x2bf6,0x2bf7, 0x2bf8,0x2bf9,0x2bfa,0x2bfb,
  0x2bfc,0x2bfd,0x2bfe,0x2bff, 0x2c00,0x2c01,0x2c02,0x2c03,
  0x2c04,0x2c05,0x2c06,0x2c07, 0x2c08,0x2c09,0x2c0a,0x2c0b,
  0x2c0c,0x2c0d,0x2c0e,0x2c0f, 0x2c10,0x2c11,0x2c12,0x2c13,
  0x2c14,0x2c15,0x2c16,0x2c17, 0x2c18,0x2c19,0x2c1a,0x2c1b,
  0x2c1c,0x2c1d,0x2c1e,0x2c1f, 0x2c20,0x2c21,0x2c22,0x2c23,
  0x2c24,0x2c25,0x2c26,0x2c27, 0x2c28,0x2c29,0x2c2a,0x2c2b,
  0x2c2c,0x2c2d,0x2c2e,0x2c2f, 0x2c30,0x2c31,0x2c32,0x2c33,
  0x2c34,0x2c35,0x2c36,0x2c37, 0x2c38,0x2c39,0x2c3a,0x2c3b,
  0x2c3c,0x2c3d,0x2c3e,0x2c3f, 0x2c40,0x2c41,0x2c42,0x2c43,
  0x2c44,0x2c45,0x2c46,0x2c47, 0x2c48,0x2c49,0x2c4a,0x2c4b,
  0x2c4c,0x2c4d,0x2c4e,0x2c4f, 0x2c50,0x2c51,0x2c52,0x2c53,
  0x2c54,0x2c55,0x2c56,0x2c57, 0x2c58,0x2c59,0x2c5a,0x2c5b,
  0x2c5c,0x2c5d,0x2c5e,0x2c5f, 0x2c60,0x2c61,0x2c62,0x2c63,
  0x2c64,0x2c65,0x2c66,0x2c67, 0x2c68,0x2c69,0x2c6a,0x2c6b,
  0x2c6c,0x2c6d,0x2c6e,0x2c6f,
/* 0xbd81(i:10800) */
  0x2c70,0x2c71,0x2c72,0x2c73, 0x2c74,0x2c75,0x2c76,0x2c77,
  0x2c78,0x2c79,0x2c7a,0x2c7b, 0x2c7c,0x2c7d,0x2c7e,0x2c7f,
  0x2c80,0x2c81,0x2c82,0x2c83, 0x2c84,0x2c85,0x2c86,0x2c87,
  0x2c88,0x2c89,0x2c8a,0x2c8b, 0x2c8c,0x2c8d,0x2c8e,0x2c8f,
  0x2c90,0x2c91,0x2c92,0x2c93, 0x2c94,0x2c95,0x2c96,0x2c97,
  0x2c98,0x2c99,0x2c9a,0x2c9b, 0x2c9c,0x2c9d,0x2c9e,0x2c9f,
  0x2ca0,0x2ca1,0x2ca2,0x2ca3, 0x2ca4,0x2ca5,0x2ca6,0x2ca7,
  0x2ca8,0x2ca9,0x2caa,0x2cab, 0x2cac,0x2cad,0x2cae,0x2caf,
  0x2cb0,0x2cb1,0x2cb2,0x2cb3, 0x2cb4,0x2cb5,0x2cb6,0x2cb7,
  0x2cb8,0x2cb9,0x2cba,0x2cbb, 0x2cbc,0x2cbd,0x2cbe,0x2cbf,
  0x2cc0,0x2cc1,0x2cc2,0x2cc3, 0x2cc4,0x2cc5,0x2cc6,0x2cc7,
  0x2cc8,0x2cc9,0x2cca,0x2ccb, 0x2ccc,0x2ccd,0x2cce,0x2ccf,
  0x2cd0,0x2cd1,0x2cd2,0x2cd3, 0x2cd4,0x2cd5,0x2cd6,0x2cd7,
  0x2cd8,0x2cd9,0x2cda,0x2cdb, 0x2cdc,0x2cdd,0x2cde,0x2cdf,
  0x2ce0,0x2ce1,0x2ce2,0x2ce3, 0x2ce4,0x2ce5,0x2ce6,0x2ce7,
  0x2ce8,0x2ce9,0x2cea,0x2ceb, 0x2cec,0x2ced,0x2cee,0x2cef,
  0x2cf0,0x2cf1,0x2cf2,0x2cf3, 0x2cf4,0x2cf5,0x2cf6,0x2cf7,
  0x2cf8,0x2cf9,0x2cfa,0x2cfb, 0x2cfc,0x2cfd,0x2cfe,0x2cff,
  0x2d00,0x2d01,0x2d02,0x2d03, 0x2d04,0x2d05,0x2d06,0x2d07,
  0x2d08,0x2d09,0x2d0a,0x2d0b, 0x2d0c,0x2d0d,0x2d0e,0x2d0f,
  0x2d10,0x2d11,0x2d12,0x2d13, 0x2d14,0x2d15,0x2d16,0x2d17,
  0x2d18,0x2d19,0x2d1a,0x2d1b, 0x2d1c,0x2d1d,0x2d1e,0x2d1f,
  0x2d20,0x2d21,0x2d22,0x2d23,
/* 0xbe81(i:10980) */
  0x2d24,0x2d25,0x2d26,0x2d27, 0x2d28,0x2d29,0x2d2a,0x2d2b,
  0x2d2c,0x2d2d,0x2d2e,0x2d2f, 0x2d30,0x2d31,0x2d32,0x2d33,
  0x2d34,0x2d35,0x2d36,0x2d37, 0x2d38,0x2d39,0x2d3a,0x2d3b,
  0x2d3c,0x2d3d,0x2d3e,0x2d3f, 0x2d40,0x2d41,0x2d42,0x2d43,
  0x2d44,0x2d45,0x2d46,0x2d47, 0x2d48,0x2d49,0x2d4a,0x2d4b,
  0x2d4c,0x2d4d,0x2d4e,0x2d4f, 0x2d50,0x2d51,0x2d52,0x2d53,
  0x2d54,0x2d55,0x2d56,0x2d57, 0x2d58,0x2d59,0x2d5a,0x2d5b,
  0x2d5c,0x2d5d,0x2d5e,0x2d5f, 0x2d60,0x2d61,0x2d62,0x2d63,
  0x2d64,0x2d65,0x2d66,0x2d67, 0x2d68,0x2d69,0x2d6a,0x2d6b,
  0x2d6c,0x2d6d,0x2d6e,0x2d6f, 0x2d70,0x2d71,0x2d72,0x2d73,
  0x2d74,0x2d75,0x2d76,0x2d77, 0x2d78,0x2d79,0x2d7a,0x2d7b,
  0x2d7c,0x2d7d,0x2d7e,0x2d7f, 0x2d80,0x2d81,0x2d82,0x2d83,
  0x2d84,0x2d85,0x2d86,0x2d87, 0x2d88,0x2d89,0x2d8a,0x2d8b,
  0x2d8c,0x2d8d,0x2d8e,0x2d8f, 0x2d90,0x2d91,0x2d92,0x2d93,
  0x2d94,0x2d95,0x2d96,0x2d97, 0x2d98,0x2d99,0x2d9a,0x2d9b,
  0x2d9c,0x2d9d,0x2d9e,0x2d9f, 0x2da0,0x2da1,0x2da2,0x2da3,
  0x2da4,0x2da5,0x2da6,0x2da7, 0x2da8,0x2da9,0x2daa,0x2dab,
  0x2dac,0x2dad,0x2dae,0x2daf, 0x2db0,0x2db1,0x2db2,0x2db3,
  0x2db4,0x2db5,0x2db6,0x2db7, 0x2db8,0x2db9,0x2dba,0x2dbb,
  0x2dbc,0x2dbd,0x2dbe,0x2dbf, 0x2dc0,0x2dc1,0x2dc2,0x2dc3,
  0x2dc4,0x2dc5,0x2dc6,0x2dc7, 0x2dc8,0x2dc9,0x2dca,0x2dcb,
  0x2dcc,0x2dcd,0x2dce,0x2dcf, 0x2dd0,0x2dd1,0x2dd2,0x2dd3,
  0x2dd4,0x2dd5,0x2dd6,0x2dd7,
/* 0xbf81(i:11160) */
  0x2dd8,0x2dd9,0x2dda,0x2ddb, 0x2ddc,0x2ddd,0x2dde,0x2ddf,
  0x2de0,0x2de1,0x2de2,0x2de3, 0x2de4,0x2de5,0x2de6,0x2de7,
  0x2de8,0x2de9,0x2dea,0x2deb, 0x2dec,0x2ded,0x2dee,0x2def,
  0x2df0,0x2df1,0x2df2,0x2df3, 0x2df4,0x2df5,0x2df6,0x2df7,
  0x2df8,0x2df9,0x2dfa,0x2dfb, 0x2dfc,0x2dfd,0x2dfe,0x2dff,
  0x2e00,0x2e01,0x2e02,0x2e03, 0x2e04,0x2e05,0x2e06,0x2e07,
  0x2e08,0x2e09,0x2e0a,0x2e0b, 0x2e0c,0x2e0d,0x2e0e,0x2e0f,
  0x2e10,0x2e11,0x2e12,0x2e13, 0x2e14,0x2e15,0x2e16,0x2e17,
  0x2e18,0x2e19,0x2e1a,0x2e1b, 0x2e1c,0x2e1d,0x2e1e,0x2e1f,
  0x2e20,0x2e21,0x2e22,0x2e23, 0x2e24,0x2e25,0x2e26,0x2e27,
  0x2e28,0x2e29,0x2e2a,0x2e2b, 0x2e2c,0x2e2d,0x2e2e,0x2e2f,
  0x2e30,0x2e31,0x2e32,0x2e33, 0x2e34,0x2e35,0x2e36,0x2e37,
  0x2e38,0x2e39,0x2e3a,0x2e3b, 0x2e3c,0x2e3d,0x2e3e,0x2e3f,
  0x2e40,0x2e41,0x2e42,0x2e43, 0x2e44,0x2e45,0x2e46,0x2e47,
  0x2e48,0x2e49,0x2e4a,0x2e4b, 0x2e4c,0x2e4d,0x2e4e,0x2e4f,
  0x2e50,0x2e51,0x2e52,0x2e53, 0x2e54,0x2e55,0x2e56,0x2e57,
  0x2e58,0x2e59,0x2e5a,0x2e5b, 0x2e5c,0x2e5d,0x2e5e,0x2e5f,
  0x2e60,0x2e61,0x2e62,0x2e63, 0x2e64,0x2e65,0x2e66,0x2e67,
  0x2e68,0x2e69,0x2e6a,0x2e6b, 0x2e6c,0x2e6d,0x2e6e,0x2e6f,
  0x2e70,0x2e71,0x2e72,0x2e73, 0x2e74,0x2e75,0x2e76,0x2e77,
  0x2e78,0x2e79,0x2e7a,0x2e7b, 0x2e7c,0x2e7d,0x2e7e,0x2e7f,
  0x2e80,0x2e82,0x2e83,0x2e85, 0x2e86,0x2e87,0x2e89,0x2e8a,
  0x2e8d,0x2e8e,0x2e8f,0x2e90, 
/* 0xc081(i:11340) */
  0x2e91,0x2e92,0x2e93,0x2e94, 0x2e95,0x2e96,0x2e98,0x2e99,
  0x2e9a,0x2e9b,0x2e9c,0x2e9d, 0x2e9e,0x2e9f,0x2ea0,0x2ea1,
  0x2ea2,0x2ea3,0x2ea4,0x2ea5, 0x2ea6,0x2ea8,0x2ea9,0x2eab,
  0x2eac,0x2ead,0x2eaf,0x2eb0, 0x2eb1,0x2eb2,0x2eb4,0x2eb5,
  0x2eb8,0x2eb9,0x2eba,0x2ebc, 0x2ebd,0x2ebe,0x2ebf,0x2ec0,
  0x2ec1,0x2ec2,0x2ec3,0x2ec4, 0x2ec5,0x2ec6,0x2ec7,0x2ec8,
  0x2ec9,0x2ecb,0x2ecc,0x2ecd, 0x2ece,0x2ecf,0x2ed0,0x2ed1,
  0x2ed2,0x2ed3,0x2ed4,0x2ed5, 0x2ed6,0x2ed7,0x2ed8,0x2ed9,
  0x2eda,0x2edb,0x2edc,0x2edd, 0x2ede,0x2edf,0x2ee0,0x2ee1,
  0x2ee2,0x2ee3,0x2ee4,0x2ee5, 0x2ee6,0x2ee7,0x2ee8,0x2ee9,
  0x2eea,0x2eeb,0x2eec,0x2eed, 0x2eee,0x2eef,0x2ef0,0x2ef1,
  0x2ef2,0x2ef3,0x2ef4,0x2ef5, 0x2ef6,0x2ef7,0x2ef8,0x2ef9,
  0x2efa,0x2efb,0x2efc,0x2efd, 0x2efe,0x2eff,0x2f00,0x2f01,
  0x2f02,0x2f03,0x2f04,0x2f05, 0x2f06,0x2f07,0x2f08,0x2f09,
  0x2f0a,0x2f0b,0x2f0c,0x2f0d, 0x2f0e,0x2f0f,0x2f10,0x2f11,
  0x2f12,0x2f13,0x2f14,0x2f15, 0x2f16,0x2f17,0x2f18,0x2f19,
  0x2f1a,0x2f1b,0x2f1c,0x2f1d, 0x2f1e,0x2f1f,0x2f20,0x2f21,
  0x2f22,0x2f23,0x2f24,0x2f25, 0x2f26,0x2f27,0x2f28,0x2f29,
  0x2f2a,0x2f2b,0x2f2c,0x2f2d, 0x2f2e,0x2f2f,0x2f30,0x2f31,
  0x2f32,0x2f33,0x2f34,0x2f35, 0x2f36,0x2f37,0x2f38,0x2f39,
  0x2f3a,0x2f3b,0x2f3c,0x2f3d, 0x2f3e,0x2f3f,0x2f40,0x2f41,
  0x2f42,0x2f43,0x2f44,0x2f45, 0x2f46,0x2f47,0x2f48,0x2f49,
  0x2f4a,0x2f4b,0x2f4c,0x2f4d, 
/* 0xc181(i:11520) */
  0x2f4e,0x2f4f,0x2f50,0x2f51, 0x2f52,0x2f53,0x2f54,0x2f55,
  0x2f56,0x2f57,0x2f58,0x2f59, 0x2f5a,0x2f5b,0x2f5c,0x2f5d,
  0x2f5e,0x2f5f,0x2f60,0x2f61, 0x2f62,0x2f63,0x2f64,0x2f65,
  0x2f66,0x2f67,0x2f68,0x2f69, 0x2f6a,0x2f6b,0x2f6c,0x2f6d,
  0x2f6e,0x2f6f,0x2f70,0x2f71, 0x2f72,0x2f73,0x2f74,0x2f75,
  0x2f76,0x2f77,0x2f78,0x2f79, 0x2f7a,0x2f7b,0x2f7c,0x2f7d,
  0x2f7e,0x2f7f,0x2f80,0x2f81, 0x2f82,0x2f83,0x2f84,0x2f85,
  0x2f86,0x2f87,0x2f88,0x2f89, 0x2f8a,0x2f8b,0x2f8c,0x2f8d,
  0x2f8e,0x2f8f,0x2f90,0x2f91, 0x2f92,0x2f93,0x2f94,0x2f95,
  0x2f96,0x2f97,0x2f98,0x2f99, 0x2f9a,0x2f9b,0x2f9c,0x2f9d,
  0x2f9e,0x2f9f,0x2fa0,0x2fa1, 0x2fa2,0x2fa3,0x2fa4,0x2fa5,
  0x2fa6,0x2fa7,0x2fa8,0x2fa9, 0x2faa,0x2fab,0x2fac,0x2fad,
  0x2fae,0x2faf,0x2fb0,0x2fb1, 0x2fb2,0x2fb3,0x2fb4,0x2fb5,
  0x2fb6,0x2fb7,0x2fb8,0x2fb9, 0x2fba,0x2fbb,0x2fbc,0x2fbd,
  0x2fbe,0x2fbf,0x2fc0,0x2fc1, 0x2fc2,0x2fc3,0x2fc4,0x2fc5,
  0x2fc6,0x2fc7,0x2fc8,0x2fc9, 0x2fca,0x2fcb,0x2fcc,0x2fcd,
  0x2fce,0x2fcf,0x2fd0,0x2fd1, 0x2fd2,0x2fd3,0x2fd4,0x2fd5,
  0x2fd6,0x2fd7,0x2fd8,0x2fd9, 0x2fda,0x2fdb,0x2fdc,0x2fdd,
  0x2fde,0x2fdf,0x2fe0,0x2fe1, 0x2fe2,0x2fe3,0x2fe4,0x2fe5,
  0x2fe6,0x2fe7,0x2fe8,0x2fe9, 0x2fea,0x2feb,0x2fec,0x2fed,
  0x2fee,0x2fef,0x2ffc,0x2ffd, 0x2ffe,0x2fff,0x3004,0x3018,
  0x3019,0x301a,0x301b,0x301c, 0x301f,0x3020,0x302a,0x302b,
  0x302c,0x302d,0x302e,0x302f, 
/* 0xc281(i:11700) */
  0x3030,0x3031,0x3032,0x3033, 0x3034,0x3035,0x3036,0x3037,
  0x3038,0x3039,0x303a,0x303b, 0x303c,0x303d,0x303f,0x3040,
  0x3094,0x3095,0x3096,0x3097, 0x3098,0x3099,0x309a,0x309f,
  0x30a0,0x30f7,0x30f8,0x30f9, 0x30fa,0x30fb,0x30ff,0x3100,
  0x3101,0x3102,0x3103,0x3104, 0x312a,0x312b,0x312c,0x312d,
  0x312e,0x312f,0x3130,0x3131, 0x3132,0x3133,0x3134,0x3135,
  0x3136,0x3137,0x3138,0x3139, 0x313a,0x313b,0x313c,0x313d,
  0x313e,0x313f,0x3140,0x3141, 0x3142,0x3143,0x3144,0x3145,
  0x3146,0x3147,0x3148,0x3149, 0x314a,0x314b,0x314c,0x314d,
  0x314e,0x314f,0x3150,0x3151, 0x3152,0x3153,0x3154,0x3155,
  0x3156,0x3157,0x3158,0x3159, 0x315a,0x315b,0x315c,0x315d,
  0x315e,0x315f,0x3160,0x3161, 0x3162,0x3163,0x3164,0x3165,
  0x3166,0x3167,0x3168,0x3169, 0x316a,0x316b,0x316c,0x316d,
  0x316e,0x316f,0x3170,0x3171, 0x3172,0x3173,0x3174,0x3175,
  0x3176,0x3177,0x3178,0x3179, 0x317a,0x317b,0x317c,0x317d,
  0x317e,0x317f,0x3180,0x3181, 0x3182,0x3183,0x3184,0x3185,
  0x3186,0x3187,0x3188,0x3189, 0x318a,0x318b,0x318c,0x318d,
  0x318e,0x318f,0x3190,0x3191, 0x3192,0x3193,0x3194,0x3195,
  0x3196,0x3197,0x3198,0x3199, 0x319a,0x319b,0x319c,0x319d,
  0x319e,0x319f,0x31a0,0x31a1, 0x31a2,0x31a3,0x31a4,0x31a5,
  0x31a6,0x31a7,0x31a8,0x31a9, 0x31aa,0x31ab,0x31ac,0x31ad,
  0x31ae,0x31af,0x31b0,0x31b1, 0x31b2,0x31b3,0x31b4,0x31b5,
  0x31b6,0x31b7,0x31b8,0x31b9, 
/* 0xc381(i:11880) */
  0x31ba,0x31bb,0x31bc,0x31bd, 0x31be,0x31bf,0x31c0,0x31c1,
  0x31c2,0x31c3,0x31c4,0x31c5, 0x31c6,0x31c7,0x31c8,0x31c9,
  0x31ca,0x31cb,0x31cc,0x31cd, 0x31ce,0x31cf,0x31d0,0x31d1,
  0x31d2,0x31d3,0x31d4,0x31d5, 0x31d6,0x31d7,0x31d8,0x31d9,
  0x31da,0x31db,0x31dc,0x31dd, 0x31de,0x31df,0x31e0,0x31e1,
  0x31e2,0x31e3,0x31e4,0x31e5, 0x31e6,0x31e7,0x31e8,0x31e9,
  0x31ea,0x31eb,0x31ec,0x31ed, 0x31ee,0x31ef,0x31f0,0x31f1,
  0x31f2,0x31f3,0x31f4,0x31f5, 0x31f6,0x31f7,0x31f8,0x31f9,
  0x31fa,0x31fb,0x31fc,0x31fd, 0x31fe,0x31ff,0x3200,0x3201,
  0x3202,0x3203,0x3204,0x3205, 0x3206,0x3207,0x3208,0x3209,
  0x320a,0x320b,0x320c,0x320d, 0x320e,0x320f,0x3210,0x3211,
  0x3212,0x3213,0x3214,0x3215, 0x3216,0x3217,0x3218,0x3219,
  0x321a,0x321b,0x321c,0x321d, 0x321e,0x321f,0x322a,0x322b,
  0x322c,0x322d,0x322e,0x322f, 0x3230,0x3232,0x3233,0x3234,
  0x3235,0x3236,0x3237,0x3238, 0x3239,0x323a,0x323b,0x323c,
  0x323d,0x323e,0x323f,0x3240, 0x3241,0x3242,0x3243,0x3244,
  0x3245,0x3246,0x3247,0x3248, 0x3249,0x324a,0x324b,0x324c,
  0x324d,0x324e,0x324f,0x3250, 0x3251,0x3252,0x3253,0x3254,
  0x3255,0x3256,0x3257,0x3258, 0x3259,0x325a,0x325b,0x325c,
  0x325d,0x325e,0x325f,0x3260, 0x3261,0x3262,0x3263,0x3264,
  0x3265,0x3266,0x3267,0x3268, 0x3269,0x326a,0x326b,0x326c,
  0x326d,0x326e,0x326f,0x3270, 0x3271,0x3272,0x3273,0x3274,
  0x3275,0x3276,0x3277,0x3278, 
/* 0xc481(i:12060) */
  0x3279,0x327a,0x327b,0x327c, 0x327d,0x327e,0x327f,0x3280,
  0x3281,0x3282,0x3283,0x3284, 0x3285,0x3286,0x3287,0x3288,
  0x3289,0x328a,0x328b,0x328c, 0x328d,0x328e,0x328f,0x3290,
  0x3291,0x3292,0x3293,0x3294, 0x3295,0x3296,0x3297,0x3298,
  0x3299,0x329a,0x329b,0x329c, 0x329d,0x329e,0x329f,0x32a0,
  0x32a1,0x32a2,0x32a4,0x32a5, 0x32a6,0x32a7,0x32a8,0x32a9,
  0x32aa,0x32ab,0x32ac,0x32ad, 0x32ae,0x32af,0x32b0,0x32b1,
  0x32b2,0x32b3,0x32b4,0x32b5, 0x32b6,0x32b7,0x32b8,0x32b9,
  0x32ba,0x32bb,0x32bc,0x32bd, 0x32be,0x32bf,0x32c0,0x32c1,
  0x32c2,0x32c3,0x32c4,0x32c5, 0x32c6,0x32c7,0x32c8,0x32c9,
  0x32ca,0x32cb,0x32cc,0x32cd, 0x32ce,0x32cf,0x32d0,0x32d1,
  0x32d2,0x32d3,0x32d4,0x32d5, 0x32d6,0x32d7,0x32d8,0x32d9,
  0x32da,0x32db,0x32dc,0x32dd, 0x32de,0x32df,0x32e0,0x32e1,
  0x32e2,0x32e3,0x32e4,0x32e5, 0x32e6,0x32e7,0x32e8,0x32e9,
  0x32ea,0x32eb,0x32ec,0x32ed, 0x32ee,0x32ef,0x32f0,0x32f1,
  0x32f2,0x32f3,0x32f4,0x32f5, 0x32f6,0x32f7,0x32f8,0x32f9,
  0x32fa,0x32fb,0x32fc,0x32fd, 0x32fe,0x32ff,0x3300,0x3301,
  0x3302,0x3303,0x3304,0x3305, 0x3306,0x3307,0x3308,0x3309,
  0x330a,0x330b,0x330c,0x330d, 0x330e,0x330f,0x3310,0x3311,
  0x3312,0x3313,0x3314,0x3315, 0x3316,0x3317,0x3318,0x3319,
  0x331a,0x331b,0x331c,0x331d, 0x331e,0x331f,0x3320,0x3321,
  0x3322,0x3323,0x3324,0x3325, 0x3326,0x3327,0x3328,0x3329,
  0x332a,0x332b,0x332c,0x332d, 
/* 0xc581(i:12240) */
  0x332e,0x332f,0x3330,0x3331, 0x3332,0x3333,0x3334,0x3335,
  0x3336,0x3337,0x3338,0x3339, 0x333a,0x333b,0x333c,0x333d,
  0x333e,0x333f,0x3340,0x3341, 0x3342,0x3343,0x3344,0x3345,
  0x3346,0x3347,0x3348,0x3349, 0x334a,0x334b,0x334c,0x334d,
  0x334e,0x334f,0x3350,0x3351, 0x3352,0x3353,0x3354,0x3355,
  0x3356,0x3357,0x3358,0x3359, 0x335a,0x335b,0x335c,0x335d,
  0x335e,0x335f,0x3360,0x3361, 0x3362,0x3363,0x3364,0x3365,
  0x3366,0x3367,0x3368,0x3369, 0x336a,0x336b,0x336c,0x336d,
  0x336e,0x336f,0x3370,0x3371, 0x3372,0x3373,0x3374,0x3375,
  0x3376,0x3377,0x3378,0x3379, 0x337a,0x337b,0x337c,0x337d,
  0x337e,0x337f,0x3380,0x3381, 0x3382,0x3383,0x3384,0x3385,
  0x3386,0x3387,0x3388,0x3389, 0x338a,0x338b,0x338c,0x338d,
  0x3390,0x3391,0x3392,0x3393, 0x3394,0x3395,0x3396,0x3397,
  0x3398,0x3399,0x339a,0x339b, 0x339f,0x33a0,0x33a2,0x33a3,
  0x33a4,0x33a5,0x33a6,0x33a7, 0x33a8,0x33a9,0x33aa,0x33ab,
  0x33ac,0x33ad,0x33ae,0x33af, 0x33b0,0x33b1,0x33b2,0x33b3,
  0x33b4,0x33b5,0x33b6,0x33b7, 0x33b8,0x33b9,0x33ba,0x33bb,
  0x33bc,0x33bd,0x33be,0x33bf, 0x33c0,0x33c1,0x33c2,0x33c3,
  0x33c5,0x33c6,0x33c7,0x33c8, 0x33c9,0x33ca,0x33cb,0x33cc,
  0x33cd,0x33cf,0x33d0,0x33d3, 0x33d4,0x33d6,0x33d7,0x33d8,
  0x33d9,0x33da,0x33db,0x33dc, 0x33dd,0x33de,0x33df,0x33e0,
  0x33e1,0x33e2,0x33e3,0x33e4, 0x33e5,0x33e6,0x33e7,0x33e8,
  0x33e9,0x33ea,0x33eb,0x33ec, 
/* 0xc681(i:12420) */
  0x33ed,0x33ee,0x33ef,0x33f0, 0x33f1,0x33f2,0x33f3,0x33f4,
  0x33f5,0x33f6,0x33f7,0x33f8, 0x33f9,0x33fa,0x33fb,0x33fc,
  0x33fd,0x33fe,0x33ff,0x3400, 0x3401,0x3402,0x3403,0x3404,
  0x3405,0x3406,0x3407,0x3408, 0x3409,0x340a,0x340b,0x340c,
  0x340d,0x340e,0x340f,0x3410, 0x3411,0x3412,0x3413,0x3414,
  0x3415,0x3416,0x3417,0x3418, 0x3419,0x341a,0x341b,0x341c,
  0x341d,0x341e,0x341f,0x3420, 0x3421,0x3422,0x3423,0x3424,
  0x3425,0x3426,0x3427,0x3428, 0x3429,0x342a,0x342b,0x342c,
  0x342d,0x342e,0x342f,0x3430, 0x3431,0x3432,0x3433,0x3434,
  0x3435,0x3436,0x3437,0x3438, 0x3439,0x343a,0x343b,0x343c,
  0x343d,0x343e,0x343f,0x3440, 0x3441,0x3442,0x3443,0x3444,
  0x3445,0x3446,0x3448,0x3449, 0x344a,0x344b,0x344c,0x344d,
  0x344e,0x344f,0x3450,0x3451, 0x3452,0x3453,0x3454,0x3455,
  0x3456,0x3457,0x3458,0x3459, 0x345a,0x345b,0x345c,0x345d,
  0x345e,0x345f,0x3460,0x3461, 0x3462,0x3463,0x3464,0x3465,
  0x3466,0x3467,0x3468,0x3469, 0x346a,0x346b,0x346c,0x346d,
  0x346e,0x346f,0x3470,0x3471, 0x3472,0x3474,0x3475,0x3476,
  0x3477,0x3478,0x3479,0x347a, 0x347b,0x347c,0x347d,0x347e,
  0x347f,0x3480,0x3481,0x3482, 0x3483,0x3484,0x3485,0x3486,
  0x3487,0x3488,0x3489,0x348a, 0x348b,0x348c,0x348d,0x348e,
  0x348f,0x3490,0x3491,0x3492, 0x3493,0x3494,0x3495,0x3496,
  0x3497,0x3498,0x3499,0x349a, 0x349b,0x349c,0x349d,0x349e,
  0x349f,0x34a0,0x34a1,0x34a2, 
/* 0xc781(i:12600) */
  0x34a3,0x34a4,0x34a5,0x34a6, 0x34a7,0x34a8,0x34a9,0x34aa,
  0x34ab,0x34ac,0x34ad,0x34ae, 0x34af,0x34b0,0x34b1,0x34b2,
  0x34b3,0x34b4,0x34b5,0x34b6, 0x34b7,0x34b8,0x34b9,0x34ba,
  0x34bb,0x34bc,0x34bd,0x34be, 0x34bf,0x34c0,0x34c1,0x34c2,
  0x34c3,0x34c4,0x34c5,0x34c6, 0x34c7,0x34c8,0x34c9,0x34ca,
  0x34cb,0x34cc,0x34cd,0x34ce, 0x34cf,0x34d0,0x34d1,0x34d2,
  0x34d3,0x34d4,0x34d5,0x34d6, 0x34d7,0x34d8,0x34d9,0x34da,
  0x34db,0x34dc,0x34dd,0x34de, 0x34df,0x34e0,0x34e1,0x34e2,
  0x34e3,0x34e4,0x34e5,0x34e6, 0x34e7,0x34e8,0x34e9,0x34ea,
  0x34eb,0x34ec,0x34ed,0x34ee, 0x34ef,0x34f0,0x34f1,0x34f2,
  0x34f3,0x34f4,0x34f5,0x34f6, 0x34f7,0x34f8,0x34f9,0x34fa,
  0x34fb,0x34fc,0x34fd,0x34fe, 0x34ff,0x3500,0x3501,0x3502,
  0x3503,0x3504,0x3505,0x3506, 0x3507,0x3508,0x3509,0x350a,
  0x350b,0x350c,0x350d,0x350e, 0x350f,0x3510,0x3511,0x3512,
  0x3513,0x3514,0x3515,0x3516, 0x3517,0x3518,0x3519,0x351a,
  0x351b,0x351c,0x351d,0x351e, 0x351f,0x3520,0x3521,0x3522,
  0x3523,0x3524,0x3525,0x3526, 0x3527,0x3528,0x3529,0x352a,
  0x352b,0x352c,0x352d,0x352e, 0x352f,0x3530,0x3531,0x3532,
  0x3533,0x3534,0x3535,0x3536, 0x3537,0x3538,0x3539,0x353a,
  0x353b,0x353c,0x353d,0x353e, 0x353f,0x3540,0x3541,0x3542,
  0x3543,0x3544,0x3545,0x3546, 0x3547,0x3548,0x3549,0x354a,
  0x354b,0x354c,0x354d,0x354e, 0x354f,0x3550,0x3551,0x3552,
  0x3553,0x3554,0x3555,0x3556, 
/* 0xc881(i:12780) */
  0x3557,0x3558,0x3559,0x355a, 0x355b,0x355c,0x355d,0x355e,
  0x355f,0x3560,0x3561,0x3562, 0x3563,0x3564,0x3565,0x3566,
  0x3567,0x3568,0x3569,0x356a, 0x356b,0x356c,0x356d,0x356e,
  0x356f,0x3570,0x3571,0x3572, 0x3573,0x3574,0x3575,0x3576,
  0x3577,0x3578,0x3579,0x357a, 0x357b,0x357c,0x357d,0x357e,
  0x357f,0x3580,0x3581,0x3582, 0x3583,0x3584,0x3585,0x3586,
  0x3587,0x3588,0x3589,0x358a, 0x358b,0x358c,0x358d,0x358e,
  0x358f,0x3590,0x3591,0x3592, 0x3593,0x3594,0x3595,0x3596,
  0x3597,0x3598,0x3599,0x359a, 0x359b,0x359c,0x359d,0x359f,
  0x35a0,0x35a1,0x35a2,0x35a3, 0x35a4,0x35a5,0x35a6,0x35a7,
  0x35a8,0x35a9,0x35aa,0x35ab, 0x35ac,0x35ad,0x35ae,0x35af,
  0x35b0,0x35b1,0x35b2,0x35b3, 0x35b4,0x35b5,0x35b6,0x35b7,
  0x35b8,0x35b9,0x35ba,0x35bb, 0x35bc,0x35bd,0x35be,0x35bf,
  0x35c0,0x35c1,0x35c2,0x35c3, 0x35c4,0x35c5,0x35c6,0x35c7,
  0x35c8,0x35c9,0x35ca,0x35cb, 0x35cc,0x35cd,0x35ce,0x35cf,
  0x35d0,0x35d1,0x35d2,0x35d3, 0x35d4,0x35d5,0x35d6,0x35d7,
  0x35d8,0x35d9,0x35da,0x35db, 0x35dc,0x35dd,0x35de,0x35df,
  0x35e0,0x35e1,0x35e2,0x35e3, 0x35e4,0x35e5,0x35e6,0x35e7,
  0x35e8,0x35e9,0x35ea,0x35eb, 0x35ec,0x35ed,0x35ee,0x35ef,
  0x35f0,0x35f1,0x35f2,0x35f3, 0x35f4,0x35f5,0x35f6,0x35f7,
  0x35f8,0x35f9,0x35fa,0x35fb, 0x35fc,0x35fd,0x35fe,0x35ff,
  0x3600,0x3601,0x3602,0x3603, 0x3604,0x3605,0x3606,0x3607,
  0x3608,0x3609,0x360a,0x360b, 
/* 0xc981(i:12960) */
  0x360c,0x360d,0x360f,0x3610, 0x3611,0x3612,0x3613,0x3614,
  0x3615,0x3616,0x3617,0x3618, 0x3619,0x361b,0x361c,0x361d,
  0x361e,0x361f,0x3620,0x3621,0x3622,0x3623, 0x3624,0x3625,
  0x3626,0x3627,0x3628,0x3629,0x362a,0x362b, 0x362c,0x362d,
  0x362e,0x362f,0x3630,0x3631,0x3632,0x3633, 0x3634,0x3635,
  0x3636,0x3637,0x3638,0x3639,0x363a,0x363b, 0x363c,0x363d,
  0x363e,0x363f,0x3640,0x3641,0x3642,0x3643, 0x3644,0x3645,
  0x3646,0x3647,0x3648,0x3649,0x364a,0x364b, 0x364c,0x364d,
  0x364e,0x364f,0x3650,0x3651,0x3652,0x3653, 0x3654,0x3655,
  0x3656,0x3657,0x3658,0x3659,0x365a,0x365b, 0x365c,0x365d,
  0x365e,0x365f,0x3660,0x3661,0x3662,0x3663, 0x3664,0x3665,
  0x3666,0x3667,0x3668,0x3669,0x366a,0x366b, 0x366c,0x366d,
  0x366e,0x366f,0x3670,0x3671,0x3672,0x3673, 0x3674,0x3675,
  0x3676,0x3677,0x3678,0x3679,0x367a,0x367b, 0x367c,0x367d,
  0x367e,0x367f,0x3680,0x3681,0x3682,0x3683, 0x3684,0x3685,
  0x3686,0x3687,0x3688,0x3689,0x368a,0x368b, 0x368c,0x368d,
  0x368e,0x368f,0x3690,0x3691,0x3692,0x3693, 0x3694,0x3695,
  0x3696,0x3697,0x3698,0x3699,0x369a,0x369b, 0x369c,0x369d,
  0x369e,0x369f,0x36a0,0x36a1,0x36a2,0x36a3, 0x36a4,0x36a5,
  0x36a6,0x36a7,0x36a8,0x36a9,0x36aa,0x36ab, 0x36ac,0x36ad,
  0x36ae,0x36af,0x36b0,0x36b1,0x36b2,0x36b3, 0x36b4,0x36b5,
  0x36b6,0x36b7,0x36b8,0x36b9,0x36ba,0x36bb, 0x36bc,0x36bd,
  0x36be,0x36bf,0x36c0,0x36c1,
/* 0xca81(i:13140) */
  0x36c2,0x36c3, 0x36c4,0x36c5,0x36c6,0x36c7,0x36c8,0x36c9,
  0x36ca,0x36cb, 0x36cc,0x36cd,0x36ce,0x36cf,0x36d0,0x36d1,
  0x36d2,0x36d3, 0x36d4,0x36d5,0x36d6,0x36d7,0x36d8,0x36d9,
  0x36da,0x36db, 0x36dc,0x36dd,0x36de,0x36df,0x36e0,0x36e1,
  0x36e2,0x36e3, 0x36e4,0x36e5,0x36e6,0x36e7,0x36e8,0x36e9,
  0x36ea,0x36eb, 0x36ec,0x36ed,0x36ee,0x36ef,0x36f0,0x36f1,
  0x36f2,0x36f3, 0x36f4,0x36f5,0x36f6,0x36f7,0x36f8,0x36f9,
  0x36fa,0x36fb, 0x36fc,0x36fd,0x36fe,0x36ff,0x3700,0x3701,
  0x3702,0x3703, 0x3704,0x3705,0x3706,0x3707,0x3708,0x3709,
  0x370a,0x370b, 0x370c,0x370d,0x370e,0x370f,0x3710,0x3711,
  0x3712,0x3713, 0x3714,0x3715,0x3716,0x3717,0x3718,0x3719,
  0x371a,0x371b, 0x371c,0x371d,0x371e,0x371f,0x3720,0x3721,
  0x3722,0x3723, 0x3724,0x3725,0x3726,0x3727,0x3728,0x3729,
  0x372a,0x372b, 0x372c,0x372d,0x372e,0x372f,0x3730,0x3731,
  0x3732,0x3733, 0x3734,0x3735,0x3736,0x3737,0x3738,0x3739,
  0x373a,0x373b, 0x373c,0x373d,0x373e,0x373f,0x3740,0x3741,
  0x3742,0x3743, 0x3744,0x3745,0x3746,0x3747,0x3748,0x3749,
  0x374a,0x374b, 0x374c,0x374d,0x374e,0x374f,0x3750,0x3751,
  0x3752,0x3753, 0x3754,0x3755,0x3756,0x3757,0x3758,0x3759,
  0x375a,0x375b, 0x375c,0x375d,0x375e,0x375f,0x3760,0x3761,
  0x3762,0x3763, 0x3764,0x3765,0x3766,0x3767,0x3768,0x3769,
  0x376a,0x376b, 0x376c,0x376d,0x376e,0x376f,0x3770,0x3771,
  0x3772,0x3773, 0x3774,0x3775,
/* 0xcb81(i:13320) */
  0x3776,0x3777,0x3778,0x3779,0x377a,0x377b, 0x377c,0x377d,
  0x377e,0x377f,0x3780,0x3781,0x3782,0x3783, 0x3784,0x3785,
  0x3786,0x3787,0x3788,0x3789,0x378a,0x378b, 0x378c,0x378d,
  0x378e,0x378f,0x3790,0x3791,0x3792,0x3793, 0x3794,0x3795,
  0x3796,0x3797,0x3798,0x3799,0x379a,0x379b, 0x379c,0x379d,
  0x379e,0x379f,0x37a0,0x37a1,0x37a2,0x37a3, 0x37a4,0x37a5,
  0x37a6,0x37a7,0x37a8,0x37a9,0x37aa,0x37ab, 0x37ac,0x37ad,
  0x37ae,0x37af,0x37b0,0x37b1,0x37b2,0x37b3, 0x37b4,0x37b5,
  0x37b6,0x37b7,0x37b8,0x37b9,0x37ba,0x37bb, 0x37bc,0x37bd,
  0x37be,0x37bf,0x37c0,0x37c1,0x37c2,0x37c3, 0x37c4,0x37c5,
  0x37c6,0x37c7,0x37c8,0x37c9,0x37ca,0x37cb, 0x37cc,0x37cd,
  0x37ce,0x37cf,0x37d0,0x37d1,0x37d2,0x37d3, 0x37d4,0x37d5,
  0x37d6,0x37d7,0x37d8,0x37d9,0x37da,0x37db, 0x37dc,0x37dd,
  0x37de,0x37df,0x37e0,0x37e1,0x37e2,0x37e3, 0x37e4,0x37e5,
  0x37e6,0x37e7,0x37e8,0x37e9,0x37ea,0x37eb, 0x37ec,0x37ed,
  0x37ee,0x37ef,0x37f0,0x37f1,0x37f2,0x37f3, 0x37f4,0x37f5,
  0x37f6,0x37f7,0x37f8,0x37f9,0x37fa,0x37fb, 0x37fc,0x37fd,
  0x37fe,0x37ff,0x3800,0x3801,0x3802,0x3803, 0x3804,0x3805,
  0x3806,0x3807,0x3808,0x3809,0x380a,0x380b, 0x380c,0x380d,
  0x380e,0x380f,0x3810,0x3811,0x3812,0x3813, 0x3814,0x3815,
  0x3816,0x3817,0x3818,0x3819,0x381a,0x381b, 0x381c,0x381d,
  0x381e,0x381f,0x3820,0x3821,0x3822,0x3823, 0x3824,0x3825,
  0x3826,0x3827,0x3828,0x3829, 
/* 0xcc81(i:13500) */
  0x382a,0x382b, 0x382c,0x382d,0x382e,0x382f,0x3830,0x3831,
  0x3832,0x3833, 0x3834,0x3835,0x3836,0x3837,0x3838,0x3839,
  0x383a,0x383b, 0x383c,0x383d,0x383e,0x383f,0x3840,0x3841,
  0x3842,0x3843, 0x3844,0x3845,0x3846,0x3847,0x3848,0x3849,
  0x384a,0x384b, 0x384c,0x384d,0x384e,0x384f,0x3850,0x3851,
  0x3852,0x3853, 0x3854,0x3855,0x3856,0x3857,0x3858,0x3859,
  0x385a,0x385b, 0x385c,0x385d,0x385e,0x385f,0x3860,0x3861,
  0x3862,0x3863, 0x3864,0x3865,0x3866,0x3867,0x3868,0x3869,
  0x386a,0x386b, 0x386c,0x386d,0x386e,0x386f,0x3870,0x3871,
  0x3872,0x3873, 0x3874,0x3875,0x3876,0x3877,0x3878,0x3879,
  0x387a,0x387b, 0x387c,0x387d,0x387e,0x387f,0x3880,0x3881,
  0x3882,0x3883, 0x3884,0x3885,0x3886,0x3887,0x3888,0x3889,
  0x388a,0x388b, 0x388c,0x388d,0x388e,0x388f,0x3890,0x3891,
  0x3892,0x3893, 0x3894,0x3895,0x3896,0x3897,0x3898,0x3899,
  0x389a,0x389b, 0x389c,0x389d,0x389e,0x389f,0x38a0,0x38a1,
  0x38a2,0x38a3, 0x38a4,0x38a5,0x38a6,0x38a7,0x38a8,0x38a9,
  0x38aa,0x38ab, 0x38ac,0x38ad,0x38ae,0x38af,0x38b0,0x38b1,
  0x38b2,0x38b3, 0x38b4,0x38b5,0x38b6,0x38b7,0x38b8,0x38b9,
  0x38ba,0x38bb, 0x38bc,0x38bd,0x38be,0x38bf,0x38c0,0x38c1,
  0x38c2,0x38c3, 0x38c4,0x38c5,0x38c6,0x38c7,0x38c8,0x38c9,
  0x38ca,0x38cb, 0x38cc,0x38cd,0x38ce,0x38cf,0x38d0,0x38d1,
  0x38d2,0x38d3, 0x38d4,0x38d5,0x38d6,0x38d7,0x38d8,0x38d9,
  0x38da,0x38db, 0x38dc,0x38dd,
/* 0xcd81(i:13680) */
  0x38de,0x38df,0x38e0,0x38e1,0x38e2,0x38e3, 0x38e4,0x38e5,
  0x38e6,0x38e7,0x38e8,0x38e9,0x38ea,0x38eb, 0x38ec,0x38ed,
  0x38ee,0x38ef,0x38f0,0x38f1,0x38f2,0x38f3, 0x38f4,0x38f5,
  0x38f6,0x38f7,0x38f8,0x38f9,0x38fa,0x38fb, 0x38fc,0x38fd,
  0x38fe,0x38ff,0x3900,0x3901,0x3902,0x3903, 0x3904,0x3905,
  0x3906,0x3907,0x3908,0x3909,0x390a,0x390b, 0x390c,0x390d,
  0x390e,0x390f,0x3910,0x3911,0x3912,0x3913, 0x3914,0x3915,
  0x3916,0x3917,0x3919,0x391a, 0x391b,0x391c,0x391d,0x391e,
  0x391f,0x3920,0x3921,0x3922, 0x3923,0x3924,0x3925,0x3926,
  0x3927,0x3928,0x3929,0x392a, 0x392b,0x392c,0x392d,0x392e,
  0x392f,0x3930,0x3931,0x3932, 0x3933,0x3934,0x3935,0x3936,
  0x3937,0x3938,0x3939,0x393a, 0x393b,0x393c,0x393d,0x393e,
  0x393f,0x3940,0x3941,0x3942, 0x3943,0x3944,0x3945,0x3946,
  0x3947,0x3948,0x3949,0x394a, 0x394b,0x394c,0x394d,0x394e,
  0x394f,0x3950,0x3951,0x3952, 0x3953,0x3954,0x3955,0x3956,
  0x3957,0x3958,0x3959,0x395a, 0x395b,0x395c,0x395d,0x395e,
  0x395f,0x3960,0x3961,0x3962, 0x3963,0x3964,0x3965,0x3966,
  0x3967,0x3968,0x3969,0x396a, 0x396b,0x396c,0x396d,0x396f,
  0x3970,0x3971,0x3972,0x3973, 0x3974,0x3975,0x3976,0x3977,
  0x3978,0x3979,0x397a,0x397b, 0x397c,0x397d,0x397e,0x397f,
  0x3980,0x3981,0x3982,0x3983, 0x3984,0x3985,0x3986,0x3987,
  0x3988,0x3989,0x398a,0x398b, 0x398c,0x398d,0x398e,0x398f,
  0x3990,0x3991,0x3992,0x3993, 
/* 0xce81(i:13860) */
  0x3994,0x3995,0x3996,0x3997, 0x3998,0x3999,0x399a,0x399b,
  0x399c,0x399d,0x399e,0x399f, 0x39a0,0x39a1,0x39a2,0x39a3,
  0x39a4,0x39a5,0x39a6,0x39a7, 0x39a8,0x39a9,0x39aa,0x39ab,
  0x39ac,0x39ad,0x39ae,0x39af, 0x39b0,0x39b1,0x39b2,0x39b3,
  0x39b4,0x39b5,0x39b6,0x39b7, 0x39b8,0x39b9,0x39ba,0x39bb,
  0x39bc,0x39bd,0x39be,0x39bf, 0x39c0,0x39c1,0x39c2,0x39c3,
  0x39c4,0x39c5,0x39c6,0x39c7, 0x39c8,0x39c9,0x39ca,0x39cb,
  0x39cc,0x39cd,0x39ce,0x39d1, 0x39d2,0x39d3,0x39d4,0x39d5,
  0x39d6,0x39d7,0x39d8,0x39d9, 0x39da,0x39db,0x39dc,0x39dd,
  0x39de,0x39e0,0x39e1,0x39e2, 0x39e3,0x39e4,0x39e5,0x39e6,
  0x39e7,0x39e8,0x39e9,0x39ea, 0x39eb,0x39ec,0x39ed,0x39ee,
  0x39ef,0x39f0,0x39f1,0x39f2, 0x39f3,0x39f4,0x39f5,0x39f6,
  0x39f7,0x39f8,0x39f9,0x39fa, 0x39fb,0x39fc,0x39fd,0x39fe,
  0x39ff,0x3a00,0x3a01,0x3a02, 0x3a03,0x3a04,0x3a05,0x3a06,
  0x3a07,0x3a08,0x3a09,0x3a0a, 0x3a0b,0x3a0c,0x3a0d,0x3a0e,
  0x3a0f,0x3a10,0x3a11,0x3a12, 0x3a13,0x3a14,0x3a15,0x3a16,
  0x3a17,0x3a18,0x3a19,0x3a1a, 0x3a1b,0x3a1c,0x3a1d,0x3a1e,
  0x3a1f,0x3a20,0x3a21,0x3a22, 0x3a23,0x3a24,0x3a25,0x3a26,
  0x3a27,0x3a28,0x3a29,0x3a2a, 0x3a2b,0x3a2c,0x3a2d,0x3a2e,
  0x3a2f,0x3a30,0x3a31,0x3a32, 0x3a33,0x3a34,0x3a35,0x3a36,
  0x3a37,0x3a38,0x3a39,0x3a3a, 0x3a3b,0x3a3c,0x3a3d,0x3a3e,
  0x3a3f,0x3a40,0x3a41,0x3a42, 0x3a43,0x3a44,0x3a45,0x3a46,
  0x3a47,0x3a48,0x3a49,0x3a4a, 
/* 0xcf81(i:14040) */
  0x3a4b,0x3a4c,0x3a4d,0x3a4e, 0x3a4f,0x3a50,0x3a51,0x3a52,
  0x3a53,0x3a54,0x3a55,0x3a56, 0x3a57,0x3a58,0x3a59,0x3a5a,
  0x3a5b,0x3a5c,0x3a5d,0x3a5e, 0x3a5f,0x3a60,0x3a61,0x3a62,
  0x3a63,0x3a64,0x3a65,0x3a66, 0x3a67,0x3a68,0x3a69,0x3a6a,
  0x3a6b,0x3a6c,0x3a6d,0x3a6e, 0x3a6f,0x3a70,0x3a71,0x3a72,
  0x3a74,0x3a75,0x3a76,0x3a77, 0x3a78,0x3a79,0x3a7a,0x3a7b,
  0x3a7c,0x3a7d,0x3a7e,0x3a7f, 0x3a80,0x3a81,0x3a82,0x3a83,
  0x3a84,0x3a85,0x3a86,0x3a87, 0x3a88,0x3a89,0x3a8a,0x3a8b,
  0x3a8c,0x3a8d,0x3a8e,0x3a8f, 0x3a90,0x3a91,0x3a92,0x3a93,
  0x3a94,0x3a95,0x3a96,0x3a97, 0x3a98,0x3a99,0x3a9a,0x3a9b,
  0x3a9c,0x3a9d,0x3a9e,0x3a9f, 0x3aa0,0x3aa1,0x3aa2,0x3aa3,
  0x3aa4,0x3aa5,0x3aa6,0x3aa7, 0x3aa8,0x3aa9,0x3aaa,0x3aab,
  0x3aac,0x3aad,0x3aae,0x3aaf, 0x3ab0,0x3ab1,0x3ab2,0x3ab3,
  0x3ab4,0x3ab5,0x3ab6,0x3ab7, 0x3ab8,0x3ab9,0x3aba,0x3abb,
  0x3abc,0x3abd,0x3abe,0x3abf, 0x3ac0,0x3ac1,0x3ac2,0x3ac3,
  0x3ac4,0x3ac5,0x3ac6,0x3ac7, 0x3ac8,0x3ac9,0x3aca,0x3acb,
  0x3acc,0x3acd,0x3ace,0x3acf, 0x3ad0,0x3ad1,0x3ad2,0x3ad3,
  0x3ad4,0x3ad5,0x3ad6,0x3ad7, 0x3ad8,0x3ad9,0x3ada,0x3adb,
  0x3adc,0x3add,0x3ade,0x3adf, 0x3ae0,0x3ae1,0x3ae2,0x3ae3,
  0x3ae4,0x3ae5,0x3ae6,0x3ae7, 0x3ae8,0x3ae9,0x3aea,0x3aeb,
  0x3aec,0x3aed,0x3aee,0x3aef, 0x3af0,0x3af1,0x3af2,0x3af3,
  0x3af4,0x3af5,0x3af6,0x3af7, 0x3af8,0x3af9,0x3afa,0x3afb,
  0x3afc,0x3afd,0x3afe,0x3aff, 
/* 0xd081(i:14220) */
  0x3b00,0x3b01,0x3b02,0x3b03, 0x3b04,0x3b05,0x3b06,0x3b07,
  0x3b08,0x3b09,0x3b0a,0x3b0b, 0x3b0c,0x3b0d,0x3b0e,0x3b0f,
  0x3b10,0x3b11,0x3b12,0x3b13, 0x3b14,0x3b15,0x3b16,0x3b17,
  0x3b18,0x3b19,0x3b1a,0x3b1b, 0x3b1c,0x3b1d,0x3b1e,0x3b1f,
  0x3b20,0x3b21,0x3b22,0x3b23, 0x3b24,0x3b25,0x3b26,0x3b27,
  0x3b28,0x3b29,0x3b2a,0x3b2b, 0x3b2c,0x3b2d,0x3b2e,0x3b2f,
  0x3b30,0x3b31,0x3b32,0x3b33, 0x3b34,0x3b35,0x3b36,0x3b37,
  0x3b38,0x3b39,0x3b3a,0x3b3b, 0x3b3c,0x3b3d,0x3b3e,0x3b3f,
  0x3b40,0x3b41,0x3b42,0x3b43, 0x3b44,0x3b45,0x3b46,0x3b47,
  0x3b48,0x3b49,0x3b4a,0x3b4b, 0x3b4c,0x3b4d,0x3b4f,0x3b50,
  0x3b51,0x3b52,0x3b53,0x3b54, 0x3b55,0x3b56,0x3b57,0x3b58,
  0x3b59,0x3b5a,0x3b5b,0x3b5c, 0x3b5d,0x3b5e,0x3b5f,0x3b60,
  0x3b61,0x3b62,0x3b63,0x3b64, 0x3b65,0x3b66,0x3b67,0x3b68,
  0x3b69,0x3b6a,0x3b6b,0x3b6c, 0x3b6d,0x3b6e,0x3b6f,0x3b70,
  0x3b71,0x3b72,0x3b73,0x3b74, 0x3b75,0x3b76,0x3b77,0x3b78,
  0x3b79,0x3b7a,0x3b7b,0x3b7c, 0x3b7d,0x3b7e,0x3b7f,0x3b80,
  0x3b81,0x3b82,0x3b83,0x3b84, 0x3b85,0x3b86,0x3b87,0x3b88,
  0x3b89,0x3b8a,0x3b8b,0x3b8c, 0x3b8d,0x3b8e,0x3b8f,0x3b90,
  0x3b91,0x3b92,0x3b93,0x3b94, 0x3b95,0x3b96,0x3b97,0x3b98,
  0x3b99,0x3b9a,0x3b9b,0x3b9c, 0x3b9d,0x3b9e,0x3b9f,0x3ba0,
  0x3ba1,0x3ba2,0x3ba3,0x3ba4, 0x3ba5,0x3ba6,0x3ba7,0x3ba8,
  0x3ba9,0x3baa,0x3bab,0x3bac, 0x3bad,0x3bae,0x3baf,0x3bb0,
  0x3bb1,0x3bb2,0x3bb3,0x3bb4, 
/* 0xd181(i:14400) */
  0x3bb5,0x3bb6,0x3bb7,0x3bb8, 0x3bb9,0x3bba,0x3bbb,0x3bbc,
  0x3bbd,0x3bbe,0x3bbf,0x3bc0, 0x3bc1,0x3bc2,0x3bc3,0x3bc4,
  0x3bc5,0x3bc6,0x3bc7,0x3bc8, 0x3bc9,0x3bca,0x3bcb,0x3bcc,
  0x3bcd,0x3bce,0x3bcf,0x3bd0, 0x3bd1,0x3bd2,0x3bd3,0x3bd4,
  0x3bd5,0x3bd6,0x3bd7,0x3bd8, 0x3bd9,0x3bda,0x3bdb,0x3bdc,
  0x3bdd,0x3bde,0x3bdf,0x3be0, 0x3be1,0x3be2,0x3be3,0x3be4,
  0x3be5,0x3be6,0x3be7,0x3be8, 0x3be9,0x3bea,0x3beb,0x3bec,
  0x3bed,0x3bee,0x3bef,0x3bf0, 0x3bf1,0x3bf2,0x3bf3,0x3bf4,
  0x3bf5,0x3bf6,0x3bf7,0x3bf8, 0x3bf9,0x3bfa,0x3bfb,0x3bfc,
  0x3bfd,0x3bfe,0x3bff,0x3c00, 0x3c01,0x3c02,0x3c03,0x3c04,
  0x3c05,0x3c06,0x3c07,0x3c08, 0x3c09,0x3c0a,0x3c0b,0x3c0c,
  0x3c0d,0x3c0e,0x3c0f,0x3c10, 0x3c11,0x3c12,0x3c13,0x3c14,
  0x3c15,0x3c16,0x3c17,0x3c18, 0x3c19,0x3c1a,0x3c1b,0x3c1c,
  0x3c1d,0x3c1e,0x3c1f,0x3c20, 0x3c21,0x3c22,0x3c23,0x3c24,
  0x3c25,0x3c26,0x3c27,0x3c28, 0x3c29,0x3c2a,0x3c2b,0x3c2c,
  0x3c2d,0x3c2e,0x3c2f,0x3c30, 0x3c31,0x3c32,0x3c33,0x3c34,
  0x3c35,0x3c36,0x3c37,0x3c38, 0x3c39,0x3c3a,0x3c3b,0x3c3c,
  0x3c3d,0x3c3e,0x3c3f,0x3c40, 0x3c41,0x3c42,0x3c43,0x3c44,
  0x3c45,0x3c46,0x3c47,0x3c48, 0x3c49,0x3c4a,0x3c4b,0x3c4c,
  0x3c4d,0x3c4e,0x3c4f,0x3c50, 0x3c51,0x3c52,0x3c53,0x3c54,
  0x3c55,0x3c56,0x3c57,0x3c58, 0x3c59,0x3c5a,0x3c5b,0x3c5c,
  0x3c5d,0x3c5e,0x3c5f,0x3c60, 0x3c61,0x3c62,0x3c63,0x3c64,
  0x3c65,0x3c66,0x3c67,0x3c68, 
/* 0xd281(i:14580) */
  0x3c69,0x3c6a,0x3c6b,0x3c6c, 0x3c6d,0x3c6f,0x3c70,0x3c71,
  0x3c72,0x3c73,0x3c74,0x3c75, 0x3c76,0x3c77,0x3c78,0x3c79,
  0x3c7a,0x3c7b,0x3c7c,0x3c7d, 0x3c7e,0x3c7f,0x3c80,0x3c81,
  0x3c82,0x3c83,0x3c84,0x3c85, 0x3c86,0x3c87,0x3c88,0x3c89,
  0x3c8a,0x3c8b,0x3c8c,0x3c8d, 0x3c8e,0x3c8f,0x3c90,0x3c91,
  0x3c92,0x3c93,0x3c94,0x3c95, 0x3c96,0x3c97,0x3c98,0x3c99,
  0x3c9a,0x3c9b,0x3c9c,0x3c9d, 0x3c9e,0x3c9f,0x3ca0,0x3ca1,
  0x3ca2,0x3ca3,0x3ca4,0x3ca5, 0x3ca6,0x3ca7,0x3ca8,0x3ca9,
  0x3caa,0x3cab,0x3cac,0x3cad, 0x3cae,0x3caf,0x3cb0,0x3cb1,
  0x3cb2,0x3cb3,0x3cb4,0x3cb5, 0x3cb6,0x3cb7,0x3cb8,0x3cb9,
  0x3cba,0x3cbb,0x3cbc,0x3cbd, 0x3cbe,0x3cbf,0x3cc0,0x3cc1,
  0x3cc2,0x3cc3,0x3cc4,0x3cc5, 0x3cc6,0x3cc7,0x3cc8,0x3cc9,
  0x3cca,0x3ccb,0x3ccc,0x3ccd, 0x3cce,0x3ccf,0x3cd0,0x3cd1,
  0x3cd2,0x3cd3,0x3cd4,0x3cd5, 0x3cd6,0x3cd7,0x3cd8,0x3cd9,
  0x3cda,0x3cdb,0x3cdc,0x3cdd, 0x3cde,0x3cdf,0x3ce1,0x3ce2,
  0x3ce3, 0x3ce4,0x3ce5,0x3ce6,0x3ce7,0x3ce8,0x3ce9,0x3cea,
  0x3ceb, 0x3cec,0x3ced,0x3cee,0x3cef,0x3cf0,0x3cf1,0x3cf2,
  0x3cf3, 0x3cf4,0x3cf5,0x3cf6,0x3cf7,0x3cf8,0x3cf9,0x3cfa,
  0x3cfb, 0x3cfc,0x3cfd,0x3cfe,0x3cff,0x3d00,0x3d01,0x3d02,
  0x3d03, 0x3d04,0x3d05,0x3d06,0x3d07,0x3d08,0x3d09,0x3d0a,
  0x3d0b, 0x3d0c,0x3d0d,0x3d0e,0x3d0f,0x3d10,0x3d11,0x3d12,
  0x3d13, 0x3d14,0x3d15,0x3d16,0x3d17,0x3d18,0x3d19,0x3d1a,
  0x3d1b, 0x3d1c,0x3d1d,0x3d1e,
/* 0xd381(i:14760) */
  0x3d1f,0x3d20,0x3d21,0x3d22,0x3d23, 0x3d24,0x3d25,0x3d26,
  0x3d27,0x3d28,0x3d29,0x3d2a,0x3d2b, 0x3d2c,0x3d2d,0x3d2e,
  0x3d2f,0x3d30,0x3d31,0x3d32,0x3d33, 0x3d34,0x3d35,0x3d36,
  0x3d37,0x3d38,0x3d39,0x3d3a,0x3d3b, 0x3d3c,0x3d3d,0x3d3e,
  0x3d3f,0x3d40,0x3d41,0x3d42,0x3d43, 0x3d44,0x3d45,0x3d46,
  0x3d47,0x3d48,0x3d49,0x3d4a,0x3d4b, 0x3d4c,0x3d4d,0x3d4e,
  0x3d4f,0x3d50,0x3d51,0x3d52,0x3d53, 0x3d54,0x3d55,0x3d56,
  0x3d57,0x3d58,0x3d59,0x3d5a,0x3d5b, 0x3d5c,0x3d5d,0x3d5e,
  0x3d5f,0x3d60,0x3d61,0x3d62,0x3d63, 0x3d64,0x3d65,0x3d66,
  0x3d67,0x3d68,0x3d69,0x3d6a,0x3d6b, 0x3d6c,0x3d6d,0x3d6e,
  0x3d6f,0x3d70,0x3d71,0x3d72,0x3d73, 0x3d74,0x3d75,0x3d76,
  0x3d77,0x3d78,0x3d79,0x3d7a,0x3d7b, 0x3d7c,0x3d7d,0x3d7e,
  0x3d7f,0x3d80,0x3d81,0x3d82,0x3d83, 0x3d84,0x3d85,0x3d86,
  0x3d87,0x3d88,0x3d89,0x3d8a,0x3d8b, 0x3d8c,0x3d8d,0x3d8e,
  0x3d8f,0x3d90,0x3d91,0x3d92,0x3d93, 0x3d94,0x3d95,0x3d96,
  0x3d97,0x3d98,0x3d99,0x3d9a,0x3d9b, 0x3d9c,0x3d9d,0x3d9e,
  0x3d9f,0x3da0,0x3da1,0x3da2,0x3da3, 0x3da4,0x3da5,0x3da6,
  0x3da7,0x3da8,0x3da9,0x3daa,0x3dab, 0x3dac,0x3dad,0x3dae,
  0x3daf,0x3db0,0x3db1,0x3db2,0x3db3, 0x3db4,0x3db5,0x3db6,
  0x3db7,0x3db8,0x3db9,0x3dba,0x3dbb, 0x3dbc,0x3dbd,0x3dbe,
  0x3dbf,0x3dc0,0x3dc1,0x3dc2,0x3dc3, 0x3dc4,0x3dc5,0x3dc6,
  0x3dc7,0x3dc8,0x3dc9,0x3dca,0x3dcb, 0x3dcc,0x3dcd,0x3dce,
  0x3dcf,0x3dd0,0x3dd1,0x3dd2,
 /* 0xd481(i:14940) */
  0x3dd3, 0x3dd4,0x3dd5,0x3dd6,0x3dd7,
  0x3dd8,0x3dd9,0x3dda,0x3ddb, 0x3ddc,0x3ddd,0x3dde,0x3ddf,
  0x3de0,0x3de1,0x3de2,0x3de3, 0x3de4,0x3de5,0x3de6,0x3de7,
  0x3de8,0x3de9,0x3dea,0x3deb, 0x3dec,0x3ded,0x3dee,0x3def,
  0x3df0,0x3df1,0x3df2,0x3df3, 0x3df4,0x3df5,0x3df6,0x3df7,
  0x3df8,0x3df9,0x3dfa,0x3dfb, 0x3dfc,0x3dfd,0x3dfe,0x3dff,
  0x3e00,0x3e01,0x3e02,0x3e03, 0x3e04,0x3e05,0x3e06,0x3e07,
  0x3e08,0x3e09,0x3e0a,0x3e0b, 0x3e0c,0x3e0d,0x3e0e,0x3e0f,
  0x3e10,0x3e11,0x3e12,0x3e13, 0x3e14,0x3e15,0x3e16,0x3e17,
  0x3e18,0x3e19,0x3e1a,0x3e1b, 0x3e1c,0x3e1d,0x3e1e,0x3e1f,
  0x3e20,0x3e21,0x3e22,0x3e23, 0x3e24,0x3e25,0x3e26,0x3e27,
  0x3e28,0x3e29,0x3e2a,0x3e2b, 0x3e2c,0x3e2d,0x3e2e,0x3e2f,
  0x3e30,0x3e31,0x3e32,0x3e33, 0x3e34,0x3e35,0x3e36,0x3e37,
  0x3e38,0x3e39,0x3e3a,0x3e3b, 0x3e3c,0x3e3d,0x3e3e,0x3e3f,
  0x3e40,0x3e41,0x3e42,0x3e43, 0x3e44,0x3e45,0x3e46,0x3e47,
  0x3e48,0x3e49,0x3e4a,0x3e4b, 0x3e4c,0x3e4d,0x3e4e,0x3e4f,
  0x3e50,0x3e51,0x3e52,0x3e53, 0x3e54,0x3e55,0x3e56,0x3e57,
  0x3e58,0x3e59,0x3e5a,0x3e5b, 0x3e5c,0x3e5d,0x3e5e,0x3e5f,
  0x3e60,0x3e61,0x3e62,0x3e63, 0x3e64,0x3e65,0x3e66,0x3e67,
  0x3e68,0x3e69,0x3e6a,0x3e6b, 0x3e6c,0x3e6d,0x3e6e,0x3e6f,
  0x3e70,0x3e71,0x3e72,0x3e73, 0x3e74,0x3e75,0x3e76,0x3e77,
  0x3e78,0x3e79,0x3e7a,0x3e7b, 0x3e7c,0x3e7d,0x3e7e,0x3e7f,
  0x3e80,0x3e81,0x3e82,0x3e83, 0x3e84,0x3e85,0x3e86,
 /* 0xd581(i:15120) */
  0x3e87,0x3e88,0x3e89,0x3e8a,0x3e8b, 0x3e8c,0x3e8d,0x3e8e,
  0x3e8f,0x3e90,0x3e91,0x3e92,0x3e93, 0x3e94,0x3e95,0x3e96,
  0x3e97,0x3e98,0x3e99,0x3e9a,0x3e9b, 0x3e9c,0x3e9d,0x3e9e,
  0x3e9f,0x3ea0,0x3ea1,0x3ea2,0x3ea3, 0x3ea4,0x3ea5,0x3ea6,
  0x3ea7,0x3ea8,0x3ea9,0x3eaa,0x3eab, 0x3eac,0x3ead,0x3eae,
  0x3eaf,0x3eb0,0x3eb1,0x3eb2,0x3eb3, 0x3eb4,0x3eb5,0x3eb6,
  0x3eb7,0x3eb8,0x3eb9,0x3eba,0x3ebb, 0x3ebc,0x3ebd,0x3ebe,
  0x3ebf,0x3ec0,0x3ec1,0x3ec2,0x3ec3, 0x3ec4,0x3ec5,0x3ec6,
  0x3ec7,0x3ec8,0x3ec9,0x3eca,0x3ecb, 0x3ecc,0x3ecd,0x3ece,
  0x3ecf,0x3ed0,0x3ed1,0x3ed2,0x3ed3, 0x3ed4,0x3ed5,0x3ed6,
  0x3ed7,0x3ed8,0x3ed9,0x3eda,0x3edb, 0x3edc,0x3edd,0x3ede,
  0x3edf,0x3ee0,0x3ee1,0x3ee2,0x3ee3, 0x3ee4,0x3ee5,0x3ee6,
  0x3ee7,0x3ee8,0x3ee9,0x3eea,0x3eeb, 0x3eec,0x3eed,0x3eee,
  0x3eef,0x3ef0,0x3ef1,0x3ef2,0x3ef3, 0x3ef4,0x3ef5,0x3ef6,
  0x3ef7,0x3ef8,0x3ef9,0x3efa,0x3efb, 0x3efc,0x3efd,0x3efe,
  0x3eff,0x3f00,0x3f01,0x3f02,0x3f03, 0x3f04,0x3f05,0x3f06,
  0x3f07,0x3f08,0x3f09,0x3f0a,0x3f0b, 0x3f0c,0x3f0d,0x3f0e,
  0x3f0f,0x3f10,0x3f11,0x3f12,0x3f13, 0x3f14,0x3f15,0x3f16,
  0x3f17,0x3f18,0x3f19,0x3f1a,0x3f1b, 0x3f1c,0x3f1d,0x3f1e,
  0x3f1f,0x3f20,0x3f21,0x3f22,0x3f23, 0x3f24,0x3f25,0x3f26,
  0x3f27,0x3f28,0x3f29,0x3f2a,0x3f2b, 0x3f2c,0x3f2d,0x3f2e,
  0x3f2f,0x3f30,0x3f31,0x3f32,0x3f33, 0x3f34,0x3f35,0x3f36,
  0x3f37,0x3f38,0x3f39,0x3f3a,
/* 0xd681(i:15300) */
  0x3f3b, 0x3f3c,0x3f3d,0x3f3e,0x3f3f,0x3f40,0x3f41,0x3f42,
  0x3f43, 0x3f44,0x3f45,0x3f46,0x3f47,0x3f48,0x3f49,0x3f4a,
  0x3f4b, 0x3f4c,0x3f4d,0x3f4e,0x3f4f,0x3f50,0x3f51,0x3f52,
  0x3f53, 0x3f54,0x3f55,0x3f56,0x3f57,0x3f58,0x3f59,0x3f5a,
  0x3f5b, 0x3f5c,0x3f5d,0x3f5e,0x3f5f,0x3f60,0x3f61,0x3f62,
  0x3f63, 0x3f64,0x3f65,0x3f66,0x3f67,0x3f68,0x3f69,0x3f6a,
  0x3f6b, 0x3f6c,0x3f6d,0x3f6e,0x3f6f,0x3f70,0x3f71,0x3f72,
  0x3f73, 0x3f74,0x3f75,0x3f76,0x3f77,0x3f78,0x3f79,0x3f7a,
  0x3f7b, 0x3f7c,0x3f7d,0x3f7e,0x3f7f,0x3f80,0x3f81,0x3f82,
  0x3f83, 0x3f84,0x3f85,0x3f86,0x3f87,0x3f88,0x3f89,0x3f8a,
  0x3f8b, 0x3f8c,0x3f8d,0x3f8e,0x3f8f,0x3f90,0x3f91,0x3f92,
  0x3f93, 0x3f94,0x3f95,0x3f96,0x3f97,0x3f98,0x3f99,0x3f9a,
  0x3f9b, 0x3f9c,0x3f9d,0x3f9e,0x3f9f,0x3fa0,0x3fa1,0x3fa2,
  0x3fa3, 0x3fa4,0x3fa5,0x3fa6,0x3fa7,0x3fa8,0x3fa9,0x3faa,
  0x3fab, 0x3fac,0x3fad,0x3fae,0x3faf,0x3fb0,0x3fb1,0x3fb2,
  0x3fb3, 0x3fb4,0x3fb5,0x3fb6,0x3fb7,0x3fb8,0x3fb9,0x3fba,
  0x3fbb, 0x3fbc,0x3fbd,0x3fbe,0x3fbf,0x3fc0,0x3fc1,0x3fc2,
  0x3fc3, 0x3fc4,0x3fc5,0x3fc6,0x3fc7,0x3fc8,0x3fc9,0x3fca,
  0x3fcb, 0x3fcc,0x3fcd,0x3fce,0x3fcf,0x3fd0,0x3fd1,0x3fd2,
  0x3fd3, 0x3fd4,0x3fd5,0x3fd6,0x3fd7,0x3fd8,0x3fd9,0x3fda,
  0x3fdb, 0x3fdc,0x3fdd,0x3fde,0x3fdf,0x3fe0,0x3fe1,0x3fe2,
  0x3fe3, 0x3fe4,0x3fe5,0x3fe6,0x3fe7,0x3fe8,0x3fe9,0x3fea,
  0x3feb, 0x3fec,0x3fed,0x3fee,
 /* 0xd781(i:15480) */
  0x3fef,0x3ff0,0x3ff1,0x3ff2,0x3ff3, 0x3ff4,0x3ff5,0x3ff6,
  0x3ff7,0x3ff8,0x3ff9,0x3ffa,0x3ffb, 0x3ffc,0x3ffd,0x3ffe,
  0x3fff,0x4000,0x4001,0x4002,0x4003, 0x4004,0x4005,0x4006,
  0x4007,0x4008,0x4009,0x400a,0x400b, 0x400c,0x400d,0x400e,
  0x400f,0x4010,0x4011,0x4012,0x4013, 0x4014,0x4015,0x4016,
  0x4017,0x4018,0x4019,0x401a,0x401b, 0x401c,0x401d,0x401e,
  0x401f,0x4020,0x4021,0x4022,0x4023, 0x4024,0x4025,0x4026,
  0x4027,0x4028,0x4029,0x402a,0x402b, 0x402c,0x402d,0x402e,
  0x402f,0x4030,0x4031,0x4032,0x4033, 0x4034,0x4035,0x4036,
  0x4037,0x4038,0x4039,0x403a,0x403b, 0x403c,0x403d,0x403e,
  0x403f,0x4040,0x4041,0x4042,0x4043, 0x4044,0x4045,0x4046,
  0x4047,0x4048,0x4049,0x404a,0x404b, 0x404c,0x404d,0x404e,
  0x404f,0x4050,0x4051,0x4052,0x4053, 0x4054,0x4055,0x4057,
  0x4058,0x4059,0x405a,0x405b, 0x405c,0x405d,0x405e,0x405f,
  0x4060,0x4061,0x4062,0x4063, 0x4064,0x4065,0x4066,0x4067,
  0x4068,0x4069,0x406a,0x406b, 0x406c,0x406d,0x406e,0x406f,
  0x4070,0x4071,0x4072,0x4073, 0x4074,0x4075,0x4076,0x4077,
  0x4078,0x4079,0x407a,0x407b, 0x407c,0x407d,0x407e,0x407f,
  0x4080,0x4081,0x4082,0x4083, 0x4084,0x4085,0x4086,0x4087,
  0x4088,0x4089,0x408a,0x408b, 0x408c,0x408d,0x408e,0x408f,
  0x4090,0x4091,0x4092,0x4093, 0x4094,0x4095,0x4096,0x4097,
  0x4098,0x4099,0x409a,0x409b, 0x409c,0x409d,0x409e,0x409f,
  0x40a0,0x40a1,0x40a2,0x40a3, 
/* 0xd881(i:15660) */
  0x40a4,0x40a5,0x40a6,0x40a7, 0x40a8,0x40a9,0x40aa,0x40ab,
  0x40ac,0x40ad,0x40ae,0x40af, 0x40b0,0x40b1,0x40b2,0x40b3,
  0x40b4,0x40b5,0x40b6,0x40b7, 0x40b8,0x40b9,0x40ba,0x40bb,
  0x40bc,0x40bd,0x40be,0x40bf, 0x40c0,0x40c1,0x40c2,0x40c3,
  0x40c4,0x40c5,0x40c6,0x40c7, 0x40c8,0x40c9,0x40ca,0x40cb,
  0x40cc,0x40cd,0x40ce,0x40cf, 0x40d0,0x40d1,0x40d2,0x40d3,
  0x40d4,0x40d5,0x40d6,0x40d7, 0x40d8,0x40d9,0x40da,0x40db,
  0x40dc,0x40dd,0x40de,0x40df, 0x40e0,0x40e1,0x40e2,0x40e3,
  0x40e4,0x40e5,0x40e6,0x40e7, 0x40e8,0x40e9,0x40ea,0x40eb,
  0x40ec,0x40ed,0x40ee,0x40ef, 0x40f0,0x40f1,0x40f2,0x40f3,
  0x40f4,0x40f5,0x40f6,0x40f7, 0x40f8,0x40f9,0x40fa,0x40fb,
  0x40fc,0x40fd,0x40fe,0x40ff, 0x4100,0x4101,0x4102,0x4103,
  0x4104,0x4105,0x4106,0x4107, 0x4108,0x4109,0x410a,0x410b,
  0x410c,0x410d,0x410e,0x410f, 0x4110,0x4111,0x4112,0x4113,
  0x4114,0x4115,0x4116,0x4117, 0x4118,0x4119,0x411a,0x411b,
  0x411c,0x411d,0x411e,0x411f, 0x4120,0x4121,0x4122,0x4123,
  0x4124,0x4125,0x4126,0x4127, 0x4128,0x4129,0x412a,0x412b,
  0x412c,0x412d,0x412e,0x412f, 0x4130,0x4131,0x4132,0x4133,
  0x4134,0x4135,0x4136,0x4137, 0x4138,0x4139,0x413a,0x413b,
  0x413c,0x413d,0x413e,0x413f, 0x4140,0x4141,0x4142,0x4143,
  0x4144,0x4145,0x4146,0x4147, 0x4148,0x4149,0x414a,0x414b,
  0x414c,0x414d,0x414e,0x414f, 0x4150,0x4151,0x4152,0x4153,
  0x4154,0x4155,0x4156,0x4157, 
/* 0xd981(i:15840) */
  0x4158,0x4159,0x415a,0x415b, 0x415c,0x415d,0x415e,0x4160,
  0x4161,0x4162,0x4163, 0x4164,0x4165,0x4166,0x4167,0x4168,
  0x4169,0x416a,0x416b, 0x416c,0x416d,0x416e,0x416f,0x4170,
  0x4171,0x4172,0x4173, 0x4174,0x4175,0x4176,0x4177,0x4178,
  0x4179,0x417a,0x417b, 0x417c,0x417d,0x417e,0x417f,0x4180,
  0x4181,0x4182,0x4183, 0x4184,0x4185,0x4186,0x4187,0x4188,
  0x4189,0x418a,0x418b, 0x418c,0x418d,0x418e,0x418f,0x4190,
  0x4191,0x4192,0x4193, 0x4194,0x4195,0x4196,0x4197,0x4198,
  0x4199,0x419a,0x419b, 0x419c,0x419d,0x419e,0x419f,0x41a0,
  0x41a1,0x41a2,0x41a3, 0x41a4,0x41a5,0x41a6,0x41a7,0x41a8,
  0x41a9,0x41aa,0x41ab, 0x41ac,0x41ad,0x41ae,0x41af,0x41b0,
  0x41b1,0x41b2,0x41b3, 0x41b4,0x41b5,0x41b6,0x41b7,0x41b8,
  0x41b9,0x41ba,0x41bb, 0x41bc,0x41bd,0x41be,0x41bf,0x41c0,
  0x41c1,0x41c2,0x41c3, 0x41c4,0x41c5,0x41c6,0x41c7,0x41c8,
  0x41c9,0x41ca,0x41cb, 0x41cc,0x41cd,0x41ce,0x41cf,0x41d0,
  0x41d1,0x41d2,0x41d3, 0x41d4,0x41d5,0x41d6,0x41d7,0x41d8,
  0x41d9,0x41da,0x41db, 0x41dc,0x41dd,0x41de,0x41df,0x41e0,
  0x41e1,0x41e2,0x41e3, 0x41e4,0x41e5,0x41e6,0x41e7,0x41e8,
  0x41e9,0x41ea,0x41eb, 0x41ec,0x41ed,0x41ee,0x41ef,0x41f0,
  0x41f1,0x41f2,0x41f3, 0x41f4,0x41f5,0x41f6,0x41f7,0x41f8,
  0x41f9,0x41fa,0x41fb, 0x41fc,0x41fd,0x41fe,0x41ff,0x4200,
  0x4201,0x4202,0x4203, 0x4204,0x4205,0x4206,0x4207,0x4208,
  0x4209,0x420a,0x420b, 0x420c,
/* 0xda81(i:16020) */
  0x420d,0x420e,0x420f,0x4210,0x4211,0x4212,0x4213, 0x4214,
  0x4215,0x4216,0x4217,0x4218,0x4219,0x421a,0x421b, 0x421c,
  0x421d,0x421e,0x421f,0x4220,0x4221,0x4222,0x4223, 0x4224,
  0x4225,0x4226,0x4227,0x4228,0x4229,0x422a,0x422b, 0x422c,
  0x422d,0x422e,0x422f,0x4230,0x4231,0x4232,0x4233, 0x4234,
  0x4235,0x4236,0x4237,0x4238,0x4239,0x423a,0x423b, 0x423c,
  0x423d,0x423e,0x423f,0x4240,0x4241,0x4242,0x4243, 0x4244,
  0x4245,0x4246,0x4247,0x4248,0x4249,0x424a,0x424b, 0x424c,
  0x424d,0x424e,0x424f,0x4250,0x4251,0x4252,0x4253, 0x4254,
  0x4255,0x4256,0x4257,0x4258,0x4259,0x425a,0x425b, 0x425c,
  0x425d,0x425e,0x425f,0x4260,0x4261,0x4262,0x4263, 0x4264,
  0x4265,0x4266,0x4267,0x4268,0x4269,0x426a,0x426b, 0x426c,
  0x426d,0x426e,0x426f,0x4270,0x4271,0x4272,0x4273, 0x4274,
  0x4275,0x4276,0x4277,0x4278,0x4279,0x427a,0x427b, 0x427c,
  0x427d,0x427e,0x427f,0x4280,0x4281,0x4282,0x4283, 0x4284,
  0x4285,0x4286,0x4287,0x4288,0x4289,0x428a,0x428b, 0x428c,
  0x428d,0x428e,0x428f,0x4290,0x4291,0x4292,0x4293, 0x4294,
  0x4295,0x4296,0x4297,0x4298,0x4299,0x429a,0x429b, 0x429c,
  0x429d,0x429e,0x429f,0x42a0,0x42a1,0x42a2,0x42a3, 0x42a4,
  0x42a5,0x42a6,0x42a7,0x42a8,0x42a9,0x42aa,0x42ab, 0x42ac,
  0x42ad,0x42ae,0x42af,0x42b0,0x42b1,0x42b2,0x42b3, 0x42b4,
  0x42b5,0x42b6,0x42b7,0x42b8,0x42b9,0x42ba,0x42bb, 0x42bc,
  0x42bd,0x42be,0x42bf,0x42c0,
/* 0xdb81(i:16200) */
  0x42c1,0x42c2,0x42c3, 0x42c4,0x42c5,0x42c6,0x42c7,0x42c8,
  0x42c9,0x42ca,0x42cb, 0x42cc,0x42cd,0x42ce,0x42cf,0x42d0,
  0x42d1,0x42d2,0x42d3, 0x42d4,0x42d5,0x42d6,0x42d7,0x42d8,
  0x42d9,0x42da,0x42db, 0x42dc,0x42dd,0x42de,0x42df,0x42e0,
  0x42e1,0x42e2,0x42e3, 0x42e4,0x42e5,0x42e6,0x42e7,0x42e8,
  0x42e9,0x42ea,0x42eb, 0x42ec,0x42ed,0x42ee,0x42ef,0x42f0,
  0x42f1,0x42f2,0x42f3, 0x42f4,0x42f5,0x42f6,0x42f7,0x42f8,
  0x42f9,0x42fa,0x42fb, 0x42fc,0x42fd,0x42fe,0x42ff,0x4300,
  0x4301,0x4302,0x4303, 0x4304,0x4305,0x4306,0x4307,0x4308,
  0x4309,0x430a,0x430b, 0x430c,0x430d,0x430e,0x430f,0x4310,
  0x4311,0x4312,0x4313, 0x4314,0x4315,0x4316,0x4317,0x4318,
  0x4319,0x431a,0x431b, 0x431c,0x431d,0x431e,0x431f,0x4320,
  0x4321,0x4322,0x4323, 0x4324,0x4325,0x4326,0x4327,0x4328,
  0x4329,0x432a,0x432b, 0x432c,0x432d,0x432e,0x432f,0x4330,
  0x4331,0x4332,0x4333, 0x4334,0x4335,0x4336,0x4338,0x4339,
  0x433a,0x433b,0x433c,0x433d, 0x433e,0x433f,0x4340,0x4341,
  0x4342,0x4343,0x4344,0x4345, 0x4346,0x4347,0x4348,0x4349,
  0x434a,0x434b,0x434c,0x434d, 0x434e,0x434f,0x4350,0x4351,
  0x4352,0x4353,0x4354,0x4355, 0x4356,0x4357,0x4358,0x4359,
  0x435a,0x435b,0x435c,0x435d, 0x435e,0x435f,0x4360,0x4361,
  0x4362,0x4363,0x4364,0x4365, 0x4366,0x4367,0x4368,0x4369,
  0x436a,0x436b,0x436c,0x436d, 0x436e,0x436f,0x4370,0x4371,
  0x4372,0x4373,0x4374,0x4375, 
/* 0xdc81(i:16380) */
  0x4376,0x4377,0x4378,0x4379, 0x437a,0x437b,0x437c,0x437d,
  0x437e,0x437f,0x4380,0x4381, 0x4382,0x4383,0x4384,0x4385,
  0x4386,0x4387,0x4388,0x4389, 0x438a,0x438b,0x438c,0x438d,
  0x438e,0x438f,0x4390,0x4391, 0x4392,0x4393,0x4394,0x4395,
  0x4396,0x4397,0x4398,0x4399, 0x439a,0x439b,0x439c,0x439d,
  0x439e,0x439f,0x43a0,0x43a1, 0x43a2,0x43a3,0x43a4,0x43a5,
  0x43a6,0x43a7,0x43a8,0x43a9, 0x43aa,0x43ab,0x43ad,0x43ae,
  0x43af,0x43b0,0x43b2,0x43b3, 0x43b4,0x43b5,0x43b6,0x43b7,
  0x43b8,0x43b9,0x43ba,0x43bb, 0x43bc,0x43bd,0x43be,0x43bf,
  0x43c0,0x43c1,0x43c2,0x43c3, 0x43c4,0x43c5,0x43c6,0x43c7,
  0x43c8,0x43c9,0x43ca,0x43cb, 0x43cc,0x43cd,0x43ce,0x43cf,
  0x43d0,0x43d1,0x43d2,0x43d3, 0x43d4,0x43d5,0x43d6,0x43d7,
  0x43d8,0x43d9,0x43da,0x43db, 0x43dc,0x43de,0x43df,0x43e0,
  0x43e1,0x43e2,0x43e3,0x43e4, 0x43e5,0x43e6,0x43e7,0x43e8,
  0x43e9,0x43ea,0x43eb,0x43ec, 0x43ed,0x43ee,0x43ef,0x43f0,
  0x43f1,0x43f2,0x43f3,0x43f4, 0x43f5,0x43f6,0x43f7,0x43f8,
  0x43f9,0x43fa,0x43fb,0x43fc, 0x43fd,0x43fe,0x43ff,0x4400,
  0x4401,0x4402,0x4403,0x4404, 0x4405,0x4406,0x4407,0x4408,
  0x4409,0x440a,0x440b,0x440c, 0x440d,0x440e,0x440f,0x4410,
  0x4411,0x4412,0x4413,0x4414, 0x4415,0x4416,0x4417,0x4418,
  0x4419,0x441a,0x441b,0x441c, 0x441d,0x441e,0x441f,0x4420,
  0x4421,0x4422,0x4423,0x4424, 0x4425,0x4426,0x4427,0x4428,
  0x4429,0x442a,0x442b,0x442c, 
/* 0xdd81(i:16560) */
  0x442d,0x442e,0x442f,0x4430, 0x4431,0x4432,0x4433,0x4434,
  0x4435,0x4436,0x4437,0x4438, 0x4439,0x443a,0x443b,0x443c,
  0x443d,0x443e,0x443f,0x4440, 0x4441,0x4442,0x4443,0x4444,
  0x4445,0x4446,0x4447,0x4448, 0x4449,0x444a,0x444b,0x444c,
  0x444d,0x444e,0x444f,0x4450, 0x4451,0x4452,0x4453,0x4454,
  0x4455,0x4456,0x4457,0x4458, 0x4459,0x445a,0x445b,0x445c,
  0x445d,0x445e,0x445f,0x4460, 0x4461,0x4462,0x4463,0x4464,
  0x4465,0x4466,0x4467,0x4468, 0x4469,0x446a,0x446b,0x446c,
  0x446d,0x446e,0x446f,0x4470, 0x4471,0x4472,0x4473,0x4474,
  0x4475,0x4476,0x4477,0x4478, 0x4479,0x447a,0x447b,0x447c,
  0x447d,0x447e,0x447f,0x4480, 0x4481,0x4482,0x4483,0x4484,
  0x4485,0x4486,0x4487,0x4488, 0x4489,0x448a,0x448b,0x448c,
  0x448d,0x448e,0x448f,0x4490, 0x4491,0x4492,0x4493,0x4494,
  0x4495,0x4496,0x4497,0x4498, 0x4499,0x449a,0x449b,0x449c,
  0x449d,0x449e,0x449f,0x44a0, 0x44a1,0x44a2,0x44a3,0x44a4,
  0x44a5,0x44a6,0x44a7,0x44a8, 0x44a9,0x44aa,0x44ab,0x44ac,
  0x44ad,0x44ae,0x44af,0x44b0, 0x44b1,0x44b2,0x44b3,0x44b4,
  0x44b5,0x44b6,0x44b7,0x44b8, 0x44b9,0x44ba,0x44bb,0x44bc,
  0x44bd,0x44be,0x44bf,0x44c0, 0x44c1,0x44c2,0x44c3,0x44c4,
  0x44c5,0x44c6,0x44c7,0x44c8, 0x44c9,0x44ca,0x44cb,0x44cc,
  0x44cd,0x44ce,0x44cf,0x44d0, 0x44d1,0x44d2,0x44d3,0x44d4,
  0x44d5,0x44d7,0x44d8,0x44d9,0x44da,0x44db, 0x44dc,0x44dd,
  0x44de,0x44df,0x44e0,0x44e1,
/* 0xde81(i:16740) */
  0x44e2,0x44e3, 0x44e4,0x44e5,0x44e6,0x44e7,0x44e8,0x44e9,
  0x44ea,0x44eb, 0x44ec,0x44ed,0x44ee,0x44ef,0x44f0,0x44f1,
  0x44f2,0x44f3, 0x44f4,0x44f5,0x44f6,0x44f7,0x44f8,0x44f9,
  0x44fa,0x44fb, 0x44fc,0x44fd,0x44fe,0x44ff,0x4500,0x4501,
  0x4502,0x4503, 0x4504,0x4505,0x4506,0x4507,0x4508,0x4509,
  0x450a,0x450b, 0x450c,0x450d,0x450e,0x450f,0x4510,0x4511,
  0x4512,0x4513, 0x4514,0x4515,0x4516,0x4517,0x4518,0x4519,
  0x451a,0x451b, 0x451c,0x451d,0x451e,0x451f,0x4520,0x4521,
  0x4522,0x4523, 0x4524,0x4525,0x4526,0x4527,0x4528,0x4529,
  0x452a,0x452b, 0x452c,0x452d,0x452e,0x452f,0x4530,0x4531,
  0x4532,0x4533, 0x4534,0x4535,0x4536,0x4537,0x4538,0x4539,
  0x453a,0x453b, 0x453c,0x453d,0x453e,0x453f,0x4540,0x4541,
  0x4542,0x4543, 0x4544,0x4545,0x4546,0x4547,0x4548,0x4549,
  0x454a,0x454b, 0x454c,0x454d,0x454e,0x454f,0x4550,0x4551,
  0x4552,0x4553, 0x4554,0x4555,0x4556,0x4557,0x4558,0x4559,
  0x455a,0x455b, 0x455c,0x455d,0x455e,0x455f,0x4560,0x4561,
  0x4562,0x4563, 0x4564,0x4565,0x4566,0x4567,0x4568,0x4569,
  0x456a,0x456b, 0x456c,0x456d,0x456e,0x456f,0x4570,0x4571,
  0x4572,0x4573, 0x4574,0x4575,0x4576,0x4577,0x4578,0x4579,
  0x457a,0x457b, 0x457c,0x457d,0x457e,0x457f,0x4580,0x4581,
  0x4582,0x4583, 0x4584,0x4585,0x4586,0x4587,0x4588,0x4589,
  0x458a,0x458b, 0x458c,0x458d,0x458e,0x458f,0x4590,0x4591,
  0x4592,0x4593, 0x4594,0x4595,
/* 0xdf81(i:16920) */
  0x4596,0x4597,0x4598,0x4599,0x459a,0x459b, 0x459c,0x459d,
  0x459e,0x459f,0x45a0,0x45a1,0x45a2,0x45a3, 0x45a4,0x45a5,
  0x45a6,0x45a7,0x45a8,0x45a9,0x45aa,0x45ab, 0x45ac,0x45ad,
  0x45ae,0x45af,0x45b0,0x45b1,0x45b2,0x45b3, 0x45b4,0x45b5,
  0x45b6,0x45b7,0x45b8,0x45b9,0x45ba,0x45bb, 0x45bc,0x45bd,
  0x45be,0x45bf,0x45c0,0x45c1,0x45c2,0x45c3, 0x45c4,0x45c5,
  0x45c6,0x45c7,0x45c8,0x45c9,0x45ca,0x45cb, 0x45cc,0x45cd,
  0x45ce,0x45cf,0x45d0,0x45d1,0x45d2,0x45d3, 0x45d4,0x45d5,
  0x45d6,0x45d7,0x45d8,0x45d9,0x45da,0x45db, 0x45dc,0x45dd,
  0x45de,0x45df,0x45e0,0x45e1,0x45e2,0x45e3, 0x45e4,0x45e5,
  0x45e6,0x45e7,0x45e8,0x45e9,0x45ea,0x45eb, 0x45ec,0x45ed,
  0x45ee,0x45ef,0x45f0,0x45f1,0x45f2,0x45f3, 0x45f4,0x45f5,
  0x45f6,0x45f7,0x45f8,0x45f9,0x45fa,0x45fb, 0x45fc,0x45fd,
  0x45fe,0x45ff,0x4600,0x4601,0x4602,0x4603, 0x4604,0x4605,
  0x4606,0x4607,0x4608,0x4609,0x460a,0x460b, 0x460c,0x460d,
  0x460e,0x460f,0x4610,0x4611,0x4612,0x4613, 0x4614,0x4615,
  0x4616,0x4617,0x4618,0x4619,0x461a,0x461b, 0x461c,0x461d,
  0x461e,0x461f,0x4620,0x4621,0x4622,0x4623, 0x4624,0x4625,
  0x4626,0x4627,0x4628,0x4629,0x462a,0x462b, 0x462c,0x462d,
  0x462e,0x462f,0x4630,0x4631,0x4632,0x4633, 0x4634,0x4635,
  0x4636,0x4637,0x4638,0x4639,0x463a,0x463b, 0x463c,0x463d,
  0x463e,0x463f,0x4640,0x4641,0x4642,0x4643, 0x4644,0x4645,
  0x4646,0x4647,0x4648,0x4649,
/* 0xe081(i:17100) */
  0x464a,0x464b,0x464d,0x464e, 0x464f,0x4650,0x4651,0x4652,
  0x4653,0x4654,0x4655,0x4656, 0x4657,0x4658,0x4659,0x465a,
  0x465b,0x465c,0x465d,0x465e, 0x465f,0x4660,0x4662,0x4663,
  0x4664,0x4665,0x4666,0x4667, 0x4668,0x4669,0x466a,0x466b,
  0x466c,0x466d,0x466e,0x466f, 0x4670,0x4671,0x4672,0x4673,
  0x4674,0x4675,0x4676,0x4677, 0x4678,0x4679,0x467a,0x467b,
  0x467c,0x467d,0x467e,0x467f, 0x4680,0x4681,0x4682,0x4683,
  0x4684,0x4685,0x4686,0x4687, 0x4688,0x4689,0x468a,0x468b,
  0x468c,0x468d,0x468e,0x468f, 0x4690,0x4691,0x4692,0x4693,
  0x4694,0x4695,0x4696,0x4697, 0x4698,0x4699,0x469a,0x469b,
  0x469c,0x469d,0x469e,0x469f, 0x46a0,0x46a1,0x46a2,0x46a3,
  0x46a4,0x46a5,0x46a6,0x46a7, 0x46a8,0x46a9,0x46aa,0x46ab,
  0x46ac,0x46ad,0x46ae,0x46af, 0x46b0,0x46b1,0x46b2,0x46b3,
  0x46b4,0x46b5,0x46b6,0x46b7, 0x46b8,0x46b9,0x46ba,0x46bb,
  0x46bc,0x46bd,0x46be,0x46bf, 0x46c0,0x46c1,0x46c2,0x46c3,
  0x46c4,0x46c5,0x46c6,0x46c7, 0x46c8,0x46c9,0x46ca,0x46cb,
  0x46cc,0x46cd,0x46ce,0x46cf, 0x46d0,0x46d1,0x46d2,0x46d3,
  0x46d4,0x46d5,0x46d6,0x46d7, 0x46d8,0x46d9,0x46da,0x46db,
  0x46dc,0x46dd,0x46de,0x46df, 0x46e0,0x46e1,0x46e2,0x46e3,
  0x46e4,0x46e5,0x46e6,0x46e7, 0x46e8,0x46e9,0x46ea,0x46eb,
  0x46ec,0x46ed,0x46ee,0x46ef, 0x46f0,0x46f1,0x46f2,0x46f3,
  0x46f4,0x46f5,0x46f6,0x46f7, 0x46f8,0x46f9,0x46fa,0x46fb,
  0x46fc,0x46fd,0x46fe,0x46ff, 
/* 0xe181(i:17280) */
  0x4700,0x4701,0x4702,0x4703, 0x4704,0x4705,0x4706,0x4707,
  0x4708,0x4709,0x470a,0x470b, 0x470c,0x470d,0x470e,0x470f,
  0x4710,0x4711,0x4712,0x4713, 0x4714,0x4715,0x4716,0x4717,
  0x4718,0x4719,0x471a,0x471b, 0x471c,0x471d,0x471e,0x471f,
  0x4720,0x4721,0x4722,0x4724, 0x4725,0x4726,0x4727,0x4728,
  0x472a,0x472b,0x472c,0x472d, 0x472e,0x472f,0x4730,0x4731,
  0x4732,0x4733,0x4734,0x4735, 0x4736,0x4737,0x4738,0x4739,
  0x473a,0x473b,0x473c,0x473d, 0x473e,0x473f,0x4740,0x4741,
  0x4742,0x4743,0x4744,0x4745, 0x4746,0x4747,0x4748,0x4749,
  0x474a,0x474b,0x474c,0x474d, 0x474e,0x474f,0x4750,0x4751,
  0x4752,0x4753,0x4754,0x4755, 0x4756,0x4757,0x4758,0x4759,
  0x475a,0x475b,0x475c,0x475d, 0x475e,0x475f,0x4760,0x4761,
  0x4762,0x4763,0x4764,0x4765, 0x4766,0x4767,0x4768,0x4769,
  0x476a,0x476b,0x476c,0x476d, 0x476e,0x476f,0x4770,0x4771,
  0x4772,0x4773,0x4774,0x4775, 0x4776,0x4777,0x4778,0x4779,
  0x477a,0x477b,0x477d,0x477e, 0x477f,0x4780,0x4781,0x4782,
  0x4783,0x4784,0x4785,0x4786, 0x4787,0x4788,0x4789,0x478a,
  0x478b,0x478c,0x478e,0x478f, 0x4790,0x4791,0x4792,0x4793,
  0x4794,0x4795,0x4796,0x4797, 0x4798,0x4799,0x479a,0x479b,
  0x479c,0x479d,0x479e,0x479f, 0x47a0,0x47a1,0x47a2,0x47a3,
  0x47a4,0x47a5,0x47a6,0x47a7, 0x47a8,0x47a9,0x47aa,0x47ab,
  0x47ac,0x47ad,0x47ae,0x47af, 0x47b0,0x47b1,0x47b2,0x47b3,
  0x47b4,0x47b5,0x47b6,0x47b7,
/* 0xe281(i:17460) */
  0x47b8,0x47b9,0x47ba,0x47bb, 0x47bc,0x47bd,0x47be,0x47bf,
  0x47c0,0x47c1,0x47c2,0x47c3, 0x47c4,0x47c5,0x47c6,0x47c7,
  0x47c8,0x47c9,0x47ca,0x47cb, 0x47cc,0x47cd,0x47ce,0x47cf,
  0x47d0,0x47d1,0x47d2,0x47d3, 0x47d4,0x47d5,0x47d6,0x47d7,
  0x47d8,0x47d9,0x47da,0x47db, 0x47dc,0x47dd,0x47de,0x47df,
  0x47e0,0x47e1,0x47e2,0x47e3, 0x47e4,0x47e5,0x47e6,0x47e7,
  0x47e8,0x47e9,0x47ea,0x47eb, 0x47ec,0x47ed,0x47ee,0x47ef,
  0x47f0,0x47f1,0x47f2,0x47f3, 0x47f4,0x47f5,0x47f6,0x47f7,
  0x47f8,0x47f9,0x47fa,0x47fb, 0x47fc,0x47fd,0x47fe,0x47ff,
  0x4800,0x4801,0x4802,0x4803, 0x4804,0x4805,0x4806,0x4807,
  0x4808,0x4809,0x480a,0x480b, 0x480c,0x480d,0x480e,0x480f,
  0x4810,0x4811,0x4812,0x4813, 0x4814,0x4815,0x4816,0x4817,
  0x4818,0x4819,0x481a,0x481b, 0x481c,0x481d,0x481e,0x481f,
  0x4820,0x4821,0x4822,0x4823, 0x4824,0x4825,0x4826,0x4827,
  0x4828,0x4829,0x482a,0x482b, 0x482c,0x482d,0x482e,0x482f,
  0x4830,0x4831,0x4832,0x4833, 0x4834,0x4835,0x4836,0x4837,
  0x4838,0x4839,0x483a,0x483b, 0x483c,0x483d,0x483e,0x483f,
  0x4840,0x4841,0x4842,0x4843, 0x4844,0x4845,0x4846,0x4847,
  0x4848,0x4849,0x484a,0x484b, 0x484c,0x484d,0x484e,0x484f,
  0x4850,0x4851,0x4852,0x4853, 0x4854,0x4855,0x4856,0x4857,
  0x4858,0x4859,0x485a,0x485b, 0x485c,0x485d,0x485e,0x485f,
  0x4860,0x4861,0x4862,0x4863, 0x4864,0x4865,0x4866,0x4867,
  0x4868,0x4869,0x486a,0x486b, 
/* 0xe381(i:17640) */
  0x486c,0x486d,0x486e,0x486f,
  0x4870,0x4871,0x4872,0x4873, 0x4874,0x4875,0x4876,0x4877,
  0x4878,0x4879,0x487a,0x487b, 0x487c,0x487d,0x487e,0x487f,
  0x4880,0x4881,0x4882,0x4883, 0x4884,0x4885,0x4886,0x4887,
  0x4888,0x4889,0x488a,0x488b, 0x488c,0x488d,0x488e,0x488f,
  0x4890,0x4891,0x4892,0x4893, 0x4894,0x4895,0x4896,0x4897,
  0x4898,0x4899,0x489a,0x489b, 0x489c,0x489d,0x489e,0x489f,
  0x48a0,0x48a1,0x48a2,0x48a3, 0x48a4,0x48a5,0x48a6,0x48a7,
  0x48a8,0x48a9,0x48aa,0x48ab, 0x48ac,0x48ad,0x48ae,0x48af,
  0x48b0,0x48b1,0x48b2,0x48b3, 0x48b4,0x48b5,0x48b6,0x48b7,
  0x48b8,0x48b9,0x48ba,0x48bb, 0x48bc,0x48bd,0x48be,0x48bf,
  0x48c0,0x48c1,0x48c2,0x48c3, 0x48c4,0x48c5,0x48c6,0x48c7,
  0x48c8,0x48c9,0x48ca,0x48cb, 0x48cc,0x48cd,0x48ce,0x48cf,
  0x48d0,0x48d1,0x48d2,0x48d3, 0x48d4,0x48d5,0x48d6,0x48d7,
  0x48d8,0x48d9,0x48da,0x48db, 0x48dc,0x48dd,0x48de,0x48df,
  0x48e0,0x48e1,0x48e2,0x48e3, 0x48e4,0x48e5,0x48e6,0x48e7,
  0x48e8,0x48e9,0x48ea,0x48eb, 0x48ec,0x48ed,0x48ee,0x48ef,
  0x48f0,0x48f1,0x48f2,0x48f3, 0x48f4,0x48f5,0x48f6,0x48f7,
  0x48f8,0x48f9,0x48fa,0x48fb, 0x48fc,0x48fd,0x48fe,0x48ff,
  0x4900,0x4901,0x4902,0x4903, 0x4904,0x4905,0x4906,0x4907,
  0x4908,0x4909,0x490a,0x490b, 0x490c,0x490d,0x490e,0x490f,
  0x4910,0x4911,0x4912,0x4913, 0x4914,0x4915,0x4916,0x4917,
  0x4918,0x4919,0x491a,0x491b, 0x491c,0x491d,0x491e,0x491f,
/* 0xe481(i:17820) */
  0x4920,0x4921,0x4922,0x4923, 0x4924,0x4925,0x4926,0x4927,
  0x4928,0x4929,0x492a,0x492b, 0x492c,0x492d,0x492e,0x492f,
  0x4930,0x4931,0x4932,0x4933, 0x4934,0x4935,0x4936,0x4937,
  0x4938,0x4939,0x493a,0x493b, 0x493c,0x493d,0x493e,0x493f,
  0x4940,0x4941,0x4942,0x4943, 0x4944,0x4945,0x4946,0x4948,
  0x4949,0x494a,0x494b,0x494c, 0x494d,0x494e,0x494f,0x4950,
  0x4951,0x4952,0x4953,0x4954, 0x4955,0x4956,0x4957,0x4958,
  0x4959,0x495a,0x495b,0x495c, 0x495d,0x495e,0x495f,0x4960,
  0x4961,0x4962,0x4963,0x4964, 0x4965,0x4966,0x4967,0x4968,
  0x4969,0x496a,0x496b,0x496c, 0x496d,0x496e,0x496f,0x4970,
  0x4971,0x4972,0x4973,0x4974, 0x4975,0x4976,0x4977,0x4978,
  0x4979,0x497b,0x497c,0x497e, 0x497f,0x4980,0x4981,0x4984,
  0x4987,0x4988,0x4989,0x498a, 0x498b,0x498c,0x498d,0x498e,
  0x498f,0x4990,0x4991,0x4992, 0x4993,0x4994,0x4995,0x4996,
  0x4997,0x4998,0x4999,0x499a, 0x499c,0x499d,0x499e,0x49a0,
  0x49a1,0x49a2,0x49a3,0x49a4, 0x49a5,0x49a6,0x49a7,0x49a8,
  0x49a9,0x49aa,0x49ab,0x49ac, 0x49ad,0x49ae,0x49af,0x49b0,
  0x49b1,0x49b2,0x49b3,0x49b4, 0x49b5,0x49b8,0x49b9,0x49ba,
  0x49bb, 0x49bc,0x49bd,0x49be,0x49bf,0x49c0,0x49c1,0x49c2,
  0x49c3, 0x49c4,0x49c5,0x49c6,0x49c7,0x49c8,0x49c9,0x49ca,
  0x49cb, 0x49cc,0x49cd,0x49ce,0x49cf,0x49d0,0x49d1,0x49d2,
  0x49d3, 0x49d4,0x49d5,0x49d6,0x49d7,0x49d8,0x49d9,0x49da,
  0x49db, 0x49dc,0x49dd,0x49de,
/* 0xe581(i:18000) */
  0x49df,0x49e0,0x49e1,0x49e2,0x49e3, 0x49e4,0x49e5,0x49e6,
  0x49e7,0x49e8,0x49e9,0x49ea,0x49eb, 0x49ec,0x49ed,0x49ee,
  0x49ef,0x49f0,0x49f1,0x49f2,0x49f3, 0x49f4,0x49f5,0x49f6,
  0x49f7,0x49f8,0x49f9,0x49fa,0x49fb, 0x49fc,0x49fd,0x49fe,
  0x49ff,0x4a00,0x4a01,0x4a02,0x4a03, 0x4a04,0x4a05,0x4a06,
  0x4a07,0x4a08,0x4a09,0x4a0a,0x4a0b, 0x4a0c,0x4a0d,0x4a0e,
  0x4a0f,0x4a10,0x4a11,0x4a12,0x4a13, 0x4a14,0x4a15,0x4a16,
  0x4a17,0x4a18,0x4a19,0x4a1a,0x4a1b, 0x4a1c,0x4a1d,0x4a1e,
  0x4a1f,0x4a20,0x4a21,0x4a22,0x4a23, 0x4a24,0x4a25,0x4a26,
  0x4a27,0x4a28,0x4a29,0x4a2a,0x4a2b, 0x4a2c,0x4a2d,0x4a2e,
  0x4a2f,0x4a30,0x4a31,0x4a32,0x4a33, 0x4a34,0x4a35,0x4a36,
  0x4a37,0x4a38,0x4a39,0x4a3a,0x4a3b, 0x4a3c,0x4a3d,0x4a3e,
  0x4a3f,0x4a40,0x4a41,0x4a42,0x4a43, 0x4a44,0x4a45,0x4a46,
  0x4a47,0x4a48,0x4a49,0x4a4a,0x4a4b, 0x4a4c,0x4a4d,0x4a4e,
  0x4a4f,0x4a50,0x4a51,0x4a52,0x4a53, 0x4a54,0x4a55,0x4a56,
  0x4a57,0x4a58,0x4a59,0x4a5a,0x4a5b, 0x4a5c,0x4a5d,0x4a5e,
  0x4a5f,0x4a60,0x4a61,0x4a62,0x4a63, 0x4a64,0x4a65,0x4a66,
  0x4a67,0x4a68,0x4a69,0x4a6a,0x4a6b, 0x4a6c,0x4a6d,0x4a6e,
  0x4a6f,0x4a70,0x4a71,0x4a72,0x4a73, 0x4a74,0x4a75,0x4a76,
  0x4a77,0x4a78,0x4a79,0x4a7a,0x4a7b, 0x4a7c,0x4a7d,0x4a7e,
  0x4a7f,0x4a80,0x4a81,0x4a82,0x4a83, 0x4a84,0x4a85,0x4a86,
  0x4a87,0x4a88,0x4a89,0x4a8a,0x4a8b, 0x4a8c,0x4a8d,0x4a8e,
  0x4a8f,0x4a90,0x4a91,0x4a92,
/* 0xe681(i:18180) */
  0x4a93, 0x4a94,0x4a95,0x4a96,0x4a97,
  0x4a98,0x4a99,0x4a9a,0x4a9b, 0x4a9c,0x4a9d,0x4a9e,0x4a9f,
  0x4aa0,0x4aa1,0x4aa2,0x4aa3, 0x4aa4,0x4aa5,0x4aa6,0x4aa7,
  0x4aa8,0x4aa9,0x4aaa,0x4aab, 0x4aac,0x4aad,0x4aae,0x4aaf,
  0x4ab0,0x4ab1,0x4ab2,0x4ab3, 0x4ab4,0x4ab5,0x4ab6,0x4ab7,
  0x4ab8,0x4ab9,0x4aba,0x4abb, 0x4abc,0x4abd,0x4abe,0x4abf,
  0x4ac0,0x4ac1,0x4ac2,0x4ac3, 0x4ac4,0x4ac5,0x4ac6,0x4ac7,
  0x4ac8,0x4ac9,0x4aca,0x4acb, 0x4acc,0x4acd,0x4ace,0x4acf,
  0x4ad0,0x4ad1,0x4ad2,0x4ad3, 0x4ad4,0x4ad5,0x4ad6,0x4ad7,
  0x4ad8,0x4ad9,0x4ada,0x4adb, 0x4adc,0x4add,0x4ade,0x4adf,
  0x4ae0,0x4ae1,0x4ae2,0x4ae3, 0x4ae4,0x4ae5,0x4ae6,0x4ae7,
  0x4ae8,0x4ae9,0x4aea,0x4aeb, 0x4aec,0x4aed,0x4aee,0x4aef,
  0x4af0,0x4af1,0x4af2,0x4af3, 0x4af4,0x4af5,0x4af6,0x4af7,
  0x4af8,0x4af9,0x4afa,0x4afb, 0x4afc,0x4afd,0x4afe,0x4aff,
  0x4b00,0x4b01,0x4b02,0x4b03, 0x4b04,0x4b05,0x4b06,0x4b07,
  0x4b08,0x4b09,0x4b0a,0x4b0b, 0x4b0c,0x4b0d,0x4b0e,0x4b0f,
  0x4b10,0x4b11,0x4b12,0x4b13, 0x4b14,0x4b15,0x4b16,0x4b17,
  0x4b18,0x4b19,0x4b1a,0x4b1b, 0x4b1c,0x4b1d,0x4b1e,0x4b1f,
  0x4b20,0x4b21,0x4b22,0x4b23, 0x4b24,0x4b25,0x4b26,0x4b27,
  0x4b28,0x4b29,0x4b2a,0x4b2b, 0x4b2c,0x4b2d,0x4b2e,0x4b2f,
  0x4b30,0x4b31,0x4b32,0x4b33, 0x4b34,0x4b35,0x4b36,0x4b37,
  0x4b38,0x4b39,0x4b3a,0x4b3b, 0x4b3c,0x4b3d,0x4b3e,0x4b3f,
  0x4b40,0x4b41,0x4b42,0x4b43, 0x4b44,0x4b45,0x4b46,
/* 0xe781(i:18360) */
  0x4b47,0x4b48,0x4b49,0x4b4a,0x4b4b, 0x4b4c,0x4b4d,0x4b4e,
  0x4b4f,0x4b50,0x4b51,0x4b52,0x4b53, 0x4b54,0x4b55,0x4b56,
  0x4b57,0x4b58,0x4b59,0x4b5a,0x4b5b, 0x4b5c,0x4b5d,0x4b5e,
  0x4b5f,0x4b60,0x4b61,0x4b62,0x4b63, 0x4b64,0x4b65,0x4b66,
  0x4b67,0x4b68,0x4b69,0x4b6a,0x4b6b, 0x4b6c,0x4b6d,0x4b6e,
  0x4b6f,0x4b70,0x4b71,0x4b72,0x4b73, 0x4b74,0x4b75,0x4b76,
  0x4b77,0x4b78,0x4b79,0x4b7a,0x4b7b, 0x4b7c,0x4b7d,0x4b7e,
  0x4b7f,0x4b80,0x4b81,0x4b82,0x4b83, 0x4b84,0x4b85,0x4b86,
  0x4b87,0x4b88,0x4b89,0x4b8a,0x4b8b, 0x4b8c,0x4b8d,0x4b8e,
  0x4b8f,0x4b90,0x4b91,0x4b92,0x4b93, 0x4b94,0x4b95,0x4b96,
  0x4b97,0x4b98,0x4b99,0x4b9a,0x4b9b, 0x4b9c,0x4b9d,0x4b9e,
  0x4b9f,0x4ba0,0x4ba1,0x4ba2,0x4ba3, 0x4ba4,0x4ba5,0x4ba6,
  0x4ba7,0x4ba8,0x4ba9,0x4baa,0x4bab, 0x4bac,0x4bad,0x4bae,
  0x4baf,0x4bb0,0x4bb1,0x4bb2,0x4bb3, 0x4bb4,0x4bb5,0x4bb6,
  0x4bb7,0x4bb8,0x4bb9,0x4bba,0x4bbb, 0x4bbc,0x4bbd,0x4bbe,
  0x4bbf,0x4bc0,0x4bc1,0x4bc2,0x4bc3, 0x4bc4,0x4bc5,0x4bc6,
  0x4bc7,0x4bc8,0x4bc9,0x4bca,0x4bcb, 0x4bcc,0x4bcd,0x4bce,
  0x4bcf,0x4bd0,0x4bd1,0x4bd2,0x4bd3, 0x4bd4,0x4bd5,0x4bd6,
  0x4bd7,0x4bd8,0x4bd9,0x4bda,0x4bdb, 0x4bdc,0x4bdd,0x4bde,
  0x4bdf,0x4be0,0x4be1,0x4be2,0x4be3, 0x4be4,0x4be5,0x4be6,
  0x4be7,0x4be8,0x4be9,0x4bea,0x4beb, 0x4bec,0x4bed,0x4bee,
  0x4bef,0x4bf0,0x4bf1,0x4bf2,0x4bf3, 0x4bf4,0x4bf5,0x4bf6,
  0x4bf7,0x4bf8,0x4bf9,0x4bfa,
/* 0xe881(i:18540) */
  0x4bfb, 0x4bfc,0x4bfd,0x4bfe,0x4bff,0x4c00,0x4c01,0x4c02,
  0x4c03, 0x4c04,0x4c05,0x4c06,0x4c07,0x4c08,0x4c09,0x4c0a,
  0x4c0b, 0x4c0c,0x4c0d,0x4c0e,0x4c0f,0x4c10,0x4c11,0x4c12,
  0x4c13, 0x4c14,0x4c15,0x4c16,0x4c17,0x4c18,0x4c19,0x4c1a,
  0x4c1b, 0x4c1c,0x4c1d,0x4c1e,0x4c1f,0x4c20,0x4c21,0x4c22,
  0x4c23, 0x4c24,0x4c25,0x4c26,0x4c27,0x4c28,0x4c29,0x4c2a,
  0x4c2b, 0x4c2c,0x4c2d,0x4c2e,0x4c2f,0x4c30,0x4c31,0x4c32,
  0x4c33, 0x4c34,0x4c35,0x4c36,0x4c37,0x4c38,0x4c39,0x4c3a,
  0x4c3b, 0x4c3c,0x4c3d,0x4c3e,0x4c3f,0x4c40,0x4c41,0x4c42,
  0x4c43, 0x4c44,0x4c45,0x4c46,0x4c47,0x4c48,0x4c49,0x4c4a,
  0x4c4b, 0x4c4c,0x4c4d,0x4c4e,0x4c4f,0x4c50,0x4c51,0x4c52,
  0x4c53, 0x4c54,0x4c55,0x4c56,0x4c57,0x4c58,0x4c59,0x4c5a,
  0x4c5b, 0x4c5c,0x4c5d,0x4c5e,0x4c5f,0x4c60,0x4c61,0x4c62,
  0x4c63, 0x4c64,0x4c65,0x4c66,0x4c67,0x4c68,0x4c69,0x4c6a,
  0x4c6b, 0x4c6c,0x4c6d,0x4c6e,0x4c6f,0x4c70,0x4c71,0x4c72,
  0x4c73, 0x4c74,0x4c75,0x4c76,0x4c78,0x4c79,0x4c7a,0x4c7b,
  0x4c7c,0x4c7d,0x4c7e,0x4c7f, 0x4c80,0x4c81,0x4c82,0x4c83,
  0x4c84,0x4c85,0x4c86,0x4c87, 0x4c88,0x4c89,0x4c8a,0x4c8b,
  0x4c8c,0x4c8d,0x4c8e,0x4c8f, 0x4c90,0x4c91,0x4c92,0x4c93,
  0x4c94,0x4c95,0x4c96,0x4c97, 0x4c98,0x4c99,0x4c9a,0x4c9b,
  0x4c9c,0x4c9d,0x4c9e,0x4ca4, 0x4ca5,0x4ca6,0x4ca7,0x4ca8,
  0x4ca9,0x4caa,0x4cab,0x4cac, 0x4cad,0x4cae,0x4caf,0x4cb0,
  0x4cb1,0x4cb2,0x4cb3,0x4cb4, 
/* 0xe981(i:18720) */
  0x4cb5,0x4cb6,0x4cb7,0x4cb8, 0x4cb9,0x4cba,0x4cbb,0x4cbc,
  0x4cbd,0x4cbe,0x4cbf,0x4cc0, 0x4cc1,0x4cc2,0x4cc3,0x4cc4,
  0x4cc5,0x4cc6,0x4cc7,0x4cc8, 0x4cc9,0x4cca,0x4ccb,0x4ccc,
  0x4ccd,0x4cce,0x4ccf,0x4cd0, 0x4cd1,0x4cd2,0x4cd3,0x4cd4,
  0x4cd5,0x4cd6,0x4cd7,0x4cd8, 0x4cd9,0x4cda,0x4cdb,0x4cdc,
  0x4cdd,0x4cde,0x4cdf,0x4ce0, 0x4ce1,0x4ce2,0x4ce3,0x4ce4,
  0x4ce5,0x4ce6,0x4ce7,0x4ce8, 0x4ce9,0x4cea,0x4ceb,0x4cec,
  0x4ced,0x4cee,0x4cef,0x4cf0, 0x4cf1,0x4cf2,0x4cf3,0x4cf4,
  0x4cf5,0x4cf6,0x4cf7,0x4cf8, 0x4cf9,0x4cfa,0x4cfb,0x4cfc,
  0x4cfd,0x4cfe,0x4cff,0x4d00, 0x4d01,0x4d02,0x4d03,0x4d04,
  0x4d05,0x4d06,0x4d07,0x4d08, 0x4d09,0x4d0a,0x4d0b,0x4d0c,
  0x4d0d,0x4d0e,0x4d0f,0x4d10, 0x4d11,0x4d12,0x4d1a,0x4d1b,
  0x4d1c,0x4d1d,0x4d1e,0x4d1f, 0x4d20,0x4d21,0x4d22,0x4d23,
  0x4d24,0x4d25,0x4d26,0x4d27, 0x4d28,0x4d29,0x4d2a,0x4d2b,
  0x4d2c,0x4d2d,0x4d2e,0x4d2f, 0x4d30,0x4d31,0x4d32,0x4d33,
  0x4d34,0x4d35,0x4d36,0x4d37, 0x4d38,0x4d39,0x4d3a,0x4d3b,
  0x4d3c,0x4d3d,0x4d3e,0x4d3f, 0x4d40,0x4d41,0x4d42,0x4d43,
  0x4d44,0x4d45,0x4d46,0x4d47, 0x4d48,0x4d49,0x4d4a,0x4d4b,
  0x4d4c,0x4d4d,0x4d4e,0x4d4f, 0x4d50,0x4d51,0x4d52,0x4d53,
  0x4d54,0x4d55,0x4d56,0x4d57, 0x4d58,0x4d59,0x4d5a,0x4d5b,
  0x4d5c,0x4d5d,0x4d5e,0x4d5f, 0x4d60,0x4d61,0x4d62,0x4d63,
  0x4d64,0x4d65,0x4d66,0x4d67, 0x4d68,0x4d69,0x4d6a,0x4d6b,
  0x4d6c,0x4d6d,0x4d6e,0x4d6f, 
/* 0xea81(i:18900) */
  0x4d70,0x4d71,0x4d72,0x4d73, 0x4d74,0x4d75,0x4d76,0x4d77,
  0x4d78,0x4d79,0x4d7a,0x4d7b, 0x4d7c,0x4d7d,0x4d7e,0x4d7f,
  0x4d80,0x4d81,0x4d82,0x4d83, 0x4d84,0x4d85,0x4d86,0x4d87,
  0x4d88,0x4d89,0x4d8a,0x4d8b, 0x4d8c,0x4d8d,0x4d8e,0x4d8f,
  0x4d90,0x4d91,0x4d92,0x4d93, 0x4d94,0x4d95,0x4d96,0x4d97,
  0x4d98,0x4d99,0x4d9a,0x4d9b, 0x4d9c,0x4d9d,0x4d9e,0x4d9f,
  0x4da0,0x4da1,0x4da2,0x4da3, 0x4da4,0x4da5,0x4da6,0x4da7,
  0x4da8,0x4da9,0x4daa,0x4dab, 0x4dac,0x4dad,0x4daf,0x4db0,
  0x4db1,0x4db2,0x4db3,0x4db4, 0x4db5,0x4db6,0x4db7,0x4db8,
  0x4db9,0x4dba,0x4dbb,0x4dbc, 0x4dbd,0x4dbe,0x4dbf,0x4dc0,
  0x4dc1,0x4dc2,0x4dc3,0x4dc4, 0x4dc5,0x4dc6,0x4dc7,0x4dc8,
  0x4dc9,0x4dca,0x4dcb,0x4dcc, 0x4dcd,0x4dce,0x4dcf,0x4dd0,
  0x4dd1,0x4dd2,0x4dd3,0x4dd4, 0x4dd5,0x4dd6,0x4dd7,0x4dd8,
  0x4dd9,0x4dda,0x4ddb,0x4ddc, 0x4ddd,0x4dde,0x4ddf,0x4de0,
  0x4de1,0x4de2,0x4de3,0x4de4, 0x4de5,0x4de6,0x4de7,0x4de8,
  0x4de9,0x4dea,0x4deb,0x4dec, 0x4ded,0x4dee,0x4def,0x4df0,
  0x4df1,0x4df2,0x4df3,0x4df4, 0x4df5,0x4df6,0x4df7,0x4df8,
  0x4df9,0x4dfa,0x4dfb,0x4dfc, 0x4dfd,0x4dfe,0x4dff,0x9fa6,
  0x9fa7,0x9fa8,0x9fa9,0x9faa, 0x9fab,0x9fac,0x9fad,0x9fae,
  0x9faf,0x9fb0,0x9fb1,0x9fb2, 0x9fb3,0x9fb4,0x9fb5,0x9fb6,
  0x9fb7,0x9fb8,0x9fb9,0x9fba, 0x9fbb,0x9fbc,0x9fbd,0x9fbe,
  0x9fbf,0x9fc0,0x9fc1,0x9fc2, 0x9fc3,0x9fc4,0x9fc5,0x9fc6,
  0x9fc7,0x9fc8,0x9fc9,0x9fca, 
/* 0xeb81(i:19080) */
  0x9fcb,0x9fcc,0x9fcd,0x9fce, 0x9fcf,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 
/* 0xec81(i:19260) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 
/* 0xed81(i:19440) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 
/* 0xee81(i:19620) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 
/* 0xef81(i:19800) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 
/* 0xf081(i:19980) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 
/* 0xf181(i:20160) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 
/* 0xf281(i:20340) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 
/* 0xf381(i:20520) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 
/* 0xf481(i:20700) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 
/* 0xf581(i:20880) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 
/* 0xf681(i:21060) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 
/* 0xf781(i:21240) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 
/* 0xf881(i:21420) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 
/* 0xf981(i:21600) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 
/* 0xfa81(i:21780) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 
/* 0xfb81(i:21960) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 
/* 0xfc81(i:22140) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 
/* 0xfd81(i:22320) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 
/* 0xfe81(i:22500) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 
/* 0xff81(i:22680) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 
/* 0x10081(i:22860) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 
/* 0x10181(i:23040) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 
/* 0x10281(i:23220) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 
/* 0x10381(i:23400) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 
/* 0x10481(i:23580) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 
/* 0x10581(i:23760) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 
/* 0x10681(i:23940) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 
/* 0x10781(i:24120) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 
/* 0x10881(i:24300) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 
/* 0x10981(i:24480) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 
/* 0x10a81(i:24660) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 
/* 0x10b81(i:24840) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 
/* 0x10c81(i:25020) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 
/* 0x10d81(i:25200) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 
/* 0x10e81(i:25380) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 
/* 0x10f81(i:25560) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 
/* 0x11081(i:25740) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 
/* overlay: 0x83368130 - 0x8431fe39 */
/* 0x11281(i:26100) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 
/* 0x11381(i:26280) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 
/* 0x11481(i:26460) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 
/* 0x11581(i:26640) */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0xe76c,0xe7c8,0xe7e7, 0xe7e8,0xe7e9,0xe7ea,0xe7eb,
  0xe7ec,0xe7ed,0xe7ee,0xe7ef, 
/* 0x11681(i:26820) */
  0xe7f0,0xe7f1,0xe7f2,0xe7f3, 0xe815,0xe819,0xe81a,0xe81b,
  0xe81c,0xe81d,0xe81f,0xe820, 0xe821,0xe822,0xe823,0xe824,
  0xe825,0xe827,0xe828,0xe829, 0xe82a,0xe82d,0xe82e,0xe82f,
  0xe830,0xe833,0xe834,0xe835, 0xe836,0xe837,0xe838,0xe839,
  0xe83a,0xe83c,0xe83d,0xe83e, 0xe83f,0xe840,0xe841,0xe842,
  0xe844,0xe845,0xe846,0xe847, 0xe848,0xe849,0xe84a,0xe84b,
  0xe84c,0xe84d,0xe84e,0xe84f, 0xe850,0xe851,0xe852,0xe853,
  0xe856,0xe857,0xe858,0xe859, 0xe85a,0xe85b,0xe85c,0xe85d,
  0xe85e,0xe85f,0xe860,0xe861, 0xe862,0xe863,0xe865,0xe866,
  0xe867,0xe868,0xe869,0xe86a,0xe86b, 0xe86c,0xe86d,0xe86e,
  0xe86f,0xe870,0xe871,0xe872,0xe873, 0xe874,0xe875,0xe876,
  0xe877,0xe878,0xe879,0xe87a,0xe87b, 0xe87c,0xe87d,0xe87e,
  0xe87f,0xe880,0xe881,0xe882,0xe883, 0xe884,0xe885,0xe886,
  0xe887,0xe888,0xe889,0xe88a,0xe88b, 0xe88c,0xe88d,0xe88e,
  0xe88f,0xe890,0xe891,0xe892,0xe893, 0xe894,0xe895,0xe896,
  0xe897,0xe898,0xe899,0xe89a,0xe89b, 0xe89c,0xe89d,0xe89e,
  0xe89f,0xe8a0,0xe8a1,0xe8a2,0xe8a3, 0xe8a4,0xe8a5,0xe8a6,
  0xe8a7,0xe8a8,0xe8a9,0xe8aa,0xe8ab, 0xe8ac,0xe8ad,0xe8ae,
  0xe8af,0xe8b0,0xe8b1,0xe8b2,0xe8b3, 0xe8b4,0xe8b5,0xe8b6,
  0xe8b7,0xe8b8,0xe8b9,0xe8ba,0xe8bb, 0xe8bc,0xe8bd,0xe8be,
  0xe8bf,0xe8c0,0xe8c1,0xe8c2,0xe8c3, 0xe8c4,0xe8c5,0xe8c6,
  0xe8c7,0xe8c8,0xe8c9,0xe8ca,0xe8cb, 0xe8cc,0xe8cd,0xe8ce,
  0xe8cf,0xe8d0,0xe8d1,0xe8d2,
/* 0x11781(i:27000) */
  0xe8d3, 0xe8d4,0xe8d5,0xe8d6,0xe8d7,
  0xe8d8,0xe8d9,0xe8da,0xe8db, 0xe8dc,0xe8dd,0xe8de,0xe8df,
  0xe8e0,0xe8e1,0xe8e2,0xe8e3, 0xe8e4,0xe8e5,0xe8e6,0xe8e7,
  0xe8e8,0xe8e9,0xe8ea,0xe8eb, 0xe8ec,0xe8ed,0xe8ee,0xe8ef,
  0xe8f0,0xe8f1,0xe8f2,0xe8f3, 0xe8f4,0xe8f5,0xe8f6,0xe8f7,
  0xe8f8,0xe8f9,0xe8fa,0xe8fb, 0xe8fc,0xe8fd,0xe8fe,0xe8ff,
  0xe900,0xe901,0xe902,0xe903, 0xe904,0xe905,0xe906,0xe907,
  0xe908,0xe909,0xe90a,0xe90b, 0xe90c,0xe90d,0xe90e,0xe90f,
  0xe910,0xe911,0xe912,0xe913, 0xe914,0xe915,0xe916,0xe917,
  0xe918,0xe919,0xe91a,0xe91b, 0xe91c,0xe91d,0xe91e,0xe91f,
  0xe920,0xe921,0xe922,0xe923, 0xe924,0xe925,0xe926,0xe927,
  0xe928,0xe929,0xe92a,0xe92b, 0xe92c,0xe92d,0xe92e,0xe92f,
  0xe930,0xe931,0xe932,0xe933, 0xe934,0xe935,0xe936,0xe937,
  0xe938,0xe939,0xe93a,0xe93b, 0xe93c,0xe93d,0xe93e,0xe93f,
  0xe940,0xe941,0xe942,0xe943, 0xe944,0xe945,0xe946,0xe947,
  0xe948,0xe949,0xe94a,0xe94b, 0xe94c,0xe94d,0xe94e,0xe94f,
  0xe950,0xe951,0xe952,0xe953, 0xe954,0xe955,0xe956,0xe957,
  0xe958,0xe959,0xe95a,0xe95b, 0xe95c,0xe95d,0xe95e,0xe95f,
  0xe960,0xe961,0xe962,0xe963, 0xe964,0xe965,0xe966,0xe967,
  0xe968,0xe969,0xe96a,0xe96b, 0xe96c,0xe96d,0xe96e,0xe96f,
  0xe970,0xe971,0xe972,0xe973, 0xe974,0xe975,0xe976,0xe977,
  0xe978,0xe979,0xe97a,0xe97b, 0xe97c,0xe97d,0xe97e,0xe97f,
  0xe980,0xe981,0xe982,0xe983, 0xe984,0xe985,0xe986,
/* 0x11881(i:27180) */
  0xe987,0xe988,0xe989,0xe98a,0xe98b, 0xe98c,0xe98d,0xe98e,
  0xe98f,0xe990,0xe991,0xe992,0xe993, 0xe994,0xe995,0xe996,
  0xe997,0xe998,0xe999,0xe99a,0xe99b, 0xe99c,0xe99d,0xe99e,
  0xe99f,0xe9a0,0xe9a1,0xe9a2,0xe9a3, 0xe9a4,0xe9a5,0xe9a6,
  0xe9a7,0xe9a8,0xe9a9,0xe9aa,0xe9ab, 0xe9ac,0xe9ad,0xe9ae,
  0xe9af,0xe9b0,0xe9b1,0xe9b2,0xe9b3, 0xe9b4,0xe9b5,0xe9b6,
  0xe9b7,0xe9b8,0xe9b9,0xe9ba,0xe9bb, 0xe9bc,0xe9bd,0xe9be,
  0xe9bf,0xe9c0,0xe9c1,0xe9c2,0xe9c3, 0xe9c4,0xe9c5,0xe9c6,
  0xe9c7,0xe9c8,0xe9c9,0xe9ca,0xe9cb, 0xe9cc,0xe9cd,0xe9ce,
  0xe9cf,0xe9d0,0xe9d1,0xe9d2,0xe9d3, 0xe9d4,0xe9d5,0xe9d6,
  0xe9d7,0xe9d8,0xe9d9,0xe9da,0xe9db, 0xe9dc,0xe9dd,0xe9de,
  0xe9df,0xe9e0,0xe9e1,0xe9e2,0xe9e3, 0xe9e4,0xe9e5,0xe9e6,
  0xe9e7,0xe9e8,0xe9e9,0xe9ea,0xe9eb, 0xe9ec,0xe9ed,0xe9ee,
  0xe9ef,0xe9f0,0xe9f1,0xe9f2,0xe9f3, 0xe9f4,0xe9f5,0xe9f6,
  0xe9f7,0xe9f8,0xe9f9,0xe9fa,0xe9fb, 0xe9fc,0xe9fd,0xe9fe,
  0xe9ff,0xea00,0xea01,0xea02,0xea03, 0xea04,0xea05,0xea06,
  0xea07,0xea08,0xea09,0xea0a,0xea0b, 0xea0c,0xea0d,0xea0e,
  0xea0f,0xea10,0xea11,0xea12,0xea13, 0xea14,0xea15,0xea16,
  0xea17,0xea18,0xea19,0xea1a,0xea1b, 0xea1c,0xea1d,0xea1e,
  0xea1f,0xea20,0xea21,0xea22,0xea23, 0xea24,0xea25,0xea26,
  0xea27,0xea28,0xea29,0xea2a,0xea2b, 0xea2c,0xea2d,0xea2e,
  0xea2f,0xea30,0xea31,0xea32,0xea33, 0xea34,0xea35,0xea36,
  0xea37,0xea38,0xea39,0xea3a,
/* 0x11981(i:27360) */
  0xea3b, 0xea3c,0xea3d,0xea3e,0xea3f,
  0xea40,0xea41,0xea42,0xea43, 0xea44,0xea45,0xea46,0xea47,
  0xea48,0xea49,0xea4a,0xea4b, 0xea4c,0xea4d,0xea4e,0xea4f,
  0xea50,0xea51,0xea52,0xea53, 0xea54,0xea55,0xea56,0xea57,
  0xea58,0xea59,0xea5a,0xea5b, 0xea5c,0xea5d,0xea5e,0xea5f,
  0xea60,0xea61,0xea62,0xea63, 0xea64,0xea65,0xea66,0xea67,
  0xea68,0xea69,0xea6a,0xea6b, 0xea6c,0xea6d,0xea6e,0xea6f,
  0xea70,0xea71,0xea72,0xea73, 0xea74,0xea75,0xea76,0xea77,
  0xea78,0xea79,0xea7a,0xea7b, 0xea7c,0xea7d,0xea7e,0xea7f,
  0xea80,0xea81,0xea82,0xea83, 0xea84,0xea85,0xea86,0xea87,
  0xea88,0xea89,0xea8a,0xea8b, 0xea8c,0xea8d,0xea8e,0xea8f,
  0xea90,0xea91,0xea92,0xea93, 0xea94,0xea95,0xea96,0xea97,
  0xea98,0xea99,0xea9a,0xea9b, 0xea9c,0xea9d,0xea9e,0xea9f,
  0xeaa0,0xeaa1,0xeaa2,0xeaa3, 0xeaa4,0xeaa5,0xeaa6,0xeaa7,
  0xeaa8,0xeaa9,0xeaaa,0xeaab, 0xeaac,0xeaad,0xeaae,0xeaaf,
  0xeab0,0xeab1,0xeab2,0xeab3, 0xeab4,0xeab5,0xeab6,0xeab7,
  0xeab8,0xeab9,0xeaba,0xeabb, 0xeabc,0xeabd,0xeabe,0xeabf,
  0xeac0,0xeac1,0xeac2,0xeac3, 0xeac4,0xeac5,0xeac6,0xeac7,
  0xeac8,0xeac9,0xeaca,0xeacb, 0xeacc,0xeacd,0xeace,0xeacf,
  0xead0,0xead1,0xead2,0xead3, 0xead4,0xead5,0xead6,0xead7,
  0xead8,0xead9,0xeada,0xeadb, 0xeadc,0xeadd,0xeade,0xeadf,
  0xeae0,0xeae1,0xeae2,0xeae3, 0xeae4,0xeae5,0xeae6,0xeae7,
  0xeae8,0xeae9,0xeaea,0xeaeb, 0xeaec,0xeaed,0xeaee,
/* 0x11a81(i:27540) */
  0xeaef,0xeaf0,0xeaf1,0xeaf2,0xeaf3, 0xeaf4,0xeaf5,0xeaf6,
  0xeaf7,0xeaf8,0xeaf9,0xeafa,0xeafb, 0xeafc,0xeafd,0xeafe,
  0xeaff,0xeb00,0xeb01,0xeb02,0xeb03, 0xeb04,0xeb05,0xeb06,
  0xeb07,0xeb08,0xeb09,0xeb0a,0xeb0b, 0xeb0c,0xeb0d,0xeb0e,
  0xeb0f,0xeb10,0xeb11,0xeb12,0xeb13, 0xeb14,0xeb15,0xeb16,
  0xeb17,0xeb18,0xeb19,0xeb1a,0xeb1b, 0xeb1c,0xeb1d,0xeb1e,
  0xeb1f,0xeb20,0xeb21,0xeb22,0xeb23, 0xeb24,0xeb25,0xeb26,
  0xeb27,0xeb28,0xeb29,0xeb2a,0xeb2b, 0xeb2c,0xeb2d,0xeb2e,
  0xeb2f,0xeb30,0xeb31,0xeb32,0xeb33, 0xeb34,0xeb35,0xeb36,
  0xeb37,0xeb38,0xeb39,0xeb3a,0xeb3b, 0xeb3c,0xeb3d,0xeb3e,
  0xeb3f,0xeb40,0xeb41,0xeb42,0xeb43, 0xeb44,0xeb45,0xeb46,
  0xeb47,0xeb48,0xeb49,0xeb4a,0xeb4b, 0xeb4c,0xeb4d,0xeb4e,
  0xeb4f,0xeb50,0xeb51,0xeb52,0xeb53, 0xeb54,0xeb55,0xeb56,
  0xeb57,0xeb58,0xeb59,0xeb5a,0xeb5b, 0xeb5c,0xeb5d,0xeb5e,
  0xeb5f,0xeb60,0xeb61,0xeb62,0xeb63, 0xeb64,0xeb65,0xeb66,
  0xeb67,0xeb68,0xeb69,0xeb6a,0xeb6b, 0xeb6c,0xeb6d,0xeb6e,
  0xeb6f,0xeb70,0xeb71,0xeb72,0xeb73, 0xeb74,0xeb75,0xeb76,
  0xeb77,0xeb78,0xeb79,0xeb7a,0xeb7b, 0xeb7c,0xeb7d,0xeb7e,
  0xeb7f,0xeb80,0xeb81,0xeb82,0xeb83, 0xeb84,0xeb85,0xeb86,
  0xeb87,0xeb88,0xeb89,0xeb8a,0xeb8b, 0xeb8c,0xeb8d,0xeb8e,
  0xeb8f,0xeb90,0xeb91,0xeb92,0xeb93, 0xeb94,0xeb95,0xeb96,
  0xeb97,0xeb98,0xeb99,0xeb9a,0xeb9b, 0xeb9c,0xeb9d,0xeb9e,
  0xeb9f,0xeba0,0xeba1,0xeba2,
/* 0x11b81(i:27720) */
  0xeba3, 0xeba4,0xeba5,0xeba6,0xeba7,
  0xeba8,0xeba9,0xebaa,0xebab, 0xebac,0xebad,0xebae,0xebaf,
  0xebb0,0xebb1,0xebb2,0xebb3, 0xebb4,0xebb5,0xebb6,0xebb7,
  0xebb8,0xebb9,0xebba,0xebbb, 0xebbc,0xebbd,0xebbe,0xebbf,
  0xebc0,0xebc1,0xebc2,0xebc3, 0xebc4,0xebc5,0xebc6,0xebc7,
  0xebc8,0xebc9,0xebca,0xebcb, 0xebcc,0xebcd,0xebce,0xebcf,
  0xebd0,0xebd1,0xebd2,0xebd3, 0xebd4,0xebd5,0xebd6,0xebd7,
  0xebd8,0xebd9,0xebda,0xebdb, 0xebdc,0xebdd,0xebde,0xebdf,
  0xebe0,0xebe1,0xebe2,0xebe3, 0xebe4,0xebe5,0xebe6,0xebe7,
  0xebe8,0xebe9,0xebea,0xebeb, 0xebec,0xebed,0xebee,0xebef,
  0xebf0,0xebf1,0xebf2,0xebf3, 0xebf4,0xebf5,0xebf6,0xebf7,
  0xebf8,0xebf9,0xebfa,0xebfb, 0xebfc,0xebfd,0xebfe,0xebff,
  0xec00,0xec01,0xec02,0xec03, 0xec04,0xec05,0xec06,0xec07,
  0xec08,0xec09,0xec0a,0xec0b, 0xec0c,0xec0d,0xec0e,0xec0f,
  0xec10,0xec11,0xec12,0xec13, 0xec14,0xec15,0xec16,0xec17,
  0xec18,0xec19,0xec1a,0xec1b, 0xec1c,0xec1d,0xec1e,0xec1f,
  0xec20,0xec21,0xec22,0xec23, 0xec24,0xec25,0xec26,0xec27,
  0xec28,0xec29,0xec2a,0xec2b, 0xec2c,0xec2d,0xec2e,0xec2f,
  0xec30,0xec31,0xec32,0xec33, 0xec34,0xec35,0xec36,0xec37,
  0xec38,0xec39,0xec3a,0xec3b, 0xec3c,0xec3d,0xec3e,0xec3f,
  0xec40,0xec41,0xec42,0xec43, 0xec44,0xec45,0xec46,0xec47,
  0xec48,0xec49,0xec4a,0xec4b, 0xec4c,0xec4d,0xec4e,0xec4f,
  0xec50,0xec51,0xec52,0xec53, 0xec54,0xec55,0xec56,0xec57,
/* 0x11c81(i:27901) */
  0xec58,0xec59,0xec5a,0xec5b, 0xec5c,0xec5d,0xec5e,0xec5f,
  0xec60,0xec61,0xec62,0xec63, 0xec64,0xec65,0xec66,0xec67,
  0xec68,0xec69,0xec6a,0xec6b, 0xec6c,0xec6d,0xec6e,0xec6f,
  0xec70,0xec71,0xec72,0xec73, 0xec74,0xec75,0xec76,0xec77,
  0xec78,0xec79,0xec7a,0xec7b, 0xec7c,0xec7d,0xec7e,0xec7f,
  0xec80,0xec81,0xec82,0xec83, 0xec84,0xec85,0xec86,0xec87,
  0xec88,0xec89,0xec8a,0xec8b, 0xec8c,0xec8d,0xec8e,0xec8f,
  0xec90,0xec91,0xec92,0xec93, 0xec94,0xec95,0xec96,0xec97,
  0xec98,0xec99,0xec9a,0xec9b, 0xec9c,0xec9d,0xec9e,0xec9f,
  0xeca0,0xeca1,0xeca2,0xeca3, 0xeca4,0xeca5,0xeca6,0xeca7,
  0xeca8,0xeca9,0xecaa,0xecab, 0xecac,0xecad,0xecae,0xecaf,
  0xecb0,0xecb1,0xecb2,0xecb3, 0xecb4,0xecb5,0xecb6,0xecb7,
  0xecb8,0xecb9,0xecba,0xecbb, 0xecbc,0xecbd,0xecbe,0xecbf,
  0xecc0,0xecc1,0xecc2,0xecc3, 0xecc4,0xecc5,0xecc6,0xecc7,
  0xecc8,0xecc9,0xecca,0xeccb, 0xeccc,0xeccd,0xecce,0xeccf,
  0xecd0,0xecd1,0xecd2,0xecd3, 0xecd4,0xecd5,0xecd6,0xecd7,
  0xecd8,0xecd9,0xecda,0xecdb, 0xecdc,0xecdd,0xecde,0xecdf,
  0xece0,0xece1,0xece2,0xece3, 0xece4,0xece5,0xece6,0xece7,
  0xece8,0xece9,0xecea,0xeceb, 0xecec,0xeced,0xecee,0xecef,
  0xecf0,0xecf1,0xecf2,0xecf3, 0xecf4,0xecf5,0xecf6,0xecf7,
  0xecf8,0xecf9,0xecfa,0xecfb, 0xecfc,0xecfd,0xecfe,0xecff,
  0xed00,0xed01,0xed02,0xed03, 0xed04,0xed05,0xed06,0xed07,
  0xed08,0xed09,0xed0a,
/* 0x11d81(i:28080) */
  0xed0b, 0xed0c,0xed0d,0xed0e,0xed0f,
  0xed10,0xed11,0xed12,0xed13, 0xed14,0xed15,0xed16,0xed17,
  0xed18,0xed19,0xed1a,0xed1b, 0xed1c,0xed1d,0xed1e,0xed1f,
  0xed20,0xed21,0xed22,0xed23, 0xed24,0xed25,0xed26,0xed27,
  0xed28,0xed29,0xed2a,0xed2b, 0xed2c,0xed2d,0xed2e,0xed2f,
  0xed30,0xed31,0xed32,0xed33, 0xed34,0xed35,0xed36,0xed37,
  0xed38,0xed39,0xed3a,0xed3b, 0xed3c,0xed3d,0xed3e,0xed3f,
  0xed40,0xed41,0xed42,0xed43, 0xed44,0xed45,0xed46,0xed47,
  0xed48,0xed49,0xed4a,0xed4b, 0xed4c,0xed4d,0xed4e,0xed4f,
  0xed50,0xed51,0xed52,0xed53, 0xed54,0xed55,0xed56,0xed57,
  0xed58,0xed59,0xed5a,0xed5b, 0xed5c,0xed5d,0xed5e,0xed5f,
  0xed60,0xed61,0xed62,0xed63, 0xed64,0xed65,0xed66,0xed67,
  0xed68,0xed69,0xed6a,0xed6b, 0xed6c,0xed6d,0xed6e,0xed6f,
  0xed70,0xed71,0xed72,0xed73, 0xed74,0xed75,0xed76,0xed77,
  0xed78,0xed79,0xed7a,0xed7b, 0xed7c,0xed7d,0xed7e,0xed7f,
  0xed80,0xed81,0xed82,0xed83, 0xed84,0xed85,0xed86,0xed87,
  0xed88,0xed89,0xed8a,0xed8b, 0xed8c,0xed8d,0xed8e,0xed8f,
  0xed90,0xed91,0xed92,0xed93, 0xed94,0xed95,0xed96,0xed97,
  0xed98,0xed99,0xed9a,0xed9b, 0xed9c,0xed9d,0xed9e,0xed9f,
  0xeda0,0xeda1,0xeda2,0xeda3, 0xeda4,0xeda5,0xeda6,0xeda7,
  0xeda8,0xeda9,0xedaa,0xedab, 0xedac,0xedad,0xedae,0xedaf,
  0xedb0,0xedb1,0xedb2,0xedb3, 0xedb4,0xedb5,0xedb6,0xedb7,
  0xedb8,0xedb9,0xedba,0xedbb, 0xedbc,0xedbd,0xedbe,
/* 0x11e81(i:28260) */
  0xedbf,0xedc0,0xedc1,0xedc2,0xedc3, 0xedc4,0xedc5,0xedc6,
  0xedc7,0xedc8,0xedc9,0xedca,0xedcb, 0xedcc,0xedcd,0xedce,
  0xedcf,0xedd0,0xedd1,0xedd2,0xedd3, 0xedd4,0xedd5,0xedd6,
  0xedd7,0xedd8,0xedd9,0xedda,0xeddb, 0xeddc,0xeddd,0xedde,
  0xeddf,0xede0,0xede1,0xede2,0xede3, 0xede4,0xede5,0xede6,
  0xede7,0xede8,0xede9,0xedea,0xedeb, 0xedec,0xeded,0xedee,
  0xedef,0xedf0,0xedf1,0xedf2,0xedf3, 0xedf4,0xedf5,0xedf6,
  0xedf7,0xedf8,0xedf9,0xedfa,0xedfb, 0xedfc,0xedfd,0xedfe,
  0xedff,0xee00,0xee01,0xee02,0xee03, 0xee04,0xee05,0xee06,
  0xee07,0xee08,0xee09,0xee0a,0xee0b, 0xee0c,0xee0d,0xee0e,
  0xee0f,0xee10,0xee11,0xee12,0xee13, 0xee14,0xee15,0xee16,
  0xee17,0xee18,0xee19,0xee1a,0xee1b, 0xee1c,0xee1d,0xee1e,
  0xee1f,0xee20,0xee21,0xee22,0xee23, 0xee24,0xee25,0xee26,
  0xee27,0xee28,0xee29,0xee2a,0xee2b, 0xee2c,0xee2d,0xee2e,
  0xee2f,0xee30,0xee31,0xee32,0xee33, 0xee34,0xee35,0xee36,
  0xee37,0xee38,0xee39,0xee3a,0xee3b, 0xee3c,0xee3d,0xee3e,
  0xee3f,0xee40,0xee41,0xee42,0xee43, 0xee44,0xee45,0xee46,
  0xee47,0xee48,0xee49,0xee4a,0xee4b, 0xee4c,0xee4d,0xee4e,
  0xee4f,0xee50,0xee51,0xee52,0xee53, 0xee54,0xee55,0xee56,
  0xee57,0xee58,0xee59,0xee5a,0xee5b, 0xee5c,0xee5d,0xee5e,
  0xee5f,0xee60,0xee61,0xee62,0xee63, 0xee64,0xee65,0xee66,
  0xee67,0xee68,0xee69,0xee6a,0xee6b, 0xee6c,0xee6d,0xee6e,
  0xee6f,0xee70,0xee71,0xee72,
/* 0x11f81(i:28440) */
  0xee73, 0xee74,0xee75,0xee76,0xee77,
  0xee78,0xee79,0xee7a,0xee7b, 0xee7c,0xee7d,0xee7e,0xee7f,
  0xee80,0xee81,0xee82,0xee83, 0xee84,0xee85,0xee86,0xee87,
  0xee88,0xee89,0xee8a,0xee8b, 0xee8c,0xee8d,0xee8e,0xee8f,
  0xee90,0xee91,0xee92,0xee93, 0xee94,0xee95,0xee96,0xee97,
  0xee98,0xee99,0xee9a,0xee9b, 0xee9c,0xee9d,0xee9e,0xee9f,
  0xeea0,0xeea1,0xeea2,0xeea3, 0xeea4,0xeea5,0xeea6,0xeea7,
  0xeea8,0xeea9,0xeeaa,0xeeab, 0xeeac,0xeead,0xeeae,0xeeaf,
  0xeeb0,0xeeb1,0xeeb2,0xeeb3, 0xeeb4,0xeeb5,0xeeb6,0xeeb7,
  0xeeb8,0xeeb9,0xeeba,0xeebb, 0xeebc,0xeebd,0xeebe,0xeebf,
  0xeec0,0xeec1,0xeec2,0xeec3, 0xeec4,0xeec5,0xeec6,0xeec7,
  0xeec8,0xeec9,0xeeca,0xeecb, 0xeecc,0xeecd,0xeece,0xeecf,
  0xeed0,0xeed1,0xeed2,0xeed3, 0xeed4,0xeed5,0xeed6,0xeed7,
  0xeed8,0xeed9,0xeeda,0xeedb, 0xeedc,0xeedd,0xeede,0xeedf,
  0xeee0,0xeee1,0xeee2,0xeee3, 0xeee4,0xeee5,0xeee6,0xeee7,
  0xeee8,0xeee9,0xeeea,0xeeeb, 0xeeec,0xeeed,0xeeee,0xeeef,
  0xeef0,0xeef1,0xeef2,0xeef3, 0xeef4,0xeef5,0xeef6,0xeef7,
  0xeef8,0xeef9,0xeefa,0xeefb, 0xeefc,0xeefd,0xeefe,0xeeff,
  0xef00,0xef01,0xef02,0xef03, 0xef04,0xef05,0xef06,0xef07,
  0xef08,0xef09,0xef0a,0xef0b, 0xef0c,0xef0d,0xef0e,0xef0f,
  0xef10,0xef11,0xef12,0xef13, 0xef14,0xef15,0xef16,0xef17,
  0xef18,0xef19,0xef1a,0xef1b, 0xef1c,0xef1d,0xef1e,0xef1f,
  0xef20,0xef21,0xef22,0xef23, 0xef24,0xef25,0xef26,
/* 0x12081(i:28620) */
  0xef27,
  0xef28,0xef29,0xef2a,0xef2b, 0xef2c,0xef2d,0xef2e,0xef2f,
  0xef30,0xef31,0xef32,0xef33, 0xef34,0xef35,0xef36,0xef37,
  0xef38,0xef39,0xef3a,0xef3b, 0xef3c,0xef3d,0xef3e,0xef3f,

  0xef40,0xef41,0xef42,0xef43, 0xef44,0xef45,0xef46,0xef47,
  0xef48,0xef49,0xef4a,0xef4b, 0xef4c,0xef4d,0xef4e,0xef4f,
  0xef50,0xef51,0xef52,0xef53, 0xef54,0xef55,0xef56,0xef57,
  0xef58,0xef59,0xef5a,0xef5b, 0xef5c,0xef5d,0xef5e,0xef5f,
  0xef60,0xef61,0xef62,0xef63, 0xef64,0xef65,0xef66,0xef67,
  0xef68,0xef69,0xef6a,0xef6b, 0xef6c,0xef6d,0xef6e,0xef6f,
  0xef70,0xef71,0xef72,0xef73, 0xef74,0xef75,0xef76,0xef77,
  0xef78,0xef79,0xef7a,0xef7b, 0xef7c,0xef7d,0xef7e,0xef7f,

  0xef80,0xef81,0xef82,0xef83, 0xef84,0xef85,0xef86,0xef87,
  0xef88,0xef89,0xef8a,0xef8b, 0xef8c,0xef8d,0xef8e,0xef8f,
  0xef90,0xef91,0xef92,0xef93, 0xef94,0xef95,0xef96,0xef97,
  0xef98,0xef99,0xef9a,0xef9b, 0xef9c,0xef9d,0xef9e,0xef9f,
  0xefa0,0xefa1,0xefa2,0xefa3, 0xefa4,0xefa5,0xefa6,0xefa7,
  0xefa8,0xefa9,0xefaa,0xefab, 0xefac,0xefad,0xefae,0xefaf,
  0xefb0,0xefb1,0xefb2,0xefb3, 0xefb4,0xefb5,0xefb6,0xefb7,
  0xefb8,0xefb9,0xefba,0xefbb, 0xefbc,0xefbd,0xefbe,0xefbf,

  0xefc0,0xefc1,0xefc2,0xefc3, 0xefc4,0xefc5,0xefc6,0xefc7,
  0xefc8,0xefc9,0xefca,0xefcb, 0xefcc,0xefcd,0xefce,0xefcf,
  0xefd0,0xefd1,0xefd2,0xefd3, 0xefd4,0xefd5,0xefd6,0xefd7,
  0xefd8,0xefd9,0xefda,
  
/* 0x12181(i:28800) */
  0xefdb, 0xefdc,0xefdd,0xefde,0xefdf,
  0xefe0,0xefe1,0xefe2,0xefe3, 0xefe4,0xefe5,0xefe6,0xefe7,
  0xefe8,0xefe9,0xefea,0xefeb, 0xefec,0xefed,0xefee,0xefef,
  0xeff0,0xeff1,0xeff2,0xeff3, 0xeff4,0xeff5,0xeff6,0xeff7,
  0xeff8,0xeff9,0xeffa,0xeffb, 0xeffc,0xeffd,0xeffe,0xefff,

  0xf000,0xf001,0xf002,0xf003, 0xf004,0xf005,0xf006,0xf007,
  0xf008,0xf009,0xf00a,0xf00b, 0xf00c,0xf00d,0xf00e,0xf00f,
  0xf010,0xf011,0xf012,0xf013, 0xf014,0xf015,0xf016,0xf017,
  0xf018,0xf019,0xf01a,0xf01b, 0xf01c,0xf01d,0xf01e,0xf01f,
  0xf020,0xf021,0xf022,0xf023, 0xf024,0xf025,0xf026,0xf027,
  0xf028,0xf029,0xf02a,0xf02b, 0xf02c,0xf02d,0xf02e,0xf02f,
  0xf030,0xf031,0xf032,0xf033, 0xf034,0xf035,0xf036,0xf037,
  0xf038,0xf039,0xf03a,0xf03b, 0xf03c,0xf03d,0xf03e,0xf03f,

  0xf040,0xf041,0xf042,0xf043, 0xf044,0xf045,0xf046,0xf047,
  0xf048,0xf049,0xf04a,0xf04b, 0xf04c,0xf04d,0xf04e,0xf04f,
  0xf050,0xf051,0xf052,0xf053, 0xf054,0xf055,0xf056,0xf057,
  0xf058,0xf059,0xf05a,0xf05b, 0xf05c,0xf05d,0xf05e,0xf05f,
  0xf060,0xf061,0xf062,0xf063, 0xf064,0xf065,0xf066,0xf067,
  0xf068,0xf069,0xf06a,0xf06b, 0xf06c,0xf06d,0xf06e,0xf06f,
  0xf070,0xf071,0xf072,0xf073, 0xf074,0xf075,0xf076,0xf077,
  0xf078,0xf079,0xf07a,0xf07b, 0xf07c,0xf07d,0xf07e,0xf07f,

  0xf080,0xf081,0xf082,0xf083, 0xf084,0xf085,0xf086,0xf087,
  0xf088,0xf089,0xf08a,0xf08b, 0xf08c,0xf08d,0xf08e,
  
  
/* 0x12281(i:28980) */
  0xf08f,
  0xf090,0xf091,0xf092,0xf093, 0xf094,0xf095,0xf096,0xf097,
  0xf098,0xf099,0xf09a,0xf09b, 0xf09c,0xf09d,0xf09e,0xf09f,
  0xf0a0,0xf0a1,0xf0a2,0xf0a3, 0xf0a4,0xf0a5,0xf0a6,0xf0a7,
  0xf0a8,0xf0a9,0xf0aa,0xf0ab, 0xf0ac,0xf0ad,0xf0ae,0xf0af,
  0xf0b0,0xf0b1,0xf0b2,0xf0b3, 0xf0b4,0xf0b5,0xf0b6,0xf0b7,
  0xf0b8,0xf0b9,0xf0ba,0xf0bb, 0xf0bc,0xf0bd,0xf0be,0xf0bf,

  0xf0c0,0xf0c1,0xf0c2,0xf0c3, 0xf0c4,0xf0c5,0xf0c6,0xf0c7,
  0xf0c8,0xf0c9,0xf0ca,0xf0cb, 0xf0cc,0xf0cd,0xf0ce,0xf0cf,
  0xf0d0,0xf0d1,0xf0d2,0xf0d3, 0xf0d4,0xf0d5,0xf0d6,0xf0d7,
  0xf0d8,0xf0d9,0xf0da,0xf0db, 0xf0dc,0xf0dd,0xf0de,0xf0df,
  0xf0e0,0xf0e1,0xf0e2,0xf0e3, 0xf0e4,0xf0e5,0xf0e6,0xf0e7,
  0xf0e8,0xf0e9,0xf0ea,0xf0eb, 0xf0ec,0xf0ed,0xf0ee,0xf0ef,
  0xf0f0,0xf0f1,0xf0f2,0xf0f3, 0xf0f4,0xf0f5,0xf0f6,0xf0f7,
  0xf0f8,0xf0f9,0xf0fa,0xf0fb, 0xf0fc,0xf0fd,0xf0fe,0xf0ff,

  0xf100,0xf101,0xf102,0xf103, 0xf104,0xf105,0xf106,0xf107,
  0xf108,0xf109,0xf10a,0xf10b, 0xf10c,0xf10d,0xf10e,0xf10f,
  0xf110,0xf111,0xf112,0xf113, 0xf114,0xf115,0xf116,0xf117,
  0xf118,0xf119,0xf11a,0xf11b, 0xf11c,0xf11d,0xf11e,0xf11f,
  0xf120,0xf121,0xf122,0xf123, 0xf124,0xf125,0xf126,0xf127,
  0xf128,0xf129,0xf12a,0xf12b, 0xf12c,0xf12d,0xf12e,0xf12f,
  0xf130,0xf131,0xf132,0xf133, 0xf134,0xf135,0xf136,0xf137,
  0xf138,0xf139,0xf13a,0xf13b, 0xf13c,0xf13d,0xf13e,0xf13f,

  0xf140,0xf141,0xf142,
  
/* 0x12381(i:29160) */
  
  0xf143, 0xf144,0xf145,0xf146,0xf147,
  0xf148,0xf149,0xf14a,0xf14b, 0xf14c,0xf14d,0xf14e,0xf14f,
  0xf150,0xf151,0xf152,0xf153, 0xf154,0xf155,0xf156,0xf157,
  0xf158,0xf159,0xf15a,0xf15b, 0xf15c,0xf15d,0xf15e,0xf15f,
  0xf160,0xf161,0xf162,0xf163, 0xf164,0xf165,0xf166,0xf167,
  0xf168,0xf169,0xf16a,0xf16b, 0xf16c,0xf16d,0xf16e,0xf16f,
  0xf170,0xf171,0xf172,0xf173, 0xf174,0xf175,0xf176,0xf177,

  0xf178,0xf179,0xf17a,0xf17b, 0xf17c,0xf17d,0xf17e,0xf17f,
  0xf180,0xf181,0xf182,0xf183, 0xf184,0xf185,0xf186,0xf187,
  0xf188,0xf189,0xf18a,0xf18b, 0xf18c,0xf18d,0xf18e,0xf18f,
  0xf190,0xf191,0xf192,0xf193, 0xf194,0xf195,0xf196,0xf197,
  0xf198,0xf199,0xf19a,0xf19b, 0xf19c,0xf19d,0xf19e,0xf19f,
  0xf1a0,0xf1a1,0xf1a2,0xf1a3, 0xf1a4,0xf1a5,0xf1a6,0xf1a7,
  0xf1a8,0xf1a9,0xf1aa,0xf1ab, 0xf1ac,0xf1ad,0xf1ae,0xf1af,
  0xf1b0,0xf1b1,0xf1b2,0xf1b3, 0xf1b4,0xf1b5,0xf1b6,0xf1b7,

  0xf1b8,0xf1b9,0xf1ba,0xf1bb, 0xf1bc,0xf1bd,0xf1be,0xf1bf,
  0xf1c0,0xf1c1,0xf1c2,0xf1c3, 0xf1c4,0xf1c5,0xf1c6,0xf1c7,
  0xf1c8,0xf1c9,0xf1ca,0xf1cb, 0xf1cc,0xf1cd,0xf1ce,0xf1cf,
  0xf1d0,0xf1d1,0xf1d2,0xf1d3, 0xf1d4,0xf1d5,0xf1d6,0xf1d7,
  0xf1d8,0xf1d9,0xf1da,0xf1db, 0xf1dc,0xf1dd,0xf1de,0xf1df,
  0xf1e0,0xf1e1,0xf1e2,0xf1e3, 0xf1e4,0xf1e5,0xf1e6,0xf1e7,
  0xf1e8,0xf1e9,0xf1ea,0xf1eb, 0xf1ec,0xf1ed,0xf1ee,0xf1ef,
  0xf1f0,0xf1f1,0xf1f2,0xf1f3, 0xf1f4,0xf1f5,0xf1f6,
  
/* 0x12481(i:29340) */
  
  0xf1f7,
  0xf1f8,0xf1f9,0xf1fa,0xf1fb, 0xf1fc,0xf1fd,0xf1fe,0xf1ff,

  0xf200,0xf201,0xf202,0xf203, 0xf204,0xf205,0xf206,0xf207,
  0xf208,0xf209,0xf20a,0xf20b, 0xf20c,0xf20d,0xf20e,0xf20f,
  0xf210,0xf211,0xf212,0xf213, 0xf214,0xf215,0xf216,0xf217,
  0xf218,0xf219,0xf21a,0xf21b, 0xf21c,0xf21d,0xf21e,0xf21f,
  0xf220,0xf221,0xf222,0xf223, 0xf224,0xf225,0xf226,0xf227,
  0xf228,0xf229,0xf22a,0xf22b, 0xf22c,0xf22d,0xf22e,0xf22f,
  0xf230,0xf231,0xf232,0xf233, 0xf234,0xf235,0xf236,0xf237,
  0xf238,0xf239,0xf23a,0xf23b, 0xf23c,0xf23d,0xf23e,0xf23f,

  0xf240,0xf241,0xf242,0xf243, 0xf244,0xf245,0xf246,0xf247,
  0xf248,0xf249,0xf24a,0xf24b, 0xf24c,0xf24d,0xf24e,0xf24f,
  0xf250,0xf251,0xf252,0xf253, 0xf254,0xf255,0xf256,0xf257,
  0xf258,0xf259,0xf25a,0xf25b, 0xf25c,0xf25d,0xf25e,0xf25f,
  0xf260,0xf261,0xf262,0xf263, 0xf264,0xf265,0xf266,0xf267,
  0xf268,0xf269,0xf26a,0xf26b, 0xf26c,0xf26d,0xf26e,0xf26f,
  0xf270,0xf271,0xf272,0xf273, 0xf274,0xf275,0xf276,0xf277,
  0xf278,0xf279,0xf27a,0xf27b, 0xf27c,0xf27d,0xf27e,0xf27f,

  0xf280,0xf281,0xf282,0xf283, 0xf284,0xf285,0xf286,0xf287,
  0xf288,0xf289,0xf28a,0xf28b, 0xf28c,0xf28d,0xf28e,0xf28f,
  0xf290,0xf291,0xf292,0xf293, 0xf294,0xf295,0xf296,0xf297,
  0xf298,0xf299,0xf29a,0xf29b, 0xf29c,0xf29d,0xf29e,0xf29f,
  0xf2a0,0xf2a1,0xf2a2,0xf2a3, 0xf2a4,0xf2a5,0xf2a6,0xf2a7,
  0xf2a8,0xf2a9,0xf2aa,
  
/* 0x12581(i:29520) */
  
  
  0xf2ab, 0xf2ac,0xf2ad,0xf2ae,0xf2af,
  0xf2b0,0xf2b1,0xf2b2,0xf2b3, 0xf2b4,0xf2b5,0xf2b6,0xf2b7,
  0xf2b8,0xf2b9,0xf2ba,0xf2bb, 0xf2bc,0xf2bd,0xf2be,0xf2bf,

  0xf2c0,0xf2c1,0xf2c2,0xf2c3, 0xf2c4,0xf2c5,0xf2c6,0xf2c7,
  0xf2c8,0xf2c9,0xf2ca,0xf2cb, 0xf2cc,0xf2cd,0xf2ce,0xf2cf,
  0xf2d0,0xf2d1,0xf2d2,0xf2d3, 0xf2d4,0xf2d5,0xf2d6,0xf2d7,
  0xf2d8,0xf2d9,0xf2da,0xf2db, 0xf2dc,0xf2dd,0xf2de,0xf2df,
  0xf2e0,0xf2e1,0xf2e2,0xf2e3, 0xf2e4,0xf2e5,0xf2e6,0xf2e7,
  0xf2e8,0xf2e9,0xf2ea,0xf2eb, 0xf2ec,0xf2ed,0xf2ee,0xf2ef,
  0xf2f0,0xf2f1,0xf2f2,0xf2f3, 0xf2f4,0xf2f5,0xf2f6,0xf2f7,
  0xf2f8,0xf2f9,0xf2fa,0xf2fb, 0xf2fc,0xf2fd,0xf2fe,0xf2ff,

  0xf300,0xf301,0xf302,0xf303, 0xf304,0xf305,0xf306,0xf307,
  0xf308,0xf309,0xf30a,0xf30b, 0xf30c,0xf30d,0xf30e,0xf30f,
  0xf310,0xf311,0xf312,0xf313, 0xf314,0xf315,0xf316,0xf317,
  0xf318,0xf319,0xf31a,0xf31b, 0xf31c,0xf31d,0xf31e,0xf31f,
  0xf320,0xf321,0xf322,0xf323, 0xf324,0xf325,0xf326,0xf327,
  0xf328,0xf329,0xf32a,0xf32b, 0xf32c,0xf32d,0xf32e,0xf32f,
  0xf330,0xf331,0xf332,0xf333, 0xf334,0xf335,0xf336,0xf337,
  0xf338,0xf339,0xf33a,0xf33b, 0xf33c,0xf33d,0xf33e,0xf33f,

  0xf340,0xf341,0xf342,0xf343, 0xf344,0xf345,0xf346,0xf347,
  0xf348,0xf349,0xf34a,0xf34b, 0xf34c,0xf34d,0xf34e,0xf34f,
  0xf350,0xf351,0xf352,0xf353, 0xf354,0xf355,0xf356,0xf357,
  0xf358,0xf359,0xf35a,0xf35b, 0xf35c,0xf35d,0xf35e,
  
/* 0x12681(i:29700) */
  
  
  0xf35f,
  0xf360,0xf361,0xf362,0xf363, 0xf364,0xf365,0xf366,0xf367,
  0xf368,0xf369,0xf36a,0xf36b, 0xf36c,0xf36d,0xf36e,0xf36f,
  0xf370,0xf371,0xf372,0xf373, 0xf374,0xf375,0xf376,0xf377,
  0xf378,0xf379,0xf37a,0xf37b, 0xf37c,0xf37d,0xf37e,0xf37f,

  0xf380,0xf381,0xf382,0xf383, 0xf384,0xf385,0xf386,0xf387,
  0xf388,0xf389,0xf38a,0xf38b, 0xf38c,0xf38d,0xf38e,0xf38f,
  0xf390,0xf391,0xf392,0xf393, 0xf394,0xf395,0xf396,0xf397,
  0xf398,0xf399,0xf39a,0xf39b, 0xf39c,0xf39d,0xf39e,0xf39f,
  0xf3a0,0xf3a1,0xf3a2,0xf3a3, 0xf3a4,0xf3a5,0xf3a6,0xf3a7,
  0xf3a8,0xf3a9,0xf3aa,0xf3ab, 0xf3ac,0xf3ad,0xf3ae,0xf3af,
  0xf3b0,0xf3b1,0xf3b2,0xf3b3, 0xf3b4,0xf3b5,0xf3b6,0xf3b7,
  0xf3b8,0xf3b9,0xf3ba,0xf3bb, 0xf3bc,0xf3bd,0xf3be,0xf3bf,

  0xf3c0,0xf3c1,0xf3c2,0xf3c3, 0xf3c4,0xf3c5,0xf3c6,0xf3c7,
  0xf3c8,0xf3c9,0xf3ca,0xf3cb, 0xf3cc,0xf3cd,0xf3ce,0xf3cf,
  0xf3d0,0xf3d1,0xf3d2,0xf3d3, 0xf3d4,0xf3d5,0xf3d6,0xf3d7,
  0xf3d8,0xf3d9,0xf3da,0xf3db, 0xf3dc,0xf3dd,0xf3de,0xf3df,
  0xf3e0,0xf3e1,0xf3e2,0xf3e3, 0xf3e4,0xf3e5,0xf3e6,0xf3e7,
  0xf3e8,0xf3e9,0xf3ea,0xf3eb, 0xf3ec,0xf3ed,0xf3ee,0xf3ef,
  0xf3f0,0xf3f1,0xf3f2,0xf3f3, 0xf3f4,0xf3f5,0xf3f6,0xf3f7,
  0xf3f8,0xf3f9,0xf3fa,0xf3fb, 0xf3fc,0xf3fd,0xf3fe,0xf3ff,

  0xf400,0xf401,0xf402,0xf403, 0xf404,0xf405,0xf406,0xf407,
  0xf408,0xf409,0xf40a,0xf40b, 0xf40c,0xf40d,0xf40e,0xf40f,
  0xf410,0xf411,0xf412,
  
/* 0x12781(i:29880) */
  
  
  0xf413, 0xf414,0xf415,0xf416,0xf417,
  0xf418,0xf419,0xf41a,0xf41b, 0xf41c,0xf41d,0xf41e,0xf41f,
  0xf420,0xf421,0xf422,0xf423, 0xf424,0xf425,0xf426,0xf427,
  0xf428,0xf429,0xf42a,0xf42b, 0xf42c,0xf42d,0xf42e,0xf42f,
  0xf430,0xf431,0xf432,0xf433, 0xf434,0xf435,0xf436,0xf437,
  0xf438,0xf439,0xf43a,0xf43b, 0xf43c,0xf43d,0xf43e,0xf43f,

  0xf440,0xf441,0xf442,0xf443, 0xf444,0xf445,0xf446,0xf447,
  0xf448,0xf449,0xf44a,0xf44b, 0xf44c,0xf44d,0xf44e,0xf44f,
  0xf450,0xf451,0xf452,0xf453, 0xf454,0xf455,0xf456,0xf457,
  0xf458,0xf459,0xf45a,0xf45b, 0xf45c,0xf45d,0xf45e,0xf45f,
  0xf460,0xf461,0xf462,0xf463, 0xf464,0xf465,0xf466,0xf467,
  0xf468,0xf469,0xf46a,0xf46b, 0xf46c,0xf46d,0xf46e,0xf46f,
  0xf470,0xf471,0xf472,0xf473, 0xf474,0xf475,0xf476,0xf477,
  0xf478,0xf479,0xf47a,0xf47b, 0xf47c,0xf47d,0xf47e,0xf47f,

  0xf480,0xf481,0xf482,0xf483, 0xf484,0xf485,0xf486,0xf487,
  0xf488,0xf489,0xf48a,0xf48b, 0xf48c,0xf48d,0xf48e,0xf48f,
  0xf490,0xf491,0xf492,0xf493, 0xf494,0xf495,0xf496,0xf497,
  0xf498,0xf499,0xf49a,0xf49b, 0xf49c,0xf49d,0xf49e,0xf49f,
  0xf4a0,0xf4a1,0xf4a2,0xf4a3, 0xf4a4,0xf4a5,0xf4a6,0xf4a7,
  0xf4a8,0xf4a9,0xf4aa,0xf4ab, 0xf4ac,0xf4ad,0xf4ae,0xf4af,
  0xf4b0,0xf4b1,0xf4b2,0xf4b3, 0xf4b4,0xf4b5,0xf4b6,0xf4b7,
  0xf4b8,0xf4b9,0xf4ba,0xf4bb, 0xf4bc,0xf4bd,0xf4be,0xf4bf,

  0xf4c0,0xf4c1,0xf4c2,0xf4c3, 0xf4c4,0xf4c5,0xf4c6,
/* 0x12881(i:30060) */
  0xf4c7,
  0xf4c8,0xf4c9,0xf4ca,0xf4cb, 0xf4cc,0xf4cd,0xf4ce,0xf4cf,
  0xf4d0,0xf4d1,0xf4d2,0xf4d3, 0xf4d4,0xf4d5,0xf4d6,0xf4d7,
  0xf4d8,0xf4d9,0xf4da,0xf4db, 0xf4dc,0xf4dd,0xf4de,0xf4df,
  0xf4e0,0xf4e1,0xf4e2,0xf4e3, 0xf4e4,0xf4e5,0xf4e6,0xf4e7,
  0xf4e8,0xf4e9,0xf4ea,0xf4eb, 0xf4ec,0xf4ed,0xf4ee,0xf4ef,
  0xf4f0,0xf4f1,0xf4f2,0xf4f3, 0xf4f4,0xf4f5,0xf4f6,0xf4f7,
  0xf4f8,0xf4f9,0xf4fa,0xf4fb, 0xf4fc,0xf4fd,0xf4fe,0xf4ff,

  0xf500,0xf501,0xf502,0xf503, 0xf504,0xf505,0xf506,0xf507,
  0xf508,0xf509,0xf50a,0xf50b, 0xf50c,0xf50d,0xf50e,0xf50f,
  0xf510,0xf511,0xf512,0xf513, 0xf514,0xf515,0xf516,0xf517,
  0xf518,0xf519,0xf51a,0xf51b, 0xf51c,0xf51d,0xf51e,0xf51f,
  0xf520,0xf521,0xf522,0xf523, 0xf524,0xf525,0xf526,0xf527,
  0xf528,0xf529,0xf52a,0xf52b, 0xf52c,0xf52d,0xf52e,0xf52f,
  0xf530,0xf531,0xf532,0xf533, 0xf534,0xf535,0xf536,0xf537,
  0xf538,0xf539,0xf53a,0xf53b, 0xf53c,0xf53d,0xf53e,0xf53f,

  0xf540,0xf541,0xf542,0xf543, 0xf544,0xf545,0xf546,0xf547,
  0xf548,0xf549,0xf54a,0xf54b, 0xf54c,0xf54d,0xf54e,0xf54f,
  0xf550,0xf551,0xf552,0xf553, 0xf554,0xf555,0xf556,0xf557,
  0xf558,0xf559,0xf55a,0xf55b, 0xf55c,0xf55d,0xf55e,0xf55f,
  0xf560,0xf561,0xf562,0xf563, 0xf564,0xf565,0xf566,0xf567,
  0xf568,0xf569,0xf56a,0xf56b, 0xf56c,0xf56d,0xf56e,0xf56f,
  0xf570,0xf571,0xf572,0xf573, 0xf574,0xf575,0xf576,0xf577,
  0xf578,0xf579,0xf57a,
  
/* 0x12981(i:30240) */
  0xf57b, 0xf57c,0xf57d,0xf57e,0xf57f,

  0xf580,0xf581,0xf582,0xf583, 0xf584,0xf585,0xf586,0xf587,
  0xf588,0xf589,0xf58a,0xf58b, 0xf58c,0xf58d,0xf58e,0xf58f,
  0xf590,0xf591,0xf592,0xf593, 0xf594,0xf595,0xf596,0xf597,
  0xf598,0xf599,0xf59a,0xf59b, 0xf59c,0xf59d,0xf59e,0xf59f,
  0xf5a0,0xf5a1,0xf5a2,0xf5a3, 0xf5a4,0xf5a5,0xf5a6,0xf5a7,
  0xf5a8,0xf5a9,0xf5aa,0xf5ab, 0xf5ac,0xf5ad,0xf5ae,0xf5af,
  0xf5b0,0xf5b1,0xf5b2,0xf5b3, 0xf5b4,0xf5b5,0xf5b6,0xf5b7,
  0xf5b8,0xf5b9,0xf5ba,0xf5bb, 0xf5bc,0xf5bd,0xf5be,0xf5bf,

  0xf5c0,0xf5c1,0xf5c2,0xf5c3, 0xf5c4,0xf5c5,0xf5c6,0xf5c7,
  0xf5c8,0xf5c9,0xf5ca,0xf5cb, 0xf5cc,0xf5cd,0xf5ce,0xf5cf,
  0xf5d0,0xf5d1,0xf5d2,0xf5d3, 0xf5d4,0xf5d5,0xf5d6,0xf5d7,
  0xf5d8,0xf5d9,0xf5da,0xf5db, 0xf5dc,0xf5dd,0xf5de,0xf5df,
  0xf5e0,0xf5e1,0xf5e2,0xf5e3, 0xf5e4,0xf5e5,0xf5e6,0xf5e7,
  0xf5e8,0xf5e9,0xf5ea,0xf5eb, 0xf5ec,0xf5ed,0xf5ee,0xf5ef,
  0xf5f0,0xf5f1,0xf5f2,0xf5f3, 0xf5f4,0xf5f5,0xf5f6,0xf5f7,
  0xf5f8,0xf5f9,0xf5fa,0xf5fb, 0xf5fc,0xf5fd,0xf5fe,0xf5ff,

  0xf600,0xf601,0xf602,0xf603, 0xf604,0xf605,0xf606,0xf607,
  0xf608,0xf609,0xf60a,0xf60b, 0xf60c,0xf60d,0xf60e,0xf60f,
  0xf610,0xf611,0xf612,0xf613, 0xf614,0xf615,0xf616,0xf617,
  0xf618,0xf619,0xf61a,0xf61b, 0xf61c,0xf61d,0xf61e,0xf61f,
  0xf620,0xf621,0xf622,0xf623, 0xf624,0xf625,0xf626,0xf627,
  0xf628,0xf629,0xf62a,0xf62b, 0xf62c,0xf62d,0xf62e,
  
/* 0x12a81(i:30420) */
  0xf62f,
  0xf630,0xf631,0xf632,0xf633, 0xf634,0xf635,0xf636,0xf637,
  0xf638,0xf639,0xf63a,0xf63b, 0xf63c,0xf63d,0xf63e,0xf63f,

  0xf640,0xf641,0xf642,0xf643, 0xf644,0xf645,0xf646,0xf647,
  0xf648,0xf649,0xf64a,0xf64b, 0xf64c,0xf64d,0xf64e,0xf64f,
  0xf650,0xf651,0xf652,0xf653, 0xf654,0xf655,0xf656,0xf657,
  0xf658,0xf659,0xf65a,0xf65b, 0xf65c,0xf65d,0xf65e,0xf65f,
  0xf660,0xf661,0xf662,0xf663, 0xf664,0xf665,0xf666,0xf667,
  0xf668,0xf669,0xf66a,0xf66b, 0xf66c,0xf66d,0xf66e,0xf66f,
  0xf670,0xf671,0xf672,0xf673, 0xf674,0xf675,0xf676,0xf677,
  0xf678,0xf679,0xf67a,0xf67b, 0xf67c,0xf67d,0xf67e,0xf67f,

  0xf680,0xf681,0xf682,0xf683, 0xf684,0xf685,0xf686,0xf687,
  0xf688,0xf689,0xf68a,0xf68b, 0xf68c,0xf68d,0xf68e,0xf68f,
  0xf690,0xf691,0xf692,0xf693, 0xf694,0xf695,0xf696,0xf697,
  0xf698,0xf699,0xf69a,0xf69b, 0xf69c,0xf69d,0xf69e,0xf69f,
  0xf6a0,0xf6a1,0xf6a2,0xf6a3, 0xf6a4,0xf6a5,0xf6a6,0xf6a7,
  0xf6a8,0xf6a9,0xf6aa,0xf6ab, 0xf6ac,0xf6ad,0xf6ae,0xf6af,
  0xf6b0,0xf6b1,0xf6b2,0xf6b3, 0xf6b4,0xf6b5,0xf6b6,0xf6b7,
  0xf6b8,0xf6b9,0xf6ba,0xf6bb, 0xf6bc,0xf6bd,0xf6be,0xf6bf,

  0xf6c0,0xf6c1,0xf6c2,0xf6c3, 0xf6c4,0xf6c5,0xf6c6,0xf6c7,
  0xf6c8,0xf6c9,0xf6ca,0xf6cb, 0xf6cc,0xf6cd,0xf6ce,0xf6cf,
  0xf6d0,0xf6d1,0xf6d2,0xf6d3, 0xf6d4,0xf6d5,0xf6d6,0xf6d7,
  0xf6d8,0xf6d9,0xf6da,0xf6db, 0xf6dc,0xf6dd,0xf6de,0xf6df,
  0xf6e0,0xf6e1,0xf6e2,
  
/* 0x12b81(i:30600) */
  0xf6e3, 0xf6e4,0xf6e5,0xf6e6,0xf6e7,
  0xf6e8,0xf6e9,0xf6ea,0xf6eb, 0xf6ec,0xf6ed,0xf6ee,0xf6ef,
  0xf6f0,0xf6f1,0xf6f2,0xf6f3, 0xf6f4,0xf6f5,0xf6f6,0xf6f7,
  0xf6f8,0xf6f9,0xf6fa,0xf6fb, 0xf6fc,0xf6fd,0xf6fe,0xf6ff,
  0xf700,0xf701,0xf702,0xf703, 0xf704,0xf705,0xf706,0xf707,
  0xf708,0xf709,0xf70a,0xf70b, 0xf70c,0xf70d,0xf70e,0xf70f,
  0xf710,0xf711,0xf712,0xf713, 0xf714,0xf715,0xf716,0xf717,
  0xf718,0xf719,0xf71a,0xf71b, 0xf71c,0xf71d,0xf71e,0xf71f,
  0xf720,0xf721,0xf722,0xf723, 0xf724,0xf725,0xf726,0xf727,
  0xf728,0xf729,0xf72a,0xf72b, 0xf72c,0xf72d,0xf72e,0xf72f,
  0xf730,0xf731,0xf732,0xf733, 0xf734,0xf735,0xf736,0xf737,
  0xf738,0xf739,0xf73a,0xf73b, 0xf73c,0xf73d,0xf73e,0xf73f,
  0xf740,0xf741,0xf742,0xf743, 0xf744,0xf745,0xf746,0xf747,
  0xf748,0xf749,0xf74a,0xf74b, 0xf74c,0xf74d,0xf74e,0xf74f,
  0xf750,0xf751,0xf752,0xf753, 0xf754,0xf755,0xf756,0xf757,
  0xf758,0xf759,0xf75a,0xf75b, 0xf75c,0xf75d,0xf75e,0xf75f,
  0xf760,0xf761,0xf762,0xf763, 0xf764,0xf765,0xf766,0xf767,
  0xf768,0xf769,0xf76a,0xf76b, 0xf76c,0xf76d,0xf76e,0xf76f,
  0xf770,0xf771,0xf772,0xf773, 0xf774,0xf775,0xf776,0xf777,
  0xf778,0xf779,0xf77a,0xf77b, 0xf77c,0xf77d,0xf77e,0xf77f,
  0xf780,0xf781,0xf782,0xf783, 0xf784,0xf785,0xf786,0xf787,
  0xf788,0xf789,0xf78a,0xf78b, 0xf78c,0xf78d,0xf78e,0xf78f,
  0xf790,0xf791,0xf792,0xf793, 0xf794,0xf795,0xf796,
/* 0x12c81(i:30780) */
  
  
  0xf797,
  0xf798,0xf799,0xf79a,0xf79b, 0xf79c,0xf79d,0xf79e,0xf79f,
  0xf7a0,0xf7a1,0xf7a2,0xf7a3, 0xf7a4,0xf7a5,0xf7a6,0xf7a7,
  0xf7a8,0xf7a9,0xf7aa,0xf7ab, 0xf7ac,0xf7ad,0xf7ae,0xf7af,
  0xf7b0,0xf7b1,0xf7b2,0xf7b3, 0xf7b4,0xf7b5,0xf7b6,0xf7b7,
  0xf7b8,0xf7b9,0xf7ba,0xf7bb, 0xf7bc,0xf7bd,0xf7be,0xf7bf,

  0xf7c0,0xf7c1,0xf7c2,0xf7c3, 0xf7c4,0xf7c5,0xf7c6,0xf7c7,
  0xf7c8,0xf7c9,0xf7ca,0xf7cb, 0xf7cc,0xf7cd,0xf7ce,0xf7cf,
  0xf7d0,0xf7d1,0xf7d2,0xf7d3, 0xf7d4,0xf7d5,0xf7d6,0xf7d7,
  0xf7d8,0xf7d9,0xf7da,0xf7db, 0xf7dc,0xf7dd,0xf7de,0xf7df,
  0xf7e0,0xf7e1,0xf7e2,0xf7e3, 0xf7e4,0xf7e5,0xf7e6,0xf7e7,
  0xf7e8,0xf7e9,0xf7ea,0xf7eb, 0xf7ec,0xf7ed,0xf7ee,0xf7ef,
  0xf7f0,0xf7f1,0xf7f2,0xf7f3, 0xf7f4,0xf7f5,0xf7f6,0xf7f7,
  0xf7f8,0xf7f9,0xf7fa,0xf7fb, 0xf7fc,0xf7fd,0xf7fe,0xf7ff,

  0xf800,0xf801,0xf802,0xf803, 0xf804,0xf805,0xf806,0xf807,
  0xf808,0xf809,0xf80a,0xf80b, 0xf80c,0xf80d,0xf80e,0xf80f,
  0xf810,0xf811,0xf812,0xf813, 0xf814,0xf815,0xf816,0xf817,
  0xf818,0xf819,0xf81a,0xf81b, 0xf81c,0xf81d,0xf81e,0xf81f,
  0xf820,0xf821,0xf822,0xf823, 0xf824,0xf825,0xf826,0xf827,
  0xf828,0xf829,0xf82a,0xf82b, 0xf82c,0xf82d,0xf82e,0xf82f,
  0xf830,0xf831,0xf832,0xf833, 0xf834,0xf835,0xf836,0xf837,
  0xf838,0xf839,0xf83a,0xf83b, 0xf83c,0xf83d,0xf83e,0xf83f,

  0xf840,0xf841,0xf842,0xf843, 0xf844,0xf845,0xf846,0xf847,
  0xf848,0xf849,0xf84a,
  
/* 0x12d81(i:30960) */
  0xf84b, 0xf84c,0xf84d,0xf84e,0xf84f,
  0xf850,0xf851,0xf852,0xf853, 0xf854,0xf855,0xf856,0xf857,
  0xf858,0xf859,0xf85a,0xf85b, 0xf85c,0xf85d,0xf85e,0xf85f,
  0xf860,0xf861,0xf862,0xf863, 0xf864,0xf865,0xf866,0xf867,
  0xf868,0xf869,0xf86a,0xf86b, 0xf86c,0xf86d,0xf86e,0xf86f,
  0xf870,0xf871,0xf872,0xf873, 0xf874,0xf875,0xf876,0xf877,
  0xf878,0xf879,0xf87a,0xf87b, 0xf87c,0xf87d,0xf87e,0xf87f,
  0xf880,0xf881,0xf882,0xf883, 0xf884,0xf885,0xf886,0xf887,
  0xf888,0xf889,0xf88a,0xf88b, 0xf88c,0xf88d,0xf88e,0xf88f,
  0xf890,0xf891,0xf892,0xf893, 0xf894,0xf895,0xf896,0xf897,
  0xf898,0xf899,0xf89a,0xf89b, 0xf89c,0xf89d,0xf89e,0xf89f,
  0xf8a0,0xf8a1,0xf8a2,0xf8a3, 0xf8a4,0xf8a5,0xf8a6,0xf8a7,
  0xf8a8,0xf8a9,0xf8aa,0xf8ab, 0xf8ac,0xf8ad,0xf8ae,0xf8af,
  0xf8b0,0xf8b1,0xf8b2,0xf8b3, 0xf8b4,0xf8b5,0xf8b6,0xf8b7,
  0xf8b8,0xf8b9,0xf8ba,0xf8bb, 0xf8bc,0xf8bd,0xf8be,0xf8bf,
  0xf8c0,0xf8c1,0xf8c2,0xf8c3, 0xf8c4,0xf8c5,0xf8c6,0xf8c7,
  0xf8c8,0xf8c9,0xf8ca,0xf8cb, 0xf8cc,0xf8cd,0xf8ce,0xf8cf,
  0xf8d0,0xf8d1,0xf8d2,0xf8d3, 0xf8d4,0xf8d5,0xf8d6,0xf8d7,
  0xf8d8,0xf8d9,0xf8da,0xf8db, 0xf8dc,0xf8dd,0xf8de,0xf8df,
  0xf8e0,0xf8e1,0xf8e2,0xf8e3, 0xf8e4,0xf8e5,0xf8e6,0xf8e7,
  0xf8e8,0xf8e9,0xf8ea,0xf8eb, 0xf8ec,0xf8ed,0xf8ee,0xf8ef,
  0xf8f0,0xf8f1,0xf8f2,0xf8f3, 0xf8f4,0xf8f5,0xf8f6,0xf8f7,
  0xf8f8,0xf8f9,0xf8fa,0xf8fb, 0xf8fc,0xf8fd,0xf8fe,
/* 0x12e81(i:31140) */
  0xf8ff,0xf900,0xf901,0xf902,0xf903, 0xf904,0xf905,0xf906,
  0xf907,0xf908,0xf909,0xf90a,0xf90b, 0xf90c,0xf90d,0xf90e,
  0xf90f,0xf910,0xf911,0xf912,0xf913, 0xf914,0xf915,0xf916,
  0xf917,0xf918,0xf919,0xf91a,0xf91b, 0xf91c,0xf91d,0xf91e,
  0xf91f,0xf920,0xf921,0xf922,0xf923, 0xf924,0xf925,0xf926,
  0xf927,0xf928,0xf929,0xf92a,0xf92b, 0xf92d,0xf92e,0xf92f,
  0xf930,0xf931,0xf932,0xf933, 0xf934,0xf935,0xf936,0xf937,
  0xf938,0xf939,0xf93a,0xf93b, 0xf93c,0xf93d,0xf93e,0xf93f,
  0xf940,0xf941,0xf942,0xf943, 0xf944,0xf945,0xf946,0xf947,
  0xf948,0xf949,0xf94a,0xf94b, 0xf94c,0xf94d,0xf94e,0xf94f,
  0xf950,0xf951,0xf952,0xf953, 0xf954,0xf955,0xf956,0xf957,
  0xf958,0xf959,0xf95a,0xf95b, 0xf95c,0xf95d,0xf95e,0xf95f,
  0xf960,0xf961,0xf962,0xf963, 0xf964,0xf965,0xf966,0xf967,
  0xf968,0xf969,0xf96a,0xf96b, 0xf96c,0xf96d,0xf96e,0xf96f,
  0xf970,0xf971,0xf972,0xf973, 0xf974,0xf975,0xf976,0xf977,
  0xf978,0xf97a,0xf97b,0xf97c, 0xf97d,0xf97e,0xf97f,0xf980,
  0xf981,0xf982,0xf983,0xf984, 0xf985,0xf986,0xf987,0xf988,
  0xf989,0xf98a,0xf98b,0xf98c, 0xf98d,0xf98e,0xf98f,0xf990,
  0xf991,0xf992,0xf993,0xf994, 0xf996,0xf997,0xf998,0xf999,
  0xf99a,0xf99b,0xf99c,0xf99d, 0xf99e,0xf99f,0xf9a0,0xf9a1,
  0xf9a2,0xf9a3,0xf9a4,0xf9a5, 0xf9a6,0xf9a7,0xf9a8,0xf9a9,
  0xf9aa,0xf9ab,0xf9ac,0xf9ad, 0xf9ae,0xf9af,0xf9b0,0xf9b1,
  0xf9b2,0xf9b3,0xf9b4,0xf9b5, 
/* 0x12f81(i:31320) */
  0xf9b6,0xf9b7,0xf9b8,0xf9b9, 0xf9ba,0xf9bb,0xf9bc,0xf9bd,
  0xf9be,0xf9bf,0xf9c0,0xf9c1, 0xf9c2,0xf9c3,0xf9c4,0xf9c5,
  0xf9c6,0xf9c7,0xf9c8,0xf9c9, 0xf9ca,0xf9cb,0xf9cc,0xf9cd,
  0xf9ce,0xf9cf,0xf9d0,0xf9d1, 0xf9d2,0xf9d3,0xf9d4,0xf9d5,
  0xf9d6,0xf9d7,0xf9d8,0xf9d9, 0xf9da,0xf9db,0xf9dc,0xf9dd,
  0xf9de,0xf9df,0xf9e0,0xf9e1, 0xf9e2,0xf9e3,0xf9e4,0xf9e5,
  0xf9e6,0xf9e8,0xf9e9,0xf9ea, 0xf9eb,0xf9ec,0xf9ed,0xf9ee,
  0xf9ef,0xf9f0,0xf9f2,0xf9f3, 0xf9f4,0xf9f5,0xf9f6,0xf9f7,
  0xf9f8,0xf9f9,0xf9fa,0xf9fb, 0xf9fc,0xf9fd,0xf9fe,0xf9ff,
  0xfa00,0xfa01,0xfa02,0xfa03, 0xfa04,0xfa05,0xfa06,0xfa07,
  0xfa08,0xfa09,0xfa0a,0xfa0b, 0xfa10,0xfa12,0xfa15,0xfa16,
  0xfa17,0xfa19,0xfa1a,0xfa1b, 0xfa1c,0xfa1d,0xfa1e,0xfa22,
  0xfa25,0xfa26,0xfa2a,0xfa2b, 0xfa2c,0xfa2d,0xfa2e,0xfa2f,
  0xfa30,0xfa31,0xfa32,0xfa33, 0xfa34,0xfa35,0xfa36,0xfa37,
  0xfa38,0xfa39,0xfa3a,0xfa3b, 0xfa3c,0xfa3d,0xfa3e,0xfa3f,
  0xfa40,0xfa41,0xfa42,0xfa43, 0xfa44,0xfa45,0xfa46,0xfa47,
  0xfa48,0xfa49,0xfa4a,0xfa4b, 0xfa4c,0xfa4d,0xfa4e,0xfa4f,
  0xfa50,0xfa51,0xfa52,0xfa53, 0xfa54,0xfa55,0xfa56,0xfa57,
  0xfa58,0xfa59,0xfa5a,0xfa5b, 0xfa5c,0xfa5d,0xfa5e,0xfa5f,
  0xfa60,0xfa61,0xfa62,0xfa63, 0xfa64,0xfa65,0xfa66,0xfa67,
  0xfa68,0xfa69,0xfa6a,0xfa6b, 0xfa6c,0xfa6d,0xfa6e,0xfa6f,
  0xfa70,0xfa71,0xfa72,0xfa73, 0xfa74,0xfa75,0xfa76,0xfa77,
  0xfa78,0xfa79,0xfa7a,0xfa7b, 
/* 0x13081(i:31500) */
  0xfa7c,0xfa7d,0xfa7e,0xfa7f,
  0xfa80,0xfa81,0xfa82,0xfa83, 0xfa84,0xfa85,0xfa86,0xfa87,
  0xfa88,0xfa89,0xfa8a,0xfa8b, 0xfa8c,0xfa8d,0xfa8e,0xfa8f,
  0xfa90,0xfa91,0xfa92,0xfa93, 0xfa94,0xfa95,0xfa96,0xfa97,
  0xfa98,0xfa99,0xfa9a,0xfa9b, 0xfa9c,0xfa9d,0xfa9e,0xfa9f,
  0xfaa0,0xfaa1,0xfaa2,0xfaa3, 0xfaa4,0xfaa5,0xfaa6,0xfaa7,
  0xfaa8,0xfaa9,0xfaaa,0xfaab, 0xfaac,0xfaad,0xfaae,0xfaaf,
  0xfab0,0xfab1,0xfab2,0xfab3, 0xfab4,0xfab5,0xfab6,0xfab7,
  0xfab8,0xfab9,0xfaba,0xfabb, 0xfabc,0xfabd,0xfabe,0xfabf,
  0xfac0,0xfac1,0xfac2,0xfac3, 0xfac4,0xfac5,0xfac6,0xfac7,
  0xfac8,0xfac9,0xfaca,0xfacb, 0xfacc,0xfacd,0xface,0xfacf,
  0xfad0,0xfad1,0xfad2,0xfad3, 0xfad4,0xfad5,0xfad6,0xfad7,
  0xfad8,0xfad9,0xfada,0xfadb, 0xfadc,0xfadd,0xfade,0xfadf,
  0xfae0,0xfae1,0xfae2,0xfae3, 0xfae4,0xfae5,0xfae6,0xfae7,
  0xfae8,0xfae9,0xfaea,0xfaeb, 0xfaec,0xfaed,0xfaee,0xfaef,
  0xfaf0,0xfaf1,0xfaf2,0xfaf3, 0xfaf4,0xfaf5,0xfaf6,0xfaf7,
  0xfaf8,0xfaf9,0xfafa,0xfafb, 0xfafc,0xfafd,0xfafe,0xfaff,
  0xfb00,0xfb01,0xfb02,0xfb03, 0xfb04,0xfb05,0xfb06,0xfb07,
  0xfb08,0xfb09,0xfb0a,0xfb0b, 0xfb0c,0xfb0d,0xfb0e,0xfb0f,
  0xfb10,0xfb11,0xfb12,0xfb13, 0xfb14,0xfb15,0xfb16,0xfb17,
  0xfb18,0xfb19,0xfb1a,0xfb1b, 0xfb1c,0xfb1d,0xfb1e,0xfb1f,
  0xfb20,0xfb21,0xfb22,0xfb23, 0xfb24,0xfb25,0xfb26,0xfb27,
  0xfb28,0xfb29,0xfb2a,0xfb2b, 0xfb2c,0xfb2d,0xfb2e,0xfb2f,
/* 0x13181(i:31680) */
  0xfb30,0xfb31,0xfb32,0xfb33, 0xfb34,0xfb35,0xfb36,0xfb37,
  0xfb38,0xfb39,0xfb3a,0xfb3b, 0xfb3c,0xfb3d,0xfb3e,0xfb3f,
  0xfb40,0xfb41,0xfb42,0xfb43, 0xfb44,0xfb45,0xfb46,0xfb47,
  0xfb48,0xfb49,0xfb4a,0xfb4b, 0xfb4c,0xfb4d,0xfb4e,0xfb4f,
  0xfb50,0xfb51,0xfb52,0xfb53, 0xfb54,0xfb55,0xfb56,0xfb57,
  0xfb58,0xfb59,0xfb5a,0xfb5b, 0xfb5c,0xfb5d,0xfb5e,0xfb5f,
  0xfb60,0xfb61,0xfb62,0xfb63, 0xfb64,0xfb65,0xfb66,0xfb67,
  0xfb68,0xfb69,0xfb6a,0xfb6b, 0xfb6c,0xfb6d,0xfb6e,0xfb6f,
  0xfb70,0xfb71,0xfb72,0xfb73, 0xfb74,0xfb75,0xfb76,0xfb77,
  0xfb78,0xfb79,0xfb7a,0xfb7b, 0xfb7c,0xfb7d,0xfb7e,0xfb7f,
  0xfb80,0xfb81,0xfb82,0xfb83, 0xfb84,0xfb85,0xfb86,0xfb87,
  0xfb88,0xfb89,0xfb8a,0xfb8b, 0xfb8c,0xfb8d,0xfb8e,0xfb8f,
  0xfb90,0xfb91,0xfb92,0xfb93, 0xfb94,0xfb95,0xfb96,0xfb97,
  0xfb98,0xfb99,0xfb9a,0xfb9b, 0xfb9c,0xfb9d,0xfb9e,0xfb9f,
  0xfba0,0xfba1,0xfba2,0xfba3, 0xfba4,0xfba5,0xfba6,0xfba7,
  0xfba8,0xfba9,0xfbaa,0xfbab, 0xfbac,0xfbad,0xfbae,0xfbaf,
  0xfbb0,0xfbb1,0xfbb2,0xfbb3, 0xfbb4,0xfbb5,0xfbb6,0xfbb7,
  0xfbb8,0xfbb9,0xfbba,0xfbbb, 0xfbbc,0xfbbd,0xfbbe,0xfbbf,
  0xfbc0,0xfbc1,0xfbc2,0xfbc3, 0xfbc4,0xfbc5,0xfbc6,0xfbc7,
  0xfbc8,0xfbc9,0xfbca,0xfbcb, 0xfbcc,0xfbcd,0xfbce,0xfbcf,
  0xfbd0,0xfbd1,0xfbd2,0xfbd3, 0xfbd4,0xfbd5,0xfbd6,0xfbd7,
  0xfbd8,0xfbd9,0xfbda,0xfbdb, 0xfbdc,0xfbdd,0xfbde,0xfbdf,
  0xfbe0,0xfbe1,0xfbe2,0xfbe3, 
/* 0x13281(i:31860) */
  0xfbe4,0xfbe5,0xfbe6,0xfbe7,
  0xfbe8,0xfbe9,0xfbea,0xfbeb, 0xfbec,0xfbed,0xfbee,0xfbef,
  0xfbf0,0xfbf1,0xfbf2,0xfbf3, 0xfbf4,0xfbf5,0xfbf6,0xfbf7,
  0xfbf8,0xfbf9,0xfbfa,0xfbfb, 0xfbfc,0xfbfd,0xfbfe,0xfbff,
  0xfc00,0xfc01,0xfc02,0xfc03, 0xfc04,0xfc05,0xfc06,0xfc07,
  0xfc08,0xfc09,0xfc0a,0xfc0b, 0xfc0c,0xfc0d,0xfc0e,0xfc0f,
  0xfc10,0xfc11,0xfc12,0xfc13, 0xfc14,0xfc15,0xfc16,0xfc17,
  0xfc18,0xfc19,0xfc1a,0xfc1b, 0xfc1c,0xfc1d,0xfc1e,0xfc1f,
  0xfc20,0xfc21,0xfc22,0xfc23, 0xfc24,0xfc25,0xfc26,0xfc27,
  0xfc28,0xfc29,0xfc2a,0xfc2b, 0xfc2c,0xfc2d,0xfc2e,0xfc2f,
  0xfc30,0xfc31,0xfc32,0xfc33, 0xfc34,0xfc35,0xfc36,0xfc37,
  0xfc38,0xfc39,0xfc3a,0xfc3b, 0xfc3c,0xfc3d,0xfc3e,0xfc3f,
  0xfc40,0xfc41,0xfc42,0xfc43, 0xfc44,0xfc45,0xfc46,0xfc47,
  0xfc48,0xfc49,0xfc4a,0xfc4b, 0xfc4c,0xfc4d,0xfc4e,0xfc4f,
  0xfc50,0xfc51,0xfc52,0xfc53, 0xfc54,0xfc55,0xfc56,0xfc57,
  0xfc58,0xfc59,0xfc5a,0xfc5b, 0xfc5c,0xfc5d,0xfc5e,0xfc5f,
  0xfc60,0xfc61,0xfc62,0xfc63, 0xfc64,0xfc65,0xfc66,0xfc67,
  0xfc68,0xfc69,0xfc6a,0xfc6b, 0xfc6c,0xfc6d,0xfc6e,0xfc6f,
  0xfc70,0xfc71,0xfc72,0xfc73, 0xfc74,0xfc75,0xfc76,0xfc77,
  0xfc78,0xfc79,0xfc7a,0xfc7b, 0xfc7c,0xfc7d,0xfc7e,0xfc7f,
  0xfc80,0xfc81,0xfc82,0xfc83, 0xfc84,0xfc85,0xfc86,0xfc87,
  0xfc88,0xfc89,0xfc8a,0xfc8b, 0xfc8c,0xfc8d,0xfc8e,0xfc8f,
  0xfc90,0xfc91,0xfc92,0xfc93, 0xfc94,0xfc95,0xfc96,0xfc97,
/* 0x13381(i:32040) */
  0xfc98,0xfc99,0xfc9a,0xfc9b, 0xfc9c,0xfc9d,0xfc9e,0xfc9f,
  0xfca0,0xfca1,0xfca2,0xfca3, 0xfca4,0xfca5,0xfca6,0xfca7,
  0xfca8,0xfca9,0xfcaa,0xfcab, 0xfcac,0xfcad,0xfcae,0xfcaf,
  0xfcb0,0xfcb1,0xfcb2,0xfcb3, 0xfcb4,0xfcb5,0xfcb6,0xfcb7,
  0xfcb8,0xfcb9,0xfcba,0xfcbb, 0xfcbc,0xfcbd,0xfcbe,0xfcbf,
  0xfcc0,0xfcc1,0xfcc2,0xfcc3, 0xfcc4,0xfcc5,0xfcc6,0xfcc7,
  0xfcc8,0xfcc9,0xfcca,0xfccb, 0xfccc,0xfccd,0xfcce,0xfccf,
  0xfcd0,0xfcd1,0xfcd2,0xfcd3, 0xfcd4,0xfcd5,0xfcd6,0xfcd7,
  0xfcd8,0xfcd9,0xfcda,0xfcdb, 0xfcdc,0xfcdd,0xfcde,0xfcdf,
  0xfce0,0xfce1,0xfce2,0xfce3, 0xfce4,0xfce5,0xfce6,0xfce7,
  0xfce8,0xfce9,0xfcea,0xfceb, 0xfcec,0xfced,0xfcee,0xfcef,
  0xfcf0,0xfcf1,0xfcf2,0xfcf3, 0xfcf4,0xfcf5,0xfcf6,0xfcf7,
  0xfcf8,0xfcf9,0xfcfa,0xfcfb, 0xfcfc,0xfcfd,0xfcfe,0xfcff,
  0xfd00,0xfd01,0xfd02,0xfd03, 0xfd04,0xfd05,0xfd06,0xfd07,
  0xfd08,0xfd09,0xfd0a,0xfd0b, 0xfd0c,0xfd0d,0xfd0e,0xfd0f,
  0xfd10,0xfd11,0xfd12,0xfd13, 0xfd14,0xfd15,0xfd16,0xfd17,
  0xfd18,0xfd19,0xfd1a,0xfd1b, 0xfd1c,0xfd1d,0xfd1e,0xfd1f,
  0xfd20,0xfd21,0xfd22,0xfd23, 0xfd24,0xfd25,0xfd26,0xfd27,
  0xfd28,0xfd29,0xfd2a,0xfd2b, 0xfd2c,0xfd2d,0xfd2e,0xfd2f,
  0xfd30,0xfd31,0xfd32,0xfd33, 0xfd34,0xfd35,0xfd36,0xfd37,
  0xfd38,0xfd39,0xfd3a,0xfd3b, 0xfd3c,0xfd3d,0xfd3e,0xfd3f,
  0xfd40,0xfd41,0xfd42,0xfd43, 0xfd44,0xfd45,0xfd46,0xfd47,
  0xfd48,0xfd49,0xfd4a,0xfd4b, 
/* 0x13481(i:32220) */
  0xfd4c,0xfd4d,0xfd4e,0xfd4f, 0xfd50,0xfd51,0xfd52,0xfd53,
  0xfd54,0xfd55,0xfd56,0xfd57, 0xfd58,0xfd59,0xfd5a,0xfd5b,
  0xfd5c,0xfd5d,0xfd5e,0xfd5f, 0xfd60,0xfd61,0xfd62,0xfd63,
  0xfd64,0xfd65,0xfd66,0xfd67, 0xfd68,0xfd69,0xfd6a,0xfd6b,
  0xfd6c,0xfd6d,0xfd6e,0xfd6f, 0xfd70,0xfd71,0xfd72,0xfd73,
  0xfd74,0xfd75,0xfd76,0xfd77, 0xfd78,0xfd79,0xfd7a,0xfd7b,
  0xfd7c,0xfd7d,0xfd7e,0xfd7f, 0xfd80,0xfd81,0xfd82,0xfd83,
  0xfd84,0xfd85,0xfd86,0xfd87, 0xfd88,0xfd89,0xfd8a,0xfd8b,
  0xfd8c,0xfd8d,0xfd8e,0xfd8f, 0xfd90,0xfd91,0xfd92,0xfd93,
  0xfd94,0xfd95,0xfd96,0xfd97, 0xfd98,0xfd99,0xfd9a,0xfd9b,
  0xfd9c,0xfd9d,0xfd9e,0xfd9f, 0xfda0,0xfda1,0xfda2,0xfda3,
  0xfda4,0xfda5,0xfda6,0xfda7, 0xfda8,0xfda9,0xfdaa,0xfdab,
  0xfdac,0xfdad,0xfdae,0xfdaf, 0xfdb0,0xfdb1,0xfdb2,0xfdb3,
  0xfdb4,0xfdb5,0xfdb6,0xfdb7, 0xfdb8,0xfdb9,0xfdba,0xfdbb,
  0xfdbc,0xfdbd,0xfdbe,0xfdbf, 0xfdc0,0xfdc1,0xfdc2,0xfdc3,
  0xfdc4,0xfdc5,0xfdc6,0xfdc7, 0xfdc8,0xfdc9,0xfdca,0xfdcb,
  0xfdcc,0xfdcd,0xfdce,0xfdcf, 0xfdd0,0xfdd1,0xfdd2,0xfdd3,
  0xfdd4,0xfdd5,0xfdd6,0xfdd7, 0xfdd8,0xfdd9,0xfdda,0xfddb,
  0xfddc,0xfddd,0xfdde,0xfddf, 0xfde0,0xfde1,0xfde2,0xfde3,
  0xfde4,0xfde5,0xfde6,0xfde7, 0xfde8,0xfde9,0xfdea,0xfdeb,
  0xfdec,0xfded,0xfdee,0xfdef, 0xfdf0,0xfdf1,0xfdf2,0xfdf3,
  0xfdf4,0xfdf5,0xfdf6,0xfdf7, 0xfdf8,0xfdf9,0xfdfa,0xfdfb,
  0xfdfc,0xfdfd,0xfdfe,0xfdff,
/* 0x13581(i:32400) */
  0xfe00,0xfe01,0xfe02,0xfe03, 0xfe04,0xfe05,0xfe06,0xfe07,
  0xfe08,0xfe09,0xfe0a,0xfe0b, 0xfe0c,0xfe0d,0xfe0e,0xfe0f,
  0xfe10,0xfe11,0xfe12,0xfe13, 0xfe14,0xfe15,0xfe16,0xfe17,
  0xfe18,0xfe19,0xfe1a,0xfe1b, 0xfe1c,0xfe1d,0xfe1e,0xfe1f,
  0xfe20,0xfe21,0xfe22,0xfe23, 0xfe24,0xfe25,0xfe26,0xfe27,
  0xfe28,0xfe29,0xfe2a,0xfe2b, 0xfe2c,0xfe2d,0xfe2e,0xfe2f,
  0xfe32,0xfe45,0xfe46,0xfe47, 0xfe48,0xfe53,0xfe58,0xfe67,
  0xfe6c,0xfe6d,0xfe6e,0xfe6f, 0xfe70,0xfe71,0xfe72,0xfe73,
  0xfe74,0xfe75,0xfe76,0xfe77, 0xfe78,0xfe79,0xfe7a,0xfe7b,
  0xfe7c,0xfe7d,0xfe7e,0xfe7f, 0xfe80,0xfe81,0xfe82,0xfe83,
  0xfe84,0xfe85,0xfe86,0xfe87, 0xfe88,0xfe89,0xfe8a,0xfe8b,
  0xfe8c,0xfe8d,0xfe8e,0xfe8f, 0xfe90,0xfe91,0xfe92,0xfe93,
  0xfe94,0xfe95,0xfe96,0xfe97, 0xfe98,0xfe99,0xfe9a,0xfe9b,
  0xfe9c,0xfe9d,0xfe9e,0xfe9f, 0xfea0,0xfea1,0xfea2,0xfea3,
  0xfea4,0xfea5,0xfea6,0xfea7, 0xfea8,0xfea9,0xfeaa,0xfeab,
  0xfeac,0xfead,0xfeae,0xfeaf, 0xfeb0,0xfeb1,0xfeb2,0xfeb3,
  0xfeb4,0xfeb5,0xfeb6,0xfeb7, 0xfeb8,0xfeb9,0xfeba,0xfebb,
  0xfebc,0xfebd,0xfebe,0xfebf, 0xfec0,0xfec1,0xfec2,0xfec3,
  0xfec4,0xfec5,0xfec6,0xfec7, 0xfec8,0xfec9,0xfeca,0xfecb,
  0xfecc,0xfecd,0xfece,0xfecf, 0xfed0,0xfed1,0xfed2,0xfed3,
  0xfed4,0xfed5,0xfed6,0xfed7, 0xfed8,0xfed9,0xfeda,0xfedb,
  0xfedc,0xfedd,0xfede,0xfedf, 0xfee0,0xfee1,0xfee2,0xfee3,
  0xfee4,0xfee5,0xfee6,0xfee7, 
/* 0x13681(i:32580) */
  0xfee8,0xfee9,0xfeea,0xfeeb, 0xfeec,0xfeed,0xfeee,0xfeef,
  0xfef0,0xfef1,0xfef2,0xfef3, 0xfef4,0xfef5,0xfef6,0xfef7,
  0xfef8,0xfef9,0xfefa,0xfefb, 0xfefc,0xfefd,0xfefe,0xfeff,
  0xff00,0xff5f,0xff60,0xff61, 0xff62,0xff63,0xff64,0xff65,
  0xff66,0xff67,0xff68,0xff69, 0xff6a,0xff6b,0xff6c,0xff6d,
  0xff6e,0xff6f,0xff70,0xff71, 0xff72,0xff73,0xff74,0xff75,
  0xff76,0xff77,0xff78,0xff79, 0xff7a,0xff7b,0xff7c,0xff7d,
  0xff7e,0xff7f,0xff80,0xff81, 0xff82,0xff83,0xff84,0xff85,
  0xff86,0xff87,0xff88,0xff89, 0xff8a,0xff8b,0xff8c,0xff8d,
  0xff8e,0xff8f,0xff90,0xff91, 0xff92,0xff93,0xff94,0xff95,
  0xff96,0xff97,0xff98,0xff99, 0xff9a,0xff9b,0xff9c,0xff9d,
  0xff9e,0xff9f,0xffa0,0xffa1, 0xffa2,0xffa3,0xffa4,0xffa5,
  0xffa6,0xffa7,0xffa8,0xffa9, 0xffaa,0xffab,0xffac,0xffad,
  0xffae,0xffaf,0xffb0,0xffb1, 0xffb2,0xffb3,0xffb4,0xffb5,
  0xffb6,0xffb7,0xffb8,0xffb9, 0xffba,0xffbb,0xffbc,0xffbd,
  0xffbe,0xffbf,0xffc0,0xffc1, 0xffc2,0xffc3,0xffc4,0xffc5,
  0xffc6,0xffc7,0xffc8,0xffc9, 0xffca,0xffcb,0xffcc,0xffcd,
  0xffce,0xffcf,0xffd0,0xffd1, 0xffd2,0xffd3,0xffd4,0xffd5,
  0xffd6,0xffd7,0xffd8,0xffd9, 0xffda,0xffdb,0xffdc,0xffdd,
  0xffde,0xffdf,0xffe6,0xffe7, 0xffe8,0xffe9,0xffea,0xffeb,
  0xffec,0xffed,0xffee,0xffef, 0xfff0,0xfff1,0xfff2,0xfff3,
  0xfff4,0xfff5,0xfff6,0xfff7, 0xfff8,0xfff9,0xfffa,0xfffb,
  0xfffc,0xfffd,0xfffe,0xffff /* 0x84318130 */
};

skf_ucode hkscs_fa_uni_byte[HKSCS_FA_LEN] = {  /* f940 - fefe */
/* 0xf900 */
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x7881,0x92b9,0x88cf,
  0x58bb,0x6052,0x7ca7,0x5afa,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
/* 0xfa00 */
  0x20547,0x92db,0x205df,0x23fc5,0x854c,0x42b5,0x73ef,0x51b5,
  0x3649,0x24942,0x289e4,0x9344,0x219db,0x82ee,0x23cc8,0x783c,
  0x6744,0x62df,0x24933,0x289aa,0x202a0,0x26bb3,0x21305,0x4fab,
  0x224ed,0x5008,0x26d29,0x27a84,0x23600,0x24ab1,0x22513,0x0000,
  0x2037e,0x5fa4,0x20380,0x20347,0x6edb,0x2041f,0x0000,0x5101,
  0x347a,0x510e,0x986c,0x3743,0x8416,0x249a4,0x20487,0x5160,
  0x233b4,0x516a,0x20bff,0x220fc,0x202e5,0x22530,0x2058e,0x23233,
  0x21983,0x5b82,0x877d,0x205b3,0x23c99,0x51b2,0x51b8,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x9d34,0x51c9,0x51cf,0x51d1,0x3cdc,0x51d3,0x24aa6,0x51b3,
  0x51e2,0x5342,0x51ed,0x83cd,0x693e,0x2372d,0x5f7b,0x520b,
  0x5226,0x523c,0x52b5,0x5257,0x5294,0x52b9,0x52c5,0x7c15,
  0x8542,0x52e0,0x860d,0x26b13,0x0000,0x28ade,0x5549,0x6ed9,
  0x23f80,0x20954,0x23fec,0x5333,0x0000,0x20be2,0x6ccb,0x21726,
  0x681b,0x73d5,0x604a,0x3eaa,0x38cc,0x216e8,0x71dd,0x44a2,
  0x536d,0x5374,0x286ab,0x537e,0x0000,0x21596,0x21613,0x77e6,
  0x5393,0x28a9b,0x53a0,0x53ab,0x53ae,0x73a7,0x25772,0x3f59,
  0x739c,0x53c1,0x53c5,0x6c49,0x4e49,0x57fe,0x53d9,0x3aab,
  0x20b8f,0x53e0,0x23feb,0x22da3,0x53f6,0x20c77,0x5413,0x7079,
  0x552b,0x6657,0x6d5b,0x546d,0x26b53,0x20d74,0x555d,0x548f,
  0x54a4,0x47a6,0x2170d,0x20edd,0x3db4,0x20d4d,
/* 0xfb00 */
  0x289bc,0x22698,0x5547,0x4ced,0x542f,0x7417,0x5586,0x55a9,
  0x0000,0x218d7,0x2403a,0x4552,0x24435,0x66b3,0x210b4,0x5637,
  0x66cd,0x2328a,0x66a4,0x66ad,0x564d,0x564f,0x78f1,0x56f1,
  0x9787,0x53fe,0x5700,0x56ef,0x56ed,0x28b66,0x3623,0x2124f,
  0x5746,0x241a5,0x6c6e,0x708b,0x5742,0x36b1,0x26c7e,0x57e6,
  0x21416,0x5803,0x21454,0x24363,0x5826,0x24bf5,0x585c,0x58aa,
  0x3561,0x58e0,0x58dc,0x2123c,0x58fb,0x5bff,0x5743,0x2a150,
  0x24278,0x93d3,0x35a1,0x591f,0x68a6,0x36c3,0x6e59,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x2163e,0x5a24,0x5553,0x21692,0x8505,0x59c9,0x20d4e,0x26c81,
  0x26d2a,0x217dc,0x59d9,0x217fb,0x217b2,0x26da6,0x6d71,0x21828,
  0x216d5,0x59f9,0x26e45,0x5aab,0x5a63,0x36e6,0x249a9,0x0000,
  0x3708,0x5a96,0x7465,0x5ad3,0x26fa1,0x22554,0x3d85,0x21911,
  0x3732,0x216b8,0x5e83,0x52d0,0x5b76,0x6588,0x5b7c,0x27a0e,
  0x4004,0x485d,0x20204,0x5bd5,0x6160,0x21a34,0x259cc,0x205a5,
  0x5bf3,0x5b9d,0x4d10,0x5c05,0x21b44,0x5c13,0x73ce,0x5c14,
  0x21ca5,0x26b28,0x5c49,0x48dd,0x5c85,0x5ce9,0x5cef,0x5d8b,
  0x21df9,0x21e37,0x5d10,0x5d18,0x5d46,0x21ea4,0x5cba,0x5dd7,
  0x82fc,0x382d,0x24901,0x22049,0x22173,0x8287,0x3836,0x3bc2,
  0x5e2e,0x6a8a,0x0000,0x5e7a,0x244bc,0x20cd3,0x53a6,0x4eb7,
  0x0000,0x53a8,0x21771,0x5e09,0x5ef4,0x28482,
/* 0xfc00 */
  0x5ef9,0x5efb,0x38a0,0x5efc,0x683e,0x941b,0x5f0d,0x201c1,
  0x2f894,0x3ade,0x48ae,0x2133a,0x5f3a,0x26888,0x223d0,0x0000,
  0x22471,0x5f63,0x97bd,0x26e6e,0x5f72,0x9340,0x28a36,0x5fa7,
  0x5db6,0x3d5f,0x25250,0x21f6a,0x270f8,0x22668,0x91d6,0x2029e,
  0x28a29,0x6031,0x6685,0x21877,0x3963,0x3dc7,0x3639,0x5790,
  0x227b4,0x7971,0x3e40,0x609e,0x0000,0x60b3,0x24982,0x2498f,
  0x27a53,0x74a4,0x50e1,0x5aa0,0x6164,0x8424,0x6142,0x2f8a6,
  0x26ed2,0x6181,0x51f4,0x20656,0x6187,0x5baa,0x23fb7,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x2285f,0x61d3,0x28b9d,0x2995d,0x61d0,0x3932,0x22980,0x228c1,
  0x6023,0x615c,0x651e,0x638b,0x20118,0x62c5,0x21770,0x62d5,
  0x22e0d,0x636c,0x249df,0x3a17,0x6438,0x63f8,0x2138e,0x217fc,
  0x0000,0x6f8a,0x22e36,0x9814,0x2408c,0x2571d,0x64e1,0x64e5,
  0x947b,0x3a66,0x643a,0x3a57,0x654d,0x6f16,0x24a28,0x24a23,
  0x6585,0x656d,0x655f,0x2307e,0x65b5,0x24940,0x4b37,0x65d1,
  0x40d8,0x21829,0x65e0,0x65e3,0x5fdf,0x23400,0x6618,0x231f7,
  0x231f8,0x6644,0x231a4,0x231a5,0x664b,0x20e75,0x6667,0x251e6,
  0x6673,0x0000,0x21e3d,0x23231,0x285f4,0x231c8,0x25313,0x77c5,
  0x228f7,0x99a4,0x6702,0x2439c,0x24a21,0x3b2b,0x69fa,0x237c2,
  0x0000,0x6767,0x6762,0x241cd,0x290ed,0x67d7,0x44e9,0x6822,
  0x6e50,0x923c,0x6801,0x233e6,0x26da0,0x685d,
/* 0xfd00 */
  0x2346f,0x69e1,0x6a0b,0x28adf,0x6973,0x68c3,0x235cd,0x6901,
  0x6900,0x3d32,0x3a01,0x2363c,0x3b80,0x67ac,0x6961,0x28a4a,
  0x42fc,0x6936,0x6998,0x3ba1,0x203c9,0x8363,0x5090,0x69f9,
  0x23659,0x2212a,0x6a45,0x23703,0x6a9d,0x3bf3,0x67b1,0x6ac8,
  0x2919c,0x3c0d,0x6b1d,0x20923,0x60de,0x6b35,0x6b74,0x227cd,
  0x6eb5,0x23adb,0x203b5,0x21958,0x3740,0x5421,0x23b5a,0x6be1,
  0x23efc,0x6bdc,0x6c37,0x2248b,0x248f1,0x26b51,0x6c5a,0x8226,
  0x6c79,0x23dbc,0x44c5,0x23dbd,0x241a4,0x2490c,0x24900,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x23cc9,0x36e5,0x3ceb,0x20d32,0x9b83,0x231f9,0x22491,0x7f8f,
  0x6837,0x26d25,0x26da1,0x26deb,0x6d96,0x6d5c,0x6e7c,0x6f04,
  0x2497f,0x24085,0x26e72,0x8533,0x26f74,0x51c7,0x0000,0x0000,
  0x842e,0x28b21,0x0000,0x23e2f,0x7453,0x23f82,0x79cc,0x6e4f,
  0x5a91,0x2304b,0x6ff8,0x370d,0x6f9d,0x23e30,0x6efa,0x21497,
  0x2403d,0x4555,0x93f0,0x6f44,0x6f5c,0x3d4e,0x6f74,0x29170,
  0x3d3b,0x6f9f,0x24144,0x6fd3,0x24091,0x24155,0x24039,0x23ff0,
  0x23fb4,0x2413f,0x51df,0x24156,0x24157,0x24140,0x261dd,0x704b,
  0x707e,0x70a7,0x7081,0x70cc,0x70d5,0x70d6,0x70df,0x4104,
  0x3de8,0x71b4,0x7196,0x24277,0x712b,0x7145,0x5a88,0x714a,
  0x0000,0x5c9c,0x24365,0x714f,0x9362,0x242c1,0x712c,0x2445a,
  0x24a27,0x24a22,0x71ba,0x28be8,0x70bd,0x720e,
/* 0xfe00 */
  0x9442,0x7215,0x5911,0x9443,0x7224,0x9341,0x25605,0x722e,
  0x7240,0x24974,0x68bd,0x7255,0x7257,0x3e55,0x23044,0x680d,
  0x6f3d,0x7282,0x0000,0x732b,0x24823,0x2882b,0x48ed,0x28804,
  0x7328,0x732e,0x73cf,0x73aa,0x20c3a,0x26a2e,0x73c9,0x7449,
  0x241e2,0x216e7,0x24a24,0x6623,0x36c5,0x249b7,0x2498d,0x249fb,
  0x73f7,0x7415,0x6903,0x24a26,0x7439,0x205c3,0x3ed7,0x0000,
  0x228ad,0x7460,0x28eb2,0x7447,0x73e4,0x7476,0x83b9,0x746c,
  0x3730,0x7474,0x93f1,0x6a2c,0x7482,0x4953,0x24a8c,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x2415f,0x24a79,0x28b8f,0x5b46,0x28c03,0x2189e,0x74c8,0x21988,
  0x750e,0x0000,0x751e,0x28ed9,0x21a4b,0x5bd7,0x28eac,0x9385,
  0x754d,0x754a,0x7567,0x756e,0x24f82,0x3f04,0x24d13,0x758e,
  0x745d,0x759e,0x75b4,0x7602,0x762c,0x7651,0x764f,0x766f,
  0x7676,0x263f5,0x7690,0x81ef,0x37f8,0x26911,0x2690e,0x76a1,
  0x76a5,0x76b7,0x76cc,0x26f9f,0x8462,0x2509d,0x2517d,0x21e1c,
  0x771e,0x7726,0x7740,0x64af,0x25220,0x7758,0x232ac,0x77af,
  0x28964,0x28968,0x216c1,0x77f4,0x0000,0x21376,0x24a12,0x68ca,
  0x78af,0x78c7,0x78d3,0x96a5,0x792e,0x255e0,0x78d7,0x7934,
  0x78b1,0x2760c,0x8fb8,0x8884,0x28b2b,0x26083,0x2261c,0x7986,
  0x8900,0x6902,0x7980,0x25857,0x799d,0x27b39,0x793c,0x79a9,
  0x6e2a,0x27126,0x3ea8,0x79c6,0x2910d,0x79d4
};

skf_ucode hkscs_88_uni_byte[HKSCS_88_LEN] = { /* 8840 - a0fe */
/* 0x8800 */
  0xf303,0xf304,0xf305,0xf306, 0xf307,0x2010c,0xf309,0x200d1,
  0x200cd,0xf30c,0xf30d,0x200cb,0x21fe8,0xf310,0x200ca,0xf312,
  0xf313,0xf314,0xf315,0x2010e,0xf317,0xf318,0x0100,0x00c1,
  0x01cd,0x00c0,0x0112,0x00c9,0x011a,0x00c8,0x014c,0x00d3,
  0x01d1,0x00d2,0xf325,0x1ebe,0xf327,0x1ec0,0x00ca,0x0101,
  0x00e1,0x01ce,0x00e0,0x0251,0x0113,0x00e9,0x011b,0x00e8,
  0x012b,0x00ed,0x01d0,0x00ec,0x014d,0x00f3,0x01d2,0x00f2,
  0x016b,0x00fa,0x01d4,0x00f9,0x01d6,0x01d8,0x01da,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x01dc,0x00fc,0xf344,0x1ebf,0xf346,0x1ec1,0x00ea,0x0261,
  0xf34a,0xf34b,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
/* 0x8900 */
  0x2a3a9,0x21145,0x0000,0x650a,0x0000,0x0000,0x4e3d,0x6edd,
  0x9d4e,0x91df,0x0000,0x0000,0x27735,0x6491,0x4f1a,0x4f28,
  0x4fa8,0x5156,0x5174,0x519c,0x51e4,0x52a1,0x52a8,0x533b,
  0x534e,0x53d1,0x53d8,0x56e2,0x58f0,0x5904,0x5907,0x5932,
  0x5934,0x5b66,0x5b9e,0x5b9f,0x5c9a,0x5e86,0x603b,0x6589,
  0x67fe,0x6804,0x6865,0x6d4e,0x70bc,0x7535,0x7ea4,0x7eac,
  0x7eba,0x7ec7,0x7ecf,0x7edf,0x7f06,0x7f37,0x827a,0x82cf,
  0x836f,0x89c6,0x8bbe,0x8be2,0x8f66,0x8f67,0x8f6e,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x7411,0x7cfc,0x7dcd,0x6946,0x7ac9,0x5227,0x0000,0x0000,
  0x0000,0x0000,0x918c,0x78b8,0x915e,0x80bc,0x0000,0x8d0b,
  0x80f6,0x209e7,0x0000,0x0000,0x809f,0x9ec7,0x4ccd,0x9dc9,
  0x9e0c,0x4c3e,0x29df6,0x2700e,0x9e0a,0x2a133,0x35c1,0x0000,
  0x6e9a,0x823e,0x7519,0x0000,0x4911,0x9a6c,0x9a8f,0x9f99,
  0x7987,0x2846c,0x21dca,0x205d0,0x22ae6,0x4e24,0x4e81,0x4e80,
  0x4e87,0x4ebf,0x4eeb,0x4f37,0x344c,0x4fbd,0x3e48,0x5003,
  0x5088,0x347d,0x3493,0x34a5,0x5186,0x5905,0x51db,0x51fc,
  0x5205,0x4e89,0x5279,0x5290,0x5327,0x35c7,0x53a9,0x3551,
  0x53b0,0x3553,0x53c2,0x5423,0x356d,0x3572,0x3681,0x5493,
  0x54a3,0x54b4,0x54b9,0x54d0,0x54ef,0x5518,0x5523,0x5528,
  0x3598,0x553f,0x35a5,0x35bf,0x55d7,0x35c5,
/* 0x8a00 */
  0x27d84,0x5525,0x0000,0x20c42,0x20d15,0x2512b,0x5590,0x22cc6,
  0x39ec,0x20341,0x8e46,0x24db8,0x294e5,0x4053,0x280be,0x777a,
  0x22c38,0x3a34,0x47d5,0x2815d,0x269f2,0x24dea,0x64dd,0x20d7c,
  0x20fb4,0x20cd5,0x210f4,0x648d,0x8e7e,0x20e96,0x20c0b,0x20f64,
  0x22ca9,0x28256,0x244d3,0x0000,0x20d46,0x29a4d,0x280e9,0x47f4,
  0x24ea7,0x22cc2,0x9ab2,0x3a67,0x295f4,0x3fed,0x3506,0x252c7,
  0x297d4,0x278c8,0x22d44,0x9d6e,0x9815,0x0000,0x43d9,0x260a5,
  0x64b4,0x54e3,0x22d4c,0x22bca,0x21077,0x39fb,0x2106f,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x266da,0x26716,0x279a0,0x64ea,0x25052,0x20c43,0x8e68,0x221a1,
  0x28b4c,0x20731,0x0000,0x480b,0x201a9,0x3ffa,0x5873,0x22d8d,
  0x0000,0x245c8,0x204fc,0x26097,0x20f4c,0x20d96,0x5579,0x40bb,
  0x43ba,0x0000,0x4ab4,0x22a66,0x2109d,0x81aa,0x98f5,0x20d9c,
  0x6379,0x39fe,0x22775,0x8dc0,0x56a1,0x647c,0x3e43,0x0000,
  0x2a601,0x20e09,0x22acf,0x22cc9,0x0000,0x210c8,0x239c2,0x3992,
  0x3a06,0x2829b,0x3578,0x25e49,0x220c7,0x5652,0x20f31,0x22cb2,
  0x29720,0x34bc,0x6c3d,0x24e3b,0x0000,0x0000,0x27574,0x22e8b,
  0x22208,0x2a65b,0x28ccd,0x20e7a,0x20c34,0x2681c,0x7f93,0x210cf,
  0x22803,0x22939,0x35fb,0x251e3,0x20e8c,0x20f8d,0x20eaa,0x3f93,
  0x20f30,0x20d47,0x2114f,0x20e4c,0x0000,0x20eab,0x20ba9,0x20d48,
  0x210c0,0x2113d,0x3ff9,0x22696,0x6432,0x20fad,
/* 0x8b00 */
  0x233f4,0x27639,0x22bce,0x20d7e,0x20d7f,0x22c51,0x22c55,0x3a18,
  0x20e98,0x210c7,0x20f2e,0x2a632,0x26b50,0x28cd2,0x28d99,0x28cca,
  0x95aa,0x54cc,0x82c4,0x55b9,0x0000,0x29ec3,0x9c26,0x9ab6,
  0x2775e,0x22dee,0x7140,0x816d,0x80ec,0x5c1c,0x26572,0x8134,
  0x3797,0x535f,0x280bd,0x91b6,0x20efa,0x20e0f,0x20e77,0x20efb,
  0x35dd,0x24deb,0x3609,0x20cd6,0x56af,0x227b5,0x210c9,0x20e10,
  0x20e78,0x21078,0x21148,0x28207,0x21455,0x20e79,0x24e50,0x22da4,
  0x5a54,0x2101d,0x2101e,0x210f5,0x210f6,0x579c,0x20e11,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x27694,0x282cd,0x20fb5,0x20e7b,0x2517e,0x3703,0x20fb6,0x21180,
  0x252d8,0x2a2bd,0x249da,0x2183a,0x24177,0x2827c,0x5899,0x5268,
  0x361a,0x2573d,0x7bb2,0x5b68,0x4800,0x4b2c,0x9f27,0x49e7,
  0x9c1f,0x9b8d,0x25b74,0x2313d,0x55fb,0x35f2,0x5689,0x4e28,
  0x5902,0x21bc1,0x2f878,0x9751,0x20086,0x4e5b,0x4ebb,0x353e,
  0x5c23,0x5f51,0x5fc4,0x38fa,0x624c,0x6535,0x6b7a,0x6c35,
  0x6c3a,0x706c,0x722b,0x4e2c,0x72ad,0x248e9,0x7f52,0x793b,
  0x7cf9,0x7f53,0x2626a,0x34c1,0x0000,0x2634b,0x8002,0x8080,
  0x26612,0x26951,0x535d,0x8864,0x89c1,0x278b2,0x8ba0,0x8d1d,
  0x9485,0x9578,0x957f,0x95e8,0x28e0f,0x97e6,0x9875,0x98ce,
  0x98de,0x9963,0x29810,0x9c7c,0x9e1f,0x9ec4,0x6b6f,0xf907,
  0x4e37,0x20087,0x961d,0x6237,0x94a2,0x0000,
/* 0x8c00 */
  0x503b,0x6dfe,0x29c73,0x0000,0x3dc9,0x888f,0x2414e,0x7077,
  0x5cf5,0x4b20,0x251cd,0x3559,0x25d30,0x6122,0x28a32,0x8fa7,
  0x91f6,0x7191,0x6719,0x73ba,0x23281,0x2a107,0x3c8b,0x21980,
  0x4b10,0x78e4,0x7402,0x51ae,0x2870f,0x4009,0x6a63,0x2a2ba,
  0x4223,0x860f,0x0000,0x7a2a,0x29947,0x28aea,0x9755,0x704d,
  0x5324,0x2207e,0x93f4,0x76d9,0x289e3,0x0000,0x77dd,0x4ea3,
  0x4ff0,0x50bc,0x4e2f,0x4f17,0x0000,0x5434,0x7d8b,0x5892,
  0x58d0,0x21db6,0x5e92,0x5e99,0x5fc2,0x22712,0x658b,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x233f9,0x6919,0x6a43,0x23c63,0x6cff,0x0000,0x7200,0x24505,
  0x738c,0x3edb,0x24a13,0x5b15,0x74b9,0x8b83,0x25ca4,0x25695,
  0x7a93,0x7bec,0x7cc3,0x7e6c,0x82f8,0x8597,0x0000,0x8890,
  0x0000,0x8eb9,0x0000,0x8fcf,0x855f,0x99e0,0x9221,0x0000,
  0x28db9,0x2143f,0x4071,0x42a2,0x5a1a,0x0000,0x0000,0x0000,
  0x9868,0x676b,0x4276,0x573d,0x0000,0x85d6,0x2497b,0x82bf,
  0x2710d,0x4c81,0x26d74,0x5d7b,0x26b15,0x26fbe,0x0000,0x0000,
  0x5b96,0x0000,0x0000,0x7e5b,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
/* 0x8d00 */
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x5d3e,0x5d48,0x5d56,0x3dfc,0x380f,0x5da4,0x5db9,0x3820,
  0x3838,0x5e42,0x5ebd,0x5f25,0x5f83,0x3908,0x3914,0x393f,
  0x394d,0x60d7,0x613d,0x5ce5,0x3989,0x61b7,0x61b9,0x61cf,
  0x39b8,0x622c,0x6290,0x62e5,0x6318,0x39f8,0x56b1,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x3a03,0x63e2,0x63fb,0x6407,0x645a,0x3a4b,0x64c0,0x5d15,
  0x5621,0x9f9f,0x3a97,0x6586,0x3abd,0x65ff,0x6653,0x3af2,
  0x6692,0x3b22,0x6716,0x3b42,0x67a4,0x6800,0x3b58,0x684a,
  0x6884,0x3b72,0x3b71,0x3b7b,0x6909,0x6943,0x725c,0x6964,
  0x699f,0x6985,0x3bbc,0x69d6,0x3bdd,0x6a65,0x6a74,0x6a71,
  0x6a82,0x3bec,0x6a99,0x3bf2,0x6aab,0x6ab5,0x6ad4,0x6af6,
  0x6b81,0x6bc1,0x6bea,0x6c75,0x6caa,0x3ccb,0x6d02,0x6d06,
  0x6d26,0x6d81,0x3cef,0x6da4,0x6db1,0x6e15,0x6e18,0x6e29,
  0x6e86,0x289c0,0x6ebb,0x6ee2,0x6eda,0x9f7f,0x6ee8,0x6ee9,
  0x6f24,0x6f34,0x3d46,0x23f41,0x6f81,0x6fbe,0x3d6a,0x3d75,
  0x71b7,0x5c99,0x3d8a,0x702c,0x3d91,0x7050,0x7054,0x706f,
  0x707f,0x7089,0x20325,0x43c1,0x35f1,0x20ed8,
/* 0x8e00 */
  0x23ed7,0x57be,0x26ed3,0x713e,0x257e0,0x364e,0x69a2,0x28be9,
  0x5b74,0x7a49,0x258e1,0x294d9,0x7a65,0x7a7d,0x259ac,0x7abb,
  0x7ab0,0x7ac2,0x7ac3,0x71d1,0x2648d,0x41ca,0x7ada,0x7add,
  0x7aea,0x41ef,0x54b2,0x25c01,0x7b0b,0x7b55,0x7b29,0x2530e,
  0x25cfe,0x7ba2,0x7b6f,0x839c,0x25bb4,0x26c7f,0x7bd0,0x8421,
  0x7b92,0x0000,0x25d20,0x3dad,0x25c65,0x8492,0x7bfa,0x0000,
  0x7c35,0x25cc1,0x7c44,0x7c83,0x24882,0x7ca6,0x667d,0x24578,
  0x7cc9,0x7cc7,0x7ce6,0x7c74,0x7cf3,0x7cf5,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x7e67,0x451d,0x26e44,0x7d5d,0x26ed6,0x748d,0x7d89,0x7dab,
  0x7135,0x7db3,0x0000,0x24057,0x26029,0x7de4,0x3d13,0x7df5,
  0x217f9,0x7de5,0x2836d,0x0000,0x26121,0x2615a,0x7e6e,0x7e92,
  0x432b,0x946c,0x7e27,0x7f40,0x7f41,0x7f47,0x7936,0x262d0,
  0x99e1,0x7f97,0x26351,0x7fa3,0x21661,0x20068,0x455c,0x23766,
  0x4503,0x2833a,0x7ffa,0x26489,0x0000,0x8008,0x801d,0x0000,
  0x802f,0x2a087,0x26cc3,0x803b,0x803c,0x8061,0x22714,0x4989,
  0x26626,0x23de3,0x266e8,0x6725,0x80a7,0x28a48,0x8107,0x811a,
  0x58b0,0x226f6,0x6c7f,0x26498,0x24fb8,0x64e7,0x2148a,0x8218,
  0x2185e,0x6a53,0x24a65,0x24a95,0x447a,0x8229,0x20b0d,0x26a52,
  0x23d7e,0x4ff9,0x214fd,0x84e2,0x8362,0x26b0a,0x249a7,0x23530,
  0x21773,0x23df8,0x82aa,0x691b,0x2f994,0x41db,
/* 0x8f00 */
  0x854b,0x82d0,0x831a,0x20e16,0x217b4,0x36c1,0x2317d,0x2355a,
  0x827b,0x82e2,0x8318,0x23e8b,0x26da3,0x26b05,0x26b97,0x235ce,
  0x3dbf,0x831d,0x55ec,0x8385,0x450b,0x26da5,0x83ac,0x0000,
  0x83d3,0x347e,0x26ed4,0x6a57,0x855a,0x3496,0x26e42,0x22eef,
  0x8458,0x25be4,0x8471,0x3dd3,0x44e4,0x6aa7,0x844a,0x23cb5,
  0x7958,0x0000,0x26b96,0x26e77,0x26e43,0x84de,0x0000,0x8391,
  0x44a0,0x8493,0x84e4,0x25c91,0x4240,0x25cc0,0x4543,0x8534,
  0x5af2,0x26e99,0x4527,0x8573,0x4516,0x67bf,0x8616,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x28625,0x2863b,0x85c1,0x27088,0x8602,0x21582,0x270cd,0x2f9b2,
  0x456a,0x8628,0x3648,0x218a2,0x53f7,0x2739a,0x867e,0x8771,
  0x2a0f8,0x87ee,0x22c27,0x87b1,0x87da,0x880f,0x5661,0x866c,
  0x6856,0x460f,0x8845,0x8846,0x275e0,0x23db9,0x275e4,0x885e,
  0x889c,0x465b,0x88b4,0x88b5,0x63c1,0x88c5,0x7777,0x2770f,
  0x8987,0x898a,0x0000,0x0000,0x89a7,0x89bc,0x28a25,0x89e7,
  0x27924,0x27abd,0x8a9c,0x7793,0x91fe,0x8a90,0x27a59,0x7ae9,
  0x27b3a,0x23f8f,0x4713,0x27b38,0x717c,0x8b0c,0x8b1f,0x25430,
  0x25565,0x8b3f,0x8b4c,0x8b4d,0x8aa9,0x24a7a,0x8b90,0x8b9b,
  0x8aaf,0x216df,0x4615,0x884f,0x8c9b,0x27d54,0x27d8f,0x2f9d4,
  0x3725,0x27d53,0x8cd6,0x27d98,0x27dbd,0x8d12,0x8d03,0x21910,
  0x8cdb,0x705c,0x8d11,0x24cc9,0x3ed0,0x0000,
/* 0x9000 */
  0x8da9,0x28002,0x21014,0x2498a,0x3b7c,0x281bc,0x2710c,0x7ae7,
  0x8ead,0x8eb6,0x8ec3,0x92d4,0x8f19,0x8f2d,0x28365,0x28412,
  0x8fa5,0x9303,0x2a29f,0x20a50,0x8fb3,0x492a,0x289de,0x2853d,
  0x23dbb,0x5ef8,0x23262,0x8ff9,0x2a014,0x286bc,0x28501,0x22325,
  0x3980,0x26ed7,0x9037,0x2853c,0x27abe,0x9061,0x2856c,0x2860b,
  0x90a8,0x28713,0x90c4,0x286e6,0x90ae,0x0000,0x9167,0x3af0,
  0x91a9,0x91c4,0x7cac,0x28933,0x21e89,0x920e,0x6c9f,0x9241,
  0x9262,0x255b9,0x0000,0x28ac6,0x23c9b,0x28b0c,0x255db,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x20d31,0x932c,0x936b,0x28ae1,0x28beb,0x708f,0x5ac3,0x28ae2,
  0x28ae5,0x4965,0x9244,0x28bec,0x28c39,0x28bff,0x9373,0x945b,
  0x8ebc,0x9585,0x95a6,0x9426,0x95a0,0x6ff6,0x42b9,0x2267a,
  0x286d8,0x2127c,0x23e2e,0x49df,0x6c1c,0x967b,0x9696,0x416c,
  0x96a3,0x26ed5,0x61da,0x96b6,0x78f5,0x28ae0,0x96bd,0x53cc,
  0x49a1,0x26cb8,0x20274,0x26410,0x290af,0x290e5,0x24ad1,0x21915,
  0x2330a,0x9731,0x8642,0x9736,0x4a0f,0x453d,0x4585,0x24ae9,
  0x7075,0x5b41,0x971b,0x0000,0x291d5,0x9757,0x5b4a,0x291eb,
  0x975f,0x9425,0x50d0,0x230b7,0x230bc,0x9789,0x979f,0x97b1,
  0x97be,0x97c0,0x97d2,0x97e0,0x2546c,0x97ee,0x741c,0x29433,
  0x0000,0x97f5,0x2941d,0x2797a,0x4ad1,0x9834,0x9833,0x984b,
  0x9866,0x3b0e,0x27175,0x3d51,0x20630,0x2415c,
/* 0x9100 */
  0x25706,0x98ca,0x98b7,0x98c8,0x98c7,0x4aff,0x26d27,0x216d3,
  0x55b0,0x98e1,0x98e6,0x98ec,0x9378,0x9939,0x24a29,0x4b72,
  0x29857,0x29905,0x99f5,0x9a0c,0x9a3b,0x9a10,0x9a58,0x25725,
  0x36c4,0x290b1,0x29bd5,0x9ae0,0x9ae2,0x29b05,0x9af4,0x4c0e,
  0x9b14,0x9b2d,0x28600,0x5034,0x9b34,0x269a8,0x38c3,0x2307d,
  0x9b50,0x9b40,0x29d3e,0x5a45,0x21863,0x9b8e,0x2424b,0x9c02,
  0x9bff,0x9c0c,0x29e68,0x9dd4,0x29fb7,0x2a192,0x2a1ab,0x2a0e1,
  0x2a123,0x2a1df,0x9d7e,0x9d83,0x2a134,0x9e0e,0x6888,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x9dc4,0x2215b,0x2a193,0x2a220,0x2193b,0x2a233,0x9d39,0x2a0b9,
  0x2a2b4,0x9e90,0x9e95,0x9e9e,0x9ea2,0x4d34,0x9eaa,0x9eaf,
  0x24364,0x9ec1,0x3b60,0x39e5,0x3d1d,0x4f32,0x37be,0x28c2b,
  0x9f02,0x9f08,0x4b96,0x9424,0x26da2,0x9f17,0x0000,0x9f39,
  0x569f,0x568a,0x9f45,0x99b8,0x2908b,0x97f2,0x847f,0x9f62,
  0x9f69,0x7adc,0x9f8e,0x7216,0x4bbe,0x24975,0x249bb,0x7177,
  0x249f8,0x24348,0x24a51,0x739e,0x28bda,0x218fa,0x799f,0x2897e,
  0x28e36,0x9369,0x93f3,0x28a44,0x92ec,0x9381,0x93cb,0x2896c,
  0x244b9,0x7217,0x3eeb,0x7772,0x7a43,0x70d0,0x24473,0x243f8,
  0x717e,0x217ef,0x70a3,0x218be,0x23599,0x3ec7,0x21885,0x2542f,
  0x217f8,0x3722,0x216fb,0x21839,0x36e1,0x21774,0x218d1,0x25f4b,
  0x3723,0x216c0,0x575b,0x24a25,0x213fe,0x212a8,
/* 0x9200 */
  0x213c6,0x214b6,0x8503,0x236a6,0x0000,0x8455,0x24994,0x27165,
  0x23e31,0x2555c,0x23efb,0x27052,0x44f4,0x236ee,0x2999d,0x26f26,
  0x67f9,0x3733,0x3c15,0x3de7,0x586c,0x21922,0x6810,0x4057,
  0x2373f,0x240e1,0x2408b,0x2410f,0x26c21,0x54cb,0x569e,0x266b1,
  0x5692,0x20fdf,0x20ba8,0x20e0d,0x93c6,0x28b13,0x939c,0x4ef8,
  0x512b,0x3819,0x24436,0x4ebc,0x20465,0x2037f,0x4f4b,0x4f8a,
  0x25651,0x5a68,0x201ab,0x203cb,0x3999,0x2030a,0x20414,0x3435,
  0x4f29,0x202c0,0x28eb3,0x20275,0x8ada,0x2020c,0x4e98,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x50cd,0x510d,0x4fa2,0x4f03,0x24a0e,0x23e8a,0x4f42,0x502e,
  0x506c,0x5081,0x4fcc,0x4fe5,0x5058,0x50fc,0x0000,0x0000,
  0x0000,0x0000,0x6e76,0x23595,0x23e39,0x23ebf,0x6d72,0x21884,
  0x23e89,0x51a8,0x51c3,0x205e0,0x44dd,0x204a3,0x20492,0x20491,
  0x8d7a,0x28a9c,0x2070e,0x5259,0x52a4,0x20873,0x52e1,0x0000,
  0x467a,0x718c,0x2438c,0x20c20,0x249ac,0x210e4,0x69d1,0x20e1d,
  0x0000,0x3ede,0x7499,0x7414,0x7456,0x7398,0x4b8e,0x24abc,
  0x2408d,0x53d0,0x3584,0x720f,0x240c9,0x55b4,0x20345,0x54cd,
  0x20bc6,0x571d,0x925d,0x96f4,0x9366,0x57dd,0x578d,0x577f,
  0x363e,0x58cb,0x5a99,0x28a46,0x216fa,0x2176f,0x21710,0x5a2c,
  0x59b8,0x928f,0x5a7e,0x5acf,0x5a12,0x25946,0x219f3,0x21861,
  0x24295,0x36f5,0x6d05,0x7443,0x5a21,0x25e83,
/* 0x9300 */
  0x5a81,0x28bd7,0x20413,0x93e0,0x748c,0x21303,0x7105,0x4972,
  0x9408,0x289fb,0x93bd,0x37a0,0x5c1e,0x5c9e,0x5e5e,0x5e48,
  0x21996,0x2197c,0x23aee,0x5ecd,0x5b4f,0x21903,0x21904,0x3701,
  0x218a0,0x36dd,0x216fe,0x36d3,0x812a,0x28a47,0x21dba,0x23472,
  0x289a8,0x5f0c,0x5f0e,0x21927,0x217ab,0x5a6b,0x2173b,0x5b44,
  0x8614,0x275fd,0x8860,0x607e,0x22860,0x2262b,0x5fdb,0x3eb8,
  0x225af,0x225be,0x29088,0x26f73,0x61c0,0x2003e,0x20046,0x2261b,
  0x6199,0x6198,0x6075,0x22c9b,0x22d07,0x246d4,0x2914d,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x6471,0x24665,0x22b6a,0x3a29,0x22b22,0x23450,0x298ea,0x22e78,
  0x6337,0x2a45b,0x64b6,0x6331,0x63d1,0x249e3,0x22d67,0x62a4,
  0x22ca1,0x643b,0x656b,0x6972,0x3bf4,0x2308e,0x232ad,0x24989,
  0x232ab,0x550d,0x232e0,0x218d9,0x2943f,0x66ce,0x23289,0x231b3,
  0x3ae0,0x4190,0x25584,0x28b22,0x2558f,0x216fc,0x2555b,0x25425,
  0x78ee,0x23103,0x2182a,0x23234,0x3464,0x2320f,0x23182,0x242c9,
  0x668e,0x26d24,0x666b,0x4b93,0x6630,0x27870,0x21deb,0x6663,
  0x232d2,0x232e1,0x661e,0x25872,0x38d1,0x2383a,0x237bc,0x3b99,
  0x237a2,0x233fe,0x74d0,0x3b96,0x678f,0x2462a,0x68b6,0x681e,
  0x3bc4,0x6abe,0x3863,0x237d5,0x24487,0x6a33,0x6a52,0x6ac9,
  0x6b05,0x21912,0x6511,0x6898,0x6a4c,0x3bd7,0x6a7a,0x6b57,
  0x23fc0,0x23c9a,0x93a0,0x92f2,0x28bea,0x28acb,
/* 0x9400 */
  0x9289,0x2801e,0x289dc,0x9467,0x6da5,0x6f0b,0x249ec,0x0000,
  0x23f7f,0x3d8f,0x6e04,0x2403c,0x5a3d,0x6e0a,0x5847,0x6d24,
  0x7842,0x713b,0x2431a,0x24276,0x70f1,0x7250,0x7287,0x7294,
  0x2478f,0x24725,0x5179,0x24aa4,0x205eb,0x747a,0x23ef8,0x2365f,
  0x24a4a,0x24917,0x25fe1,0x3f06,0x3eb1,0x24adf,0x28c23,0x23f35,
  0x60a7,0x3ef3,0x74cc,0x743c,0x9387,0x7437,0x449f,0x26dea,
  0x4551,0x7583,0x3f63,0x24cd9,0x24d06,0x3f58,0x7555,0x7673,
  0x2a5c6,0x3b19,0x7468,0x28acc,0x249ab,0x2498e,0x3afb,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x3dcd,0x24a4e,0x3eff,0x249c5,0x248f3,0x91fa,0x5732,0x9342,
  0x28ae3,0x21864,0x50df,0x25221,0x251e7,0x7778,0x23232,0x770e,
  0x770f,0x777b,0x24697,0x23781,0x3a5e,0x248f0,0x7438,0x749b,
  0x3ebf,0x24aba,0x24ac7,0x40c8,0x24a96,0x261ae,0x9307,0x25581,
  0x781e,0x788d,0x7888,0x78d2,0x73d0,0x7959,0x27741,0x256e3,
  0x410e,0x0000,0x8496,0x79a5,0x6a2d,0x23efa,0x7a3a,0x79f4,
  0x416e,0x216e6,0x4132,0x9235,0x79f1,0x20d4c,0x2498c,0x20299,
  0x23dba,0x2176e,0x3597,0x556b,0x3570,0x36aa,0x201d4,0x20c0d,
  0x7ae2,0x5a59,0x226f5,0x25aaf,0x25a9c,0x5a0d,0x2025b,0x78f0,
  0x5a2a,0x25bc6,0x7afe,0x41f9,0x7c5d,0x7c6d,0x4211,0x25bb3,
  0x25ebc,0x25ea6,0x7ccd,0x249f9,0x217b0,0x7c8e,0x7c7c,0x7cae,
  0x6ab2,0x7ddc,0x7e07,0x7dd3,0x7f4e,0x26261,
/* 0x9500 */
  0x2615c,0x27b48,0x7d97,0x25e82,0x426a,0x26b75,0x20916,0x67d6,
  0x2004e,0x235cf,0x57c4,0x26412,0x263f8,0x24962,0x7fdd,0x7b27,
  0x2082c,0x25ae9,0x25d43,0x7b0c,0x25e0e,0x99e6,0x8645,0x9a63,
  0x6a1c,0x2343f,0x39e2,0x249f7,0x265ad,0x9a1f,0x265a0,0x8480,
  0x27127,0x26cd1,0x44ea,0x8137,0x4402,0x80c6,0x8109,0x8142,
  0x267b4,0x98c3,0x26a42,0x8262,0x8265,0x26a51,0x8453,0x26da7,
  0x8610,0x2721b,0x5a86,0x417f,0x21840,0x5b2b,0x218a1,0x5ae4,
  0x218d8,0x86a0,0x2f9bc,0x23d8f,0x882d,0x27422,0x5a02,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x886e,0x4f45,0x8887,0x88bf,0x88e6,0x8965,0x894d,0x25683,
  0x8954,0x27785,0x27784,0x28bf5,0x28bd9,0x28b9c,0x289f9,0x3ead,
  0x84a3,0x46f5,0x46cf,0x37f2,0x8a3d,0x8a1c,0x29448,0x5f4d,
  0x922b,0x24284,0x65d4,0x7129,0x70c4,0x21845,0x9d6d,0x8c9f,
  0x8ce9,0x27ddc,0x599a,0x77c3,0x59f0,0x436e,0x36d4,0x8e2a,
  0x8ea7,0x24c09,0x8f30,0x8f4a,0x42f4,0x6c58,0x6fbb,0x22321,
  0x489b,0x6f79,0x6e8b,0x217da,0x9be9,0x36b5,0x2492f,0x90bb,
  0x0000,0x5571,0x4906,0x91bb,0x9404,0x28a4b,0x4062,0x28afc,
  0x9427,0x28c1d,0x28c3b,0x84e5,0x8a2b,0x9599,0x95a7,0x9597,
  0x9596,0x28d34,0x7445,0x3ec2,0x248ff,0x24a42,0x243ea,0x3ee7,
  0x23225,0x968f,0x28ee7,0x28e66,0x28e65,0x3ecc,0x249ed,0x24a78,
  0x23fee,0x7412,0x746b,0x3efc,0x9741,0x290b0,
/* 0x9600 */
  0x6847,0x4a1d,0x29093,0x257df,0x0000,0x9368,0x28989,0x28c26,
  0x28b2f,0x263be,0x92ba,0x5b11,0x8b69,0x493c,0x73f9,0x2421b,
  0x979b,0x9771,0x9938,0x20f26,0x5dc1,0x28bc5,0x24ab2,0x981f,
  0x294da,0x92f6,0x295d7,0x91e5,0x44c0,0x28b50,0x24a67,0x28b64,
  0x98dc,0x28a45,0x3f00,0x922a,0x4925,0x8414,0x993b,0x994d,
  0x27b06,0x3dfd,0x999b,0x4b6f,0x99aa,0x9a5c,0x28b65,0x258c8,
  0x6a8f,0x9a21,0x5afe,0x9a2f,0x298f1,0x4b90,0x29948,0x99bc,
  0x4bbd,0x4b97,0x937d,0x5872,0x21302,0x5822,0x249b8,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x214e8,0x7844,0x2271f,0x23db8,0x68c5,0x3d7d,0x9458,0x3927,
  0x6150,0x22781,0x2296b,0x6107,0x9c4f,0x9c53,0x9c7b,0x9c35,
  0x9c10,0x9b7f,0x9bcf,0x29e2d,0x9b9f,0x2a1f5,0x2a0fe,0x9d21,
  0x4cae,0x24104,0x9e18,0x4cb0,0x9d0c,0x2a1b4,0x2a0ed,0x2a0f3,
  0x2992f,0x9da5,0x84bd,0x26e12,0x26fdf,0x26b82,0x85fc,0x4533,
  0x26da4,0x26e84,0x26df0,0x8420,0x85ee,0x26e00,0x237d7,0x26064,
  0x79e2,0x2359c,0x23640,0x492d,0x249de,0x3d62,0x93db,0x92be,
  0x9348,0x202bf,0x78b9,0x9277,0x944d,0x4fe4,0x3440,0x9064,
  0x2555d,0x783d,0x7854,0x78b6,0x784b,0x21757,0x231c9,0x24941,
  0x369a,0x4f72,0x6fda,0x6fd9,0x0000,0x701e,0x5414,0x241b5,
  0x57bb,0x58f3,0x578a,0x9d16,0x57d7,0x7134,0x34af,0x241ac,
  0x71eb,0x26c40,0x24f97,0x0000,0x217b5,0x28a49,
/* 0x9700 */
  0x610c,0x5ace,0x5a0b,0x42bc,0x24488,0x372c,0x4b7b,0x289fc,
  0x93bb,0x93b8,0x218d6,0x20f1d,0x8472,0x26cc0,0x21413,0x242fa,
  0x22c26,0x243c1,0x5994,0x23db7,0x26741,0x7da8,0x2615b,0x260a4,
  0x249b9,0x2498b,0x289fa,0x92e5,0x73e2,0x3ee9,0x74b4,0x28b63,
  0x2189f,0x3ee1,0x24ab3,0x6ad8,0x73f3,0x73fb,0x3ed6,0x24a3e,
  0x24a94,0x217d9,0x24a66,0x203a7,0x21424,0x249e5,0x7448,0x24916,
  0x70a5,0x24976,0x9284,0x73e6,0x935f,0x204fe,0x9331,0x28ace,
  0x28a16,0x9386,0x28be7,0x255d5,0x4935,0x28a82,0x716b,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x24943,0x20cff,0x56a4,0x2061a,0x20beb,0x20cb8,0x5502,0x79c4,
  0x217fa,0x7dfe,0x216c2,0x24a50,0x21852,0x452e,0x9401,0x370a,
  0x28ac0,0x249ad,0x59b0,0x218bf,0x21883,0x27484,0x5aa1,0x36e2,
  0x23d5b,0x36b0,0x925f,0x5a79,0x28a81,0x21862,0x9374,0x3ccd,
  0x20ab4,0x4a96,0x398a,0x50f4,0x3d69,0x3d4c,0x2139c,0x7175,
  0x42fb,0x28218,0x6e0f,0x290e4,0x44eb,0x6d57,0x27e4f,0x7067,
  0x6caf,0x3cd6,0x23fed,0x23e2d,0x6e02,0x6f0c,0x3d6f,0x203f5,
  0x7551,0x36bc,0x34c8,0x4680,0x3eda,0x4871,0x59c4,0x926e,
  0x493e,0x8f41,0x28c1c,0x26bc0,0x5812,0x57c8,0x36d6,0x21452,
  0x70fe,0x24362,0x24a71,0x22fe3,0x212b0,0x223bd,0x68b9,0x6967,
  0x21398,0x234e5,0x27bf4,0x236df,0x28a83,0x237d6,0x233fa,0x24c9f,
  0x6a1a,0x236ad,0x26cb7,0x843e,0x44df,0x44ce,
/* 0x9800 */
  0x26d26,0x26d51,0x26c82,0x26fde,0x6f17,0x27109,0x833d,0x2173a,
  0x83ed,0x26c80,0x27053,0x217db,0x5989,0x5a82,0x217b3,0x5a61,
  0x5a71,0x21905,0x241fc,0x372d,0x59ef,0x2173c,0x36c7,0x718e,
  0x9390,0x669a,0x242a5,0x5a6e,0x5a2b,0x24293,0x6a2b,0x23ef9,
  0x27736,0x2445b,0x242ca,0x711d,0x24259,0x289e1,0x4fb0,0x26d28,
  0x5cc2,0x244ce,0x27e4d,0x243bd,0x6a0c,0x24256,0x21304,0x70a6,
  0x7133,0x243e9,0x3da5,0x6cdf,0x2f825,0x24a4f,0x7e65,0x59eb,
  0x5d2f,0x3df3,0x5f5c,0x24a5d,0x217df,0x7da4,0x8426,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x5485,0x23afa,0x23300,0x20214,0x577e,0x208d5,0x20619,0x3fe5,
  0x21f9e,0x2a2b6,0x7003,0x2915b,0x5d70,0x738f,0x7cd3,0x28a59,
  0x29420,0x4fc8,0x7fe7,0x72cd,0x7310,0x27af4,0x7338,0x7339,
  0x256f6,0x7341,0x7348,0x3ea9,0x27b18,0x906c,0x71f5,0x248f2,
  0x73e1,0x81f6,0x3eca,0x770c,0x3ed1,0x6ca2,0x56fd,0x7419,
  0x741e,0x741f,0x3ee2,0x3ef0,0x3ef4,0x3efa,0x74d3,0x3f0e,
  0x3f53,0x7542,0x756d,0x7572,0x758d,0x3f7c,0x75c8,0x75dc,
  0x3fc0,0x764d,0x3fd7,0x7674,0x3fdc,0x767a,0x24f5c,0x7188,
  0x5623,0x8980,0x5869,0x401d,0x7743,0x4039,0x6761,0x4045,
  0x35db,0x7798,0x406a,0x406f,0x5c5e,0x77be,0x77cb,0x58f2,
  0x7818,0x70b9,0x781c,0x40a8,0x7839,0x7847,0x7851,0x7866,
  0x8448,0x25535,0x7933,0x6803,0x7932,0x4103,
/* 0x9900 */
  0x4109,0x7991,0x7999,0x8fbb,0x7a06,0x8fbc,0x4167,0x7a91,
  0x41b2,0x7abc,0x8279,0x41c4,0x7acf,0x7adb,0x41cf,0x4e21,
  0x7b62,0x7b6c,0x7b7b,0x7c12,0x7c1b,0x4260,0x427a,0x7c7b,
  0x7c9c,0x428c,0x7cb8,0x4294,0x7ced,0x8f93,0x70c0,0x20ccf,
  0x7dcf,0x7dd4,0x7dd0,0x7dfd,0x7fae,0x7fb4,0x729f,0x4397,
  0x8020,0x8025,0x7b39,0x802e,0x8031,0x8054,0x3dcc,0x57b4,
  0x70a0,0x80b7,0x80e9,0x43ed,0x810c,0x732a,0x810e,0x8112,
  0x7560,0x8114,0x4401,0x3b39,0x8156,0x8159,0x815a,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x4413,0x583a,0x817c,0x8184,0x4425,0x8193,0x442d,0x81a5,
  0x57ef,0x81c1,0x81e4,0x8254,0x448f,0x82a6,0x8276,0x82ca,
  0x82d8,0x82ff,0x44b0,0x8357,0x9669,0x698a,0x8405,0x70f5,
  0x8464,0x60e3,0x8488,0x4504,0x84be,0x84e1,0x84f8,0x8510,
  0x8538,0x8552,0x453b,0x856f,0x8570,0x85e0,0x4577,0x8672,
  0x8692,0x86b2,0x86ef,0x9645,0x878b,0x4606,0x4617,0x88ae,
  0x88ff,0x8924,0x8947,0x8991,0x27967,0x8a29,0x8a38,0x8a94,
  0x8ab4,0x8c51,0x8cd4,0x8cf2,0x8d1c,0x4798,0x585f,0x8dc3,
  0x47ed,0x4eee,0x8e3a,0x55d8,0x5754,0x8e71,0x55f5,0x8eb0,
  0x4837,0x8ece,0x8ee2,0x8ee4,0x8eed,0x8ef2,0x8fb7,0x8fc1,
  0x8fca,0x8fcc,0x9033,0x99c4,0x48ad,0x98e0,0x9213,0x491e,
  0x9228,0x9258,0x926b,0x92b1,0x92ae,0x92bf,
/* 0x9a00 */
  0x92e3,0x92eb,0x92f3,0x92f4,0x92fd,0x9343,0x9384,0x93ad,
  0x4945,0x4951,0x9ebf,0x9417,0x5301,0x941d,0x942d,0x943e,
  0x496a,0x9454,0x9479,0x952d,0x95a2,0x49a7,0x95f4,0x9633,
  0x49e5,0x67a0,0x4a24,0x9740,0x4a35,0x97b2,0x97c2,0x5654,
  0x4ae4,0x60e8,0x98b9,0x4b19,0x98f1,0x5844,0x990e,0x9919,
  0x51b4,0x991c,0x9937,0x9942,0x995d,0x9962,0x4b70,0x99c5,
  0x4b9d,0x9a3c,0x9b0f,0x7a83,0x9b69,0x9b81,0x9bdd,0x9bf1,
  0x9bf4,0x4c6d,0x9c20,0x376f,0x21bc2,0x9d49,0x9c3a,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x9efe,0x5650,0x9d93,0x9dbd,0x9dc0,0x9dfc,0x94f6,0x8fb6,
  0x9e7b,0x9eac,0x9eb1,0x9ebd,0x9ec6,0x94dc,0x9ee2,0x9ef1,
  0x9ef8,0x7ac8,0x9f44,0x20094,0x202b7,0x203a0,0x691a,0x94c3,
  0x59ac,0x204d7,0x5840,0x94c1,0x37b9,0x205d5,0x20615,0x20676,
  0x216ba,0x5757,0x7173,0x20ac2,0x20acd,0x20bbf,0x546a,0x2f83b,
  0x20bcb,0x549e,0x20bfb,0x20c3b,0x20c53,0x20c65,0x20c7c,0x60e7,
  0x20c8d,0x567a,0x20cb5,0x20cdd,0x20ced,0x20d6f,0x20db2,0x20dc8,
  0x6955,0x9c2f,0x87a5,0x20e04,0x20e0e,0x20ed7,0x20f90,0x20f2d,
  0x20e73,0x5c20,0x20fbc,0x5e0b,0x2105c,0x2104f,0x21076,0x671e,
  0x2107b,0x21088,0x21096,0x3647,0x210bf,0x210d3,0x2112f,0x2113b,
  0x5364,0x84ad,0x212e3,0x21375,0x21336,0x8b81,0x21577,0x21619,
  0x217c3,0x217c7,0x4e78,0x70bb,0x2182d,0x2196a,
/* 0x9b00 */
  0x21a2d,0x21a45,0x21c2a,0x21c70,0x21cac,0x21ec8,0x62c3,0x21ed5,
  0x21f15,0x7198,0x6855,0x22045,0x69e9,0x36c8,0x2227c,0x223d7,
  0x223fa,0x2272a,0x22871,0x2294f,0x82fd,0x22967,0x22993,0x22ad5,
  0x89a5,0x22ae8,0x8fa0,0x22b0e,0x97b8,0x22b3f,0x9847,0x9abd,
  0x22c4c,0x0000,0x22c88,0x22cb7,0x25be8,0x22d08,0x22d12,0x22db7,
  0x22d95,0x22e42,0x22f74,0x22fcc,0x23033,0x23066,0x2331f,0x233de,
  0x5fb1,0x6648,0x66bf,0x27a79,0x23567,0x235f3,0x0000,0x249ba,
  0x0000,0x2361a,0x23716,0x0000,0x20346,0x58b5,0x670e,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x6918,0x23aa7,0x27657,0x25fe2,0x23e11,0x23eb9,0x275fe,0x2209a,
  0x48d0,0x4ab8,0x24119,0x28a9a,0x242ee,0x2430d,0x2403b,0x24334,
  0x24396,0x24a45,0x205ca,0x51d2,0x20611,0x599f,0x21ea8,0x3bbe,
  0x23cff,0x24404,0x244d6,0x5788,0x24674,0x399b,0x2472f,0x285e8,
  0x299c9,0x3762,0x221c3,0x8b5e,0x28b4e,0x0000,0x24812,0x248fb,
  0x24a15,0x7209,0x24ac0,0x20c78,0x5965,0x24ea5,0x24f86,0x20779,
  0x8eda,0x2502c,0x528f,0x573f,0x7171,0x25299,0x25419,0x23f4a,
  0x24aa7,0x55bc,0x25446,0x2546e,0x26b52,0x0000,0x3473,0x2553f,
  0x27632,0x2555e,0x4718,0x25562,0x25566,0x257c7,0x2493f,0x2585d,
  0x5066,0x34fb,0x233cc,0x0000,0x25903,0x477c,0x28948,0x25aae,
  0x25b89,0x25c06,0x21d90,0x57a1,0x7151,0x0000,0x26102,0x27c12,
  0x9056,0x261b2,0x24f9a,0x8b62,0x26402,0x2644a,
/* 0x9c00 */
  0x5d5b,0x26bf7,0x0000,0x26484,0x2191c,0x8aea,0x249f6,0x26488,
  0x23fef,0x26512,0x4bc0,0x265bf,0x266b5,0x2271b,0x9465,0x257e1,
  0x6195,0x5a27,0x2f8cd,0x0000,0x56b9,0x24521,0x266fc,0x4e6a,
  0x24934,0x9656,0x6d8f,0x26cbd,0x3618,0x8977,0x26799,0x2686e,
  0x26411,0x2685e,0x0000,0x268c7,0x7b42,0x290c0,0x20a11,0x26926,
  0x0000,0x26939,0x7a45,0x0000,0x269fa,0x9a26,0x26a2d,0x365f,
  0x26469,0x20021,0x7983,0x26a34,0x26b5b,0x5d2c,0x23519,0x0000,
  0x26b9d,0x46d0,0x26ca4,0x753b,0x8865,0x26dae,0x58b6,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x371c,0x2258d,0x2704b,0x271cd,0x3c54,0x27280,0x27285,0x9281,
  0x2217a,0x2728b,0x9330,0x272e6,0x249d0,0x6c39,0x949f,0x27450,
  0x20ef8,0x8827,0x88f5,0x22926,0x28473,0x217b1,0x6eb8,0x24a2a,
  0x21820,0x39a4,0x36b9,0x0000,0x0000,0x453f,0x66b6,0x29cad,
  0x298a4,0x8943,0x277cc,0x27858,0x56d6,0x40df,0x2160a,0x39a1,
  0x2372f,0x280e8,0x213c5,0x71ad,0x8366,0x279dd,0x291a8,0x0000,
  0x4cb7,0x270af,0x289ab,0x279fd,0x27a0a,0x27b0b,0x27d66,0x2417a,
  0x7b43,0x797e,0x28009,0x6fb5,0x2a2df,0x6a03,0x28318,0x53a2,
  0x26e07,0x93bf,0x6836,0x975d,0x2816f,0x28023,0x269b5,0x213ed,
  0x2322f,0x28048,0x5d85,0x28c30,0x28083,0x5715,0x9823,0x28949,
  0x5dab,0x24988,0x65be,0x69d5,0x53d2,0x24aa5,0x23f81,0x3c11,
  0x6736,0x28090,0x280f4,0x2812e,0x21fa1,0x2814f,
/* 0x9d00 */
  0x28189,0x281af,0x2821a,0x28306,0x2832f,0x2838a,0x35ca,0x28468,
  0x286aa,0x48fa,0x63e6,0x28956,0x7808,0x9255,0x289b8,0x43f2,
  0x289e7,0x43df,0x289e8,0x28b46,0x28bd4,0x59f8,0x28c09,0x0000,
  0x28fc5,0x290ec,0x0000,0x29110,0x2913c,0x3df7,0x2915e,0x24aca,
  0x8fd0,0x728f,0x568b,0x294e7,0x295e9,0x295b0,0x295b8,0x29732,
  0x298d1,0x29949,0x2996a,0x299c3,0x29a28,0x29b0e,0x29d5a,0x29d9b,
  0x7e9f,0x29ef8,0x29f23,0x4ca4,0x9547,0x2a293,0x71a2,0x2a2ff,
  0x4d91,0x9012,0x2a5cb,0x4d9c,0x20c9c,0x8fbe,0x55c1,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x8fba,0x224b0,0x8fb9,0x24a93,0x4509,0x7e7f,0x6f56,0x6ab1,
  0x4eea,0x34e4,0x28b2c,0x2789d,0x373a,0x8e80,0x217f5,0x28024,
  0x28b6c,0x28b99,0x27a3e,0x266af,0x3deb,0x27655,0x23cb7,0x25635,
  0x25956,0x4e9a,0x25e81,0x26258,0x56bf,0x20e6d,0x8e0e,0x5b6d,
  0x23e88,0x24c9e,0x63de,0x0000,0x217f6,0x2187b,0x6530,0x562d,
  0x25c4a,0x541a,0x25311,0x3dc6,0x29d98,0x4c7d,0x5622,0x561e,
  0x7f49,0x25ed8,0x5975,0x23d40,0x8770,0x4e1c,0x20fea,0x20d49,
  0x236ba,0x8117,0x9d5e,0x8d18,0x763b,0x9c45,0x764e,0x77b9,
  0x9345,0x5432,0x8148,0x82f7,0x5625,0x8132,0x8418,0x80bd,
  0x55ea,0x7962,0x5643,0x5416,0x20e9d,0x35ce,0x5605,0x55f1,
  0x66f1,0x282e2,0x362d,0x7534,0x55f0,0x55ba,0x5497,0x5572,
  0x20c41,0x20c96,0x5ed0,0x25148,0x20e76,0x22c62,
/* 0x9e00 */
  0x20ea2,0x9eab,0x7d5a,0x55de,0x21075,0x629d,0x976d,0x5494,
  0x8ccd,0x71f6,0x9176,0x63fc,0x63b9,0x63fe,0x5569,0x22b43,
  0x9c72,0x22eb3,0x519a,0x34df,0x20da7,0x51a7,0x544d,0x551e,
  0x5513,0x7666,0x8e2d,0x2688a,0x75b1,0x80b6,0x8804,0x8786,
  0x88c7,0x81b6,0x841c,0x210c1,0x44ec,0x7304,0x24706,0x5b90,
  0x830b,0x26893,0x567b,0x226f4,0x27d2f,0x241a3,0x27d73,0x26ed0,
  0x272b6,0x9170,0x211d9,0x9208,0x23cfc,0x2a6a9,0x20eac,0x20ef9,
  0x7266,0x21ca2,0x474e,0x24fc2,0x27ff9,0x20feb,0x40fa,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x9c5d,0x651f,0x22da0,0x48f3,0x247e0,0x29d7c,0x20fec,0x20e0a,
  0x0000,0x275a3,0x20fed,0x0000,0x26048,0x21187,0x71a3,0x7e8e,
  0x9d50,0x4e1a,0x4e04,0x3577,0x5b0d,0x6cb2,0x5367,0x36ac,
  0x39dc,0x537d,0x36a5,0x24618,0x589a,0x24b6e,0x822d,0x544b,
  0x57aa,0x25a95,0x20979,0x0000,0x3a52,0x22465,0x7374,0x29eac,
  0x4d09,0x9bed,0x23cfe,0x29f30,0x4c5b,0x24fa9,0x2959e,0x29fde,
  0x845c,0x23db6,0x272b2,0x267b3,0x23720,0x632e,0x7d25,0x23ef7,
  0x23e2c,0x3a2a,0x9008,0x52cc,0x3e74,0x367a,0x45e9,0x2048e,
  0x7640,0x5af0,0x20eb6,0x787a,0x47b6,0x58a7,0x40bf,0x567c,
  0x9b8b,0x5d74,0x7654,0x2a434,0x9e85,0x4ce1,0x0000,0x37fb,
  0x6119,0x230da,0x243f2,0x0000,0x565d,0x212a9,0x57a7,0x24963,
  0x29e06,0x5234,0x270ae,0x35ad,0x0000,0x9d7c,
/* 0x9f00 */
  0x7c56,0x9b39,0x57de,0x2176c,0x5c53,0x64d3,0x294d0,0x26335,
  0x27164,0x86ad,0x20d28,0x26d22,0x24ae2,0x20d71,0x0000,0x51fe,
  0x21f0f,0x5d8e,0x9703,0x21dd1,0x9e81,0x904c,0x7b1f,0x9b02,
  0x5cd1,0x7ba3,0x6268,0x6335,0x9aff,0x7bcf,0x9b2a,0x7c7e,
  0x0000,0x7c42,0x7c86,0x9c15,0x7bfc,0x9b09,0x0000,0x9c1b,
  0x2493e,0x9f5a,0x5573,0x5bc3,0x4ffd,0x9e98,0x4ff2,0x5260,
  0x3e06,0x52d1,0x5767,0x5056,0x59b7,0x5e12,0x97c8,0x9dab,
  0x8f5c,0x5469,0x97b4,0x9940,0x97ba,0x532c,0x6130,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x692c,0x53da,0x9c0a,0x9d02,0x4c3b,0x9641,0x6980,0x50a6,
  0x7546,0x2176d,0x99da,0x5273,0x0000,0x9159,0x9681,0x915c,
  0x0000,0x9151,0x28e97,0x637f,0x26d23,0x6aca,0x5611,0x918e,
  0x757a,0x6285,0x203fc,0x734f,0x7c70,0x25c21,0x23cfd,0x0000,
  0x24919,0x76d6,0x9b9d,0x4e2a,0x20cd4,0x83be,0x8842,0x0000,
  0x5c4a,0x69c0,0x0000,0x577a,0x521f,0x5df5,0x4ece,0x6c31,
  0x201f2,0x4f39,0x549c,0x54da,0x529a,0x8d82,0x35fe,0x0000,
  0x35f3,0x0000,0x6b52,0x917c,0x9fa5,0x9b97,0x982e,0x98b4,
  0x9aba,0x9ea8,0x9e84,0x717a,0x7b14,0x0000,0x6bfa,0x8818,
  0x7f78,0x0000,0x5620,0x2a64a,0x8e77,0x9f53,0x0000,0x8dd4,
  0x8e4f,0x9e1c,0x8e01,0x6282,0x2837d,0x8e28,0x8e75,0x7ad3,
  0x24a77,0x7a3e,0x78d8,0x6cea,0x8a67,0x7607,
/* 0xa000 */
  0x28a5a,0x9f26,0x6cce,0x87d6,0x75c3,0x2a2b2,0x7853,0x2f840,
  0x8d0c,0x72e2,0x7371,0x8b2d,0x7302,0x74f1,0x8ceb,0x24abb,
  0x862f,0x5fba,0x88a0,0x44b7,0x0000,0x2183b,0x26e05,0x0000,
  0x8a7e,0x2251b,0x0000,0x60fd,0x7667,0x9ad7,0x9d44,0x936e,
  0x9b8f,0x87f5,0x0000,0x0000,0x8cf7,0x732c,0x9721,0x9bb0,
  0x35d6,0x72b2,0x4c07,0x7c51,0x994a,0x26159,0x6159,0x4c04,
  0x9e96,0x617d,0x0000,0x575f,0x616f,0x62a6,0x6239,0x0000,
  0x3a5c,0x61e2,0x53aa,0x233f5,0x6364,0x6802,0x35d2,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x5d57,0x28bc2,0x8fda,0x28e39,0x0000,0x50d9,0x21d46,0x7906,
  0x5332,0x9638,0x20f3b,0x4065,0x0000,0x77fe,0x0000,0x7cc2,
  0x25f1a,0x7cda,0x7a2d,0x8066,0x8063,0x7d4d,0x7505,0x74f2,
  0x8994,0x821a,0x670c,0x8062,0x27486,0x805b,0x74f0,0x8103,
  0x7724,0x8989,0x267cc,0x7553,0x26ed1,0x87a9,0x87ce,0x81c8,
  0x878c,0x8a49,0x8cad,0x8b43,0x772b,0x74f8,0x84da,0x3635,
  0x69b2,0x8da6,0x0000,0x89a9,0x0000,0x6db9,0x87c1,0x24011,
  0x74e7,0x3ddb,0x7176,0x60a4,0x619c,0x3cd1,0x0000,0x6077,
  0x0000,0x7f71,0x28b2d,0x0000,0x60e9,0x4b7e,0x5220,0x3c18,
  0x23cc7,0x25ed7,0x27656,0x25531,0x21944,0x212fe,0x29903,0x26ddc,
  0x270ad,0x5cc1,0x261ad,0x28a0f,0x23677,0x200ee,0x26846,0x24f0e,
  0x4562,0x5b1f,0x2634c,0x9f50,0x9ea6,0x2626b
};

skf_ucode hkscs_c6_uni_byte[HKSCS_C6_LEN] = { /* c640 - c8fe */
/* c600 */
  0x8b96,0x8277,0x8d1b,0x91c0, 0x946a,0x9742,0x9748,0x9744,
  0x97c6,0x9870,0x9a5f,0x9b22, 0x9b58,0x9c5f,0x9df9,0x9dfa,
  0x9e7c,0x9e7d,0x9f07,0x9f77, 0x9f72,0x5ef3,0x6b16,0x7063,
  0x7c6c,0x7c6e,0x883b,0x89c0, 0x8ea1,0x91c1,0x9472,0x9470,
  0x9871,0x995e,0x9ad6,0x9b23, 0x9ecc,0x7064,0x77da,0x8b9a,
  0x9477,0x97c9,0x9a62,0x9a65, 0x7e9c,0x8b9c,0x8eaa,0x91c5,
  0x947d,0x947e,0x947c,0x9c77, 0x9c78,0x9ef7,0x8c54,0x947f,
  0x9e1a,0x7228,0x9a6a,0x9b31, 0x9e1b,0x9e1e,0x7c72,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x2460,0x2461,0x2462,0x2463, 0x2464,0x2465,0x2466,0x2467,
  0x2468,0x2469,0x2474,0x2475, 0x2476,0x2477,0x2478,0x2479,
  0x247a,0x247b,0x247c,0x247d, 0x2170,0x2171,0x2172,0x2173,
  0x2174,0x2175,0x2176,0x2177, 0x2178,0x2179,0x4e36,0x4e3f,
  0x4e85,0x4ea0,0x5182,0x5196, 0x51ab,0x52f9,0x5338,0x5369,
  0x53b6,0x590a,0x5b80,0x5ddb, 0x2f33,0x5e7f,0x2f35,0x5f50,
  0x5f61,0x6534,0x2f46,0x7592, 0x2f68,0x8fb5,0x2faa,0x00a8,
  0x02c6,0x30fd,0x30fe,0x309d, 0x309e,0x309b,0x4edd,0x3005,
  0x3006,0x3007,0x30fc,0xff3b, 0xff3d,0x273d,0x3041,0x3042,
  0x3043,0x3044,0x3045,0x3046, 0x3047,0x3048,0x3049,0x304a,
  0x304b,0x304c,0x304d,0x304e, 0x304f,0x3050,0x3051,0x3052,
  0x3053,0x3054,0x3055,0x3056, 0x3057,0x3058,
/* c700 */
  0x3059,0x305a,0x305b,0x305c, 0x305d,0x305e,0x305f,0x3060,
  0x3061,0x3062,0x3063,0x3064, 0x3065,0x3066,0x3067,0x3068,
  0x3069,0x306a,0x306b,0x306c, 0x306d,0x306e,0x306f,0x3070,
  0x3071,0x3072,0x3073,0x3074, 0x3075,0x3076,0x3077,0x3078,
  0x3079,0x307a,0x307b,0x307c, 0x307d,0x307e,0x307f,0x3080,
  0x3081,0x3082,0x3083,0x3084, 0x3085,0x3086,0x3087,0x3088,
  0x3089,0x308a,0x308b,0x308c, 0x308d,0x308e,0x308f,0x3090,
  0x3091,0x3092,0x3093,0x30a1, 0x30a2,0x30a3,0x30a4,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x30a5,0x30a6,0x30a7,0x30a8, 0x30a9,0x30aa,0x30ab,0x30ac,
  0x30ad,0x30ae,0x30af,0x30b0, 0x30b1,0x30b2,0x30b3,0x30b4,
  0x30b5,0x30b6,0x30b7,0x30b8, 0x30b9,0x30ba,0x30bb,0x30bc,
  0x30bd,0x30be,0x30bf,0x30c0, 0x30c1,0x30c2,0x30c3,0x30c4,
  0x30c5,0x30c6,0x30c7,0x30c8, 0x30c9,0x30ca,0x30cb,0x30cc,
  0x30cd,0x30ce,0x30cf,0x30d0, 0x30d1,0x30d2,0x30d3,0x30d4,
  0x30d5,0x30d6,0x30d7,0x30d8, 0x30d9,0x30da,0x30db,0x30dc,
  0x30dd,0x30de,0x30df,0x30e0, 0x30e1,0x30e2,0x30e3,0x30e4,
  0x30e5,0x30e6,0x30e7,0x30e8, 0x30e9,0x30ea,0x30eb,0x30ec,
  0x30ed,0x30ee,0x30ef,0x30f0, 0x30f1,0x30f2,0x30f3,0x30f4,
  0x30f5,0x30f6,0x0410,0x0411, 0x0412,0x0413,0x0414,0x0415,
  0x0401,0x0416,0x0417,0x0418, 0x0419,0x041a,
/* c800 */
  0x041b,0x041c,0x041d,0x041e, 0x041f,0x0420,0x0421,0x0422,
  0x0423,0x0424,0x0425,0x0426, 0x0427,0x0428,0x0429,0x042a,
  0x042b,0x042c,0x042d,0x042e, 0x042f,0x0430,0x0431,0x0432,
  0x0433,0x0434,0x0435,0x0451, 0x0436,0x0437,0x0438,0x0439,
  0x043a,0x043b,0x043c,0x043d, 0x043e,0x043f,0x0440,0x0441,
  0x0442,0x0443,0x0444,0x0445, 0x0446,0x0447,0x0448,0x0449,
  0x044a,0x044b,0x044c,0x044d, 0x044e,0x044f,0x21e7,0x21b8,
  0x21b9,0xf7e5,0x200cc,0x4e5a, 0x2008a,0x5202,0xf7ea,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0xf7eb,0x5188,0xf7ed,0x27607, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0xffe2,0xffe4,0xff07,0xff02,
  0x3231,0x2116,0x2121,0x309b, 0x309c,0x2e80,0x2e84,0x2e86,
  0x2e87,0x2e88,0x2e8a,0x2e8c, 0x2e8d,0x2e95,0x2e9c,0x2e9d,
  0x2ea5,0x2ea7,0x2eaa,0x2eac, 0x2eae,0x2eb6,0x2ebc,0x2ebe,
  0x2ec6,0x2eca,0x2ecc,0x2ecd, 0x2ecf,0x2ed6,0x2ed7,0x2ede,
  0x2ee3,0x0000,0x0000,0x0000, 0x0283,0x0250,0x025b,0x0254,
  0x0275,0x0153,0x00f8,0x014b, 0x028a,0x026a
};

unsigned short hkscs_priv_patch[HKSCS_PATCH_LEN] = {
 0x8845,0xF308, 0x8847,0xF30A, 0x8848,0xF30B, 0x884B,0xF30E, 
 0x884C,0xF30F, 0x884E,0xF311, 0x8853,0xF316, 0x8940,0xF3A0, 
 0x8941,0xF3A1, 0x894C,0xF3AC, 0x89B2,0xF3F0, 0x89BB,0xF3F9, 
 0x89BC,0xF3FA, 0x89BE,0xF3FC, 0x89CA,0xF408, 0x89CB,0xF409, 
 0x89CC,0xF40A, 0x89CD,0xF40B, 0x8A40,0xF43D, 0x8A43,0xF440, 
 0x8A44,0xF441, 0x8A45,0xF442, 0x8A47,0xF444, 0x8A49,0xF446, 
 0x8A4B,0xF448, 0x8A4C,0xF449, 0x8A4E,0xF44B, 0x8A50,0xF44D, 
 0x8A53,0xF450, 0x8A54,0xF451, 0x8A55,0xF452, 0x8A57,0xF454, 
 0x8A58,0xF455, 0x8A59,0xF456, 0x8A5A,0xF457, 0x8A5D,0xF45A, 
 0x8A5E,0xF45B, 0x8A5F,0xF45C, 0x8A60,0xF45D, 0x8A61,0xF45E, 
 0x8A62,0xF45F, 0x8A64,0xF461, 0x8A65,0xF462, 0x8A66,0xF463, 
 0x8A68,0xF465, 0x8A69,0xF466, 0x8A6C,0xF469, 0x8A6F,0xF46C, 
 0x8A70,0xF46D, 0x8A71,0xF46E, 0x8A72,0xF46F, 0x8A77,0xF474, 
 0x8A7A,0xF477, 0x8A7B,0xF478, 0x8A7C,0xF479, 0x8A7E,0xF47B, 
 0x8AA1,0xF47C, 0x8AA2,0xF47D, 0x8AA3,0xF47E, 0x8AA5,0xF480, 
 0x8AA6,0xF481, 0x8AA8,0xF483, 0x8AA9,0xF484, 0x8AAA,0xF485, 
 0x8AAD,0xF488, 0x8AB0,0xF48B, 0x8AB2,0xF48D, 0x8AB3,0xF48E, 
 0x8AB4,0xF48F, 0x8AB5,0xF490, 0x8AB6,0xF491, 0x8ABC,0xF497, 
 0x8ABD,0xF498, 0x8AC0,0xF49B, 0x8AC3,0xF49E, 0x8AC9,0xF4A4, 
 0x8ACA,0xF4A5, 0x8ACB,0xF4A6, 0x8ACC,0xF4A7, 0x8ACE,0xF4A9, 
 0x8ACF,0xF4AA, 0x8AD2,0xF4AD, 0x8AD4,0xF4AF, 0x8AD5,0xF4B0, 
 0x8AD7,0xF4B2, 0x8AD8,0xF4B3, 0x8AD9,0xF4B4, 0x8ADC,0xF4B7, 
 0x8ADF,0xF4BA, 0x8AE0,0xF4BB, 0x8AE1,0xF4BC, 0x8AE2,0xF4BD, 
 0x8AE3,0xF4BE, 0x8AE4,0xF4BF, 0x8AE5,0xF4C0, 0x8AE6,0xF4C1, 
 0x8AE8,0xF4C3, 0x8AE9,0xF4C4, 0x8AEA,0xF4C5, 0x8AEC,0xF4C7, 
 0x8AED,0xF4C8, 0x8AEE,0xF4C9, 0x8AEF,0xF4CA, 0x8AF1,0xF4CC, 
 0x8AF2,0xF4CD, 0x8AF3,0xF4CE, 0x8AF4,0xF4CF, 0x8AF6,0xF4D1, 
 0x8AF7,0xF4D2, 0x8AF8,0xF4D3, 0x8AF9,0xF4D4, 0x8AFA,0xF4D5, 
 0x8AFC,0xF4D7, 0x8AFE,0xF4D9, 0x8B40,0xF4DA, 0x8B41,0xF4DB, 
 0x8B42,0xF4DC, 0x8B43,0xF4DD, 0x8B44,0xF4DE, 0x8B45,0xF4DF, 
 0x8B46,0xF4E0, 0x8B48,0xF4E2, 0x8B49,0xF4E3, 0x8B4A,0xF4E4, 
 0x8B4B,0xF4E5, 0x8B4C,0xF4E6, 0x8B4D,0xF4E7, 0x8B4E,0xF4E8, 
 0x8B4F,0xF4E9, 0x8B55,0xF4EF, 0x8B58,0xF4F2, 0x8B59,0xF4F3, 
 0x8B5E,0xF4F8, 0x8B62,0xF4FC, 0x8B64,0xF4FE, 0x8B65,0xF4FF, 
 0x8B66,0xF500, 0x8B67,0xF501, 0x8B69,0xF503, 0x8B6B,0xF505, 
 0x8B6D,0xF507, 0x8B6E,0xF508, 0x8B6F,0xF509, 0x8B70,0xF50A, 
 0x8B71,0xF50B, 0x8B72,0xF50C, 0x8B73,0xF50D, 0x8B74,0xF50E, 
 0x8B75,0xF50F, 0x8B76,0xF510, 0x8B77,0xF511, 0x8B79,0xF513, 
 0x8B7A,0xF514, 0x8B7B,0xF515, 0x8B7C,0xF516, 0x8B7E,0xF518, 
 0x8BA1,0xF519, 0x8BA2,0xF51A, 0x8BA3,0xF51B, 0x8BA4,0xF51C, 
 0x8BA5,0xF51D, 0x8BA7,0xF51F, 0x8BA8,0xF520, 0x8BA9,0xF521, 
 0x8BAA,0xF522, 0x8BAB,0xF523, 0x8BAC,0xF524, 0x8BAD,0xF525, 
 0x8BAE,0xF526, 0x8BB2,0xF52A, 0x8BBB,0xF533, 0x8BBC,0xF534, 
 0x8BC2,0xF53A, 0x8BC3,0xF53B, 0x8BC5,0xF53D, 0x8BD6,0xF54E, 
 0x8BDB,0xF553, 0x8BDE,0xF556, 0x8BE1,0xF559, 0x8BE2,0xF55A, 
 0x8BE6,0xF55E, 0x8BED,0xF565, 0x8BF3,0xF56B, 0x8BFA,0xF572, 
 0x8C42,0xF579, 0x8C46,0xF57D, 0x8C4A,0xF581, 0x8C4C,0xF583, 
 0x8C4E,0xF585, 0x8C54,0xF58B, 0x8C55,0xF58C, 0x8C57,0xF58E, 
 0x8C5C,0xF593, 0x8C5F,0xF596, 0x8C64,0xF59B, 0x8C65,0xF59C, 
 0x8C69,0xF5A0, 0x8C6C,0xF5A3, 0x8C79,0xF5B0, 0x8C7D,0xF5B4, 
 0x8CA1,0xF5B6, 0x8CA4,0xF5B9, 0x8CA8,0xF5BD, 0x8CAB,0xF5C0, 
 0x8CAF,0xF5C4, 0x8CB0,0xF5C5, 0x8CC1,0xF5D6, 0x8CC2,0xF5D7, 
 0x8CCF,0xF5E4, 0x8CD1,0xF5E6, 0x8CD3,0xF5E8, 0x8CD5,0xF5EA, 
 0x8CD6,0xF5EB, 0x8DE2,0xF694, 0x8DEC,0xF69E, 0x8DFB,0xF6AD, 
 0x8DFE,0xF6B0, 0x8E40,0xE311, 0x8E42,0xE313, 0x8E44,0xE315, 
 0x8E47,0xE318, 0x8E4A,0xE31B, 0x8E4B,0xE31C, 0x8E4E,0xE31F, 
 0x8E54,0xE325, 0x8E5B,0xE32C, 0x8E5F,0xE330, 0x8E60,0xE331, 
 0x8E64,0xE335, 0x8E65,0xE336, 0x8E6A,0xE33B, 0x8E6C,0xE33D, 
 0x8E71,0xE342, 0x8E74,0xE345, 0x8E77,0xE348, 0x8EA3,0xE352, 
 0x8EA5,0xE354, 0x8EAC,0xE35B, 0x8EAD,0xE35C, 0x8EB1,0xE360, 
 0x8EB3,0xE362, 0x8EB5,0xE364, 0x8EB6,0xE365, 0x8EC0,0xE36F, 
 0x8EC3,0xE372, 0x8EC5,0xE374, 0x8EC6,0xE375, 0x8EC8,0xE377, 
 0x8ECA,0xE379, 0x8ECC,0xE37B, 0x8ED2,0xE381, 0x8ED3,0xE382, 
 0x8ED7,0xE386, 0x8ED9,0xE388, 0x8EDA,0xE389, 0x8EDB,0xE38A, 
 0x8EDE,0xE38D, 0x8EE2,0xE391, 0x8EE4,0xE393, 0x8EE5,0xE394, 
 0x8EE7,0xE396, 0x8EE9,0xE398, 0x8EEB,0xE39A, 0x8EEC,0xE39B, 
 0x8EEF,0xE39E, 0x8EF0,0xE39F, 0x8EF1,0xE3A0, 0x8EF3,0xE3A2, 
 0x8EF6,0xE3A5, 0x8EF7,0xE3A6, 0x8EF8,0xE3A7, 0x8EF9,0xE3A8, 
 0x8EFA,0xE3A9, 0x8EFD,0xE3AC, 0x8F43,0xE3B1, 0x8F44,0xE3B2, 
 0x8F46,0xE3B4, 0x8F47,0xE3B5, 0x8F4B,0xE3B9, 0x8F4C,0xE3BA, 
 0x8F4D,0xE3BB, 0x8F4E,0xE3BC, 0x8F4F,0xE3BD, 0x8F55,0xE3C3, 
 0x8F5A,0xE3C8, 0x8F5E,0xE3CC, 0x8F5F,0xE3CD, 0x8F61,0xE3CF, 
 0x8F67,0xE3D5, 0x8F6A,0xE3D8, 0x8F6B,0xE3D9, 0x8F6C,0xE3DA, 
 0x8F73,0xE3E1, 0x8F75,0xE3E3, 0x8F79,0xE3E7, 0x8FA1,0xE3ED, 
 0x8FA2,0xE3EE, 0x8FA4,0xE3F0, 0x8FA6,0xE3F2, 0x8FA7,0xE3F3, 
 0x8FA8,0xE3F4, 0x8FAC,0xE3F8, 0x8FAE,0xE3FA, 0x8FB1,0xE3FD, 
 0x8FB3,0xE3FF, 0x8FBD,0xE409, 0x8FBE,0xE40A, 0x8FBF,0xE40B, 
 0x8FC8,0xE414, 0x8FCF,0xE41B, 0x8FD1,0xE41D, 0x8FD2,0xE41E, 
 0x8FD7,0xE423, 0x8FD9,0xE425, 0x8FDA,0xE426, 0x8FDC,0xE428, 
 0x8FE0,0xE42C, 0x8FE1,0xE42D, 0x8FE6,0xE432, 0x8FEA,0xE436, 
 0x8FEE,0xE43A, 0x8FEF,0xE43B, 0x8FF0,0xE43C, 0x8FF2,0xE43E, 
 0x8FF4,0xE440, 0x8FF5,0xE441, 0x8FF8,0xE444, 0x8FFC,0xE448, 
 0x9041,0xE44C, 0x9042,0xE44D, 0x9043,0xE44E, 0x9045,0xE450, 
 0x9046,0xE451, 0x904E,0xE459, 0x904F,0xE45A, 0x9052,0xE45D, 
 0x9053,0xE45E, 0x9056,0xE461, 0x9057,0xE462, 0x9058,0xE463, 
 0x905A,0xE465, 0x905C,0xE467, 0x905D,0xE468, 0x905E,0xE469, 
 0x905F,0xE46A, 0x9061,0xE46C, 0x9063,0xE46E, 0x9064,0xE46F, 
 0x9066,0xE471, 0x9067,0xE472, 0x9069,0xE474, 0x906B,0xE476, 
 0x9073,0xE47E, 0x9074,0xE47F, 0x9079,0xE484, 0x907B,0xE486, 
 0x907C,0xE487, 0x907D,0xE488, 0x907E,0xE489, 0x90A1,0xE48A, 
 0x90A4,0xE48D, 0x90A5,0xE48E, 0x90A8,0xE491, 0x90A9,0xE492, 
 0x90AC,0xE495, 0x90AD,0xE496, 0x90AE,0xE497, 0x90B8,0xE4A1, 
 0x90B9,0xE4A2, 0x90BA,0xE4A3, 0x90BB,0xE4A4, 0x90C2,0xE4AB, 
 0x90C6,0xE4AF, 0x90CA,0xE4B3, 0x90CB,0xE4B4, 0x90CC,0xE4B5, 
 0x90CD,0xE4B6, 0x90CE,0xE4B7, 0x90CF,0xE4B8, 0x90D0,0xE4B9, 
 0x90D1,0xE4BA, 0x90D8,0xE4C1, 0x90DD,0xE4C6, 0x90E0,0xE4C9, 
 0x90E4,0xE4CD, 0x90E5,0xE4CE, 0x90ED,0xE4D6, 0x90F0,0xE4D9, 
 0x90F3,0xE4DC, 0x90F4,0xE4DD, 0x90FB,0xE4E4, 0x90FD,0xE4E6, 
 0x90FE,0xE4E7, 0x9140,0xE4E8, 0x9146,0xE4EE, 0x9147,0xE4EF, 
 0x914E,0xE4F6, 0x9150,0xE4F8, 0x9151,0xE4F9, 0x9157,0xE4FF, 
 0x9159,0xE501, 0x915A,0xE502, 0x915D,0xE505, 0x9162,0xE50A, 
 0x9165,0xE50D, 0x9167,0xE50F, 0x916A,0xE512, 0x916C,0xE514, 
 0x916E,0xE516, 0x9172,0xE51A, 0x9174,0xE51C, 0x9175,0xE51D, 
 0x9176,0xE51E, 0x9177,0xE51F, 0x9178,0xE520, 0x9179,0xE521, 
 0x917C,0xE524, 0x91A2,0xE528, 0x91A3,0xE529, 0x91A4,0xE52A, 
 0x91A5,0xE52B, 0x91A6,0xE52C, 0x91A8,0xE52E, 0x91A9,0xE52F, 
 0x91B1,0xE537, 0x91B8,0xE53E, 0x91BD,0xE543, 0x91C5,0xE54B, 
 0x91CE,0xE554, 0x91CF,0xE555, 0x91D1,0xE557, 0x91D2,0xE558, 
 0x91D3,0xE559, 0x91D5,0xE55B, 0x91D6,0xE55C, 0x91D8,0xE55E, 
 0x91D9,0xE55F, 0x91DC,0xE562, 0x91E0,0xE566, 0x91E1,0xE567, 
 0x91E7,0xE56D, 0x91E8,0xE56E, 0x91EA,0xE570, 0x91EC,0xE572, 
 0x91ED,0xE573, 0x91EF,0xE575, 0x91F0,0xE576, 0x91F1,0xE577, 
 0x91F3,0xE579, 0x91F4,0xE57A, 0x91F6,0xE57C, 0x91F7,0xE57D, 
 0x91F8,0xE57E, 0x91FA,0xE580, 0x91FC,0xE582, 0x91FD,0xE583, 
 0x91FE,0xE584, 0x9240,0xE585, 0x9241,0xE586, 0x9243,0xE588, 
 0x9246,0xE58B, 0x9247,0xE58C, 0x9248,0xE58D, 0x9249,0xE58E, 
 0x924A,0xE58F, 0x924B,0xE590, 0x924D,0xE592, 0x924E,0xE593, 
 0x924F,0xE594, 0x9255,0xE59A, 0x9258,0xE59D, 0x9259,0xE59E, 
 0x925A,0xE59F, 0x925B,0xE5A0, 0x925C,0xE5A1, 0x925F,0xE5A4, 
 0x9261,0xE5A6, 0x9262,0xE5A7, 0x9263,0xE5A8, 0x9265,0xE5AA, 
 0x926A,0xE5AF, 0x926C,0xE5B1, 0x926D,0xE5B2, 0x9270,0xE5B5, 
 0x9272,0xE5B7, 0x9273,0xE5B8, 0x9275,0xE5BA, 0x9276,0xE5BB, 
 0x9279,0xE5BE, 0x927A,0xE5BF, 0x927B,0xE5C0, 0x927D,0xE5C2, 
 0x92A5,0xE5C8, 0x92A6,0xE5C9, 0x92B4,0xE5D7, 0x92B5,0xE5D8, 
 0x92B6,0xE5D9, 0x92B8,0xE5DB, 0x92B9,0xE5DC, 0x92BC,0xE5DF, 
 0x92BE,0xE5E1, 0x92BF,0xE5E2, 0x92C0,0xE5E3, 0x92C2,0xE5E5, 
 0x92C3,0xE5E6, 0x92C6,0xE5E9, 0x92CB,0xE5EE, 0x92CC,0xE5EF, 
 0x92CD,0xE5F0, 0x92CE,0xE5F1, 0x92D0,0xE5F3, 0x92D8,0xE5FB, 
 0x92D9,0xE5FC, 0x92DD,0xE600, 0x92DF,0xE602, 0x92E1,0xE604, 
 0x92EC,0xE60F, 0x92ED,0xE610, 0x92EE,0xE611, 0x92EF,0xE612, 
 0x92F6,0xE619, 0x92F7,0xE61A, 0x92F8,0xE61B, 0x92F9,0xE61C, 
 0x92FE,0xE621, 0x9341,0xE623, 0x9342,0xE624, 0x9345,0xE627, 
 0x9349,0xE62B, 0x9350,0xE632, 0x9351,0xE633, 0x9352,0xE634, 
 0x9355,0xE637, 0x9356,0xE638, 0x9358,0xE63A, 0x935A,0xE63C, 
 0x935D,0xE63F, 0x935E,0xE640, 0x935F,0xE641, 0x9360,0xE642, 
 0x9363,0xE645, 0x9364,0xE646, 0x9366,0xE648, 0x9369,0xE64B, 
 0x936C,0xE64E, 0x936D,0xE64F, 0x9370,0xE652, 0x9371,0xE653, 
 0x9372,0xE654, 0x9373,0xE655, 0x9375,0xE657, 0x9376,0xE658, 
 0x9377,0xE659, 0x937B,0xE65D, 0x937C,0xE65E, 0x937D,0xE65F, 
 0x937E,0xE660, 0x93A2,0xE662, 0x93A3,0xE663, 0x93A5,0xE665, 
 0x93A6,0xE666, 0x93A7,0xE667, 0x93A8,0xE668, 0x93AA,0xE66A, 
 0x93AE,0xE66E, 0x93AF,0xE66F, 0x93B1,0xE671, 0x93B6,0xE676, 
 0x93B7,0xE677, 0x93B8,0xE678, 0x93B9,0xE679, 0x93BB,0xE67B, 
 0x93BC,0xE67C, 0x93BD,0xE67D, 0x93BF,0xE67F, 0x93C0,0xE680, 
 0x93C3,0xE683, 0x93C4,0xE684, 0x93C5,0xE685, 0x93C6,0xE686, 
 0x93C7,0xE687, 0x93C8,0xE688, 0x93CA,0xE68A, 0x93CB,0xE68B, 
 0x93CC,0xE68C, 0x93CE,0xE68E, 0x93CF,0xE68F, 0x93D0,0xE690, 
 0x93D2,0xE692, 0x93D6,0xE696, 0x93D7,0xE697, 0x93D9,0xE699, 
 0x93DA,0xE69A, 0x93DC,0xE69C, 0x93DE,0xE69E, 0x93DF,0xE69F, 
 0x93E1,0xE6A1, 0x93E2,0xE6A2, 0x93E6,0xE6A6, 0x93EC,0xE6AC, 
 0x93ED,0xE6AD, 0x93F2,0xE6B2, 0x93F9,0xE6B9, 0x93FA,0xE6BA, 
 0x93FD,0xE6BD, 0x93FE,0xE6BE, 0x9441,0xE6C0, 0x9442,0xE6C1, 
 0x9446,0xE6C5, 0x9448,0xE6C7, 0x944B,0xE6CA, 0x9452,0xE6D1, 
 0x9453,0xE6D2, 0x9458,0xE6D7, 0x9459,0xE6D8, 0x945B,0xE6DA, 
 0x945C,0xE6DB, 0x945E,0xE6DD, 0x945F,0xE6DE, 0x9460,0xE6DF, 
 0x9461,0xE6E0, 0x9462,0xE6E1, 0x9465,0xE6E4, 0x9466,0xE6E5, 
 0x9467,0xE6E6, 0x946F,0xE6EE, 0x9473,0xE6F2, 0x9474,0xE6F3, 
 0x9478,0xE6F7, 0x947B,0xE6FA, 0x947C,0xE6FB, 0x947D,0xE6FC, 
 0x94A2,0xE6FF, 0x94A4,0xE701, 0x94A5,0xE702, 0x94A9,0xE706, 
 0x94AA,0xE707, 0x94AC,0xE709, 0x94AD,0xE70A, 0x94AF,0xE70C, 
 0x94B3,0xE710, 0x94B4,0xE711, 0x94B6,0xE713, 0x94BA,0xE717, 
 0x94BB,0xE718, 0x94BD,0xE71A, 0x94BE,0xE71B, 0x94C0,0xE71D, 
 0x94C7,0xE724, 0x94C8,0xE725, 0x94CE,0xE72B, 0x94D2,0xE72F, 
 0x94D6,0xE733, 0x94D7,0xE734, 0x94D8,0xE735, 0x94D9,0xE736, 
 0x94DA,0xE737, 0x94DF,0xE73C, 0x94E0,0xE73D, 0x94E3,0xE740, 
 0x94E4,0xE741, 0x94E5,0xE742, 0x94E7,0xE744, 0x94EA,0xE747, 
 0x94F0,0xE74D, 0x94F1,0xE74E, 0x94F2,0xE74F, 0x94F4,0xE751, 
 0x94F5,0xE752, 0x94FE,0xE75B, 0x9540,0xE75C, 0x9541,0xE75D, 
 0x9543,0xE75F, 0x9545,0xE761, 0x9546,0xE762, 0x9548,0xE764, 
 0x9549,0xE765, 0x954B,0xE767, 0x954C,0xE768, 0x954D,0xE769, 
 0x9550,0xE76C, 0x9551,0xE76D, 0x9552,0xE76E, 0x9554,0xE770, 
 0x9559,0xE775, 0x955B,0xE777, 0x955C,0xE778, 0x955E,0xE77A, 
 0x9560,0xE77C, 0x9561,0xE77D, 0x9568,0xE784, 0x956A,0xE786, 
 0x956D,0xE789, 0x956F,0xE78B, 0x9571,0xE78D, 0x9574,0xE790, 
 0x9576,0xE792, 0x9578,0xE794, 0x957A,0xE796, 0x957B,0xE797, 
 0x957D,0xE799, 0x95A8,0xE7A2, 0x95AA,0xE7A4, 0x95AB,0xE7A5, 
 0x95AC,0xE7A6, 0x95AD,0xE7A7, 0x95AE,0xE7A8, 0x95AF,0xE7A9, 
 0x95B7,0xE7B1, 0x95BA,0xE7B4, 0x95BE,0xE7B8, 0x95C2,0xE7BC, 
 0x95CA,0xE7C4, 0x95D0,0xE7CA, 0x95D4,0xE7CE, 0x95D7,0xE7D1, 
 0x95DE,0xE7D8, 0x95E0,0xE7DA, 0x95E2,0xE7DC, 0x95E3,0xE7DD, 
 0x95EA,0xE7E4, 0x95ED,0xE7E7, 0x95EE,0xE7E8, 0x95EF,0xE7E9, 
 0x95F1,0xE7EB, 0x95F3,0xE7ED, 0x95F4,0xE7EE, 0x95F5,0xE7EF, 
 0x95F7,0xE7F1, 0x95F8,0xE7F2, 0x95F9,0xE7F3, 0x95FE,0xE7F8, 
 0x9642,0xE7FB, 0x9643,0xE7FC, 0x9646,0xE7FF, 0x9647,0xE800, 
 0x9648,0xE801, 0x9649,0xE802, 0x964F,0xE808, 0x9653,0xE80C, 
 0x9655,0xE80E, 0x9656,0xE80F, 0x9658,0xE811, 0x965A,0xE813, 
 0x965D,0xE816, 0x965E,0xE817, 0x965F,0xE818, 0x9661,0xE81A, 
 0x9668,0xE821, 0x966E,0xE827, 0x966F,0xE828, 0x9674,0xE82D, 
 0x9676,0xE82F, 0x967C,0xE835, 0x967E,0xE837, 0x96A1,0xE838, 
 0x96A3,0xE83A, 0x96A4,0xE83B, 0x96AA,0xE841, 0x96AB,0xE842, 
 0x96B4,0xE84B, 0x96B6,0xE84D, 0x96B7,0xE84E, 0x96BA,0xE851, 
 0x96BE,0xE855, 0x96BF,0xE856, 0x96C0,0xE857, 0x96C1,0xE858, 
 0x96C4,0xE85B, 0x96C5,0xE85C, 0x96C6,0xE85D, 0x96C9,0xE860, 
 0x96CA,0xE861, 0x96CB,0xE862, 0x96CE,0xE865, 0x96CF,0xE866, 
 0x96D0,0xE867, 0x96D2,0xE869, 0x96D3,0xE86A, 0x96D5,0xE86C, 
 0x96DA,0xE871, 0x96E1,0xE878, 0x96E6,0xE87D, 0x96E7,0xE87E, 
 0x96E8,0xE87F, 0x96F0,0xE887, 0x96F8,0xE88F, 0x96FA,0xE891, 
 0x96FB,0xE892, 0x96FD,0xE894, 0x96FE,0xE895, 0x9744,0xE89A, 
 0x9747,0xE89D, 0x974A,0xE8A0, 0x974B,0xE8A1, 0x974D,0xE8A3, 
 0x974E,0xE8A4, 0x974F,0xE8A5, 0x9750,0xE8A6, 0x9751,0xE8A7, 
 0x9753,0xE8A9, 0x9754,0xE8AA, 0x9756,0xE8AC, 0x9757,0xE8AD, 
 0x9758,0xE8AE, 0x9759,0xE8AF, 0x975A,0xE8B0, 0x975F,0xE8B5, 
 0x9760,0xE8B6, 0x9762,0xE8B8, 0x9767,0xE8BD, 0x9768,0xE8BE, 
 0x9769,0xE8BF, 0x976A,0xE8C0, 0x976B,0xE8C1, 0x976C,0xE8C2, 
 0x976D,0xE8C3, 0x976F,0xE8C5, 0x9771,0xE8C7, 0x9775,0xE8CB, 
 0x9777,0xE8CD, 0x9778,0xE8CE, 0x977A,0xE8D0, 0x977B,0xE8D1, 
 0x977D,0xE8D3, 0x97A1,0xE8D5, 0x97A2,0xE8D6, 0x97A4,0xE8D8, 
 0x97A5,0xE8D9, 0x97A6,0xE8DA, 0x97A9,0xE8DD, 0x97AB,0xE8DF, 
 0x97AC,0xE8E0, 0x97AD,0xE8E1, 0x97B1,0xE8E5, 0x97B2,0xE8E6, 
 0x97B4,0xE8E8, 0x97B5,0xE8E9, 0x97B6,0xE8EA, 0x97B9,0xE8ED, 
 0x97BD,0xE8F1, 0x97BE,0xE8F2, 0x97C1,0xE8F5, 0x97C7,0xE8FB, 
 0x97CA,0xE8FE, 0x97CC,0xE900, 0x97CF,0xE903, 0x97D3,0xE907, 
 0x97D4,0xE908, 0x97D8,0xE90C, 0x97E3,0xE917, 0x97E4,0xE918, 
 0x97E8,0xE91C, 0x97EA,0xE91E, 0x97EB,0xE91F, 0x97EC,0xE920, 
 0x97ED,0xE921, 0x97EE,0xE922, 0x97F1,0xE925, 0x97F2,0xE926, 
 0x97F3,0xE927, 0x97F4,0xE928, 0x97F5,0xE929, 0x97F6,0xE92A, 
 0x97F7,0xE92B, 0x97F8,0xE92C, 0x97FA,0xE92E, 0x97FB,0xE92F, 
 0x9840,0xE933, 0x9841,0xE934, 0x9842,0xE935, 0x9843,0xE936, 
 0x9845,0xE938, 0x9847,0xE93A, 0x9849,0xE93C, 0x984A,0xE93D, 
 0x984B,0xE93E, 0x984E,0xE941, 0x9851,0xE944, 0x9852,0xE945, 
 0x9855,0xE948, 0x985A,0xE94D, 0x985D,0xE950, 0x985F,0xE952, 
 0x9860,0xE953, 0x9861,0xE954, 0x9862,0xE955, 0x9864,0xE957, 
 0x9865,0xE958, 0x9867,0xE95A, 0x9869,0xE95C, 0x986A,0xE95D, 
 0x986B,0xE95E, 0x986D,0xE960, 0x986E,0xE961, 0x9871,0xE964, 
 0x9874,0xE967, 0x9875,0xE968, 0x987B,0xE96E, 0x987C,0xE96F, 
 0x98A2,0xE973, 0x98A3,0xE974, 0x98A4,0xE975, 0x98A6,0xE977, 
 0x98A7,0xE978, 0x98A9,0xE97A, 0x98AA,0xE97B, 0x98AC,0xE97D, 
 0x98B0,0xE981, 0x98B1,0xE982, 0x98B6,0xE987, 0x98B9,0xE98A, 
 0x98BD,0xE98E, 0x98C0,0xE991, 0x98DF,0xE9B0, 0x98FA,0xE9CB, 
 0x995F,0xE9EF, 0x99D5,0xEA43, 0x9A7C,0xEAA9, 0x9AB4,0xEABF, 
 0x9AB5,0xEAC0, 0x9AB6,0xEAC1, 0x9ABA,0xEAC5, 0x9ABE,0xEAC9, 
 0x9ABF,0xEACA, 0x9AC0,0xEACB, 0x9AC1,0xEACC, 0x9AC4,0xEACF, 
 0x9AC5,0xEAD0, 0x9AC6,0xEAD1, 0x9AC8,0xEAD3, 0x9AC9,0xEAD4, 
 0x9ACB,0xEAD6, 0x9ACC,0xEAD7, 0x9ACD,0xEAD8, 0x9ACE,0xEAD9, 
 0x9ACF,0xEADA, 0x9AD1,0xEADC, 0x9AD3,0xEADE, 0x9AD4,0xEADF, 
 0x9AD5,0xEAE0, 0x9AD6,0xEAE1, 0x9AD7,0xEAE2, 0x9AD8,0xEAE3, 
 0x9ADC,0xEAE7, 0x9ADD,0xEAE8, 0x9ADE,0xEAE9, 0x9ADF,0xEAEA, 
 0x9AE0,0xEAEB, 0x9AE1,0xEAEC, 0x9AE3,0xEAEE, 0x9AE5,0xEAF0, 
 0x9AE6,0xEAF1, 0x9AE7,0xEAF2, 0x9AE9,0xEAF4, 0x9AEA,0xEAF5, 
 0x9AEB,0xEAF6, 0x9AED,0xEAF8, 0x9AEE,0xEAF9, 0x9AEF,0xEAFA, 
 0x9AF0,0xEAFB, 0x9AF3,0xEAFE, 0x9AF4,0xEAFF, 0x9AF5,0xEB00, 
 0x9AF7,0xEB02, 0x9AF8,0xEB03, 0x9AF9,0xEB04, 0x9AFA,0xEB05, 
 0x9AFD,0xEB08, 0x9AFE,0xEB09, 0x9B40,0xEB0A, 0x9B41,0xEB0B, 
 0x9B42,0xEB0C, 0x9B43,0xEB0D, 0x9B44,0xEB0E, 0x9B45,0xEB0F, 
 0x9B47,0xEB11, 0x9B48,0xEB12, 0x9B4B,0xEB15, 0x9B4E,0xEB18, 
 0x9B4F,0xEB19, 0x9B50,0xEB1A, 0x9B51,0xEB1B, 0x9B52,0xEB1C, 
 0x9B53,0xEB1D, 0x9B55,0xEB1F, 0x9B56,0xEB20, 0x9B57,0xEB21, 
 0x9B59,0xEB23, 0x9B5B,0xEB25, 0x9B5D,0xEB27, 0x9B60,0xEB2A, 
 0x9B62,0xEB2C, 0x9B63,0xEB2D, 0x9B64,0xEB2E, 0x9B65,0xEB2F, 
 0x9B66,0xEB30, 0x9B67,0xEB31, 0x9B68,0xEB32, 0x9B69,0xEB33, 
 0x9B6A,0xEB34, 0x9B6B,0xEB35, 0x9B6C,0xEB36, 0x9B6D,0xEB37, 
 0x9B6E,0xEB38, 0x9B6F,0xEB39, 0x9B73,0xEB3D, 0x9B74,0xEB3E, 
 0x9B75,0xEB3F, 0x9B77,0xEB41, 0x9B79,0xEB43, 0x9B7A,0xEB44, 
 0x9B7C,0xEB46, 0x9BA2,0xEB4A, 0x9BA3,0xEB4B, 0x9BA4,0xEB4C, 
 0x9BA5,0xEB4D, 0x9BA6,0xEB4E, 0x9BA7,0xEB4F, 0x9BA8,0xEB50, 
 0x9BAB,0xEB53, 0x9BAC,0xEB54, 0x9BAD,0xEB55, 0x9BAE,0xEB56, 
 0x9BAF,0xEB57, 0x9BB0,0xEB58, 0x9BB1,0xEB59, 0x9BB2,0xEB5A, 
 0x9BB3,0xEB5B, 0x9BB5,0xEB5D, 0x9BB7,0xEB5F, 0x9BB9,0xEB61, 
 0x9BBA,0xEB62, 0x9BBB,0xEB63, 0x9BBD,0xEB65, 0x9BBF,0xEB67, 
 0x9BC0,0xEB68, 0x9BC1,0xEB69, 0x9BC3,0xEB6B, 0x9BC5,0xEB6D, 
 0x9BC7,0xEB6F, 0x9BC8,0xEB70, 0x9BC9,0xEB71, 0x9BCB,0xEB73, 
 0x9BCC,0xEB74, 0x9BCE,0xEB76, 0x9BCF,0xEB77, 0x9BD0,0xEB78, 
 0x9BD2,0xEB7A, 0x9BD6,0xEB7E, 0x9BD7,0xEB7F, 0x9BD8,0xEB80, 
 0x9BD9,0xEB81, 0x9BDB,0xEB83, 0x9BDC,0xEB84, 0x9BDD,0xEB85, 
 0x9BE0,0xEB88, 0x9BE1,0xEB89, 0x9BE2,0xEB8A, 0x9BE4,0xEB8C, 
 0x9BE5,0xEB8D, 0x9BE6,0xEB8E, 0x9BE7,0xEB8F, 0x9BE8,0xEB90, 
 0x9BEB,0xEB93, 0x9BED,0xEB95, 0x9BEF,0xEB97, 0x9BF0,0xEB98, 
 0x9BF1,0xEB99, 0x9BF2,0xEB9A, 0x9BF3,0xEB9B, 0x9BF7,0xEB9F, 
 0x9BF8,0xEBA0, 0x9BFA,0xEBA2, 0x9BFB,0xEBA3, 0x9BFD,0xEBA5, 
 0x9BFE,0xEBA6, 0x9C41,0xEBA8, 0x9C43,0xEBAA, 0x9C44,0xEBAB, 
 0x9C46,0xEBAD, 0x9C47,0xEBAE, 0x9C48,0xEBAF, 0x9C49,0xEBB0, 
 0x9C4B,0xEBB2, 0x9C4C,0xEBB3, 0x9C4D,0xEBB4, 0x9C4F,0xEBB6, 
 0x9C52,0xEBB9, 0x9C55,0xEBBC, 0x9C56,0xEBBD, 0x9C58,0xEBBF, 
 0x9C5B,0xEBC2, 0x9C5E,0xEBC5, 0x9C5F,0xEBC6, 0x9C60,0xEBC7, 
 0x9C61,0xEBC8, 0x9C63,0xEBCA, 0x9C65,0xEBCC, 0x9C66,0xEBCD, 
 0x9C67,0xEBCE, 0x9C69,0xEBD0, 0x9C6C,0xEBD3, 0x9C6E,0xEBD5, 
 0x9C70,0xEBD7, 0x9C71,0xEBD8, 0x9C73,0xEBDA, 0x9C74,0xEBDB, 
 0x9C76,0xEBDD, 0x9C78,0xEBDF, 0x9C7A,0xEBE1, 0x9C7D,0xEBE4, 
 0x9CA2,0xEBE7, 0x9CA3,0xEBE8, 0x9CA4,0xEBE9, 0x9CA6,0xEBEB, 
 0x9CA7,0xEBEC, 0x9CA9,0xEBEE, 0x9CAA,0xEBEF, 0x9CAC,0xEBF1, 
 0x9CAD,0xEBF2, 0x9CB0,0xEBF5, 0x9CB1,0xEBF6, 0x9CB4,0xEBF9, 
 0x9CB5,0xEBFA, 0x9CB6,0xEBFB, 0x9CB8,0xEBFD, 0x9CB9,0xEBFE, 
 0x9CC0,0xEC05, 0x9CC1,0xEC06, 0x9CC3,0xEC08, 0x9CC4,0xEC09, 
 0x9CC7,0xEC0C, 0x9CC9,0xEC0E, 0x9CCA,0xEC0F, 0x9CCB,0xEC10, 
 0x9CCE,0xEC13, 0x9CCF,0xEC14, 0x9CD2,0xEC17, 0x9CD3,0xEC18, 
 0x9CD4,0xEC19, 0x9CD5,0xEC1A, 0x9CD6,0xEC1B, 0x9CD7,0xEC1C, 
 0x9CD8,0xEC1D, 0x9CDB,0xEC20, 0x9CDD,0xEC22, 0x9CDF,0xEC24, 
 0x9CE1,0xEC26, 0x9CE5,0xEC2A, 0x9CE6,0xEC2B, 0x9CE7,0xEC2C, 
 0x9CE8,0xEC2D, 0x9CE9,0xEC2E, 0x9CEA,0xEC2F, 0x9CEC,0xEC31, 
 0x9CED,0xEC32, 0x9CF0,0xEC35, 0x9CF2,0xEC37, 0x9CF6,0xEC3B, 
 0x9CF7,0xEC3C, 0x9CFA,0xEC3F, 0x9CFB,0xEC40, 0x9CFC,0xEC41, 
 0x9CFD,0xEC42, 0x9CFE,0xEC43, 0x9D40,0xEC44, 0x9D41,0xEC45, 
 0x9D42,0xEC46, 0x9D43,0xEC47, 0x9D44,0xEC48, 0x9D45,0xEC49, 
 0x9D47,0xEC4B, 0x9D48,0xEC4C, 0x9D4B,0xEC4F, 0x9D4E,0xEC52, 
 0x9D50,0xEC54, 0x9D52,0xEC56, 0x9D53,0xEC57, 0x9D54,0xEC58, 
 0x9D56,0xEC5A, 0x9D58,0xEC5C, 0x9D59,0xEC5D, 0x9D5B,0xEC5F, 
 0x9D5C,0xEC60, 0x9D5E,0xEC62, 0x9D5F,0xEC63, 0x9D63,0xEC67, 
 0x9D64,0xEC68, 0x9D65,0xEC69, 0x9D66,0xEC6A, 0x9D67,0xEC6B, 
 0x9D68,0xEC6C, 0x9D69,0xEC6D, 0x9D6A,0xEC6E, 0x9D6B,0xEC6F, 
 0x9D6C,0xEC70, 0x9D6D,0xEC71, 0x9D6E,0xEC72, 0x9D6F,0xEC73, 
 0x9D71,0xEC75, 0x9D72,0xEC76, 0x9D75,0xEC79, 0x9D77,0xEC7B, 
 0x9D7A,0xEC7E, 0x9D7C,0xEC80, 0x9DA2,0xEC84, 0x9DA4,0xEC86, 
 0x9DAB,0xEC8D, 0x9DAC,0xEC8E, 0x9DAF,0xEC91, 0x9DB0,0xEC92, 
 0x9DB1,0xEC93, 0x9DB2,0xEC94, 0x9DB3,0xEC95, 0x9DB4,0xEC96, 
 0x9DB6,0xEC98, 0x9DB7,0xEC99, 0x9DB8,0xEC9A, 0x9DB9,0xEC9B, 
 0x9DBB,0xEC9D, 0x9DBC,0xEC9E, 0x9DBE,0xECA0, 0x9DC1,0xECA3, 
 0x9DC2,0xECA4, 0x9DC5,0xECA7, 0x9DC6,0xECA8, 0x9DC9,0xECAB, 
 0x9DCB,0xECAD, 0x9DCD,0xECAF, 0x9DD2,0xECB4, 0x9DD4,0xECB6, 
 0x9DD7,0xECB9, 0x9DD8,0xECBA, 0x9DD9,0xECBB, 0x9DED,0xECCF, 
 0x9DF2,0xECD4, 0x9DF9,0xECDB, 0x9DFA,0xECDC, 0x9DFC,0xECDE, 
 0x9DFD,0xECDF, 0x9DFE,0xECE0, 0x9E40,0xECE1, 0x9E44,0xECE5, 
 0x9E4F,0xECF0, 0x9E51,0xECF2, 0x9E54,0xECF5, 0x9E5B,0xECFC, 
 0x9E63,0xED04, 0x9E66,0xED07, 0x9E69,0xED0A, 0x9E6B,0xED0C, 
 0x9E6C,0xED0D, 0x9E6D,0xED0E, 0x9E6E,0xED0F, 0x9E6F,0xED10, 
 0x9E70,0xED11, 0x9E72,0xED13, 0x9E74,0xED15, 0x9E75,0xED16, 
 0x9E76,0xED17, 0x9E77,0xED18, 0x9E79,0xED1A, 0x9E7B,0xED1C, 
 0x9E7C,0xED1D, 0x9E7D,0xED1E, 0x9EA3,0xED22, 0x9EA5,0xED24, 
 0x9EA6,0xED25, 0x9EA7,0xED26, 0x9EA8,0xED27, 0x9EAA,0xED29, 
 0x9EAB,0xED2A, 0x9EAD,0xED2C, 0x9EAE,0xED2D, 0x9EBC,0xED3B, 
 0x9EBE,0xED3D, 0x9EC2,0xED41, 0x9EC3,0xED42, 0x9EC6,0xED45, 
 0x9EC8,0xED47, 0x9ECB,0xED4A, 0x9ECC,0xED4B, 0x9ECE,0xED4D, 
 0x9ECF,0xED4E, 0x9ED0,0xED4F, 0x9ED2,0xED51, 0x9ED3,0xED52, 
 0x9ED4,0xED53, 0x9ED5,0xED54, 0x9ED8,0xED57, 0x9ED9,0xED58, 
 0x9EE0,0xED5F, 0x9EE3,0xED62, 0x9EEC,0xED6B, 0x9EF2,0xED71, 
 0x9EF3,0xED72, 0x9EF6,0xED75, 0x9EF8,0xED77, 0x9EF9,0xED78, 
 0x9EFB,0xED7A, 0x9F43,0xED81, 0x9F46,0xED84, 0x9F47,0xED85, 
 0x9F48,0xED86, 0x9F4A,0xED88, 0x9F4B,0xED89, 0x9F4C,0xED8A, 
 0x9F4D,0xED8B, 0x9F50,0xED8E, 0x9F53,0xED91, 0x9F68,0xEDA6, 
 0x9FAA,0xEDC6, 0x9FB3,0xEDCF, 0x9FB5,0xEDD1, 0x9FBB,0xEDD7, 
 0x9FBE,0xEDDA, 0x9FBF,0xEDDB, 0x9FC1,0xEDDD, 0x9FC5,0xEDE1, 
 0x9FD1,0xEDED, 0x9FEC,0xEE08, 0x9FF5,0xEE11, 0x9FF9,0xEE15, 
 0xA040,0xEE1B, 0xA045,0xEE20, 0xA047,0xEE22, 0xA04F,0xEE2A, 
 0xA055,0xEE30, 0xA056,0xEE31, 0xA059,0xEE34, 0xA06D,0xEE48, 
 0xA07B,0xEE56, 0xA0A2,0xEE5B, 0xA0A4,0xEE5D, 0xA0A7,0xEE60, 
 0xA0AB,0xEE64, 0xA0B1,0xEE6A, 0xA0BD,0xEE76, 0xA0C3,0xEE7C, 
 0xA0C5,0xEE7E, 0xA0D8,0xEE91, 0xA0E3,0xEE9C, 0xA0E9,0xEEA2, 
 0xA0EA,0xEEA3, 0xA0EB,0xEEA4, 0xA0EC,0xEEA5, 0xA0ED,0xEEA6, 
 0xA0EE,0xEEA7, 0xA0EF,0xEEA8, 0xA0F0,0xEEA9, 0xA0F1,0xEEAA, 
 0xA0F3,0xEEAC, 0xA0F4,0xEEAD, 0xA0F5,0xEEAE, 0xA0F6,0xEEAF, 
 0xA0F7,0xEEB0, 0xA0F8,0xEEB1, 0xA0FB,0xEEB4, 0xA0FE,0xEEB7, 
 0xC87A,0xF7E6, 0xC87C,0xF7E8, 0xC8A4,0xF7EE, 0xFA40,0xE000, 
 0xFA42,0xE002, 0xFA43,0xE003, 0xFA49,0xE009, 0xFA4A,0xE00A, 
 0xFA4C,0xE00C, 0xFA4E,0xE00E, 0xFA52,0xE012, 0xFA53,0xE013, 
 0xFA54,0xE014, 0xFA55,0xE015, 0xFA56,0xE016, 0xFA58,0xE018, 
 0xFA5A,0xE01A, 0xFA5B,0xE01B, 0xFA5C,0xE01C, 0xFA5D,0xE01D, 
 0xFA5E,0xE01E, 0xFA60,0xE020, 0xFA62,0xE022, 0xFA63,0xE023, 
 0xFA65,0xE025, 0xFA6D,0xE02D, 0xFA6E,0xE02E, 0xFA70,0xE030, 
 0xFA72,0xE032, 0xFA73,0xE033, 0xFA74,0xE034, 0xFA75,0xE035, 
 0xFA76,0xE036, 0xFA77,0xE037, 0xFA78,0xE038, 0xFA7B,0xE03B, 
 0xFA7C,0xE03C, 0xFAA7,0xE045, 0xFAAE,0xE04C, 0xFABC,0xE05A, 
 0xFABE,0xE05C, 0xFAC1,0xE05F, 0xFAC2,0xE060, 0xFAC3,0xE061, 
 0xFAC6,0xE064, 0xFAC8,0xE066, 0xFACE,0xE06C, 0xFAD3,0xE071, 
 0xFAD6,0xE074, 0xFAD7,0xE075, 0xFADA,0xE078, 0xFADF,0xE07D, 
 0xFAE9,0xE087, 0xFAEB,0xE089, 0xFAEC,0xE08A, 0xFAEE,0xE08C, 
 0xFAF5,0xE093, 0xFAF6,0xE094, 0xFAFB,0xE099, 0xFAFC,0xE09A, 
 0xFAFE,0xE09C, 0xFB40,0xE09D, 0xFB41,0xE09E, 0xFB49,0xE0A6, 
 0xFB4A,0xE0A7, 0xFB4C,0xE0A9, 0xFB4E,0xE0AB, 0xFB51,0xE0AE, 
 0xFB5D,0xE0BA, 0xFB5F,0xE0BC, 0xFB61,0xE0BE, 0xFB66,0xE0C3, 
 0xFB68,0xE0C5, 0xFB6A,0xE0C7, 0xFB6B,0xE0C8, 0xFB6D,0xE0CA, 
 0xFB73,0xE0D0, 0xFB77,0xE0D4, 0xFB78,0xE0D5, 0xFBA1,0xE0DC, 
 0xFBA4,0xE0DF, 0xFBA7,0xE0E2, 0xFBA8,0xE0E3, 0xFBA9,0xE0E4, 
 0xFBAA,0xE0E5, 0xFBAC,0xE0E7, 0xFBAD,0xE0E8, 0xFBAE,0xE0E9, 
 0xFBB0,0xE0EB, 0xFBB1,0xE0EC, 0xFBB3,0xE0EE, 0xFBB7,0xE0F2, 
 0xFBBD,0xE0F8, 0xFBBE,0xE0F9, 0xFBC0,0xE0FB, 0xFBC2,0xE0FD, 
 0xFBC8,0xE103, 0xFBCB,0xE106, 0xFBCE,0xE109, 0xFBCF,0xE10A, 
 0xFBD0,0xE10B, 0xFBD5,0xE110, 0xFBD9,0xE114, 0xFBDA,0xE115, 
 0xFBE1,0xE11C, 0xFBE2,0xE11D, 0xFBE6,0xE121, 0xFBEB,0xE126, 
 0xFBEC,0xE127, 0xFBED,0xE128, 0xFBF5,0xE130, 0xFBF6,0xE131, 
 0xFBFB,0xE136, 0xFBFE,0xE139, 0xFC47,0xE141, 0xFC48,0xE142, 
 0xFC4B,0xE145, 0xFC4D,0xE147, 0xFC4E,0xE148, 0xFC50,0xE14A, 
 0xFC53,0xE14D, 0xFC56,0xE150, 0xFC5A,0xE154, 0xFC5B,0xE155, 
 0xFC5C,0xE156, 0xFC5D,0xE157, 0xFC5F,0xE159, 0xFC60,0xE15A, 
 0xFC63,0xE15D, 0xFC68,0xE162, 0xFC6E,0xE168, 0xFC6F,0xE169, 
 0xFC70,0xE16A, 0xFC77,0xE171, 0xFC78,0xE172, 0xFC7B,0xE175, 
 0xFC7E,0xE178, 0xFCA1,0xE179, 0xFCA3,0xE17B, 0xFCA4,0xE17C, 
 0xFCA7,0xE17F, 0xFCA8,0xE180, 0xFCAD,0xE185, 0xFCAF,0xE187, 
 0xFCB1,0xE189, 0xFCB3,0xE18B, 0xFCB7,0xE18F, 0xFCB8,0xE190, 
 0xFCBB,0xE193, 0xFCBD,0xE195, 0xFCBE,0xE196, 0xFCC7,0xE19F, 
 0xFCC8,0xE1A0, 0xFCCC,0xE1A4, 0xFCCE,0xE1A6, 0xFCD2,0xE1AA, 
 0xFCD6,0xE1AE, 0xFCD8,0xE1B0, 0xFCD9,0xE1B1, 0xFCDB,0xE1B3, 
 0xFCDC,0xE1B4, 0xFCDE,0xE1B6, 0xFCE0,0xE1B8, 0xFCE3,0xE1BB, 
 0xFCE4,0xE1BC, 0xFCE5,0xE1BD, 0xFCE6,0xE1BE, 0xFCE7,0xE1BF, 
 0xFCE9,0xE1C1, 0xFCEC,0xE1C4, 0xFCED,0xE1C5, 0xFCF0,0xE1C8, 
 0xFCF4,0xE1CC, 0xFCF5,0xE1CD, 0xFCFC,0xE1D4, 0xFCFD,0xE1D5, 
 0xFD40,0xE1D7, 0xFD43,0xE1DA, 0xFD46,0xE1DD, 0xFD4B,0xE1E2, 
 0xFD4F,0xE1E6, 0xFD54,0xE1EB, 0xFD58,0xE1EF, 0xFD59,0xE1F0, 
 0xFD5B,0xE1F2, 0xFD60,0xE1F7, 0xFD63,0xE1FA, 0xFD67,0xE1FE, 
 0xFD69,0xE200, 0xFD6A,0xE201, 0xFD6B,0xE202, 0xFD6E,0xE205, 
 0xFD70,0xE207, 0xFD73,0xE20A, 0xFD74,0xE20B, 0xFD75,0xE20C, 
 0xFD79,0xE210, 0xFD7B,0xE212, 0xFD7C,0xE213, 0xFD7D,0xE214, 
 0xFD7E,0xE215, 0xFDA1,0xE216, 0xFDA4,0xE219, 0xFDA6,0xE21B, 
 0xFDA7,0xE21C, 0xFDAA,0xE21F, 0xFDAB,0xE220, 0xFDAC,0xE221, 
 0xFDB1,0xE226, 0xFDB2,0xE227, 0xFDB3,0xE228, 0xFDB5,0xE22A, 
 0xFDBA,0xE22F, 0xFDBC,0xE231, 0xFDBE,0xE233, 0xFDC2,0xE237, 
 0xFDC6,0xE23B, 0xFDC8,0xE23D, 0xFDC9,0xE23E, 0xFDD0,0xE245, 
 0xFDD3,0xE248, 0xFDD5,0xE24A, 0xFDD6,0xE24B, 0xFDD7,0xE24C, 
 0xFDD8,0xE24D, 0xFDD9,0xE24E, 0xFDDA,0xE24F, 0xFDDC,0xE251, 
 0xFDDD,0xE252, 0xFDDE,0xE253, 0xFDDF,0xE254, 0xFDEC,0xE261, 
 0xFDF3,0xE268, 0xFDF6,0xE26B, 0xFDF8,0xE26D, 0xFDF9,0xE26E, 
 0xFDFA,0xE26F, 0xFDFC,0xE271, 0xFE46,0xE27A, 0xFE49,0xE27D, 
 0xFE4E,0xE282, 0xFE54,0xE288, 0xFE55,0xE289, 0xFE57,0xE28B, 
 0xFE5C,0xE290, 0xFE5D,0xE291, 0xFE60,0xE294, 0xFE61,0xE295, 
 0xFE62,0xE296, 0xFE65,0xE299, 0xFE66,0xE29A, 0xFE67,0xE29B, 
 0xFE6B,0xE29F, 0xFE6D,0xE2A1, 0xFE70,0xE2A4, 0xFE72,0xE2A6, 
 0xFE7E,0xE2B2, 0xFEA1,0xE2B3, 0xFEA2,0xE2B4, 0xFEA3,0xE2B5, 
 0xFEA5,0xE2B7, 0xFEA6,0xE2B8, 0xFEA8,0xE2BA, 0xFEAC,0xE2BE, 
 0xFEAD,0xE2BF, 0xFEAF,0xE2C1, 0xFEB5,0xE2C7, 0xFEB7,0xE2C9, 
 0xFEC2,0xE2D4, 0xFEC6,0xE2D8, 0xFEC7,0xE2D9, 0xFECC,0xE2DE, 
 0xFECE,0xE2E0, 0xFECF,0xE2E1, 0xFED0,0xE2E2, 0xFED5,0xE2E7, 
 0xFED7,0xE2E9, 0xFED9,0xE2EB, 0xFEDA,0xE2EC, 0xFEDB,0xE2ED, 
 0xFEDE,0xE2F0, 0xFEDF,0xE2F1, 0xFEE6,0xE2F8, 0xFEEA,0xE2FC, 
 0xFEED,0xE2FF, 0xFEEE,0xE300, 0xFEEF,0xE301, 0xFEF4,0xE306, 
 0xFEF6,0xE308, 0xFEFA,0xE30C, 0xFEFD,0xE30F, 0x0000,0x0000
};

skf_ucode big5uao_81_uni_byte[BIG5_OFFSET] = {  /* 8140 - a0fe */
  0x4E17,0x4E22,0x4E2C,0x4E55,0x4E62,0x4E8A,0x4EB0,0x4EEB,
  0x4EED,0x4EFC,0x4F1C,0x4F8A,0x4FFF,0x5042,0x5050,0x5078,
  0x50D8,0x50DE,0x50F4,0x5116,0x514A,0x5151,0x5164,0x516A,
  0x5185,0x5190,0x519D,0x51A6,0x51A8,0x51A9,0x51C7,0x51D6,
  0x51DB,0x51EC,0x51FC,0x520B,0x5214,0x5215,0x5220,0x522B,
  0x5239,0x524F,0x5271,0x5290,0x5292,0x5294,0x529C,0x52AF,
  0x52B5,0x52D0,0x5300,0x5307,0x5324,0x5346,0x535F,0x5393,
  0x53B0,0x53DD,0x5423,0x5450,0x5451,0x548A,0x549D,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x54A3,0x54B4,0x54D0,0x5523,0x553F,0x554C,0x5553,
  0x555D,0x556C,0x559E,0x55A9,0x55EC,0x55F5,0x5623,0x5650,
  0x567C,0x568A,0x5694,0x56A0,0x56AF,0x56D8,0x5700,0x5759,
  0x5765,0x577F,0x5785,0x5789,0x57A1,0x57AC,0x57B4,0x57C0,
  0x57C8,0x57D3,0x57EF,0x5844,0x586C,0x5892,0x589A,0x58B2,
  0x58B8,0x58E5,0x58FB,0x5902,0x590B,0x5910,0x5918,0x591B,
  0x748C,0x748D,0x7499,0x749B,0x74A4,0x74B4,0x74B9,0x74C8,
  0x74CC,0x74D0,0x74D3,0x7542,0x7555,0x756E,0x758D,0x759E,
  0x75DC,0x762C,0x764F,0x7651,0x7673,0x7674,0x76A5,0x76D9,
  0x770E,0x770F,0x7758,0x7772,0x7777,0x7778,0x777A,0x777B,
  0x7798,0x77AF,0x77BE,0x77C3,0x77C5,0x77CB,0x77DD,0x77E6,
  0x77F4,0x781E,0x783D,0x7842,0x7844,0x784B,0x7851,
  0x5516,0x58F7,0x9834,0x845B,0x7114,0x8276,0x8956,0x9D2C,
  0x9D0E,0x8EAF,0x6062,0x6666,0x86CE,0x64B9,0x938C,0x565B,
  0x6F45,0x8ACC,0x7149,0x5DCC,0x8749,0x9A28,0x7BAA,0x8D0B,
  0x9957,0x5C2D,0x7E4B,0x981A,0x5026,0x6372,0x9E78,0x783F,
  0x9EB9,0x9EBA,0x8CCE,0x8B83,0xEF79,0x848B,0x91A4,0x7A63,
  0x64B0,0x5DFD,0x5E96,0x8061,0x6955,0x7AEA,0x7026,0x68BC,
  0x7977,0x6D9C,0x8FE9,0x7962,0x56A2,0x877F,0x5265,0x7984,
  0x6E8C,0x9197,0x7B86,0x982C,0x685D,0x4FAD,0x85AE,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x7BED,0x874B,0x5036,0x690D,0x6B96,0x614E,0x5177,
  0x771F,0x5024,0x7F6E,0x76F4,0x69D9,0x60E3,0x62F6,0x545F,
  0x9784,0x564C,0x50C5,0x5618,0x865E,0x5932,0x595B,0x595D,
  0x5963,0x596C,0x599B,0x59D7,0x59EB,0x5A1A,0x5AAA,0x5AD0,
  0x5AF1,0x5B36,0x5BC9,0x5BF3,0x5C13,0x5C1C,0x5C1E,0x5C53,
  0x5C99,0x5C9C,0x5CBA,0x5CBB,0x5CC1,0x5CF5,0x5CFA,0x5D15,
  0x5D18,0x5D3E,0x5D53,0x5D5C,0x5D6D,0x5D73,0x5D74,0x5D8C,
  0x5D90,0x5DB9,0x5DD0,0x5DD3,0x5E47,0x5E64,0x5ECF,0x5ED0,
  0x5EEA,0x5EF0,0x5F09,0x5F0C,0x5F11,0x5F21,0x5F34,0x5F41,
  0x5F45,0x5F51,0x5F5C,0x5F66,0x5F83,0x5FF0,0x604A,0x6060,
  0x608B,0x60A6,0x60DE,0x6111,0x6120,0x6121,0x613C,0x613D,
  0x6198,0x61B7,0x61F4,0x6213,0x621D,0x621E,0x6237,
  0x5E7A,0x6C10,0x53CE,0x4F2B,0x4F4E,0x5434,0x56F1,0x58EE,
  0x5939,0x5986,0x5C2C,0x51B3,0x51B2,0x707E,0x89C1,0x89D2,
  0x8D1D,0x8F66,0x4E9A,0x6765,0x4ED1,0x4E24,0x534F,0x5C4A,
  0x5188,0x5E95,0x62B5,0x4E1C,0x4E89,0x72B6,0x7C7C,0x7EA0,
  0x5367,0x8F67,0x90B8,0x957F,0x95E8,0x4FA0,0x4FA3,0x5156,
  0x5219,0x52B2,0x5374,0x5942,0x5E05,0x67E2,0x6C79,0x4E3A,
  0x7EA3,0x7EA2,0x7EAA,0x7EAB,0x7EA5,0x7EA6,0x7EA1,0x80DD,
  0x82CE,0x8BA1,0x8BA2,0x8BA3,0x8D1E,0x8D1F,0x519B,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x8F68,0x95E9,0x97E6,0x9875,0x98CE,0x98DE,0x4FE9,
  0x4EEC,0x4F25,0x4E2A,0x4F26,0x4ED3,0x51BB,0x521A,0x5265,
  0x5458,0x5A31,0x5B59,0x5CE1,0x5C9B,0x5C98,0x5E08,0x5E93,
  0x5F84,0x631F,0x65F6,0x664B,0x4E66,0x6CFE,0x6D43,0x4E4C,
  0x72ED,0x72C8,0x4EA9,0x7825,0x79EA,0x7EBA,0x7EB1,0x7EB9,
  0x7EAF,0x7EBD,0x7EB0,0x7EA7,0x7EAD,0x7EB3,0x7EB8,0x7EB7,
  0x80C1,0x8109,0x520D,0x8BB0,0x8BA6,0x8BA8,0x8BA7,0x8BAA,
  0x8BAF,0x8BAD,0x8BAB,0x5C82,0x8D22,0x8D21,0x8F69,0x8F6B,
  0x9489,0x9488,0x948A,0x948B,0x95EA,0x9635,0x9655,0x9649,
  0x9965,0x9A6C,0x9AA8,0x4F2A,0x4F1F,0x4FA6,0x4FA7,0x52A1,
  0x52A8,0x533A,0x53C2,0x54D1,0x95EE,0x8854,0x56FD,0x575A,
  0x57A9,0x6267,0x591F,0x5A04,0x5987,0x4E13,0x5C06,
  0x5C49,0x5CE5,0x5C97,0x5E26,0x5E10,0x5F20,0x5F3A,0x4ECE,
  0x5F95,0x51C4,0x6005,0x626B,0x6302,0x626A,0x62A1,0x6323,
  0x8D25,0x542F,0x659B,0x65A9,0x663C,0x52D6,0x5F03,0x6761,
  0x67AD,0x6740,0x6C22,0x51C9,0x6D45,0x6E0A,0x6CEA,0x6CA6,
  0x51C0,0x7275,0x72F0,0x73B0,0x4EA7,0x6BD5,0x5F02,0x4F17,
  0x7ECA,0x7EDF,0x7ECD,0x7ECB,0x7ECC,0x7EC6,0x7EC5,0x7EC4,
  0x7EC8,0x7EC1,0x7EC2,0x94B5,0x4E60,0x835A,0x830E,0x8392,
  0x5E84,0x82CB,0x5904,0x672F,0x886E,0x89C5,0x89C4,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x8BBF,0x8BB6,0x8BC0,0x8BB7,0x8BB8,0x8BBE,0x8BBC,
  0x8BB9,0x8D29,0x8D23,0x8D2F,0x8D27,0x8D2A,0x8D2B,0x8F6D,
  0x8F6F,0x8FD9,0x8FDE,0x8FF3,0x9497,0x9493,0x948F,0x9492,
  0x95ED,0x9648,0x9646,0x9634,0x9876,0x9877,0x9C7C,0x9E1F,
  0x5364,0x9EA6,0x5907,0x4F27,0x4F1E,0x51EF,0x5240,0x521B,
  0x52B3,0x52CB,0x4E27,0x5355,0x54DF,0x5524,0x4E54,0x56F4,
  0x5C27,0x573A,0x62A5,0x57DA,0x58F6,0x5A32,0x5BFB,0x5C9A,
  0x5E27,0x5E0F,0x5395,0x53A9,0x6076,0x95F7,0x60EC,0x607B,
  0x607C,0x62E3,0x6325,0x6362,0x626C,0x67A3,0x680B,0x6808,
  0x94A6,0x6B8B,0x58F3,0x6C2F,0x6C29,0x6D8C,0x51D1,0x6E6E,
  0x6DA1,0x6C64,0x6D4B,0x6D51,0x6DA3,0x65E0,0x72B9,0x82CF,
  0x753B,0x75C9,0x53D1,0x76D7,0x781A,0x79C6,0x7A97,
  0x7B14,0x7B0B,0x7EDE,0x7ED3,0x7ED2,0x7EDD,0x4E1D,0x7EDC,
  0x7ED9,0x7EDA,0x7ED6,0x7EDB,0x8083,0x80BE,0x80C0,0x534E,
  0x83B1,0x82CC,0x865A,0x89C6,0x8BC4,0x8BCD,0x8BC1,0x8BC2,
  0x8BCF,0x8BC5,0x8BC8,0x8BCB,0x8BC9,0x8BCA,0x8BC3,0x8D2E,
  0x8D34,0x8D30,0x8D3B,0x8D32,0x8D39,0x8D3A,0x8D35,0x4E70,
  0x8D2C,0x8D38,0x8D37,0x8F72,0x8F74,0x8F76,0x8FDB,0x90AE,
  0x4E61,0x949E,0x94AE,0x9499,0x94A0,0x94A7,0x949D,0x94A4,
  0x94A3,0x95F5,0x95F0,0x5F00,0x95F2,0x95F4,0x95F3,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x961F,0x9636,0x9633,0x97E7,0x9879,0x987A,0x987B,
  0x996A,0x996D,0x9968,0x996E,0x996C,0x51AF,0x9A6D,0x4E71,
  0x503A,0x4F20,0x4EC5,0x503E,0x4F24,0x506C,0x94F2,0x52BF,
  0x79EF,0x6C47,0x5417,0x545C,0x545B,0x56ED,0x5706,0x6D82,
  0x5757,0x575E,0x57D8,0x8314,0x5965,0x5988,0x7231,0x5FFE,
  0x6006,0x607A,0x635F,0x62A2,0x6363,0x6784,0x6656,0x6655,
  0x65F8,0x4F1A,0x4E1A,0x6781,0x6768,0x6862,0x67AB,0x5C81,
  0x6C9F,0x706D,0x6E7F,0x6ED1,0x6CA7,0x70E6,0x70BC,0x7080,
  0x7115,0x7237,0x72EE,0x733E,0x73F2,0x5F53,0x76CF,0x7750,
  0x7741,0x96CE,0x788C,0x8282,0x7B15,0x7CA4,0x7ECF,0x7EE2,
  0x7ED1,0x7EE5,0x7EE6,0x4E49,0x7FA1,0x5723,0x80A0,0x811A,
  0x80BF,0x8111,0x8364,0x82C7,0x53F6,0x83B4,0x865E,
  0x864F,0x53F7,0x8708,0x86AC,0x8865,0x88C5,0x8BE7,0x8BE5,
  0x8BE6,0x8BD5,0x8BD7,0x8BD8,0x8BD9,0x8BE3,0x8BDA,0x8BDD,
  0x8BDB,0x8BE1,0x8BE2,0x8BE0,0x8BDF,0x8D3C,0x8D44,0x8D3E,
  0x8D3F,0x8D40,0x8D41,0x8D42,0x8D45,0x8F83,0x8F7D,0x8F7C,
  0x8F7E,0x519C,0x8FD0,0x8FBE,0x8FDD,0x8FC7,0x90B9,0x94B4,
  0x94B3,0x94B9,0x94B8,0x94BE,0x94C0,0x94C5,0x94A9,0x94C2,
  0x94C3,0x94C9,0x94CB,0x949C,0x94CD,0x94BF,0x94C6,0x95F8,
  0x9668,0x96BD,0x7535,0x9884,0x987D,0x987F,0x987C,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x9881,0x9882,0x9972,0x9974,0x9971,0x9970,0x9A70,
  0x9A6E,0x9A6F,0x9E20,0x4FA5,0x4FA8,0x532E,0x538C,0x5C1D,
  0x5455,0x53F9,0x55BD,0x5567,0x54D4,0x56E2,0x56FE,0x5C18,
  0x57AB,0x5811,0x5BFF,0x68A6,0x593A,0x5941,0x59AA,0x5B9E,
  0x5BDD,0x5BF9,0x5C61,0x5D2D,0x5C96,0x5E01,0x5E3C,0x5F7B,
  0x6001,0x60EF,0x6078,0x60ED,0x60E8,0x6402,0x63B4,0x63BA,
  0x7545,0x8363,0x67AA,0x6EDA,0x6E0D,0x6C49,0x6EE1,0x6EDE,
  0x6E10,0x6DA8,0x6D9F,0x6CAA,0x6E14,0x6E17,0x6DA4,0x8367,
  0x5C14,0x8366,0x72F1,0x7410,0x739B,0x759F,0x75A1,0x75AF,
  0x75EA,0x5C3D,0x76D1,0x7855,0x796F,0x7978,0x79CD,0x79F0,
  0x6D3C,0x7A9D,0x7B3A,0x7B5D,0x7EFD,0x7EFE,0x7EFC,0x7EF0,
  0x7EEB,0x7EFF,0x7D27,0x7F00,0x7EB2,0x7EEE,0x7EF8,
  0x7EF5,0x7EB6,0x7EF4,0x7EEA,0x7F01,0x7EF6,0x7F5A,0x95FB,
  0x8385,0x76D6,0x836A,0x82CD,0x8680,0x8BF5,0x8BED,0x8BEC,
  0x8BA4,0x8BEB,0x8BEF,0x8BF4,0x8BF0,0x8BF2,0x8BF1,0x8BF3,
  0x8BEE,0x5BBE,0x8D48,0x8D4A,0x8D75,0x8D76,0x8F85,0x8F84,
  0x8F7B,0x8FDC,0x900A,0x9012,0x94F0,0x94F6,0x94DC,0x94ED,
  0x94E2,0x94EC,0x94E8,0x94F5,0x94E3,0x9602,0x95FA,0x95FD,
  0x9601,0x9600,0x9645,0x9887,0x9886,0x98D2,0x997A,0x997C,
  0x9975,0x9977,0x9A73,0x80AE,0x9AB0,0x9E23,0x9E22,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x51E4,0x9F50,0x4EBF,0x4EEA,0x4EF7,0x4FAC,0x4FA9,
  0x4FED,0x5267,0x5218,0x5251,0x523D,0x5389,0x5520,0x5634,
  0x54D7,0x5618,0x55B7,0x5578,0x53FD,0x589F,0x575F,0x5760,
  0x5815,0x5A34,0x5A75,0x59A9,0x5A07,0x5A06,0x5BBD,0x5BA1,
  0x5199,0x5C42,0x5D94,0x5E1C,0x5E9F,0x53A8,0x5E99,0x53AE,
  0x5E7F,0x5F39,0x5E86,0x8651,0x5FE7,0x6002,0x60AF,0x60EE,
  0x6124,0x6003,0x631A,0x6251,0x635E,0x62E8,0x6320,0x629A,
  0x63B8,0x63FF,0x654C,0x6570,0x6682,0x6635,0x6837,0x6869,
  0x67A2,0x6807,0x697C,0x6868,0x4E50,0x679E,0x6B27,0x6B87,
  0x6BB4,0x6D46,0x6CFC,0x6D01,0x6D47,0x6E83,0x6DA6,0x6DA7,
  0x6D54,0x70ED,0x5956,0x83B9,0x75AE,0x7691,0x76B1,0x76D8,
  0x786E,0x7801,0x7A91,0x7A77,0x7F14,0x7EC3,0x7EAC,
  0x7F04,0x7F05,0x7F09,0x7F16,0x7F18,0x7EBF,0x7F0E,0x7F13,
  0x7F0D,0x7F02,0x7F08,0x7F07,0x9A82,0x7F62,0x80F6,0x80A4,
  0x83B2,0x836B,0x848B,0x867E,0x8717,0x536B,0x8C0A,0x8C05,
  0x8C08,0x8C06,0x8BDE,0x8BF7,0x8BF8,0x8BFE,0x8BFF,0x8C04,
  0x8C03,0x8C01,0x8BBA,0x8BE4,0x8C07,0x8BFD,0x8C00,0x7AD6,
  0x8D54,0x8D4F,0x8D4B,0x8D31,0x8D26,0x8D4C,0x8D24,0x5356,
  0x8D50,0x8D28,0x8D53,0x8DF5,0x8F89,0x8F86,0x8F8D,0x8F88,
  0x8F87,0x8F6E,0x8F8E,0x8F8B,0x8F8A,0x9002,0x8FC1,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x90BB,0x90D1,0x9093,0x950C,0x9511,0x9500,0x94FA,
  0x94D0,0x9504,0x94DD,0x9510,0x9509,0x950B,0x94A1,0x9502,
  0x95FE,0x9605,0x5DE9,0x9889,0x988C,0x517B,0x997F,0x9981,
  0x9A7C,0x9A7B,0x9A77,0x9A76,0x9A7D,0x9A7E,0x9A79,0x9A78,
  0x9AB7,0x95F9,0x9C7F,0x9C81,0x9E29,0x9E26,0x9EB8,0x9F7F,
  0x4FE6,0x50A7,0x4FAA,0x5E42,0x5242,0x5428,0x54DD,0x55F3,
  0x57A6,0x575B,0x594B,0x8885,0x5B66,0x5BFC,0x5BAA,0x51ED,
  0x60EB,0x61D4,0x5FC6,0x6218,0x62E5,0x6321,0x631E,0x636E,
  0x63B3,0x62E9,0x6361,0x62C5,0x631D,0x5386,0x6653,0x6654,
  0x6619,0x6866,0x6A2A,0x6811,0x692D,0x6865,0x673A,0x6861,
  0x6DC0,0x6D53,0x6CFD,0x6D4A,0x6CA3,0x6FA6,0x6E11,0x70BD,
  0x70E7,0x706F,0x70EB,0x7116,0x72EC,0x7391,0x74EF,
  0x7618,0x5362,0x7792,0x7816,0x789B,0x79EF,0x9896,0x7A23,
  0x7AA5,0x7B03,0x7B5B,0x7F22,0x7F23,0x8426,0x7F1A,0x53BF,
  0x7F1F,0x7F1C,0x7F19,0x7EC9,0x817B,0x5174,0x8231,0x8361,
  0x8427,0x829C,0x8682,0x8424,0x88E4,0x4EB2,0x89CE,0x8C1B,
  0x8C1A,0x8C0F,0x8BB3,0x8C0B,0x8C0D,0x8C10,0x8C18,0x8BFA,
  0x8C12,0x8C13,0x8BBD,0x8C15,0x8C19,0x8C0C,0x8C16,0x8D56,
  0x8F90,0x8F91,0x8F93,0x8F8F,0x529E,0x9009,0x8FDF,0x8FBD,
  0x9057,0x90BA,0x952D,0x952F,0x9530,0x9519,0x94B1,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x94A2,0x9521,0x5F55,0x94EE,0x9525,0x9526,0x951F,
  0x9522,0x9531,0x960E,0x968F,0x9669,0x9759,0x817C,0x988A,
  0x9888,0x9891,0x9894,0x5934,0x9893,0x9890,0x9986,0x996F,
  0x9984,0x9985,0x9A87,0x9A88,0x9A86,0x9AB8,0x9ABC,0x9C8D,
  0x9E35,0x9E2A,0x9E2F,0x9E2D,0x9E33,0x9F99,0x9F9F,0x4F18,
  0x507F,0x50A8,0x52B1,0x549B,0x5413,0x538B,0x57D9,0x5A74,
  0x5AD4,0x5B37,0x5C34,0x5C66,0x5C7F,0x5D58,0x5E2E,0x5F25,
  0x5E94,0x6073,0x620F,0x51FB,0x6324,0x62E7,0x62DF,0x6401,
  0x655B,0x6BD9,0x66A7,0x6863,0x68C0,0x6867,0x6809,0x6A2F,
  0x6B93,0x6BE1,0x6CDE,0x6EE8,0x6D4E,0x6D9B,0x6EE5,0x6DA9,
  0x6F4D,0x8425,0x707F,0x70DB,0x70E9,0x5899,0x72DE,0x83B7,
  0x73AF,0x7477,0x75E8,0x7597,0x77EB,0x78FA,0x77F6,
  0x7BD3,0x7CAA,0x9546,0x7CC1,0x7F29,0x7EE9,0x7F2A,0x7F15,
  0x7F27,0x7EF7,0x7F1D,0x603B,0x7EB5,0x7F2B,0x7EA4,0x7F25,
  0x7E66,0x7F26,0x58F0,0x806A,0x8054,0x8038,0x8113,0x80C6,
  0x8138,0x810D,0x4E34,0x4E3E,0x8270,0x8537,0x84DF,0x4E8F,
  0x877C,0x8748,0x4EB5,0x891B,0x89CA,0x8C1C,0x8C24,0x8C26,
  0x8BB2,0x8C0E,0x8C23,0x8C22,0x8A8A,0x8C27,0x8D5A,0x8D5B,
  0x8D2D,0x8D59,0x8D8B,0x8F96,0x8F97,0x6BC2,0x8F95,0x8206,
  0x8FD8,0x8FC8,0x915D,0x9540,0x9541,0x951A,0x952E,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x9532,0x9505,0x9524,0x953A,0x9539,0x953B,0x953E,
  0x9537,0x9614,0x9615,0x9611,0x95F1,0x9690,0x96B6,0x867D,
  0x97E9,0x9897,0x98D3,0x9A8B,0x9A8F,0x9C9C,0x9C9B,0x9C94,
  0x9C91,0x9E3F,0x9E3D,0x70B9,0x658B,0x4E1B,0x565C,0x5739,
  0x5792,0x5A76,0x61D1,0x6269,0x63B7,0x6270,0x64B5,0x6446,
  0x64DE,0x64B7,0x65AD,0x69DF,0x67DC,0x69DB,0x67E0,0x6B24,
  0x5F52,0x6BA1,0x6CFB,0x6E16,0x6EE4,0x6E0E,0x6E85,0x6D4F,
  0x70EC,0x7118,0x72B7,0x730E,0x74EE,0x75A0,0x7751,0x7840,
  0x793C,0x7A51,0x79FD,0x7A9C,0x7A8D,0x7BAB,0x7C27,0x7BAA,
  0x7BD1,0x7B80,0x7CAE,0x7EC7,0x7F2E,0x7ED5,0x7F2D,0x7EE3,
  0x7F2F,0x7FD8,0x804C,0x8042,0x8110,0x8191,0x65E7,0x8428,
  0x84DD,0x8360,0x86F2,0x8749,0x89D0,0x89DE,0x8C1F,
  0x8C28,0x8C2C,0x8C2A,0x8D58,0x8E52,0x8FF9,0x8DF8,0x8EAF,
  0x8F6C,0x8F99,0x8FE9,0x533B,0x9171,0x9551,0x9501,0x94A8,
  0x954D,0x9547,0x9550,0x9552,0x9549,0x9616,0x95EF,0x9617,
  0x9619,0x6742,0x53CC,0x96CF,0x9E21,0x989D,0x989C,0x9898,
  0x989A,0x989B,0x998F,0x998A,0x9988,0x9A91,0x9AC1,0x9CA8,
  0x9CA4,0x9CAB,0x9CA7,0x9E43,0x9E45,0x9E44,0x5784,0x575C,
  0x5BA0,0x5E9E,0x5E90,0x60E9,0x6000,0x61D2,0x62E2,0x65F7,
  0x6A71,0x691F,0x6988,0x6A79,0x6F47,0x6FD1,0x6CA5,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x6FD2,0x6CF8,0x70C1,0x724D,0x728A,0x517D,0x736D,
  0x73BA,0x743C,0x7574,0x762A,0x788D,0x7977,0x7A33,0x7B7E,
  0x8327,0x7ECE,0x7EF3,0x7ED8,0x7F57,0x7F34,0x81BB,0x827A,
  0x85AE,0x836F,0x8681,0x8747,0x88C6,0x8884,0x8C31,0x8BC6,
  0x8C2D,0x8C32,0x8BA5,0x8C2F,0x8D60,0x8D5E,0x8DF7,0x8F9A,
  0x8F7F,0x8F9E,0x8FB9,0x955C,0x955D,0x955E,0x94FE,0x9557,
  0x9558,0x9556,0x9559,0x9535,0x9542,0x94FF,0x933E,0x5173,
  0x9647,0x96BE,0x96FE,0x97EC,0x97F5,0x7C7B,0x98A0,0x98D5,
  0x9992,0x9991,0x9A9B,0x9A97,0x9CB8,0x9CB3,0x9CAD,0x9CB7,
  0x9E51,0x9E49,0x9E4A,0x9E4C,0x9E4F,0x4E3D,0x9EB4,0x529D,
  0x5499,0x5624,0x4E25,0x5B9D,0x60AC,0x5FCF,0x62E6,0x6400,
  0x80E7,0x6987,0x6F9C,0x6F4B,0x7089,0x73D1,0x77FF,
  0x783A,0x77FE,0x783E,0x7AA6,0x7ADE,0x7B79,0x7BEE,0x8FAB,
  0x7F24,0x7EE7,0x7F42,0x80EA,0x8230,0x853C,0x853A,0x82A6,
  0x82F9,0x8574,0x869D,0x8934,0x89C9,0x89E6,0x8BAE,0x8BD1,
  0x8C35,0x8D62,0x8D61,0x8DB8,0x91CA,0x949F,0x94D9,0x9508,
  0x9610,0x98D8,0x9976,0x9965,0x9A9E,0x817E,0x9A9A,0x9CC3,
  0x9CC5,0x515A,0x9F83,0x9F84,0x4FEA,0x55EB,0x556D,0x56A3,
  0x5C5E,0x60E7,0x6151,0x6444,0x643A,0x6593,0x6A31,0x680F,
  0x68C2,0x6B7C,0x70C2,0x727A,0x9576,0x748E,0x765E,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x7F20,0x7EED,0x5170,0x85D3,0x86CE,0x89C8,0x8C34,
  0x62A4,0x8A89,0x8D43,0x8E0C,0x8DC3,0x8DFB,0x8F70,0x8FA9,
  0x9570,0x956D,0x94C1,0x94DB,0x94CE,0x956F,0x954C,0x54CD,
  0x987E,0x98A2,0x98E8,0x9A71,0x9AA0,0x84E6,0x9AA1,0x9AC5,
  0x9CCD,0x9CCF,0x83BA,0x9E64,0x9E5E,0x9F87,0x9F88,0x556E,
  0x4FE8,0x50A5,0x5453,0x5B6A,0x5DC5,0x5CE6,0x5F2F,0x644A,
  0x6743,0x6B22,0x6EE9,0x7321,0x53E0,0x763E,0x7663,0x7B3C,
  0x7C41,0x804B,0x810F,0x88AD,0x886C,0x8BFB,0x8D4E,0x8D5D,
  0x8E2F,0x8E2C,0x8F94,0x90E6,0x94F8,0x9274,0x9701,0x9791,
  0x7E6E,0x98A4,0x9A84,0x9A81,0x9CD6,0x9CA2,0x9CD4,0x9CD7,
  0x9E67,0x9E25,0x9F39,0x9F89,0x9F8A,0x9F9A,0x604B,0x631B,
  0x6405,0x74D2,0x7A83,0x7F28,0x81E2,0x841D,0x86CA,
  0x53D8,0x9026,0x903B,0x9573,0x94C4,0x9765,0x663E,0x990D,
  0x60CA,0x9A7F,0x9A8C,0x9AD3,0x9AD1,0x9CDD,0x9CDE,0x9CDC,
  0x9E36,0x5631,0x575D,0x63FD,0x762B,0x766B,0x7F81,0x8695,
  0x8BA9,0x8C17,0x8C36,0x8273,0x8D63,0x917F,0x96F3,0x7075,
  0x972D,0x98A6,0x9AA4,0x9B13,0x9B47,0x9C8E,0x9E70,0x9E6D,
  0x7877,0x76D0,0x9CCC,0x9F8C,0x9F8B,0x5385,0x6984,0x6E7E,
  0x7BF1,0x7BA9,0x86EE,0x89C2,0x8E51,0x8845,0x94A5,0x9885,
  0x998B,0x9ACB,0x9EC9,0x6EE6,0x77A9,0x954A,0x97AF,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x9A74,0x9AA5,0x7F06,0x8C20,0x8E8F,0x917D,0x94BB,
  0x92AE,0x9523,0x9CC4,0x9C88,0x9EE9,0x51FF,0x9E66,0x9A8A,
  0x9E73,0x9E3E,0x94BA,0x4EC2,0x864D,0x6B92,0x57A7,0x577B,
  0x620B,0x4FE3,0x522D,0x538D,0x5459,0x537A,0x7EA8,0x8307,
  0x9487,0x9486,0x5457,0x5F2A,0x7953,0x7EBE,0x90CF,0x948C,
  0x5250,0x5326,0x56F5,0x57AD,0x5A05,0x5CBD,0x5D03,0x6D9E,
  0x6E0C,0x70C3,0x7726,0x7EC0,0x7ED0,0x80EB,0x948E,0x9490,
  0x9495,0x948D,0x95EB,0x59AB,0x5D5B,0x607D,0x6860,0x67A8,
  0x6CA9,0x6D48,0x7572,0x7817,0x7ED7,0x83DD,0x89C7,0x8BB5,
  0x8BCE,0x8BD2,0x8D36,0x8D33,0x8F7A,0x8F75,0x8F78,0x902F,
  0x90D3,0x9104,0x94AB,0x94AC,0x949B,0x94AF,0x94AD,0x94AA,
  0x95F6,0x9667,0x9878,0x996B,0x9EF9,0x4F1B,0x507B,
  0x4F65,0x5522,0x57B2,0x5DEF,0x5FAD,0x709C,0x8315,0x72F2,
  0x73AE,0x7EE8,0x7EE0,0x7EE1,0x7F9F,0x836D,0x86F1,0x8BD3,
  0x8BD6,0x8BE9,0x8BD4,0x8BDC,0x8D91,0x8F82,0x8F81,0x90AC,
  0x94CA,0x94C8,0x94B0,0x94B2,0x94B6,0x950D,0x94CC,0x94BD,
  0x94BC,0x9883,0x9880,0x51EB,0x9EFE,0x507E,0x551B,0x5D5D,
  0x5E3B,0x60AB,0x60AD,0x6004,0x622C,0x6217,0x629F,0x62A0,
  0x63BC,0x6864,0x6769,0x8365,0x6D52,0x6CA4,0x709D,0x76B2,
  0x7800,0x7EFB,0x7EF2,0x7EEF,0x7EFA,0x83B3,0x89CB,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x8BF6,0x8D47,0x94F1,0x94D2,0x94D1,0x94D5,0x94DF,
  0x94EB,0x94EF,0x94EA,0x94F7,0x94D6,0x94E5,0x98D1,0x523F,
  0x52A2,0x54D3,0x5452,0x5D02,0x5CE4,0x5E91,0x6126,0x6322,
  0x6920,0x6BF5,0x988D,0x6D9D,0x6F62,0x6DA0,0x6ED7,0x740F,
  0x7481,0x7617,0x7F03,0x7F17,0x7F0C,0x7F0F,0x7F11,0x835C,
  0x848C,0x8311,0x82C1,0x8BF9,0x8BFC,0x8C02,0x8D55,0x90F8,
  0x9512,0x94D7,0x94FD,0x9513,0x950A,0x94E4,0x9506,0x9507,
  0x9514,0x9606,0x9603,0x9753,0x988F,0x997D,0x9A75,0x9A80,
  0x9C82,0x9E28,0x54D2,0x54D5,0x54D9,0x5AD2,0x5CC4,0x603F,
  0x6B9A,0x6D4D,0x70E8,0x7303,0x72EF,0x789C,0x7AAD,0x7E17,
  0x7F1B,0x8487,0x8368,0x8489,0x835E,0x83B8,0x8297,0x86F3,
  0x8BE8,0x8C11,0x8C14,0x8C1D,0x90D0,0x9529,0x952C,
  0x9516,0x9517,0x94FC,0x951B,0x9515,0x951E,0x9494,0x960F,
  0x9608,0x9609,0x960A,0x960C,0x960D,0x9E32,0x9E31,0x54DC,
  0x5E31,0x6079,0x6448,0xE3C1,0x6CF6,0x7315,0x7513,0x7605,
  0x75EB,0x7857,0x7BA6,0x7B5A,0x7CE8,0x7F21,0x8027,0x835F,
  0x83B6,0x86F0,0x88E2,0x89CF,0x8C21,0x8BCC,0x8C25,0x8DC4,
  0x9538,0x9534,0x94E1,0x9536,0x9612,0x9967,0x9C92,0x9C95,
  0x9E38,0x9E39,0x9E3A,0x9F80,0x603C,0x6445,0x64B8,0x6CFA,
  0x7596,0x7F0B,0x8069,0x8369,0x87E5,0x866E,0x8BB4,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x8C29,0x8D5C,0x8D3D,0x8F98,0x909D,0x9553,0x94E0,
  0x953C,0x954F,0x84E5,0x97EA,0x9969,0x9A90,0x9A92,0x9A93,
  0x960B,0x9CA9,0x9CA0,0x9E48,0x9E41,0x9E46,0x53A3,0x5456,
  0x5786,0x69E0,0x680E,0x6C07,0x6CF7,0x6F46,0x7962,0x7F32,
  0x7F33,0x7F74,0x8223,0x86CF,0x867F,0x88E3,0x89D1,0x89EF,
  0x8C2E,0x955B,0x955F,0x956A,0x9546,0x94E9,0x97EB,0x98A1,
  0x9990,0x9AC2,0x9CB5,0x9CB6,0x9CBB,0x9CB1,0x9E4E,0x9E2B,
  0x9EFC,0x55BE,0x6484,0x680A,0x67A5,0x680C,0x7F31,0x804D,
  0x830F,0x82C8,0x8572,0x86F4,0x877E,0x94F4,0x9566,0x9568,
  0x9561,0x9563,0x9544,0x956B,0x94E7,0x9564,0x94F9,0x961A,
  0x989F,0x9994,0x9A7A,0x9A9D,0x9A9F,0x9A98,0x9E57,0x9E5A,
  0x9E5C,0x9F86,0x9F85,0x50A9,0x5CBF,0x75C8,0x64BA,
  0x6989,0x6EE0,0x783B,0x7C9D,0x7EA9,0x7F2C,0x8539,0x8D46,
  0x9571,0x95FC,0x98D9,0x9AA2,0x9A96,0x9A9C,0x9CA5,0x9CCE,
  0x9CD0,0x9E63,0x9E58,0x9E7E,0x5181,0x5A08,0x7055,0x6512,
  0x763F,0x7BA8,0x7C74,0x823B,0x89CC,0x8DF9,0x8DDE,0x8F79,
  0x9554,0x956C,0x9AA3,0x9A85,0x9CD5,0x9CA3,0x9CA6,0x9E68,
  0x9E37,0x9F9B,0x683E,0x6924,0x84E0,0x96E0,0x8F73,0x9CDF,
  0x9C9F,0x9E69,0x9E6C,0x9E6A,0x9E6B,0x9E47,0x704F,0x7C16,
  0x8C30,0x9ACC,0x7B3E,0x7C9C,0x7F35,0x8114,0x8E7F,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x9567,0x9C9A,0x8DB1,0x8E9C,0x917E,0x8C33,0x989E,
  0x98A7,0x9AA7,0x9E2C,0x6206,0x9604,0x9CA1,0x9E42,0x79B8,
  0x62D4,0x8DCB,0x73D0,0x5BAB,0x62D0,0x6BC1,0x51CF,0x7984,
  0x5415,0x6F5C,0x889C,0x90E7,0x5179,0x6238,0x629B,0x6327,
  0x63BB,0x63DE,0x63FA,0x6491,0x64C0,0x64E1,0x64F6,0x6505,
  0x6535,0x654E,0x656B,0x6588,0x65D9,0x661E,0x663B,0x663F,
  0x6644,0x6657,0x6669,0x6673,0x6683,0x66BC,0x66BF,0x66C1,
  0x66F5,0x66FA,0x66FB,0x670E,0x6716,0x6737,0x6764,0x6766,
  0x67A6,0x67A7,0x67A9,0x67FB,0x67FD,0x6800,0x6801,0x6805,
  0x681E,0x684A,0x6852,0x6855,0x6859,0x688D,0x68B9,0x68CF,
  0x5088,0x9528,0x9C97,0x6922,0x6926,0x00DC,0xE4DF,0xE4E0,
  0x00FC,0xE4E2,0xE4E3,0x00DC,0x00FC,0x6936,0x6961,
  0x82C5,0x82CA,0x82D8,0x8318,0x831A,0x8323,0x8346,0x835B,
  0x8362,0x836C,0x836E,0x839C,0x839F,0x83B5,0x83BC,0x83F7,
  0x842A,0x8448,0x845C,0x8462,0x8484,0x8488,0x84DC,0x84E3,
  0x8538,0x855A,0x8597,0x85AB,0x85C1,0x8613,0x8616,0x220B,
  0x8715,0x8770,0x877D,0x878B,0x87A8,0x87C7,0x87D0,0x8807,
  0x880E,0x8827,0x88AE,0x2208,0x88B5,0x88BF,0x88E5,0x88F5,
  0x891C,0x891D,0x8977,0x89E7,0x8A37,0x8AAC,0x8ADA,0x8B5B,
  0x8B71,0x8C2B,0x8C3A,0x8C7C,0x8C8E,0x8CAE,0x8D12,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x8D49,0x8D4D,0x8D71,0x8E08,0x8E3A,0x8E70,0x8E99,
  0x8EB0,0x8EB1,0x8EC5,0x8EC6,0x8ECE,0x8EE3,0x8F0C,0x8F71,
  0x8F77,0x8FA7,0x8FEF,0x900E,0x9039,0x9065,0x9089,0x90DE,
  0x9115,0x91D6,0x91DB,0x91DE,0x91E1,0x91E5,0x91F6,0x91FC,
  0x9229,0x922C,0xFF07,0x9259,0x9277,0x92ED,0x933A,0xE54D,
  0xE54E,0x722B,0x5182,0x5196,0x4E37,0x516B,0x513F,0xE555,
  0xE556,0x6729,0x6C3A,0x5382,0x7592,0x8080,0x8864,0x4E06,
  0xE55E,0xE55F,0xE560,0x2E97,0x52F9,0x5315,0x2021,0xE565,
  0x3404,0xE567,0xE568,0xE569,0xE56A,0xE56B,0x51F5,0xE56D,
  0x5C6E,0xE56F,0x56D7,0x4EA0,0x51AB,0x2E80,0x69C7,0xE575,
  0x254E,0x25D8,0x25D9,0x2642,0x25B6,0x25C4,0x2195,0x203C,
  0x00B6,0x2200,0x21A8,0x2194,0x2302,0xE583,0xE584,
  0x4E9C,0x60AA,0x5727,0x56F2,0x533B,0x58F1,0x9038,0x96A0,
  0x6804,0x55B6,0x99C5,0x8B01,0x5186,0x7E01,0x5FDC,0x6B27,
  0x6BB4,0x685C,0x5965,0x7A4F,0x4EEE,0x4FA1,0x753B,0x7070,
  0x4F1A,0x6094,0x6D77,0x7D75,0x58CA,0x61D0,0x62E1,0x6BBB,
  0x899A,0x5B66,0x697D,0x559D,0x6E07,0xE5AA,0x5DFB,0x9665,
  0x52E7,0x5BDB,0x6F22,0x95A2,0x6B53,0x89B3,0x6C17,0x5E30,
  0x622F,0x72A0,0x8650,0x65E7,0x6025,0x62E0,0x6319,0x865A,
  0x5CE1,0x631F,0x72ED,0x90F7,0x97FF,0x6681,0x52E4,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x8B39,0x533A,0x99C6,0x52F2,0xE5C8,0x5F84,0x830E,
  0x6075,0x63B2,0x6E13,0x7D4C,0x86CD,0x8EFD,0x7D99,0x9D8F,
  0x6483,0x770C,0x5039,0x5263,0x967A,0x570F,0x691C,0x6A29,
  0x9855,0x9A13,0x53B3,0x5449,0x5A2F,0x8AA4,0x5E83,0x6E2F,
  0x9271,0x53F7,0x56FD,0x9ED2,0x7A40,0x7815,0x6E08,0x658E,
  0x6B73,0x5264,0x96D1,0x53C2,0x685F,0x60E8,0x8CDB,0x6B8B,
  0x6B6F,0x5150,0x8F9E,0x6E7F,0x5B9F,0x5199,0x820E,0x6368,
  0x91C8,0x5BFF,0x53CE,0x8846,0x5F93,0x6E0B,0x7363,0x7E26,
  0x7C9B,0x51E6,0x5C06,0x79F0,0x6E09,0x713C,0x5968,0x6761,
  0x72B6,0x4E57,0x6D44,0x5270,0x7573,0x7E04,0x58CC,0x5B22,
  0x8B72,0x91B8,0x89E6,0x5631,0x5BDD,0x5C3D,0x56F3,0x7C8B,
  0x9154,0x7A42,0x968F,0x9AC4,0x67A2,0x6570,0x636E,
  0x702C,0x58F0,0x6589,0x9759,0x7A83,0x6442,0x7D76,0x5C02,
  0x6D45,0x6226,0x8DF5,0x92AD,0x6F5C,0x9077,0x9078,0x7E4A,
  0x7985,0x758E,0x58EE,0x4E89,0x8358,0x635C,0x633F,0x5DE3,
  0x7A93,0x88C5,0x50E7,0x5C64,0x7DCF,0x9A12,0x5897,0x618E,
  0x8535,0x8D08,0x81D3,0x5C5E,0x7D9A,0x5815,0x5BFE,0x5E2F,
  0x6EDE,0x6EDD,0x629E,0x6CA2,0x6FEF,0x5358,0x5606,0x56E3,
  0x65AD,0x5F3E,0x9045,0x663C,0x92F3,0x5E81,0x5FB4,0x8074,
  0x61F2,0x585A,0x9013,0x9244,0x70B9,0x8EE2,0x4F1D,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x96FB,0x706F,0x5F53,0x515A,0x76D7,0x7A32,0x95D8,
  0x5FB3,0x6BD2,0x72EC,0x8AAD,0x5C4A,0x96E3,0x5F10,0x60A9,
  0x8133,0x62DD,0x5EC3,0x58F2,0x6885,0x535A,0x8584,0x9EA6,
  0x7E1B,0x767A,0x9AEA,0x629C,0x6D5C,0x6D5C,0x654F,0x6577,
  0x4FAE,0x6255,0x4ECF,0x8FBA,0x5909,0x6B69,0x8217,0x7C3F,
  0x5305,0x5B9D,0x62B1,0x6CE1,0x80DE,0x7832,0x8C4A,0x98FD,
  0x58A8,0x6BCE,0x6E80,0x8108,0x9ED9,0x8A33,0x85AC,0x8E8D,
  0x4E0E,0x8A89,0x6447,0x69D8,0x8B21,0x66DC,0x6765,0x983C,
  0x4E71,0x89A7,0x7ADC,0x9686,0x65C5,0x4E21,0x731F,0x7DD1,
  0x6D99,0x5841,0x793C,0x52B1,0x623B,0x970A,0x9F62,0x66A6,
  0x6B74,0x604B,0x7DF4,0x932C,0x7089,0x52B4,0x697C,0x9332,
  0x6E7E,0x5F25,0x4E80,0x66FD,0x59C9,0x5B8D,0x5D8B,
  0x6A2B,0x691B,0x55B0,0x7C82,0x8FBC,0x698A,0x54B2,0x9D2B,
  0x96EB,0x6919,0x63C3,0x99C4,0x51E7,0x6802,0x8FBB,0x50CD,
  0x5CE0,0x6803,0x51EA,0x5302,0x7872,0x7551,0x7560,0x567A,
  0x92F2,0x5840,0x67FE,0x4FE3,0x6762,0x7C7E,0x5301,0x4FE4,
  0x4FE5,0x51E9,0x53FA,0x54D8,0x56CE,0x5726,0x5737,0x5738,
  0x5788,0x57B3,0x57AA,0x57B0,0x57D6,0x5870,0x58B9,0x58D7,
  0x5C76,0x5CBC,0x5CC5,0x5CBE,0x5D76,0x5F16,0x603A,0x63B5,
  0x6741,0x6763,0x67A1,0x68BA,0x6925,0x6928,0x6A7A,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x6923,0x6921,0x697E,0x6981,0x69DD,0x6A2E,0x6A72,
  0x6B1F,0x6BDF,0x6E15,0x7195,0x74E7,0x74F2,0x74F0,0x74F1,
  0x74F8,0x7505,0x7569,0x766A,0x7874,0x7ACD,0x7ACF,0x7AD5,
  0x7AD3,0x7AE1,0x7AF0,0x7B02,0x7C13,0x7C17,0x7C90,0x7CAD,
  0x7CC0,0x7CD8,0x7D9B,0x7E05,0x7E67,0x7E83,0x7E90,0x81A4,
  0x825D,0x8422,0x84D9,0x8630,0x86AB,0x86EF,0x88B0,0x88C3,
  0x88C4,0x8904,0xE72F,0x8EBE,0x8EC8,0x8F4C,0x8FB7,0x8FDA,
  0x9027,0x9056,0x9335,0x933B,0x93B9,0x958A,0x9596,0x9779,
  0x9786,0x9790,0x98AA,0x9B96,0x9B97,0x9BB4,0x9BCF,0x9BD1,
  0x9BD2,0x9BF2,0x9BF1,0x9C30,0x9C47,0x9C5A,0x9CF0,0x9D46,
  0x9D64,0x9DAB,0x4E44,0x544F,0x6318,0x9BB1,0x9C69,0x9D47,
  0x9D65,0x9C2F,0x9EBF,0x51B4,0x546A,0x67A0,0x9B8E,
  0x90A8,0x51B2,0x362D,0x62C5,0x52C5,0x67B1,0x54CD,0x6052,
  0x53C1,0x70F1,0x5803,0x555F,0x920E,0x7740,0x743C,0x714A,
  0x6ED9,0x53E0,0x732E,0x88CF,0x788D,0x7FA3,0x7DAB,0x8E2A,
  0x945B,0x636C,0x5FA7,0x5C05,0x803B,0x5CEF,0x39B8,0x7151,
  0x8CCD,0x97EE,0x5872,0x5A63,0x7F78,0x5D57,0x616F,0x6998,
  0x7D89,0x7CAE,0x7DB3,0x6F81,0x5AFA,0x58BB,0x7255,0x764E,
  0x8F2D,0x92B9,0x9D5E,0x9EAF,0x7F47,0x9DC4,0x8D18,0x51B3,
  0x866C,0x54A4,0x53A6,0x5226,0x6736,0x4E21,0x5374,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x5EF9,0x52B9,0x548F,0x5EF8,0x59AC,0x6031,0x7240,
  0x8117,0x763B,0x5F0D,0x664B,0x66A8,0x6164,0x634F,0x70DF,
  0x6D24,0x7CA7,0x7CC9,0x53D9,0x654D,0x5742,0x73CF,0x80C6,
  0x3551,0x6B35,0x7881,0x53CC,0x732B,0x732A,0x73C9,0x754A,
  0x59F9,0x71C4,0x750E,0x7DDC,0x99E1,0x89A9,0x6FF6,0x3A57,
  0x64EA,0x3BED,0x6CA1,0x6E7C,0x7567,0x5869,0x5869,0x5204,
  0xE7CA,0x6187,0x643A,0x81EF,0xE7CE,0x51B5,0x51D1,0x6C79,
  0x591F,0x8FF9,0x98F1,0x6537,0x8109,0x88B4,0x3A2A,0x8EAD,
  0x7F97,0x9A10,0x7D25,0x6AC8,0x518C,0x5227,0xE7E0,0x811A,
  0x53A0,0x53A2,0x6C5A,0x6C37,0x8218,0x5586,0x5EFB,0x51C9,
  0x78B1,0x9262,0x536D,0x51C3,0xE7EE,0x8471,0x8987,0x976D,
  0x8B90,0x96A3,0x5EFC,0x96B7,0x514E,0x9C10,0x6630,
  0x9255,0x7808,0x9345,0x9273,0x9369,0xE7FE,0xE7FF,0xE800,
  0xE801,0x91DF,0x91DA,0x7854,0x7866,0x7888,0x78B6,0x78C7,
  0x78D2,0x78D7,0x212B,0x21CB,0x78E4,0x78EE,0x78F0,0x78F1,
  0x78F5,0x7932,0x7933,0x7936,0x7958,0x3013,0x7959,0x7971,
  0x797E,0x7983,0x7986,0x7987,0x7991,0x7999,0x799F,0x79A5,
  0x79E2,0x79F1,0x79F4,0x7A2A,0x7A3A,0x7A45,0x7A65,0x7ABC,
  0x7AC2,0x7AC9,0x7ADB,0x7AE9,0x7AFE,0x7B0C,0x7B27,0x7B29,
  0x7B42,0x7B43,0x7B55,0x7B6F,0x7BB2,0x69DE,0x69F9,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x9176,0x815A,0x82F7,0x544B,0x8132,0x80BD,0x8418,
  0x915E,0x9170,0x918C,0x8148,0xE843,0x4436,0x8159,0x809F,
  0xE847,0x5549,0x5421,0x54DA,0x5432,0x55B9,0x5494,0xE84E,
  0x7852,0x7845,0x784C,0xE852,0x84BD,0x841C,0x82C4,0xE856,
  0x847B,0x8B2D,0xE859,0x574B,0xE85B,0xE85C,0x5745,0x87CE,
  0x5660,0x55EA,0x567B,0x80BC,0xE863,0x78B8,0x6A0C,0x54CC,
  0x7BD0,0x7BEC,0x7BFA,0x7C15,0x7C1B,0x7C35,0x7C44,0x7C6D,
  0x7C8E,0x7CB8,0x7CC3,0x7CE6,0x7CED,0x7CF3,0x7CF5,0x7CF9,
  0xE877,0x7CFC,0x7D8B,0x7D97,0x7DA4,0x7DA8,0x7DCD,0x7DD0,
  0x7DD3,0x7DE5,0x7DFD,0x6A12,0x6A22,0x6A30,0x6A36,0x6A65,
  0xE887,0xE888,0xE889,0xE88A,0xE88B,0xE88C,0xE88D,0xE88E,
  0x6A73,0x6A78,0xE891,0xE892,0x6A7C,0x6AA9,0x6AAA,
  0x24EA,0x2460,0x2461,0x2462,0x2463,0x2464,0x2465,0x2466,
  0x2467,0x2468,0x2469,0x246A,0x246B,0x246C,0x246D,0x246E,
  0x246F,0x2470,0x2471,0x2472,0x2473,0x9344,0x93AD,0x93C6,
  0x93E5,0x941A,0x9421,0x943E,0x9441,0x9453,0x945A,0x949A,
  0x94B7,0x94D8,0x94DE,0x94F3,0x9503,0x950E,0x950F,0x9518,
  0x951D,0x952A,0x952B,0x953F,0x9545,0x954E,0x9562,0x9565,
  0x9569,0x9572,0x9587,0x9599,0x95A0,0x95B2,0x9666,0x969D,
  0x96AF,0x96B2,0x9733,0x973B,0x974D,0x974F,0x9751,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x9755,0x9764,0x976B,0x9771,0x9792,0x97B2,0x97F2,
  0x983D,0x9854,0x98A5,0x98C3,0x98DA,0x98EE,0x991D,0x9920,
  0x9963,0x9980,0x9987,0x998D,0x9993,0x9995,0x99BC,0x99C8,
  0x99F2,0x9AB6,0x9AD9,0x9ADE,0x9B0F,0x9B49,0x9B72,0x9B83,
  0x9B9F,0x9BBB,0x9BE3,0x9BF5,0x9C00,0x9C04,0x9C1B,0x24B6,
  0x24B7,0x24B8,0x24B9,0x24BA,0x24BB,0x24BC,0x24BD,0x24BE,
  0x24BF,0x24C0,0x24C1,0x24C2,0x24C3,0x24C4,0x24C5,0x24C6,
  0x24C7,0x24C8,0x24C9,0x24CA,0x24CB,0x24CC,0x24CD,0x24CE,
  0x24CF,0x24D0,0x24D1,0x24D2,0x24D3,0x24D4,0x24D5,0x24D6,
  0x24D7,0x24D8,0x24D9,0x24DA,0x24DB,0x24DC,0x24DD,0x24DE,
  0x24DF,0x24E0,0x24E1,0x24E2,0x24E3,0x24E4,0x24E5,0x24E6,
  0x24E7,0x24E8,0x24E9,0x00AE,0x2122,0xE931,0xE932,
  0x9C76,0x278A,0x278B,0x278C,0x278D,0x278E,0x278F,0x2790,
  0x2791,0x2792,0x2793,0x9C85,0x9C86,0x9C87,0x9C8B,0x9C90,
  0x9C9E,0x9CAE,0x9CB0,0x9CB2,0x9CB4,0x9CBA,0x9CBC,0x9CBD,
  0x9CC6,0x9CC7,0x9CCA,0x9CCB,0x9CD3,0x9CD8,0x9CD9,0x9CE2,
  0x9CEB,0x9CEC,0x9D2A,0x9D48,0x9D50,0x9D7A,0x9DC6,0x9E4B,
  0x9E55,0x9E5B,0x9E71,0x9EAA,0x9EBD,0x9EC4,0x9EE2,0x9EEA,
  0x9F08,0x9F0B,0x9F0D,0x9F21,0x9F44,0x9F51,0x9F9D,0xFA0E,
  0xFA0F,0xFA11,0xFA13,0xFA14,0xFA18,0xFA1F,0xFA20,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xFA21,0xFA23,0xFA24,0xFA27,0xFA28,0xFA29,0x4E04,
  0x4E2F,0x4E81,0x4E87,0x4EA3,0x4EB7,0x4EBC,0x4EF8,0x4F28,
  0x4F29,0x4F37,0x4F42,0x4F45,0x4F4B,0x4F72,0x4FA2,0x4FB0,
  0x4FBD,0x4FC8,0x4FCC,0x4FF0,0x4FF2,0x4FF9,0x5003,0x5008,
  0x5034,0x503B,0x5058,0x5066,0x5081,0x5090,0x50BC,0x50D0,
  0x50DF,0x50E1,0x50FC,0x510D,0x512B,0x5160,0x51AE,0x51B8,
  0x51D2,0x51E2,0x5205,0x5234,0x523C,0x5259,0x5268,0x5279,
  0x52A4,0x52CC,0x5327,0x5342,0x535D,0x537D,0x537E,0x53C5,
  0x53D0,0x53D2,0x53FE,0x546D,0x5485,0x5493,0x549E,0x54B9,
  0x54E3,0x54EF,0x550D,0x5518,0x5525,0x5528,0x552B,0x5547,
  0x5579,0x5590,0x55B4,0x55C1,0x55D7,0x55D8,0x55FB,0x4FB4,
  0x5621,0x2203,0x5652,0xE9CC,0x263B,0xE9CE,0xE9CF,
  0x565D,0x2474,0x2475,0x2476,0x2477,0x2478,0x2479,0x247A,
  0x247B,0x247C,0x247D,0x247E,0x247F,0x2480,0x2481,0x2482,
  0x2483,0x2484,0x2485,0x2486,0x2487,0x5661,0x5689,0x568B,
  0x569E,0x56A1,0x56B1,0x56B9,0x56BF,0x56D6,0x56EF,0x5715,
  0x571D,0x5732,0x573D,0x573F,0x5743,0x21D4,0x577E,0x578A,
  0x578D,0x5790,0x579C,0x57BB,0x57BE,0x57C4,0x57DE,0x57FE,
  0x5812,0x5822,0x5847,0x585C,0x585F,0x5873,0x58A7,0x58AA,
  0x58B0,0x58B5,0x58B6,0x58CB,0x58D0,0x58E0,0x5905,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x5911,0x5989,0x5994,0x599A,0x599F,0x59B0,0x59B8,
  0x59C4,0x59EF,0x59F0,0x59F8,0x5A02,0x5A0B,0x5A0D,0x5A12,
  0x5A21,0x5A24,0x5A27,0x5A2A,0x5A2B,0x5A2C,0x5A3D,0x5A45,
  0x5A54,0x5A59,0x5A61,0x5A68,0x5A6B,0x5A6E,0x5A71,0x5A79,
  0x5A7E,0x5A81,0x5A82,0x5A86,0x5A88,0x5A91,0x5A99,0x5AA0,
  0x5AA1,0x5AAB,0x5AC3,0x5ACE,0x5ACF,0x5AD3,0x5AE4,0x5AF0,
  0x5AFE,0x5B0D,0x5B11,0x5B15,0x5B1F,0x5B2B,0x5B41,0x5B44,
  0x5B46,0x5B4A,0x5B4F,0x5B68,0x5B74,0x5B76,0x5B7C,0x5B82,
  0x5B90,0x249C,0x249D,0x249E,0x249F,0x24A0,0x24A1,0x24A2,
  0x24A3,0x24A4,0x24A5,0x24A6,0x24A7,0x24A8,0x24A9,0x24AA,
  0x24AB,0x24AC,0x24AD,0x24AE,0x24AF,0x24B0,0x24B1,0x24B2,
  0x24B3,0x24B4,0x24B5,0xEA69,0x3232,0x3231,0x6AAB,
  0x5B96,0x2488,0x2489,0x248A,0x248B,0x248C,0x248D,0x248E,
  0x248F,0x2490,0x2491,0x2492,0x2493,0x2494,0x2495,0x2496,
  0x2497,0x2498,0x2499,0x249A,0x249B,0x5BD5,0x5BD7,0x5C23,
  0x5C85,0x5C9E,0x5CC2,0x5D10,0x5D2C,0x5D2F,0x5D48,0x5D56,
  0x5D70,0x5D7B,0x5D85,0x5DA4,0x5DAB,0x5DB6,0x5DC1,0x5DD7,
  0x5E09,0x5E48,0x5E92,0x5EBD,0x5F0E,0x5F72,0x5FB1,0x5FC2,
  0x5FDB,0x5FDF,0x6023,0x607E,0x60D7,0x6107,0x610C,0x6119,
  0x6122,0x6150,0x6160,0x6181,0x6195,0x61B9,0x61C0,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x61CF,0x61D3,0x61DA,0x6290,0x6331,0x2283,0x6337,
  0x6379,0x638B,0x63C1,0x63E2,0x63E6,0x63FB,0x63FE,0x6407,
  0x6432,0x6438,0x643B,0x645A,0x6471,0x647C,0x648D,0x64AF,
  0x64B4,0x64B6,0x64DD,0x64E5,0x650A,0x6511,0x651F,0x655F,
  0x656D,0x6586,0x65B5,0x65BE,0x65D1,0x65D4,0x65E3,0x65FF,
  0x6618,0x6623,0x6663,0x666B,0x667D,0x6685,0x6692,0x669A,
  0x66A4,0x66AD,0x66B3,0x66B6,0x66CD,0x66CE,0x6702,0x670C,
  0x6719,0x6744,0x676B,0x678F,0x67A4,0x67BF,0x67D6,0x67D7,
  0x2282,0x680D,0x6810,0x681B,0x6836,0x6847,0x6856,0x6884,
  0x6888,0x68BD,0x68C3,0x68C5,0x6902,0x6903,0x6909,0x6918,
  0x6943,0x6946,0x6964,0x6967,0x6972,0x6985,0x699F,0x69A2,
  0x69D1,0x69D5,0x69D6,0x9A21,0x9A26,0x9A2F,0x6AC1,
  0x59BF,0x69E1,0x6A03,0x6A1A,0x6A1C,0x6A2C,0x6A2D,0x6A33,
  0x6A43,0x6A45,0x6A4C,0x6A53,0x6A57,0x6A63,0x6A74,0x6A82,
  0x6A8A,0x6A8F,0x6A99,0x6AA7,0x6AB1,0x6AB5,0x6ABE,0x6AC9,
  0x6AD4,0x6AD8,0x6AF6,0x6B57,0x6B7A,0x6BDC,0x6C1C,0x6C31,
  0x6C58,0x6C6E,0x6C75,0x6C7F,0x6CAF,0x6CCB,0x6CDF,0x6CFF,
  0x6D02,0x6D05,0x6D06,0x6D26,0x6D57,0x6D5B,0x6D71,0x6D81,
  0x6D8F,0x6DA5,0x6DB1,0x6DFE,0x6E02,0x6E04,0x6E0F,0x6E18,
  0x6E2A,0x6E50,0x6E59,0x6E9A,0x6EB5,0x6EB8,0x6EDB,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x6EFA,0x6F04,0x6F0B,0x6F0C,0x6F16,0x6F17,0x6F34,
  0x6F3D,0x6F56,0x6F79,0x6F8A,0x6F9D,0x6F9F,0x6FBB,0x6FBE,
  0x6FD3,0x6FD9,0x6FF8,0x7003,0x704B,0x704D,0x7050,0x7054,
  0x705C,0x7067,0x7077,0x7079,0x708B,0x708F,0x70A0,0x70A3,
  0x70A5,0x70A6,0x70A7,0x70C4,0x70CC,0x70D0,0x70D6,0x026A,
  0x025B,0x00E6,0x028C,0x0251,0x0254,0x028A,0x025D,0x0259,
  0x025A,0x025C,0x0261,0x1E43,0x1E49,0x014A,0x1E3B,0x0275,
  0x00F0,0x0283,0x0292,0x02A7,0x02A4,0x00E3,0xEB86,0xEB87,
  0x026F,0x0278,0x0287,0xEB8B,0x00C7,0x0153,0x0252,0xFF47,
  0x02CB,0x02CF,0xFF41,0xFF42,0xFF44,0xFF45,0xFF46,0xFF48,
  0xFF49,0xFF4A,0xFF4B,0xFF4C,0xFF4D,0xFF4E,0xFF4F,0xFF50,
  0xFF52,0xFF53,0xFF54,0xFF55,0xFF56,0xFF57,0xFF5A,
  0x70F5,0x3220,0x3221,0x3222,0x3223,0x3224,0x3225,0x3226,
  0x3227,0x3228,0x3229,0x70FE,0x7105,0x711D,0x7129,0x712B,
  0x712C,0x7133,0x7135,0x713B,0x713E,0x7140,0x714F,0x716B,
  0x7175,0x7177,0x717C,0x717E,0x718C,0x718E,0x7191,0x7196,
  0x71A2,0x71A3,0x71AD,0x71B4,0x71B7,0x71BA,0x71D1,0x71DD,
  0x71EB,0x7200,0x7209,0x720E,0x720F,0x7216,0x7217,0x7224,
  0x5AA4,0x722E,0x2286,0x7257,0x725C,0x7294,0x7304,0x7310,
  0x7341,0x7374,0x738C,0x738F,0x7398,0x739C,0x739E,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x73A7,0x73AA,0x73D5,0x73E1,0x73E2,0x73E4,0x73E6,
  0x73EF,0x73F3,0x2287,0x73F9,0x73FB,0x7402,0x7411,0x7412,
  0x7414,0x7415,0x7417,0x7419,0x741C,0x741E,0x741F,0x7437,
  0x7438,0x7439,0x7443,0x7445,0x7447,0x7448,0x7449,0x7453,
  0x7456,0x7465,0x746B,0x746C,0x7474,0x747A,0x7482,0x5382,
  0x5E7F,0x4E28,0x5E7A,0x5196,0x5B80,0x5369,0x2E87,0xEC14,
  0x5303,0x2612,0x8279,0x4491,0x2E8C,0x2E8A,0x4E36,0xEC1C,
  0x531A,0xEC1E,0xEC1F,0x2E95,0xEC21,0xEC22,0x2514,0x4E5A,
  0x8FB6,0x5EF4,0x5188,0x4E85,0xEC29,0x4E3F,0xEC2B,0xEC2C,
  0x4E5B,0x53B6,0x8F66,0x7E9F,0x8BA0,0x8D1D,0x9E1F,0x95E8,
  0x9485,0x961D,0x624C,0x6C35,0x4EBB,0x5FC4,0x706C,0x2EAE,
  0x53E3,0x6AE2,0x9A3B,0x9A3C,0x9A58,0x9A5C,0x9A63,
  0x260E,0x2192,0x2190,0x2191,0x2193,0x21E8,0x21E6,0x21E7,
  0x21E9,0x21E8,0x21E6,0x21E7,0x21E9,0x261E,0x261C,0x261B,
  0x261F,0x3016,0x3017,0x25CB,0x2715,0x2713,0x56FB,0x263D,
  0x591D,0x664D,0x7225,0x2729,0x2721,0x263A,0x2639,0xEC63,
  0xEC64,0xEC65,0xEC66,0xEC67,0x5C78,0x266C,0x266A,0x5AD1,
  0x5BB7,0x5CFC,0xEC6E,0x2709,0x2702,0xEC71,0xEC72,0xEC73,
  0xEC74,0x5CD5,0x676E,0x7461,0x749D,0x7F53,0x8593,0x274F,
  0xEC7C,0xEC7D,0x5D78,0x5F3B,0xEC80,0x2501,0x2503,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xEC83,0xEC84,0xEC85,0xEC86,0xEC87,0xEC88,0xEC89,
  0xEC8A,0xEC8B,0xEC8C,0xEC8D,0xEC8E,0xEC8F,0xEC90,0xEC91,
  0x9AB2,0x9AE0,0x9B14,0x9B34,0x9B39,0x9B40,0x9B50,0x9B7F,
  0x263C,0x7D95,0x2601,0x9734,0x2602,0xEC9F,0xECA0,0xECA1,
  0x2708,0xECA3,0xECA4,0xECA5,0xECA6,0xECA7,0xECA8,0xECA9,
  0x213B,0x2121,0x66E7,0x6E57,0xECAE,0x7157,0x79CA,0x2116,
  0x816C,0x8AF9,0x9856,0xECB5,0xECB6,0x2620,0xECB8,0x2664,
  0x2660,0x2667,0x2663,0x2662,0x2666,0x2661,0x2665,0xECC1,
  0xECC2,0x6AE4,0x211E,0x33C2,0x33D8,0x33A1,0xECC8,0x33A5,
  0xECCA,0xECCB,0xECCC,0xECCD,0xECCE,0x2611,0x9B81,0x9B8B,
  0x9B8D,0x9BDD,0x9BE9,0x9BED,0x9BF4,0x9C1F,0x9C20,0x9C26,
  0x9C53,0x9C5D,0x9C7B,0x9D0C,0x9D16,0x21B2,0x6B05,
  0x8CE9,0x8CF2,0x8D03,0x8D11,0x8D1C,0x8D7A,0x8DA9,0x8DC0,
  0x8E01,0x8E0E,0x8E46,0x8E68,0x8E71,0x8E7E,0x8E80,0x8EB6,
  0x8EB9,0x8EBC,0x8EC3,0x8EE4,0x8EED,0x8EF2,0x8F30,0x8F41,
  0x8F4A,0x8FA5,0x8FB3,0x8FB8,0x8FCA,0x8FCF,0x9008,0x9033,
  0x9037,0x9064,0x906C,0x91A9,0x91B6,0x91C4,0x91FA,0x9208,
  0x9213,0x9221,0x9228,0x922B,0x9235,0x923C,0x9241,0x9258,
  0x925D,0x925F,0x926B,0x926E,0x9281,0x9284,0x9289,0x928F,
  0x92B1,0x92BA,0x92BF,0x92D4,0x92DB,0x92E3,0x92E5,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x92EB,0x92EC,0x92F4,0x92F6,0x92FD,0x9303,0x9307,
  0x9330,0x9331,0x9340,0x9342,0x9343,0x935F,0x9362,0x9366,
  0x9368,0x9373,0x9374,0x9378,0x937D,0x9381,0x9384,0x9386,
  0x9387,0x9390,0x939C,0x93A0,0x93B8,0x93BB,0x93BD,0x93BF,
  0x93CB,0x93D3,0x93DB,0x93E0,0x93F0,0x93F1,0x93F3,0x93F4,
  0x9401,0x9404,0x9408,0x9417,0x941B,0x941D,0x9424,0x9425,
  0x9426,0x942D,0x9442,0x9443,0x944D,0x9454,0x9458,0x9465,
  0x9467,0x946C,0x9479,0x947B,0x9578,0x9585,0x95A6,0x95AA,
  0x9656,0x967B,0x96A5,0x96F4,0x971B,0x9736,0x9740,0x9741,
  0x9757,0x9787,0x9789,0x979B,0x97B1,0x97BD,0x97C0,0x97C2,
  0x97D2,0x97E0,0x9814,0x9815,0x9823,0x9833,0x9868,0x98B7,
  0x98B9,0x98C7,0x98CA,0x98E0,0x98E1,0x98EC,0x98F5,
  0x9D21,0x9D34,0x9D39,0x9D49,0x9D4E,0x9D6D,0x2237,0x9D6E,
  0x9D7C,0x9D83,0x9D93,0x9DA5,0x222C,0x9DBD,0x6B81,0x6BB1,
  0x9C4F,0x9E90,0x9DC0,0xED91,0xED92,0x262F,0x2630,0x2637,
  0x2633,0x2634,0x2635,0x2632,0x2636,0x2631,0x9DC9,0x9DD4,
  0x9DFC,0x9E0A,0x9E0C,0x9E0E,0x9E18,0x9E7B,0x9E85,0x9EA2,
  0x9EAC,0x9EB1,0x9EC1,0x9EC6,0x9EC7,0x9EF1,0x9EF8,0x9F27,
  0x990E,0x9919,0x991C,0x9937,0x995D,0x9962,0x999B,0x99A4,
  0x99AA,0x99B8,0x99E0,0x99E6,0x99F5,0x9A1F,0x7DFE,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x7E07,0x7E5B,0x7E65,0x7E6C,0x7F37,0x7F40,0x7F41,
  0x7F49,0x7F52,0x7F8F,0x7F93,0x7FB4,0x7FDD,0x7FE7,0x7FFA,
  0x8002,0x8008,0x802E,0x802F,0x803C,0x80A7,0x810C,0x812A,
  0x8134,0x8142,0x8156,0x8184,0x81A5,0x81E4,0x8254,0x8265,
  0x827B,0x8287,0x82BF,0x82E2,0x82EE,0x82F8,0x82FC,0x82FF,
  0x830B,0x831D,0x833D,0x8357,0x8391,0x83AC,0x83CD,0x83ED,
  0x8405,0x8414,0x8416,0x8421,0x842E,0x843E,0x844A,0x8453,
  0x8455,0x8458,0x8464,0x8472,0x847F,0x8480,0x8492,0x8493,
  0x8496,0x84A3,0x84BE,0x84DE,0x84E1,0x84E2,0x84E4,0x84F8,
  0x8503,0x8505,0x8510,0x8533,0x2010,0x8542,0x854C,0x8552,
  0x855F,0x856F,0x8570,0x8573,0x85D6,0x85E0,0x85EE,0x85FC,
  0x860D,0x860F,0x8614,0x8628,0x8642,0x8645,0x8672,
  0x889C,0x5B6D,0x8137,0xEE1E,0x9938,0x5572,0x556B,0xEE22,
  0x35CE,0x5571,0x55BA,0x55F1,0x35D2,0x55F0,0x5605,0x5622,
  0x562D,0x5643,0x561E,0x5692,0x7CCD,0x541A,0x5413,0x5497,
  0x66F1,0x7534,0x544D,0x56A4,0x569F,0x64D3,0x632E,0x63F8,
  0x651E,0x4E78,0x6BEA,0x6C32,0x6C3D,0x6C62,0x6CB2,0x6DF8,
  0x6E29,0x6E76,0x6E82,0x6E86,0x6EBB,0x6EDF,0x6EE2,0x6F11,
  0x6F24,0x6F74,0x6F91,0x6FB5,0x6FF3,0x6FF5,0x70BB,0x70C0,
  0x710F,0x2202,0x7155,0x7173,0x717A,0xEE58,0x5223,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0xEE5A,0x3451,0xEE5C,0x8FCC,0xEE5E,0xEE5F,0x00C0,
  0x00C8,0x00CC,0x00D2,0x00D9,0x00C1,0x00CD,0x00D3,0x00DA,
  0x0101,0x0113,0x012B,0x014D,0x016B,0x01D6,0x00C4,0x00CB,
  0x00CF,0x00D6,0x00DC,0x00C6,0x00C7,0x00D1,0x00C3,0x00D5,
  0x00E1,0x00E9,0x00ED,0x00F3,0x00FA,0x01D8,0x00E4,0x00EB,
  0x00EF,0x00F6,0x00FC,0x00E6,0x00E7,0x00F1,0x00E3,0x00F5,
  0x01CE,0x011B,0x01D0,0x01D2,0x01D4,0x01DA,0x00C5,0x00C9,
  0x7188,0x00D8,0x00D0,0x1EF2,0x00DE,0x00DF,0x00AA,0x00A1,
  0x00E0,0x00E8,0x00EC,0x00F2,0x00F9,0x01DC,0x00E5,0x7198,
  0x71D7,0x00F8,0x00F0,0x1EF3,0x00FE,0x00FF,0x00BA,0x00BF,
  0x00E2,0x00EA,0x00EE,0x00F4,0x00FB,0x71F5,0x00C2,0x00CA,
  0x00CE,0x00D4,0x00DB,0x00B8,0x00A4,0xEEB6,0x0192
};

skf_ucode big5uao_c6_uni_byte[HKSCS_C6_LEN] = { /* c640 - c8fe */
  0x8B96,0x8277,0x8D1B,0x91C0,0x946A,0x9742,0x9748,0x9744,
  0x97C6,0x9870,0x9A5F,0x9B22,0x9B58,0x9C5F,0x9DF9,0x9DFA,
  0x9E7C,0x9E7D,0x9F07,0x9F77,0x9F72,0x5EF3,0x6B16,0x7063,
  0x7C6C,0x7C6E,0x883B,0x89C0,0x8EA1,0x91C1,0x9472,0x9470,
  0x9871,0x995E,0x9AD6,0x9B23,0x9ECC,0x7064,0x77DA,0x8B9A,
  0x9477,0x97C9,0x9A62,0x9A65,0x7E9C,0x8B9C,0x8EAA,0x91C5,
  0x947D,0x947E,0x947C,0x9C77,0x9C78,0x9EF7,0x8C54,0x947F,
  0x9E1A,0x7228,0x9A6A,0x9B31,0x9E1B,0x9E1E,0x7C72,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x2460,0x2461,0x2462,0x2463,0x2464,0x2465,0x2466,
  0x2467,0x2468,0x2469,0x2474,0x2475,0x2476,0x2477,0x2478,
  0x2479,0x247A,0x247B,0x247C,0x247D,0x2170,0x2171,0x2172,
  0x2173,0x2174,0x2175,0x2176,0x2177,0x2178,0x2179,0x4E36,
  0x4E3F,0x4E85,0x4EA0,0x5182,0x5196,0x51AB,0x52F9,0x5338,
  0x5369,0x53B6,0x590A,0x5B80,0x5DDB,0x5E7A,0x5E7F,0x5EF4,
  0x5F50,0x5F61,0x6534,0x65E0,0x7592,0x7676,0x8FB5,0x96B6,
  0x00A8,0x02C6,0x30FD,0x30FE,0x309D,0x309E,0x3003,0x4EDD,
  0x3005,0x3006,0x3007,0x30FC,0xFF3B,0xFF3D,0x273D,0x3041,
  0x3042,0x3043,0x3044,0x3045,0x3046,0x3047,0x3048,0x3049,
  0x304A,0x304B,0x304C,0x304D,0x304E,0x304F,0x3050,0x3051,
  0x3052,0x3053,0x3054,0x3055,0x3056,0x3057,0x3058,
  0x3059,0x305A,0x305B,0x305C,0x305D,0x305E,0x305F,0x3060,
  0x3061,0x3062,0x3063,0x3064,0x3065,0x3066,0x3067,0x3068,
  0x3069,0x306A,0x306B,0x306C,0x306D,0x306E,0x306F,0x3070,
  0x3071,0x3072,0x3073,0x3074,0x3075,0x3076,0x3077,0x3078,
  0x3079,0x307A,0x307B,0x307C,0x307D,0x307E,0x307F,0x3080,
  0x3081,0x3082,0x3083,0x3084,0x3085,0x3086,0x3087,0x3088,
  0x3089,0x308A,0x308B,0x308C,0x308D,0x308E,0x308F,0x3090,
  0x3091,0x3092,0x3093,0x30A1,0x30A2,0x30A3,0x30A4,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x30A5,0x30A6,0x30A7,0x30A8,0x30A9,0x30AA,0x30AB,
  0x30AC,0x30AD,0x30AE,0x30AF,0x30B0,0x30B1,0x30B2,0x30B3,
  0x30B4,0x30B5,0x30B6,0x30B7,0x30B8,0x30B9,0x30BA,0x30BB,
  0x30BC,0x30BD,0x30BE,0x30BF,0x30C0,0x30C1,0x30C2,0x30C3,
  0x30C4,0x30C5,0x30C6,0x30C7,0x30C8,0x30C9,0x30CA,0x30CB,
  0x30CC,0x30CD,0x30CE,0x30CF,0x30D0,0x30D1,0x30D2,0x30D3,
  0x30D4,0x30D5,0x30D6,0x30D7,0x30D8,0x30D9,0x30DA,0x30DB,
  0x30DC,0x30DD,0x30DE,0x30DF,0x30E0,0x30E1,0x30E2,0x30E3,
  0x30E4,0x30E5,0x30E6,0x30E7,0x30E8,0x30E9,0x30EA,0x30EB,
  0x30EC,0x30ED,0x30EE,0x30EF,0x30F0,0x30F1,0x30F2,0x30F3,
  0x30F4,0x30F5,0x30F6,0x0410,0x0411,0x0412,0x0413,0x0414,
  0x0415,0x0401,0x0416,0x0417,0x0418,0x0419,0x041A,
  0x041B,0x041C,0x041D,0x041E,0x041F,0x0420,0x0421,0x0422,
  0x0423,0x0424,0x0425,0x0426,0x0427,0x0428,0x0429,0x042A,
  0x042B,0x042C,0x042D,0x042E,0x042F,0x0430,0x0431,0x0432,
  0x0433,0x0434,0x0435,0x0451,0x0436,0x0437,0x0438,0x0439,
  0x043A,0x043B,0x043C,0x043D,0x043E,0x043F,0x0440,0x0441,
  0x0442,0x0443,0x0444,0x0445,0x0446,0x0447,0x0448,0x0449,
  0x044A,0x044B,0x044C,0x044D,0x044E,0x044F,0x21E7,0x21B8,
  0x21B9,0x31CF,0xF7E6,0x4E5A,0xF7E8,0x5202,0x4491,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x9FB0,0x5188,0x9FB1,0xF7EE,0xF7EF,0xF7F0,0xF7F1,
  0xF7F2,0xF7F3,0xF7F4,0xF7F5,0xF7F6,0xF7F7,0xF7F8,0xF7F9,
  0xF7FA,0x309B,0x309C,0x3094,0x30F7,0x30F8,0x30F9,0x30FA,
  0x30FB,0xFF61,0xFF62,0xFF63,0xFF64,0xFF65,0xFF66,0xFF67,
  0xFF68,0xFF69,0xFF6A,0xFF6B,0xFF6C,0xFF6D,0xFF6E,0xFF6F,
  0xFF70,0xFF71,0xFF72,0xFF73,0xFF74,0xFFE2,0xFFE4,0xFF07,
  0xFF02,0x3231,0x2116,0x2121,0xFF75,0xFF76,0xFF77,0xFF78,
  0xFF79,0xFF7A,0xFF7B,0xFF7C,0xFF7D,0xFF7E,0xFF7F,0xFF80,
  0xFF81,0xFF82,0xFF83,0xFF84,0xFF85,0xFF86,0xFF87,0xFF88,
  0xFF89,0xFF8A,0xFF8B,0xFF8C,0xFF8D,0xFF8E,0xFF8F,0xFF90,
  0xFF91,0xFF92,0xFF93,0xFF94,0xFF95,0xFF96,0xFF97,0xFF98,
  0xFF99,0xFF9A,0xFF9B,0xFF9C,0xFF9D,0xFF9E,0xFF9F
};

skf_ucode big5uao_fa_uni_byte[BIG5UAO_FA_LEN] = {  /* fa40 - fefe */
  0xE000,0xE001,0xE002,0xE003,0xE004,0xE005,0xE006,0xE007,
  0xE008,0xE009,0xE00A,0xE00B,0xE00C,0xE00D,0xE00E,0xE00F,
  0xE010,0xE011,0xE012,0xE013,0xE014,0xE015,0xE016,0xE017,
  0xE018,0xE019,0xE01A,0xE01B,0xE01C,0xE01D,0xE01E,0xE01F,
  0xE020,0xE021,0xE022,0xE023,0x7232,0x723C,0x7266,0x7282,
  0x728F,0x729F,0x72AD,0x72B1,0x72B8,0x72BE,0x72CD,0x72DB,
  0x7324,0x732F,0x7338,0x7339,0x73BD,0x73CE,0x73F1,0x7476,
  0x74A2,0x7501,0x7519,0x7523,0x753C,0x7544,0x7549,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x754D,0x756D,0x7582,0x7583,0x7589,0x75AC,0x75D6,
  0x75E9,0x7640,0x764D,0x7654,0x7668,0x7680,0x7683,0x7690,
  0x76B7,0x76B9,0x770D,0x771E,0x7743,0x7818,0x781C,0x7839,
  0x783C,0x7847,0x7856,0x787A,0x78B5,0x78B9,0x78C6,0x78D9,
  0x7907,0x7930,0x7934,0x793B,0x7980,0x799D,0x79C3,0x79E1,
  0x7A06,0x7A0E,0x7A43,0x7A50,0x7AC3,0x7AD2,0x7AE2,0x7AE7,
  0x7AF8,0x7B36,0x7B62,0x7B6C,0x7B7A,0x7B7B,0x7B9A,0x7B9E,
  0x7B9F,0x7BA2,0x7BA7,0x7BF6,0x7C12,0x7C14,0x7C4F,0x7C56,
  0x7C58,0x7CAB,0x7CFA,0x7D48,0x7D4B,0x7D77,0x7DD4,0x7DD5,
  0x7DD6,0x7DE4,0x7E4D,0x7E5D,0x7E7F,0x7E89,0x7E8E,0x7E92,
  0x7ED4,0x7EF1,0x7F12,0x7F30,0x7F71,0x7F82,0x7FAE,0x7FC6,
  0x8020,0x8022,0x8025,0x8031,0x805F,0x8068,0x80AC,
  0x80B7,0x519A,0x5416,0x5414,0x34DF,0x4C7D,0x62C3,0xE0A4,
  0xE0A5,0xE0A6,0x54CB,0xE0A8,0x55BC,0x80B6,0x51A7,0xE0AC,
  0xE0AD,0xE0AE,0x5513,0x8226,0xE0B1,0x551E,0x55DE,0x63B9,
  0x6898,0xE0B6,0x5502,0x5569,0x75B4,0x63FC,0x9E84,0x922A,
  0xE0BD,0xE0BE,0xE0BF,0x88C7,0x609E,0x5625,0x7145,0x5AF2,
  0xE0C5,0x528F,0x564F,0x7793,0x8786,0x8E2D,0x81B6,0x35FE,
  0x71F6,0xE0CE,0x8804,0x9385,0xE0D1,0xE0D2,0x7666,0xE0D4,
  0x9C72,0xE0D6,0x62CE,0xE0D8,0x9E96,0x4989,0x7CD3,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x8EDA,0x9EAB,0x64E7,0xE0DF,0x82AA,0x6767,0x6D72,
  0x7906,0x79C4,0x7F4E,0x87EE,0xE0E7,0x83BE,0x862F,0x89A5,
  0x460F,0xE0EC,0x98C8,0x9940,0x994D,0x9A0C,0x9AD7,0x9E98,
  0x9F26,0xE0F4,0x4F03,0xE0F6,0x4F39,0x4F32,0x4FAB,0x5056,
  0xE0FB,0x502E,0x50A6,0x50D9,0x510E,0x50ED,0x5101,0x51F4,
  0x521F,0x5260,0x5257,0x529A,0x52D1,0x52E0,0x52E1,0x51D3,
  0x51DF,0x7546,0x51FE,0x5332,0x532C,0x5333,0x53AB,0x53AA,
  0x9F8E,0x5469,0x549C,0x53DA,0x6ACA,0x5573,0xE119,0x35D6,
  0xE11B,0x5611,0x564D,0xE11E,0x5654,0x35F3,0xE121,0x5746,
  0x577A,0x5767,0x583A,0x57E6,0x57DD,0x5840,0xE129,0x5826,
  0x58DC,0x59B7,0x59D9,0x5C20,0xE12F,0x5CD1,0x5CE9,0x5D46,
  0x5D8E,0xE134,0x5DF5,0x5E0B,0x5E12,0x5E2E,0x5E5E,
  0xE13A,0x5F4D,0x7A7D,0x5BC3,0x7ABB,0xE13F,0xE140,0x5FA4,
  0x5FBA,0x5FBC,0xE144,0x6077,0x60A4,0x60B3,0x60FD,0x6130,
  0xE14A,0x619C,0x6159,0x617D,0x615C,0x637F,0x61E2,0x70D5,
  0x6239,0x6268,0x6285,0x6282,0x62A6,0x62D5,0x6364,0x6335,
  0x6490,0x3A5C,0x6648,0x6667,0x671E,0x6803,0x67AC,0x67F9,
  0x68B6,0x692C,0x6901,0x6900,0x68CA,0x6973,0x6980,0x693E,
  0xE16A,0x69B2,0x69C0,0x698A,0x69FA,0x69E9,0x6AB2,0x6A52,
  0x6A9D,0x6B1D,0x6B52,0x6BFA,0x3CD1,0x6CCE,0x6E4F,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x6DB9,0x6F44,0xE17B,0x6FDA,0x7081,0x79CC,0x7134,
  0x3DCC,0x7176,0xE182,0xE183,0x7215,0x7250,0x7287,0x732C,
  0x72B2,0x72E2,0x7302,0x7348,0x7328,0x734F,0x7371,0x6585,
  0xE190,0x745D,0x7468,0x751E,0x7553,0x757A,0x76A1,0x76CC,
  0x7724,0x772B,0x4065,0x7853,0x78D3,0x78D8,0x9D7E,0x78AF,
  0xE1A0,0x6142,0x79A9,0x9C3A,0x79D4,0xE1A5,0x7A2D,0x7A3E,
  0x7A49,0x7ADD,0x7ADA,0x75C3,0x7607,0x7602,0xE1AE,0x7667,
  0x766F,0x5620,0x8A67,0x9F17,0x7B1F,0x7B92,0x7BA3,0x7BCF,
  0xE1B8,0x7BFC,0x7C42,0x7C51,0x7C5D,0x7C70,0x7C7E,0x7C86,
  0x7C83,0x7CAC,0x7CC7,0x7CC2,0xE1C4,0x7CDA,0xE1C6,0x7D4D,
  0x7D5A,0x7DF5,0x7E27,0x7E6E,0x9E95,0x5273,0x801D,0x8062,
  0x8063,0x8066,0x805B,0x80A6,0x8103,0x9E81,0x81C8,
  0xE1D7,0x8FA0,0x81F6,0x821A,0xE1DB,0x8771,0x87A9,0x878C,
  0x9E9E,0x87C1,0x9E1C,0xE1E2,0x87D6,0x87F5,0x880F,0x8818,
  0x882D,0x8842,0x8845,0x9C35,0x886E,0x88AA,0x88A0,0x629D,
  0x8943,0x894D,0x7172,0x885E,0xE1F3,0x82FD,0x44B7,0x82D0,
  0x8385,0x9D02,0x9F69,0x8420,0xE1FB,0x84DA,0x84AD,0x44FB,
  0x854B,0xE200,0x8602,0x8610,0x63D1,0x8989,0x898A,0x8994,
  0x9C45,0x89BC,0x8A7E,0x8A49,0x8B0C,0x8B43,0x8B81,0x8B4C,
  0xE20F,0x8CAD,0x8CEB,0x8CF7,0x8D0C,0x8D82,0x8DA6,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x8DD4,0x8E28,0x8E4F,0x8E77,0x8E75,0x8EA7,0x8F19,
  0xE21D,0x8F5C,0x9D44,0x90C4,0x9151,0xE222,0x915C,0x9159,
  0x9167,0x917C,0x918E,0x91BB,0x9EA8,0x9056,0x904C,0x91FE,
  0x9262,0x92BE,0x936B,0x936E,0x93BA,0x9427,0x9597,0x95A7,
  0xE235,0x9638,0xE237,0x9683,0x9696,0x9681,0x96BD,0x9703,
  0x9721,0x9731,0x975F,0x979F,0x97B4,0x97B8,0x97BA,0x97BE,
  0x97C8,0x9EBF,0x981F,0x982E,0x9FA5,0x9847,0x984B,0x9866,
  0x986C,0x98B4,0x9F5A,0x98DC,0x98E6,0x9942,0x9939,0x993B,
  0x9F53,0x994A,0x9F45,0x4B7E,0x99DA,0x7AC8,0x9ABA,0x9ABD,
  0x9F02,0x9B2A,0xE25F,0x9B2D,0x9AE2,0x9B02,0x9AFF,0x4C07,
  0x9B09,0x4C04,0x4C3B,0x9B8F,0x9B9D,0x9BB0,0x9C0C,0x9C15,
  0x9C0A,0x9BFF,0x9C2E,0x80E8,0x80E9,0x80EC,0x810E,
  0x6C39,0x4E6A,0x9641,0x58F2,0x7962,0x6822,0xE27A,0xE27B,
  0x8107,0x57D7,0x44EA,0x6435,0x8534,0x40DF,0xE282,0x691A,
  0x9C02,0x75B1,0x83D3,0x7171,0x6A0B,0xE289,0x6A7A,0x9AF4,
  0xE28C,0xE28D,0x77B9,0x6530,0x6D96,0x5637,0x6725,0x6A2B,
  0x7D5D,0x9061,0x4E98,0x7CA6,0x7B39,0xE299,0x5975,0x36C7,
  0x707F,0xE29D,0x6E8B,0xE29F,0xE2A0,0x975D,0x92D0,0x5754,
  0xE2A4,0x3ED9,0xE2A6,0xE2A7,0x6199,0x7460,0x713F,0x792E,
  0x5A96,0x9348,0x668E,0x4FFD,0x9341,0x3654,0x5D75,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x701E,0x657B,0x708D,0x5ECD,0xE2B7,0x60A7,0x7AB0,
  0x5F63,0xE2BB,0x73F7,0xE2BD,0x7468,0x75B4,0xE2C0,0x9B69,
  0x00BD,0x2153,0x2154,0x00BC,0x00BE,0x2155,0x2156,0x2157,
  0x2158,0x2159,0x215A,0x8692,0x86A0,0x86AD,0x86B2,0x87A5,
  0x87B1,0x215B,0x215C,0x215D,0x215E,0x87DA,0x884F,0x8860,
  0x8887,0x888F,0x8890,0x88E6,0x88FF,0x8900,0x8924,0x8947,
  0x8954,0x8965,0x8980,0x8991,0x8A1C,0x8A29,0x8A2B,0x8A38,
  0x8A3D,0x2312,0x8A90,0x8A94,0x8A9C,0x8AA9,0x8AAF,0x8AB4,
  0x8AEA,0x8B1F,0x2030,0x8B3F,0x8B4D,0x8B5E,0x8B62,0x8B69,
  0x8B9B,0x8C51,0x8C9B,0x8C9F,0x8CD4,0x8CD6,0x8112,0x8131,
  0x8136,0x815F,0x816D,0x817D,0x8193,0x81AA,0x81B8,0x81C1,
  0x8229,0x822D,0x822E,0x823E,0x8262,0x826A,0x8288
};
unsigned short big5uao_a3_uni_byte[29] = { /* a3e2 - a3fe */
  0xf849, 0xf84a, 0xf84b, 0xf84c, 0xf84d, 0xf84e, 0xf84f, 0xf850,
  0xf851, 0xf852, 0xf853, 0xf854, 0xf855, 0xf856, 0xf857, 0xf858,
  0xf859, 0xf85a, 0xf85b, 0xf85c, 0xf85d, 0xf85e, 0xf85f, 0xf860,
  0xf861, 0xf862, 0xf863, 0xf864, 0xf865
};

unsigned short big5_uao_otbl_patch[] = { /* dbl assign fix */
0xA246,0x00A2, 0xA247,0x00A3, 0xA244,0x00A5, 0x7C20,0x00A6,
0x6320,0x00A9, 0x2D20,0x00AD, 0x3220,0x00B2, 0x3320,0x00B3,
0xA1AC,0x00B4, 0xA367,0x00B5, 0x3120,0x00B9, 0x5920,0x00DD,
0x7920,0x00FD, 0xA277,0x2015, 0xA1FC,0x2016, 0xA1CF,0x2020,
0xA145,0x2022, 0xA3BB,0x2024, 0xA1B2,0x2033, 0xA1C3,0x203E,
0xA1F6,0x2190, 0xA1F4,0x2191, 0xA1F7,0x2192, 0xA1F5,0x2193,
0x9D4A,0x21E6, 0xC876,0x21E7, 0x9D49,0x21E8, 0x9D4C,0x21E9,
0xA1BE,0x2207, 0xA353,0x220F, 0xA355,0x2211, 0xA242,0x2216,
0xA258,0x2218, 0xA34E,0x2227, 0xA2E4,0x2228, 0xA147,0x2236,
0xA1DD,0x2263, 0xA15B,0x2307, 0xC6A1,0x2460, 0xC6A2,0x2461,
0xC6A3,0x2462, 0xC6A4,0x2463, 0xC6A5,0x2464, 0xC6A6,0x2465,
0xC6A7,0x2466, 0xC6A8,0x2467, 0xC6A9,0x2468, 0xC6AA,0x2469,
0xC6AB,0x2474, 0xC6AC,0x2475, 0xC6AD,0x2476, 0xC6AE,0x2477,
0xC6AF,0x2478, 0xC6B0,0x2479, 0xC6B1,0x247A, 0xC6B2,0x247B,
0xC6B3,0x247C, 0xC6B4,0x247D, 0xA14C,0x2504, 0xA14C,0x2505,
0xA14A,0x2506, 0xA14A,0x2507, 0xA14B,0x2508, 0xA14B,0x2509,
0xA155,0x250A, 0xA155,0x250B, 0xA27A,0x250D, 0xA27A,0x250E,
0xA27A,0x250F, 0xA27B,0x2511, 0xA27B,0x2512, 0xA27B,0x2513,
0xA27C,0x2514, 0xA27C,0x2515, 0xA27C,0x2516, 0xA27C,0x2517,
0xA27D,0x2519, 0xA27D,0x251A, 0xA27D,0x251B, 0xA275,0x251D,
0xA275,0x251E, 0xA275,0x251F, 0xA275,0x2520, 0xA275,0x2521,
0xA275,0x2522, 0xA275,0x2523, 0xA274,0x2525, 0xA274,0x2526,
0xA274,0x2527, 0xA274,0x2528, 0xA274,0x2529, 0xA274,0x252A,
0xA274,0x252B, 0xA273,0x252D, 0xA273,0x252E, 0xA273,0x252F,
0xA273,0x2530, 0xA273,0x2531, 0xA273,0x2532, 0xA273,0x2533,
0xA272,0x2535, 0xA272,0x2536, 0xA272,0x2537, 0xA272,0x2538,
0xA272,0x2539, 0xA272,0x253A, 0xA272,0x253B, 0xA271,0x253D,
0xA271,0x253E, 0xA271,0x253F, 0xA271,0x2540, 0xA271,0x2541,
0xA271,0x2542, 0xA271,0x2543, 0xA271,0x2544, 0xA271,0x2545,
0xA271,0x2546, 0xA271,0x2547, 0xA271,0x2548, 0xA271,0x2549,
0xA271,0x254A, 0xA271,0x254B, 0xF9F9,0x2550, 0xF9E9,0x255E,
0xF9EB,0x2561, 0xF9EA,0x256A, 0xA1B3,0x25CB, 0xA1B3,0x25EF,
0xA1F3,0x2609, 0xA1F2,0x2641, 0xA1F1,0x2642, 0xA2EA,0x266D,
0xA1AD,0x266F, 0x9841,0x2776, 0x9842,0x2777, 0x9843,0x2778,
0x9844,0x2779, 0x9845,0x277A, 0x9846,0x277B, 0x9847,0x277C,
0x9848,0x277D, 0x9849,0x277E, 0x984A,0x277F, 0xC6A1,0x2780,
0xC6A2,0x2781, 0xC6A3,0x2782, 0xC6A4,0x2783, 0xC6A5,0x2784,
0xC6A6,0x2785, 0xC6A7,0x2786, 0xC6A8,0x2787, 0xC6A9,0x2788,
0xC6AA,0x2789, 0x91C9,0x2EA4, 0xC6BF,0x2F02, 0xC6C0,0x2F03,
0xC6C1,0x2F05, 0xC6C2,0x2F07, 0xC6C3,0x2F0C, 0xC6C4,0x2F0D,
0xC6C5,0x2F0E, 0xC6C6,0x2F13, 0xC6C7,0x2F16, 0xC6C8,0x2F19,
0xC6C9,0x2F1B, 0xC6CA,0x2F22, 0xC6CB,0x2F27, 0xC6CC,0x2F2E,
0xC6CD,0x2F33, 0xC6CE,0x2F34, 0xC6CF,0x2F35, 0xC6D0,0x2F39,
0xC6D1,0x2F3A, 0xC6D2,0x2F41, 0xC6D3,0x2F46, 0xC6D4,0x2F67,
0xC6D5,0x2F68, 0xC6D6,0x2FA1, 0xC6D7,0x2FAA, 0xA1B2,0x3003,
0xA1E3,0x301C, 0xA1CA,0x3030, 0xA2CC,0x3038, 0xA2CD,0x3039,
0xA2CE,0x303A, 0xA440,0x3192, 0xA447,0x3193, 0xA454,0x3194,
0xA57C,0x3195, 0xA457,0x3196, 0xA4A4,0x3197, 0xA455,0x3198,
0xA5D2,0x3199, 0xA441,0x319A, 0xA4FE,0x319B, 0xA442,0x319C,
0xA4D1,0x319D, 0xA661,0x319E, 0xA448,0x319F, 0xA4EB,0x322A,
0xA4F5,0x322B, 0xA4F4,0x322C, 0xA4EC,0x322D, 0xAAF7,0x322E,
0xA467,0x322F, 0xA4E9,0x3230, 0x99FD,0x3231, 0xAAC0,0x3233,
0xA657,0x3234, 0xAF53,0x3235, 0xB05D,0x3236, 0xAFAC,0x3237,
0xB3D2,0x3238, 0xA54E,0x3239, 0xA949,0x323A, 0xBEC7,0x323B,
0xBACA,0x323C, 0xA5F8,0x323D, 0xB8EA,0x323E, 0xA8F3,0x323F,
0xB2BD,0x3240, 0xA5F0,0x3241, 0xA6DB,0x3242, 0xA6DC,0x3243,
0xA440,0x3280, 0xA447,0x3281, 0xA454,0x3282, 0xA57C,0x3283,
0xA4AD,0x3284, 0xA4BB,0x3285, 0xA443,0x3286, 0xA44B,0x3287,
0xA445,0x3288, 0xA451,0x3289, 0xA4EB,0x328A, 0xA4F5,0x328B,
0xA4F4,0x328C, 0xA4EC,0x328D, 0xAAF7,0x328E, 0xA467,0x328F,
0xA4E9,0x3290, 0xAEE8,0x3291, 0xA6B3,0x3292, 0xAAC0,0x3293,
0xA657,0x3294, 0xAF53,0x3295, 0xB05D,0x3296, 0xAFAC,0x3297,
0xB3D2,0x3298, 0xAFB5,0x3299, 0xA86B,0x329A, 0xA46B,0x329B,
0xBE41,0x329C, 0xC075,0x329D, 0xA64C,0x329E, 0xAA60,0x329F,
0xB6B5,0x32A0, 0xA5F0,0x32A1, 0xBC67,0x32A2, 0xA457,0x32A4,
0xA4A4,0x32A5, 0xA455,0x32A6, 0xA5AA,0x32A7, 0xA56B,0x32A8,
0xC2E5,0x32A9, 0xA976,0x32AA, 0xBEC7,0x32AB, 0xBACA,0x32AC,
0xA5F8,0x32AD, 0xB8EA,0x32AE, 0xA8F3,0x32AF, 0xA95D,0x32B0,
0x4B4B,0x33CD, 0x5048,0x33D7, 0x91E0,0x3404, 0xA0A2,0x3451,
0xFB44,0x34DF, 0x95B8,0x3551, 0xA048,0x35CE, 0xA04C,0x35D2,
0xFBDF,0x35D6, 0xFBE5,0x35F3, 0xFB6F,0x35FE, 0x9542,0x362D,
0xFE7D,0x3654, 0xFE67,0x36C7, 0x955E,0x39B8, 0x95DE,0x3A2A,
0x95C7,0x3A57, 0xFC61,0x3A5C, 0x95C9,0x3BED, 0xFC7C,0x3CD1,
0xFCA8,0x3DCC, 0xFE71,0x3ED9, 0xFCC2,0x4065, 0xFE4D,0x40DF,
0x96AD,0x4436, 0x9CD3,0x4491, 0xFD5E,0x44B7, 0xFE4A,0x44EA,
0xFD67,0x44FB, 0xFBB0,0x460F, 0xFB7D,0x4989, 0xFDE3,0x4B7E,
0xFDF1,0x4C04, 0xFDEF,0x4C07, 0xFDF2,0x4C3B, 0xFB45,0x4C7D,
0x93E5,0x4E21, 0x9CDF,0x4E5A, 0x85AF,0x4E71, 0x835C,0x4E89,
0x85D1,0x4F1A, 0x8DB9,0x4FE3, 0xB9B0,0x50ED, 0x8358,0x5188,
0x87C0,0x5199, 0x834C,0x51B2, 0x834B,0x51B3, 0x845B,0x51C9,
0x84EE,0x51D1, 0x8276,0x5265, 0x89CA,0x52B1, 0x83F1,0x533A,
0x8B4B,0x533B, 0x836A,0x5374, 0x83F2,0x53C2, 0x8B5A,0x53CC,
0x8342,0x53CE, 0x8CD4,0x53E0, 0x8641,0x53F7, 0x89CC,0x5413,
0x8CB7,0x54CD, 0x82B3,0x5618, 0x8D51,0x5631, 0x83F6,0x56FD,
0x87B8,0x5815, 0x9459,0x5840, 0x95CD,0x5869, 0x8347,0x58EE,
0x8A52,0x58F0, 0x93B3,0x58F2, 0x83FA,0x591F, 0x85C4,0x5965,
0x88D4,0x5B66, 0x8BF3,0x5B9D, 0x86C0,0x5BDD, 0x86BA,0x5BFF,
0x86E9,0x5C3D, 0x8357,0x5C4A, 0x8C70,0x5C5E, 0x83B3,0x5CE1,
0x89D6,0x5E2E, 0x85E5,0x5F53, 0xC255,0x5F5E, 0xE975,0x5FBC,
0x8CF6,0x604B, 0x86CC,0x60E8, 0x88E3,0x62C5, 0xA9F0,0x62CE,
0x83B9,0x631F, 0xDDAF,0x6435, 0x8C74,0x643A, 0xBCB5,0x6490,
0x87DB,0x6570, 0xE5C0,0x657B, 0x8ACA,0x65AD, 0x8AF6,0x65E7,
0x8454,0x663C, 0x83BB,0x664B, 0x8457,0x6761, 0x8353,0x6765,
0x87E0,0x67A2, 0x9451,0x6803, 0x87E2,0x697C, 0x9445,0x698A,
0x9440,0x6A2B, 0x947E,0x6A7A, 0x87E6,0x6B27, 0x87E8,0x6BB4,
0x836E,0x6C79, 0x8D6F,0x6E7E, 0x85DA,0x6E7F, 0x86D7,0x6EDE,
0x90B9,0x6F5C, 0x88F9,0x706F, 0x89F2,0x707F, 0x8ABB,0x70B9,
0xDE73,0x7172, 0x835D,0x72B6, 0x88FC,0x72EC, 0x83C0,0x72ED,
0x8BA9,0x743C, 0x84F8,0x753B, 0xFB5C,0x75B4, 0x84FB,0x76D7,
0x8BAC,0x788D, 0x8AE0,0x793C, 0x8FBE,0x7962, 0x8270,0x7977,
0x8277,0x7984, 0x85B8,0x79EF, 0x86EF,0x79F0, 0x8CFA,0x7A83,
0x8AEA,0x7CAE, 0x8CE8,0x7E6E, 0x8A57,0x80C6, 0x83D1,0x8109,
0x85F7,0x811A, 0x8748,0x8385, 0x827E,0x85AE, 0x8552,0x865A,
0x824C,0x86CE, 0x8D75,0x8845, 0x847C,0x886E, 0x90BA,0x889C,
0xD7B6,0x88AA, 0x8645,0x88C5, 0x8CA9,0x8A89, 0x8350,0x8D1D,
0x8873,0x8DF5, 0x8249,0x8EAF, 0x8351,0x8F66, 0x8BC9,0x8F9E,
0x95F1,0x9262, 0xE862,0x92D0, 0x8A42,0x9546, 0x8364,0x95E8,
0xDCA2,0x9683, 0x8679,0x96BD, 0x83E8,0x9965, 0x84BF,0x9E1F,
0x84C1,0x9EA6, 0x94FA,0x9EBF, 0xFA64,0xE024, 0xFA65,0xE025,
0xFA66,0xE026, 0xFA67,0xE027, 0xFA68,0xE028, 0xFA69,0xE029,
0xFA6A,0xE02A, 0xFA6B,0xE02B, 0xFA6C,0xE02C, 0xFA6D,0xE02D,
0xFA6E,0xE02E, 0xFA6F,0xE02F, 0xFA70,0xE030, 0xFA71,0xE031,
0xFA72,0xE032, 0xFA73,0xE033, 0xFA74,0xE034, 0xFA75,0xE035,
0xFA76,0xE036, 0xFA77,0xE037, 0xFA78,0xE038, 0xFA79,0xE039,
0xFA7A,0xE03A, 0xFA7B,0xE03B, 0xFA7C,0xE03C, 0xFA7D,0xE03D,
0xFA7E,0xE03E, 0xFAA1,0xE03F, 0xFAA2,0xE040, 0xFAA3,0xE041,
0xFAA4,0xE042, 0xFAA5,0xE043, 0xFAA6,0xE044, 0xFAA7,0xE045,
0xFAA8,0xE046, 0xFAA9,0xE047, 0xFAAA,0xE048, 0xFAAB,0xE049,
0xFAAC,0xE04A, 0xFAAD,0xE04B, 0xFAAE,0xE04C, 0xFAAF,0xE04D,
0xFAB0,0xE04E, 0xFAB1,0xE04F, 0xFAB2,0xE050, 0xFAB3,0xE051,
0xFAB4,0xE052, 0xFAB5,0xE053, 0xFAB6,0xE054, 0xFAB7,0xE055,
0xFAB8,0xE056, 0xFAB9,0xE057, 0xFABA,0xE058, 0xFABB,0xE059,
0xFABC,0xE05A, 0xFABD,0xE05B, 0xFABE,0xE05C, 0xFABF,0xE05D,
0xFAC0,0xE05E, 0xFAC1,0xE05F, 0xFAC2,0xE060, 0xFAC3,0xE061,
0xFAC4,0xE062, 0xFAC5,0xE063, 0xFAC6,0xE064, 0xFAC7,0xE065,
0xFAC8,0xE066, 0xFAC9,0xE067, 0xFACA,0xE068, 0xFACB,0xE069,
0xFACC,0xE06A, 0xFACD,0xE06B, 0xFACE,0xE06C, 0xFACF,0xE06D,
0xFAD0,0xE06E, 0xFAD1,0xE06F, 0xFAD2,0xE070, 0xFAD3,0xE071,
0xFAD4,0xE072, 0xFAD5,0xE073, 0xFAD6,0xE074, 0xFAD7,0xE075,
0xFAD8,0xE076, 0xFAD9,0xE077, 0xFADA,0xE078, 0xFADB,0xE079,
0xFADC,0xE07A, 0xFADD,0xE07B, 0xFADE,0xE07C, 0xFADF,0xE07D,
0xFAE0,0xE07E, 0xFAE1,0xE07F, 0xFAE2,0xE080, 0xFAE3,0xE081,
0xFAE4,0xE082, 0xFAE5,0xE083, 0xFAE6,0xE084, 0xFAE7,0xE085,
0xFAE8,0xE086, 0xFAE9,0xE087, 0xFAEA,0xE088, 0xFAEB,0xE089,
0xFAEC,0xE08A, 0xFAED,0xE08B, 0xFAEE,0xE08C, 0xFAEF,0xE08D,
0xFAF0,0xE08E, 0xFAF1,0xE08F, 0xFAF2,0xE090, 0xFAF3,0xE091,
0xFAF4,0xE092, 0xFAF5,0xE093, 0xFAF6,0xE094, 0xFAF7,0xE095,
0xFAF8,0xE096, 0xFAF9,0xE097, 0xFAFA,0xE098, 0xFAFB,0xE099,
0xFAFC,0xE09A, 0xFAFD,0xE09B, 0xFAFE,0xE09C, 0xFB40,0xE09D,
0xFB41,0xE09E, 0xFB42,0xE09F, 0xFB43,0xE0A0, 0xFB44,0xE0A1,
0xFB45,0xE0A2, 0xFB46,0xE0A3, 0xFB4A,0xE0A7, 0xFB4C,0xE0A9,
0xFB4D,0xE0AA, 0xFB4E,0xE0AB, 0xFB52,0xE0AF, 0xFB53,0xE0B0,
0xFB55,0xE0B2, 0xFB56,0xE0B3, 0xFB57,0xE0B4, 0xFB58,0xE0B5,
0xFB5A,0xE0B7, 0xFB5B,0xE0B8, 0xFB5C,0xE0B9, 0xFB5D,0xE0BA,
0xFB5E,0xE0BB, 0xFB5F,0xE0BC, 0xFB63,0xE0C0, 0xFB64,0xE0C1,
0xFB65,0xE0C2, 0xFB66,0xE0C3, 0xFB67,0xE0C4, 0xFB69,0xE0C6,
0xFB6A,0xE0C7, 0xFB6B,0xE0C8, 0xFB6C,0xE0C9, 0xFB6D,0xE0CA,
0xFB6E,0xE0CB, 0xFB6F,0xE0CC, 0xFB70,0xE0CD, 0xFB72,0xE0CF,
0xFB73,0xE0D0, 0xFB76,0xE0D3, 0xFB78,0xE0D5, 0xFB7A,0xE0D7,
0xFB7C,0xE0D9, 0xFB7D,0xE0DA, 0xFB7E,0xE0DB, 0xFBA1,0xE0DC,
0xFBA2,0xE0DD, 0xFBA3,0xE0DE, 0xFBA5,0xE0E0, 0xFBA6,0xE0E1,
0xFBA7,0xE0E2, 0xFBA8,0xE0E3, 0xFBA9,0xE0E4, 0xFBAA,0xE0E5,
0xFBAB,0xE0E6, 0xFBAD,0xE0E8, 0xFBAE,0xE0E9, 0xFBAF,0xE0EA,
0xFBB0,0xE0EB, 0xFBB2,0xE0ED, 0xFBB3,0xE0EE, 0xFBB4,0xE0EF,
0xFBB5,0xE0F0, 0xFBB6,0xE0F1, 0xFBB7,0xE0F2, 0xFBB8,0xE0F3,
0xFBBA,0xE0F5, 0xFBBC,0xE0F7, 0xFBBD,0xE0F8, 0xFBBE,0xE0F9,
0xFBBF,0xE0FA, 0xFBC1,0xE0FC, 0xFBC2,0xE0FD, 0xFBC3,0xE0FE,
0xFBC4,0xE0FF, 0xFBC5,0xE100, 0xFBC6,0xE101, 0xFBC7,0xE102,
0xFBC8,0xE103, 0xFBC9,0xE104, 0xFBCA,0xE105, 0xFBCB,0xE106,
0xFBCC,0xE107, 0xFBCD,0xE108, 0xFBCE,0xE109, 0xFBCF,0xE10A,
0xFBD0,0xE10B, 0xFBD1,0xE10C, 0xFBD2,0xE10D, 0xFBD3,0xE10E,
0xFBD4,0xE10F, 0xFBD5,0xE110, 0xFBD6,0xE111, 0xFBD7,0xE112,
0xFBD8,0xE113, 0xFBD9,0xE114, 0xFBDA,0xE115, 0xFBDB,0xE116,
0xFBDC,0xE117, 0xFBDD,0xE118, 0xFBDF,0xE11A, 0xFBE1,0xE11C,
0xFBE2,0xE11D, 0xFBE4,0xE11F, 0xFBE5,0xE120, 0xFBE7,0xE122,
0xFBE8,0xE123, 0xFBE9,0xE124, 0xFBEA,0xE125, 0xFBEB,0xE126,
0xFBEC,0xE127, 0xFBED,0xE128, 0xFBEF,0xE12A, 0xFBF0,0xE12B,
0xFBF1,0xE12C, 0xFBF2,0xE12D, 0xFBF3,0xE12E, 0xFBF5,0xE130,
0xFBF6,0xE131, 0xFBF7,0xE132, 0xFBF8,0xE133, 0xFBFA,0xE135,
0xFBFB,0xE136, 0xFBFC,0xE137, 0xFBFD,0xE138, 0xFBFE,0xE139,
0xFC41,0xE13B, 0xFC42,0xE13C, 0xFC43,0xE13D, 0xFC44,0xE13E,
0xFC47,0xE141, 0xFC48,0xE142, 0xFC49,0xE143, 0xFC4B,0xE145,
0xFC4C,0xE146, 0xFC4D,0xE147, 0xFC4E,0xE148, 0xFC4F,0xE149,
0xFC51,0xE14B, 0xFC52,0xE14C, 0xFC53,0xE14D, 0xFC54,0xE14E,
0xFC55,0xE14F, 0xFC56,0xE150, 0xFC57,0xE151, 0xFC58,0xE152,
0xFC59,0xE153, 0xFC5A,0xE154, 0xFC5B,0xE155, 0xFC5C,0xE156,
0xFC5D,0xE157, 0xFC5E,0xE158, 0xFC5F,0xE159, 0xFC60,0xE15A,
0xFC61,0xE15B, 0xFC62,0xE15C, 0xFC63,0xE15D, 0xFC64,0xE15E,
0xFC65,0xE15F, 0xFC66,0xE160, 0xFC67,0xE161, 0xFC68,0xE162,
0xFC69,0xE163, 0xFC6A,0xE164, 0xFC6B,0xE165, 0xFC6C,0xE166,
0xFC6D,0xE167, 0xFC6E,0xE168, 0xFC6F,0xE169, 0xFC71,0xE16B,
0xFC72,0xE16C, 0xFC73,0xE16D, 0xFC74,0xE16E, 0xFC75,0xE16F,
0xFC76,0xE170, 0xFC77,0xE171, 0xFC78,0xE172, 0xFC79,0xE173,
0xFC7A,0xE174, 0xFC7B,0xE175, 0xFC7C,0xE176, 0xFC7D,0xE177,
0xFC7E,0xE178, 0xFCA1,0xE179, 0xFCA2,0xE17A, 0xFCA4,0xE17C,
0xFCA5,0xE17D, 0xFCA6,0xE17E, 0xFCA7,0xE17F, 0xFCA8,0xE180,
0xFCA9,0xE181, 0xFCAC,0xE184, 0xFCAD,0xE185, 0xFCAE,0xE186,
0xFCAF,0xE187, 0xFCB0,0xE188, 0xFCB1,0xE189, 0xFCB2,0xE18A,
0xFCB3,0xE18B, 0xFCB4,0xE18C, 0xFCB5,0xE18D, 0xFCB6,0xE18E,
0xFCB7,0xE18F, 0xFCB9,0xE191, 0xFCBA,0xE192, 0xFCBB,0xE193,
0xFCBC,0xE194, 0xFCBD,0xE195, 0xFCBE,0xE196, 0xFCBF,0xE197,
0xFCC0,0xE198, 0xFCC1,0xE199, 0xFCC2,0xE19A, 0xFCC3,0xE19B,
0xFCC4,0xE19C, 0xFCC5,0xE19D, 0xFCC6,0xE19E, 0xFCC7,0xE19F,
0xFCC9,0xE1A1, 0xFCCA,0xE1A2, 0xFCCB,0xE1A3, 0xFCCC,0xE1A4,
0xFCCE,0xE1A6, 0xFCCF,0xE1A7, 0xFCD0,0xE1A8, 0xFCD1,0xE1A9,
0xFCD2,0xE1AA, 0xFCD3,0xE1AB, 0xFCD4,0xE1AC, 0xFCD5,0xE1AD,
0xFCD7,0xE1AF, 0xFCD8,0xE1B0, 0xFCD9,0xE1B1, 0xFCDA,0xE1B2,
0xFCDB,0xE1B3, 0xFCDC,0xE1B4, 0xFCDD,0xE1B5, 0xFCDE,0xE1B6,
0xFCDF,0xE1B7, 0xFCE1,0xE1B9, 0xFCE2,0xE1BA, 0xFCE3,0xE1BB,
0xFCE4,0xE1BC, 0xFCE5,0xE1BD, 0xFCE6,0xE1BE, 0xFCE7,0xE1BF,
0xFCE8,0xE1C0, 0xFCE9,0xE1C1, 0xFCEA,0xE1C2, 0xFCEB,0xE1C3,
0xFCED,0xE1C5, 0xFCEF,0xE1C7, 0xFCF0,0xE1C8, 0xFCF1,0xE1C9,
0xFCF2,0xE1CA, 0xFCF3,0xE1CB, 0xFCF4,0xE1CC, 0xFCF5,0xE1CD,
0xFCF6,0xE1CE, 0xFCF7,0xE1CF, 0xFCF8,0xE1D0, 0xFCF9,0xE1D1,
0xFCFA,0xE1D2, 0xFCFB,0xE1D3, 0xFCFC,0xE1D4, 0xFCFD,0xE1D5,
0xFCFE,0xE1D6, 0xFD41,0xE1D8, 0xFD42,0xE1D9, 0xFD43,0xE1DA,
0xFD45,0xE1DC, 0xFD46,0xE1DD, 0xFD47,0xE1DE, 0xFD48,0xE1DF,
0xFD49,0xE1E0, 0xFD4A,0xE1E1, 0xFD4C,0xE1E3, 0xFD4D,0xE1E4,
0xFD4E,0xE1E5, 0xFD4F,0xE1E6, 0xFD50,0xE1E7, 0xFD51,0xE1E8,
0xFD52,0xE1E9, 0xFD53,0xE1EA, 0xFD54,0xE1EB, 0xFD55,0xE1EC,
0xFD56,0xE1ED, 0xFD57,0xE1EE, 0xFD58,0xE1EF, 0xFD59,0xE1F0,
0xFD5A,0xE1F1, 0xFD5B,0xE1F2, 0xFD5D,0xE1F4, 0xFD5E,0xE1F5,
0xFD5F,0xE1F6, 0xFD60,0xE1F7, 0xFD61,0xE1F8, 0xFD62,0xE1F9,
0xFD63,0xE1FA, 0xFD65,0xE1FC, 0xFD66,0xE1FD, 0xFD67,0xE1FE,
0xFD68,0xE1FF, 0xFD6A,0xE201, 0xFD6B,0xE202, 0xFD6C,0xE203,
0xFD6D,0xE204, 0xFD6E,0xE205, 0xFD6F,0xE206, 0xFD70,0xE207,
0xFD71,0xE208, 0xFD72,0xE209, 0xFD73,0xE20A, 0xFD74,0xE20B,
0xFD75,0xE20C, 0xFD76,0xE20D, 0xFD77,0xE20E, 0xFD79,0xE210,
0xFD7A,0xE211, 0xFD7B,0xE212, 0xFD7C,0xE213, 0xFD7D,0xE214,
0xFD7E,0xE215, 0xFDA1,0xE216, 0xFDA2,0xE217, 0xFDA3,0xE218,
0xFDA4,0xE219, 0xFDA5,0xE21A, 0xFDA6,0xE21B, 0xFDA7,0xE21C,
0xFDA9,0xE21E, 0xFDAA,0xE21F, 0xFDAB,0xE220, 0xFDAC,0xE221,
0xFDAE,0xE223, 0xFDAF,0xE224, 0xFDB0,0xE225, 0xFDB1,0xE226,
0xFDB2,0xE227, 0xFDB3,0xE228, 0xFDB4,0xE229, 0xFDB5,0xE22A,
0xFDB6,0xE22B, 0xFDB7,0xE22C, 0xFDB8,0xE22D, 0xFDB9,0xE22E,
0xFDBA,0xE22F, 0xFDBB,0xE230, 0xFDBC,0xE231, 0xFDBD,0xE232,
0xFDBE,0xE233, 0xFDBF,0xE234, 0xFDC1,0xE236, 0xFDC3,0xE238,
0xFDC4,0xE239, 0xFDC5,0xE23A, 0xFDC6,0xE23B, 0xFDC7,0xE23C,
0xFDC8,0xE23D, 0xFDC9,0xE23E, 0xFDCA,0xE23F, 0xFDCB,0xE240,
0xFDCC,0xE241, 0xFDCD,0xE242, 0xFDCE,0xE243, 0xFDCF,0xE244,
0xFDD0,0xE245, 0xFDD1,0xE246, 0xFDD2,0xE247, 0xFDD3,0xE248,
0xFDD4,0xE249, 0xFDD5,0xE24A, 0xFDD6,0xE24B, 0xFDD7,0xE24C,
0xFDD8,0xE24D, 0xFDD9,0xE24E, 0xFDDA,0xE24F, 0xFDDB,0xE250,
0xFDDC,0xE251, 0xFDDD,0xE252, 0xFDDE,0xE253, 0xFDDF,0xE254,
0xFDE0,0xE255, 0xFDE1,0xE256, 0xFDE2,0xE257, 0xFDE3,0xE258,
0xFDE4,0xE259, 0xFDE5,0xE25A, 0xFDE6,0xE25B, 0xFDE7,0xE25C,
0xFDE8,0xE25D, 0xFDE9,0xE25E, 0xFDEB,0xE260, 0xFDEC,0xE261,
0xFDED,0xE262, 0xFDEE,0xE263, 0xFDEF,0xE264, 0xFDF0,0xE265,
0xFDF1,0xE266, 0xFDF2,0xE267, 0xFDF3,0xE268, 0xFDF4,0xE269,
0xFDF5,0xE26A, 0xFDF6,0xE26B, 0xFDF7,0xE26C, 0xFDF8,0xE26D,
0xFDF9,0xE26E, 0xFDFA,0xE26F, 0xFDFB,0xE270, 0xFDFC,0xE271,
0xFDFD,0xE272, 0xFDFE,0xE273, 0xFE40,0xE274, 0xFE41,0xE275,
0xFE42,0xE276, 0xFE43,0xE277, 0xFE44,0xE278, 0xFE45,0xE279,
0xFE48,0xE27C, 0xFE49,0xE27D, 0xFE4A,0xE27E, 0xFE4B,0xE27F,
0xFE4C,0xE280, 0xFE4D,0xE281, 0xFE4F,0xE283, 0xFE50,0xE284,
0xFE51,0xE285, 0xFE52,0xE286, 0xFE53,0xE287, 0xFE54,0xE288,
0xFE56,0xE28A, 0xFE57,0xE28B, 0xFE5A,0xE28E, 0xFE5B,0xE28F,
0xFE5C,0xE290, 0xFE5D,0xE291, 0xFE5E,0xE292, 0xFE5F,0xE293,
0xFE60,0xE294, 0xFE61,0xE295, 0xFE62,0xE296, 0xFE63,0xE297,
0xFE64,0xE298, 0xFE66,0xE29A, 0xFE67,0xE29B, 0xFE68,0xE29C,
0xFE6A,0xE29E, 0xFE6D,0xE2A1, 0xFE6E,0xE2A2, 0xFE6F,0xE2A3,
0xFE71,0xE2A5, 0xFE74,0xE2A8, 0xFE75,0xE2A9, 0xFE76,0xE2AA,
0xFE77,0xE2AB, 0xFE78,0xE2AC, 0xFE79,0xE2AD, 0xFE7A,0xE2AE,
0xFE7B,0xE2AF, 0xFE7C,0xE2B0, 0xFE7D,0xE2B1, 0xFE7E,0xE2B2,
0xFEA1,0xE2B3, 0xFEA2,0xE2B4, 0xFEA3,0xE2B5, 0xFEA4,0xE2B6,
0xFEA6,0xE2B8, 0xFEA7,0xE2B9, 0xFEA8,0xE2BA, 0xFEAA,0xE2BC,
0xFEAC,0xE2BE, 0xFEAD,0xE2BF, 0xFEAF,0xE2C1, 0xFEB0,0xE2C2,
0xFEB1,0xE2C3, 0xFEB2,0xE2C4, 0xFEB3,0xE2C5, 0xFEB4,0xE2C6,
0xFEB5,0xE2C7, 0xFEB6,0xE2C8, 0xFEB7,0xE2C9, 0xFEB8,0xE2CA,
0xFEB9,0xE2CB, 0xFEBA,0xE2CC, 0xFEBB,0xE2CD, 0xFEBC,0xE2CE,
0xFEBD,0xE2CF, 0xFEBE,0xE2D0, 0xFEBF,0xE2D1, 0xFEC0,0xE2D2,
0xFEC1,0xE2D3, 0xFEC2,0xE2D4, 0xFEC3,0xE2D5, 0xFEC4,0xE2D6,
0xFEC5,0xE2D7, 0xFEC6,0xE2D8, 0xFEC7,0xE2D9, 0xFEC8,0xE2DA,
0xFEC9,0xE2DB, 0xFECA,0xE2DC, 0xFECB,0xE2DD, 0xFECC,0xE2DE,
0xFECD,0xE2DF, 0xFECE,0xE2E0, 0xFECF,0xE2E1, 0xFED0,0xE2E2,
0xFED1,0xE2E3, 0xFED2,0xE2E4, 0xFED3,0xE2E5, 0xFED4,0xE2E6,
0xFED5,0xE2E7, 0xFED6,0xE2E8, 0xFED7,0xE2E9, 0xFED8,0xE2EA,
0xFED9,0xE2EB, 0xFEDA,0xE2EC, 0xFEDB,0xE2ED, 0xFEDC,0xE2EE,
0xFEDD,0xE2EF, 0xFEDE,0xE2F0, 0xFEDF,0xE2F1, 0xFEE0,0xE2F2,
0xFEE1,0xE2F3, 0xFEE2,0xE2F4, 0xFEE3,0xE2F5, 0xFEE4,0xE2F6,
0xFEE5,0xE2F7, 0xFEE6,0xE2F8, 0xFEE7,0xE2F9, 0xFEE8,0xE2FA,
0xFEE9,0xE2FB, 0xFEEA,0xE2FC, 0xFEEB,0xE2FD, 0xFEEC,0xE2FE,
0xFEED,0xE2FF, 0xFEEE,0xE300, 0xFEEF,0xE301, 0xFEF0,0xE302,
0xFEF1,0xE303, 0xFEF2,0xE304, 0xFEF3,0xE305, 0xFEF4,0xE306,
0xFEF5,0xE307, 0xFEF6,0xE308, 0xFEF7,0xE309, 0xFEF8,0xE30A,
0xFEF9,0xE30B, 0xFEFA,0xE30C, 0xFEFB,0xE30D, 0xFEFC,0xE30E,
0xFEFD,0xE30F, 0xFEFE,0xE310, 0x8E40,0xE311, 0x8E41,0xE312,
0x8E42,0xE313, 0x8E43,0xE314, 0x8E44,0xE315, 0x8E45,0xE316,
0x8E46,0xE317, 0x8E47,0xE318, 0x8E48,0xE319, 0x8E49,0xE31A,
0x8E4A,0xE31B, 0x8E4B,0xE31C, 0x8E4C,0xE31D, 0x8E4D,0xE31E,
0x8E4E,0xE31F, 0x8E4F,0xE320, 0x8E50,0xE321, 0x8E51,0xE322,
0x8E52,0xE323, 0x8E53,0xE324, 0x8E54,0xE325, 0x8E55,0xE326,
0x8E56,0xE327, 0x8E57,0xE328, 0x8E58,0xE329, 0x8E59,0xE32A,
0x8E5A,0xE32B, 0x8E5B,0xE32C, 0x8E5C,0xE32D, 0x8E5D,0xE32E,
0x8E5E,0xE32F, 0x8E5F,0xE330, 0x8E60,0xE331, 0x8E61,0xE332,
0x8E62,0xE333, 0x8E63,0xE334, 0x8E64,0xE335, 0x8E65,0xE336,
0x8E66,0xE337, 0x8E67,0xE338, 0x8E68,0xE339, 0x8E69,0xE33A,
0x8E6A,0xE33B, 0x8E6B,0xE33C, 0x8E6C,0xE33D, 0x8E6D,0xE33E,
0x8E6E,0xE33F, 0x8E6F,0xE340, 0x8E70,0xE341, 0x8E71,0xE342,
0x8E72,0xE343, 0x8E73,0xE344, 0x8E74,0xE345, 0x8E75,0xE346,
0x8E76,0xE347, 0x8E77,0xE348, 0x8E78,0xE349, 0x8E79,0xE34A,
0x8E7A,0xE34B, 0x8E7B,0xE34C, 0x8E7C,0xE34D, 0x8E7D,0xE34E,
0x8E7E,0xE34F, 0x8EA1,0xE350, 0x8EA2,0xE351, 0x8EA3,0xE352,
0x8EA4,0xE353, 0x8EA5,0xE354, 0x8EA6,0xE355, 0x8EA7,0xE356,
0x8EA8,0xE357, 0x8EA9,0xE358, 0x8EAA,0xE359, 0x8EAB,0xE35A,
0x8EAC,0xE35B, 0x8EAD,0xE35C, 0x8EAE,0xE35D, 0x8EAF,0xE35E,
0x8EB0,0xE35F, 0x8EB1,0xE360, 0x8EB2,0xE361, 0x8EB3,0xE362,
0x8EB4,0xE363, 0x8EB5,0xE364, 0x8EB6,0xE365, 0x8EB7,0xE366,
0x8EB8,0xE367, 0x8EB9,0xE368, 0x8EBA,0xE369, 0x8EBB,0xE36A,
0x8EBC,0xE36B, 0x8EBD,0xE36C, 0x8EBE,0xE36D, 0x8EBF,0xE36E,
0x8EC0,0xE36F, 0x8EC1,0xE370, 0x8EC2,0xE371, 0x8EC3,0xE372,
0x8EC4,0xE373, 0x8EC5,0xE374, 0x8EC6,0xE375, 0x8EC7,0xE376,
0x8EC8,0xE377, 0x8EC9,0xE378, 0x8ECA,0xE379, 0x8ECB,0xE37A,
0x8ECC,0xE37B, 0x8ECD,0xE37C, 0x8ECE,0xE37D, 0x8ECF,0xE37E,
0x8ED0,0xE37F, 0x8ED1,0xE380, 0x8ED2,0xE381, 0x8ED3,0xE382,
0x8ED4,0xE383, 0x8ED5,0xE384, 0x8ED6,0xE385, 0x8ED7,0xE386,
0x8ED8,0xE387, 0x8ED9,0xE388, 0x8EDA,0xE389, 0x8EDB,0xE38A,
0x8EDC,0xE38B, 0x8EDD,0xE38C, 0x8EDE,0xE38D, 0x8EDF,0xE38E,
0x8EE0,0xE38F, 0x8EE1,0xE390, 0x8EE2,0xE391, 0x8EE3,0xE392,
0x8EE4,0xE393, 0x8EE5,0xE394, 0x8EE6,0xE395, 0x8EE7,0xE396,
0x8EE8,0xE397, 0x8EE9,0xE398, 0x8EEA,0xE399, 0x8EEB,0xE39A,
0x8EEC,0xE39B, 0x8EED,0xE39C, 0x8EEE,0xE39D, 0x8EEF,0xE39E,
0x8EF0,0xE39F, 0x8EF1,0xE3A0, 0x8EF2,0xE3A1, 0x8EF3,0xE3A2,
0x8EF4,0xE3A3, 0x8EF5,0xE3A4, 0x8EF6,0xE3A5, 0x8EF7,0xE3A6,
0x8EF8,0xE3A7, 0x8EF9,0xE3A8, 0x8EFA,0xE3A9, 0x8EFB,0xE3AA,
0x8EFC,0xE3AB, 0x8EFD,0xE3AC, 0x8EFE,0xE3AD, 0x8F40,0xE3AE,
0x8F41,0xE3AF, 0x8F42,0xE3B0, 0x8F43,0xE3B1, 0x8F44,0xE3B2,
0x8F45,0xE3B3, 0x8F46,0xE3B4, 0x8F47,0xE3B5, 0x8F48,0xE3B6,
0x8F49,0xE3B7, 0x8F4A,0xE3B8, 0x8F4B,0xE3B9, 0x8F4C,0xE3BA,
0x8F4D,0xE3BB, 0x8F4E,0xE3BC, 0x8F4F,0xE3BD, 0x8F50,0xE3BE,
0x8F51,0xE3BF, 0x8F52,0xE3C0, 0x8F54,0xE3C2, 0x8F55,0xE3C3,
0x8F56,0xE3C4, 0x8F57,0xE3C5, 0x8F58,0xE3C6, 0x8F59,0xE3C7,
0x8F5A,0xE3C8, 0x8F5B,0xE3C9, 0x8F5C,0xE3CA, 0x8F5D,0xE3CB,
0x8F5E,0xE3CC, 0x8F5F,0xE3CD, 0x8F60,0xE3CE, 0x8F61,0xE3CF,
0x8F62,0xE3D0, 0x8F63,0xE3D1, 0x8F64,0xE3D2, 0x8F65,0xE3D3,
0x8F66,0xE3D4, 0x8F67,0xE3D5, 0x8F68,0xE3D6, 0x8F69,0xE3D7,
0x8F6A,0xE3D8, 0x8F6B,0xE3D9, 0x8F6C,0xE3DA, 0x8F6D,0xE3DB,
0x8F6E,0xE3DC, 0x8F6F,0xE3DD, 0x8F70,0xE3DE, 0x8F71,0xE3DF,
0x8F72,0xE3E0, 0x8F73,0xE3E1, 0x8F74,0xE3E2, 0x8F75,0xE3E3,
0x8F76,0xE3E4, 0x8F77,0xE3E5, 0x8F78,0xE3E6, 0x8F79,0xE3E7,
0x8F7A,0xE3E8, 0x8F7B,0xE3E9, 0x8F7C,0xE3EA, 0x8F7D,0xE3EB,
0x8F7E,0xE3EC, 0x8FA1,0xE3ED, 0x8FA2,0xE3EE, 0x8FA3,0xE3EF,
0x8FA4,0xE3F0, 0x8FA5,0xE3F1, 0x8FA6,0xE3F2, 0x8FA7,0xE3F3,
0x8FA8,0xE3F4, 0x8FA9,0xE3F5, 0x8FAA,0xE3F6, 0x8FAB,0xE3F7,
0x8FAC,0xE3F8, 0x8FAD,0xE3F9, 0x8FAE,0xE3FA, 0x8FAF,0xE3FB,
0x8FB0,0xE3FC, 0x8FB1,0xE3FD, 0x8FB2,0xE3FE, 0x8FB3,0xE3FF,
0x8FB4,0xE400, 0x8FB5,0xE401, 0x8FB6,0xE402, 0x8FB7,0xE403,
0x8FB8,0xE404, 0x8FB9,0xE405, 0x8FBA,0xE406, 0x8FBB,0xE407,
0x8FBC,0xE408, 0x8FBD,0xE409, 0x8FBE,0xE40A, 0x8FBF,0xE40B,
0x8FC0,0xE40C, 0x8FC1,0xE40D, 0x8FC2,0xE40E, 0x8FC3,0xE40F,
0x8FC4,0xE410, 0x8FC5,0xE411, 0x8FC6,0xE412, 0x8FC7,0xE413,
0x8FC8,0xE414, 0x8FC9,0xE415, 0x8FCA,0xE416, 0x8FCB,0xE417,
0x8FCC,0xE418, 0x8FCD,0xE419, 0x8FCE,0xE41A, 0x8FCF,0xE41B,
0x8FD0,0xE41C, 0x8FD1,0xE41D, 0x8FD2,0xE41E, 0x8FD3,0xE41F,
0x8FD4,0xE420, 0x8FD5,0xE421, 0x8FD6,0xE422, 0x8FD7,0xE423,
0x8FD8,0xE424, 0x8FD9,0xE425, 0x8FDA,0xE426, 0x8FDB,0xE427,
0x8FDC,0xE428, 0x8FDD,0xE429, 0x8FDE,0xE42A, 0x8FDF,0xE42B,
0x8FE0,0xE42C, 0x8FE1,0xE42D, 0x8FE2,0xE42E, 0x8FE3,0xE42F,
0x8FE4,0xE430, 0x8FE5,0xE431, 0x8FE6,0xE432, 0x8FE7,0xE433,
0x8FE8,0xE434, 0x8FE9,0xE435, 0x8FEA,0xE436, 0x8FEB,0xE437,
0x8FEC,0xE438, 0x8FED,0xE439, 0x8FEE,0xE43A, 0x8FEF,0xE43B,
0x8FF0,0xE43C, 0x8FF1,0xE43D, 0x8FF2,0xE43E, 0x8FF3,0xE43F,
0x8FF4,0xE440, 0x8FF5,0xE441, 0x8FF6,0xE442, 0x8FF7,0xE443,
0x8FF8,0xE444, 0x8FF9,0xE445, 0x8FFA,0xE446, 0x8FFB,0xE447,
0x8FFC,0xE448, 0x8FFD,0xE449, 0x8FFE,0xE44A, 0x9040,0xE44B,
0x9041,0xE44C, 0x9042,0xE44D, 0x9043,0xE44E, 0x9044,0xE44F,
0x9045,0xE450, 0x9046,0xE451, 0x9047,0xE452, 0x9048,0xE453,
0x9049,0xE454, 0x904A,0xE455, 0x904B,0xE456, 0x904C,0xE457,
0x904D,0xE458, 0x904E,0xE459, 0x904F,0xE45A, 0x9050,0xE45B,
0x9051,0xE45C, 0x9052,0xE45D, 0x9053,0xE45E, 0x9054,0xE45F,
0x9055,0xE460, 0x9056,0xE461, 0x9057,0xE462, 0x9058,0xE463,
0x9059,0xE464, 0x905A,0xE465, 0x905B,0xE466, 0x905C,0xE467,
0x905D,0xE468, 0x905E,0xE469, 0x905F,0xE46A, 0x9060,0xE46B,
0x9061,0xE46C, 0x9062,0xE46D, 0x9063,0xE46E, 0x9064,0xE46F,
0x9065,0xE470, 0x9066,0xE471, 0x9067,0xE472, 0x9068,0xE473,
0x9069,0xE474, 0x906A,0xE475, 0x906B,0xE476, 0x906C,0xE477,
0x906D,0xE478, 0x906E,0xE479, 0x906F,0xE47A, 0x9070,0xE47B,
0x9071,0xE47C, 0x9072,0xE47D, 0x9073,0xE47E, 0x9074,0xE47F,
0x9075,0xE480, 0x9076,0xE481, 0x9077,0xE482, 0x9078,0xE483,
0x9079,0xE484, 0x907A,0xE485, 0x907B,0xE486, 0x907C,0xE487,
0x907D,0xE488, 0x907E,0xE489, 0x90A1,0xE48A, 0x90A2,0xE48B,
0x90A3,0xE48C, 0x90A4,0xE48D, 0x90A5,0xE48E, 0x90A6,0xE48F,
0x90A7,0xE490, 0x90A8,0xE491, 0x90A9,0xE492, 0x90AA,0xE493,
0x90AB,0xE494, 0x90AC,0xE495, 0x90AD,0xE496, 0x90AE,0xE497,
0x90AF,0xE498, 0x90B0,0xE499, 0x90B1,0xE49A, 0x90B2,0xE49B,
0x90B3,0xE49C, 0x90B4,0xE49D, 0x90B5,0xE49E, 0x90B6,0xE49F,
0x90B7,0xE4A0, 0x90B8,0xE4A1, 0x90B9,0xE4A2, 0x90BA,0xE4A3,
0x90BB,0xE4A4, 0x90BC,0xE4A5, 0x90BD,0xE4A6, 0x90BE,0xE4A7,
0x90BF,0xE4A8, 0x90C0,0xE4A9, 0x90C1,0xE4AA, 0x90C2,0xE4AB,
0x90C3,0xE4AC, 0x90C4,0xE4AD, 0x90C5,0xE4AE, 0x90C6,0xE4AF,
0x90C7,0xE4B0, 0x90C8,0xE4B1, 0x90C9,0xE4B2, 0x90CA,0xE4B3,
0x90CB,0xE4B4, 0x90CC,0xE4B5, 0x90CD,0xE4B6, 0x90CE,0xE4B7,
0x90CF,0xE4B8, 0x90D0,0xE4B9, 0x90D1,0xE4BA, 0x90D2,0xE4BB,
0x90D3,0xE4BC, 0x90D4,0xE4BD, 0x90D5,0xE4BE, 0x90D6,0xE4BF,
0x90D7,0xE4C0, 0x90D8,0xE4C1, 0x90D9,0xE4C2, 0x90DA,0xE4C3,
0x90DB,0xE4C4, 0x90DC,0xE4C5, 0x90DD,0xE4C6, 0x90DE,0xE4C7,
0x90DF,0xE4C8, 0x90E0,0xE4C9, 0x90E1,0xE4CA, 0x90E2,0xE4CB,
0x90E3,0xE4CC, 0x90E4,0xE4CD, 0x90E5,0xE4CE, 0x90E6,0xE4CF,
0x90E7,0xE4D0, 0x90E8,0xE4D1, 0x90E9,0xE4D2, 0x90EA,0xE4D3,
0x90EB,0xE4D4, 0x90EC,0xE4D5, 0x90ED,0xE4D6, 0x90EE,0xE4D7,
0x90EF,0xE4D8, 0x90F0,0xE4D9, 0x90F1,0xE4DA, 0x90F2,0xE4DB,
0x90F3,0xE4DC, 0x90F4,0xE4DD, 0x90F5,0xE4DE, 0x90F8,0xE4E1,
0x90FB,0xE4E4, 0x90FC,0xE4E5, 0x90FD,0xE4E6, 0x90FE,0xE4E7,
0x9140,0xE4E8, 0x9141,0xE4E9, 0x9142,0xE4EA, 0x9143,0xE4EB,
0x9144,0xE4EC, 0x9145,0xE4ED, 0x9146,0xE4EE, 0x9147,0xE4EF,
0x9148,0xE4F0, 0x9149,0xE4F1, 0x914A,0xE4F2, 0x914B,0xE4F3,
0x914C,0xE4F4, 0x914D,0xE4F5, 0x914E,0xE4F6, 0x914F,0xE4F7,
0x9150,0xE4F8, 0x9151,0xE4F9, 0x9152,0xE4FA, 0x9153,0xE4FB,
0x9154,0xE4FC, 0x9155,0xE4FD, 0x9156,0xE4FE, 0x9157,0xE4FF,
0x9158,0xE500, 0x9159,0xE501, 0x915A,0xE502, 0x915B,0xE503,
0x915C,0xE504, 0x915D,0xE505, 0x915E,0xE506, 0x915F,0xE507,
0x9160,0xE508, 0x9161,0xE509, 0x9162,0xE50A, 0x9163,0xE50B,
0x9164,0xE50C, 0x9165,0xE50D, 0x9166,0xE50E, 0x9167,0xE50F,
0x9168,0xE510, 0x9169,0xE511, 0x916A,0xE512, 0x916B,0xE513,
0x916C,0xE514, 0x916D,0xE515, 0x916E,0xE516, 0x916F,0xE517,
0x9170,0xE518, 0x9171,0xE519, 0x9172,0xE51A, 0x9173,0xE51B,
0x9174,0xE51C, 0x9175,0xE51D, 0x9176,0xE51E, 0x9177,0xE51F,
0x9178,0xE520, 0x9179,0xE521, 0x917A,0xE522, 0x917B,0xE523,
0x917C,0xE524, 0x917D,0xE525, 0x917E,0xE526, 0x91A1,0xE527,
0x91A2,0xE528, 0x91A3,0xE529, 0x91A4,0xE52A, 0x91A5,0xE52B,
0x91A6,0xE52C, 0x91A7,0xE52D, 0x91A8,0xE52E, 0x91A9,0xE52F,
0x91AA,0xE530, 0x91AB,0xE531, 0x91AC,0xE532, 0x91AD,0xE533,
0x91AE,0xE534, 0x91AF,0xE535, 0x91B0,0xE536, 0x91B1,0xE537,
0x91B2,0xE538, 0x91B3,0xE539, 0x91B4,0xE53A, 0x91B5,0xE53B,
0x91B6,0xE53C, 0x91B7,0xE53D, 0x91B8,0xE53E, 0x91B9,0xE53F,
0x91BA,0xE540, 0x91BB,0xE541, 0x91BC,0xE542, 0x91BD,0xE543,
0x91BE,0xE544, 0x91BF,0xE545, 0x91C0,0xE546, 0x91C1,0xE547,
0x91C2,0xE548, 0x91C3,0xE549, 0x91C4,0xE54A, 0x91C5,0xE54B,
0x91C6,0xE54C, 0x91C9,0xE54F, 0x91CA,0xE550, 0x91CB,0xE551,
0x91CC,0xE552, 0x91CD,0xE553, 0x91CE,0xE554, 0x91D1,0xE557,
0x91D2,0xE558, 0x91D3,0xE559, 0x91D4,0xE55A, 0x91D5,0xE55B,
0x91D6,0xE55C, 0x91D7,0xE55D, 0x91DB,0xE561, 0x91DC,0xE562,
0x91DD,0xE563, 0x91DE,0xE564, 0x91E0,0xE566, 0x91E6,0xE56C,
0x91E8,0xE56E, 0x91EA,0xE570, 0x91EB,0xE571, 0x91EC,0xE572,
0x91ED,0xE573, 0x91EE,0xE574, 0x91F0,0xE576, 0x91F1,0xE577,
0x91F2,0xE578, 0x91F3,0xE579, 0x91F4,0xE57A, 0x91F5,0xE57B,
0x91F6,0xE57C, 0x91F7,0xE57D, 0x91F8,0xE57E, 0x91F9,0xE57F,
0x91FA,0xE580, 0x91FB,0xE581, 0x91FC,0xE582, 0x9240,0xE585,
0x9241,0xE586, 0x9242,0xE587, 0x9243,0xE588, 0x9244,0xE589,
0x9245,0xE58A, 0x9246,0xE58B, 0x9247,0xE58C, 0x9248,0xE58D,
0x9249,0xE58E, 0x924A,0xE58F, 0x924B,0xE590, 0x924C,0xE591,
0x924D,0xE592, 0x924E,0xE593, 0x924F,0xE594, 0x9250,0xE595,
0x9251,0xE596, 0x9252,0xE597, 0x9253,0xE598, 0x9254,0xE599,
0x9255,0xE59A, 0x9256,0xE59B, 0x9257,0xE59C, 0x9258,0xE59D,
0x9259,0xE59E, 0x925A,0xE59F, 0x925B,0xE5A0, 0x925C,0xE5A1,
0x925D,0xE5A2, 0x925E,0xE5A3, 0x925F,0xE5A4, 0x9260,0xE5A5,
0x9261,0xE5A6, 0x9262,0xE5A7, 0x9263,0xE5A8, 0x9264,0xE5A9,
0x9266,0xE5AB, 0x9267,0xE5AC, 0x9268,0xE5AD, 0x9269,0xE5AE,
0x926A,0xE5AF, 0x926B,0xE5B0, 0x926C,0xE5B1, 0x926D,0xE5B2,
0x926E,0xE5B3, 0x926F,0xE5B4, 0x9270,0xE5B5, 0x9271,0xE5B6,
0x9272,0xE5B7, 0x9273,0xE5B8, 0x9274,0xE5B9, 0x9275,0xE5BA,
0x9276,0xE5BB, 0x9277,0xE5BC, 0x9278,0xE5BD, 0x9279,0xE5BE,
0x927A,0xE5BF, 0x927B,0xE5C0, 0x927C,0xE5C1, 0x927D,0xE5C2,
0x927E,0xE5C3, 0x92A1,0xE5C4, 0x92A2,0xE5C5, 0x92A3,0xE5C6,
0x92A4,0xE5C7, 0x92A6,0xE5C9, 0x92A7,0xE5CA, 0x92A8,0xE5CB,
0x92A9,0xE5CC, 0x92AA,0xE5CD, 0x92AB,0xE5CE, 0x92AC,0xE5CF,
0x92AD,0xE5D0, 0x92AE,0xE5D1, 0x92AF,0xE5D2, 0x92B0,0xE5D3,
0x92B1,0xE5D4, 0x92B2,0xE5D5, 0x92B3,0xE5D6, 0x92B4,0xE5D7,
0x92B5,0xE5D8, 0x92B6,0xE5D9, 0x92B7,0xE5DA, 0x92B8,0xE5DB,
0x92B9,0xE5DC, 0x92BA,0xE5DD, 0x92BB,0xE5DE, 0x92BC,0xE5DF,
0x92BD,0xE5E0, 0x92BE,0xE5E1, 0x92BF,0xE5E2, 0x92C0,0xE5E3,
0x92C1,0xE5E4, 0x92C2,0xE5E5, 0x92C3,0xE5E6, 0x92C4,0xE5E7,
0x92C5,0xE5E8, 0x92C6,0xE5E9, 0x92C7,0xE5EA, 0x92C8,0xE5EB,
0x92C9,0xE5EC, 0x92CA,0xE5ED, 0x92CB,0xE5EE, 0x92CC,0xE5EF,
0x92CD,0xE5F0, 0x92CE,0xE5F1, 0x92CF,0xE5F2, 0x92D0,0xE5F3,
0x92D1,0xE5F4, 0x92D2,0xE5F5, 0x92D3,0xE5F6, 0x92D4,0xE5F7,
0x92D5,0xE5F8, 0x92D6,0xE5F9, 0x92D7,0xE5FA, 0x92D8,0xE5FB,
0x92D9,0xE5FC, 0x92DA,0xE5FD, 0x92DB,0xE5FE, 0x92DC,0xE5FF,
0x92DD,0xE600, 0x92DE,0xE601, 0x92DF,0xE602, 0x92E0,0xE603,
0x92E1,0xE604, 0x92E2,0xE605, 0x92E3,0xE606, 0x92E4,0xE607,
0x92E5,0xE608, 0x92E6,0xE609, 0x92E7,0xE60A, 0x92E8,0xE60B,
0x92E9,0xE60C, 0x92EA,0xE60D, 0x92EB,0xE60E, 0x92EC,0xE60F,
0x92ED,0xE610, 0x92EE,0xE611, 0x92EF,0xE612, 0x92F0,0xE613,
0x92F1,0xE614, 0x92F2,0xE615, 0x92F3,0xE616, 0x92F4,0xE617,
0x92F5,0xE618, 0x92F6,0xE619, 0x92F7,0xE61A, 0x92F8,0xE61B,
0x92F9,0xE61C, 0x92FA,0xE61D, 0x92FB,0xE61E, 0x92FC,0xE61F,
0x92FD,0xE620, 0x92FE,0xE621, 0x9340,0xE622, 0x9341,0xE623,
0x9342,0xE624, 0x9343,0xE625, 0x9344,0xE626, 0x9345,0xE627,
0x9346,0xE628, 0x9347,0xE629, 0x9348,0xE62A, 0x9349,0xE62B,
0x934A,0xE62C, 0x934B,0xE62D, 0x934C,0xE62E, 0x934D,0xE62F,
0x934E,0xE630, 0x934F,0xE631, 0x9350,0xE632, 0x9351,0xE633,
0x9352,0xE634, 0x9353,0xE635, 0x9354,0xE636, 0x9355,0xE637,
0x9356,0xE638, 0x9357,0xE639, 0x9358,0xE63A, 0x9359,0xE63B,
0x935A,0xE63C, 0x935B,0xE63D, 0x935C,0xE63E, 0x935D,0xE63F,
0x935E,0xE640, 0x935F,0xE641, 0x9360,0xE642, 0x9361,0xE643,
0x9362,0xE644, 0x9363,0xE645, 0x9364,0xE646, 0x9365,0xE647,
0x9366,0xE648, 0x9367,0xE649, 0x9368,0xE64A, 0x9369,0xE64B,
0x936A,0xE64C, 0x936B,0xE64D, 0x936C,0xE64E, 0x936D,0xE64F,
0x936E,0xE650, 0x936F,0xE651, 0x9370,0xE652, 0x9371,0xE653,
0x9372,0xE654, 0x9373,0xE655, 0x9374,0xE656, 0x9375,0xE657,
0x9376,0xE658, 0x9377,0xE659, 0x9378,0xE65A, 0x9379,0xE65B,
0x937A,0xE65C, 0x937B,0xE65D, 0x937C,0xE65E, 0x937D,0xE65F,
0x937E,0xE660, 0x93A1,0xE661, 0x93A2,0xE662, 0x93A3,0xE663,
0x93A4,0xE664, 0x93A5,0xE665, 0x93A6,0xE666, 0x93A7,0xE667,
0x93A8,0xE668, 0x93A9,0xE669, 0x93AA,0xE66A, 0x93AB,0xE66B,
0x93AC,0xE66C, 0x93AD,0xE66D, 0x93AE,0xE66E, 0x93AF,0xE66F,
0x93B0,0xE670, 0x93B1,0xE671, 0x93B2,0xE672, 0x93B3,0xE673,
0x93B4,0xE674, 0x93B5,0xE675, 0x93B6,0xE676, 0x93B7,0xE677,
0x93B8,0xE678, 0x93B9,0xE679, 0x93BA,0xE67A, 0x93BB,0xE67B,
0x93BC,0xE67C, 0x93BD,0xE67D, 0x93BE,0xE67E, 0x93BF,0xE67F,
0x93C0,0xE680, 0x93C1,0xE681, 0x93C2,0xE682, 0x93C3,0xE683,
0x93C4,0xE684, 0x93C5,0xE685, 0x93C6,0xE686, 0x93C7,0xE687,
0x93C8,0xE688, 0x93C9,0xE689, 0x93CA,0xE68A, 0x93CB,0xE68B,
0x93CC,0xE68C, 0x93CD,0xE68D, 0x93CE,0xE68E, 0x93CF,0xE68F,
0x93D0,0xE690, 0x93D1,0xE691, 0x93D2,0xE692, 0x93D3,0xE693,
0x93D4,0xE694, 0x93D5,0xE695, 0x93D6,0xE696, 0x93D7,0xE697,
0x93D8,0xE698, 0x93D9,0xE699, 0x93DA,0xE69A, 0x93DB,0xE69B,
0x93DC,0xE69C, 0x93DD,0xE69D, 0x93DE,0xE69E, 0x93DF,0xE69F,
0x93E0,0xE6A0, 0x93E1,0xE6A1, 0x93E2,0xE6A2, 0x93E3,0xE6A3,
0x93E4,0xE6A4, 0x93E5,0xE6A5, 0x93E6,0xE6A6, 0x93E7,0xE6A7,
0x93E8,0xE6A8, 0x93E9,0xE6A9, 0x93EA,0xE6AA, 0x93EB,0xE6AB,
0x93EC,0xE6AC, 0x93ED,0xE6AD, 0x93EE,0xE6AE, 0x93EF,0xE6AF,
0x93F0,0xE6B0, 0x93F1,0xE6B1, 0x93F2,0xE6B2, 0x93F3,0xE6B3,
0x93F4,0xE6B4, 0x93F5,0xE6B5, 0x93F6,0xE6B6, 0x93F7,0xE6B7,
0x93F8,0xE6B8, 0x93F9,0xE6B9, 0x93FA,0xE6BA, 0x93FB,0xE6BB,
0x93FC,0xE6BC, 0x93FD,0xE6BD, 0x93FE,0xE6BE, 0x9440,0xE6BF,
0x9441,0xE6C0, 0x9442,0xE6C1, 0x9443,0xE6C2, 0x9444,0xE6C3,
0x9445,0xE6C4, 0x9446,0xE6C5, 0x9447,0xE6C6, 0x9448,0xE6C7,
0x9449,0xE6C8, 0x944A,0xE6C9, 0x944B,0xE6CA, 0x944C,0xE6CB,
0x944D,0xE6CC, 0x944E,0xE6CD, 0x944F,0xE6CE, 0x9450,0xE6CF,
0x9451,0xE6D0, 0x9452,0xE6D1, 0x9453,0xE6D2, 0x9454,0xE6D3,
0x9455,0xE6D4, 0x9456,0xE6D5, 0x9457,0xE6D6, 0x9458,0xE6D7,
0x9459,0xE6D8, 0x945A,0xE6D9, 0x945B,0xE6DA, 0x945C,0xE6DB,
0x945D,0xE6DC, 0x945E,0xE6DD, 0x945F,0xE6DE, 0x9460,0xE6DF,
0x9461,0xE6E0, 0x9462,0xE6E1, 0x9463,0xE6E2, 0x9464,0xE6E3,
0x9465,0xE6E4, 0x9466,0xE6E5, 0x9467,0xE6E6, 0x9468,0xE6E7,
0x9469,0xE6E8, 0x946A,0xE6E9, 0x946B,0xE6EA, 0x946C,0xE6EB,
0x946D,0xE6EC, 0x946E,0xE6ED, 0x946F,0xE6EE, 0x9470,0xE6EF,
0x9471,0xE6F0, 0x9472,0xE6F1, 0x9473,0xE6F2, 0x9474,0xE6F3,
0x9475,0xE6F4, 0x9476,0xE6F5, 0x9477,0xE6F6, 0x9478,0xE6F7,
0x9479,0xE6F8, 0x947A,0xE6F9, 0x947B,0xE6FA, 0x947C,0xE6FB,
0x947D,0xE6FC, 0x947E,0xE6FD, 0x94A1,0xE6FE, 0x94A2,0xE6FF,
0x94A3,0xE700, 0x94A4,0xE701, 0x94A5,0xE702, 0x94A6,0xE703,
0x94A7,0xE704, 0x94A8,0xE705, 0x94A9,0xE706, 0x94AA,0xE707,
0x94AB,0xE708, 0x94AC,0xE709, 0x94AD,0xE70A, 0x94AE,0xE70B,
0x94AF,0xE70C, 0x94B0,0xE70D, 0x94B1,0xE70E, 0x94B2,0xE70F,
0x94B3,0xE710, 0x94B4,0xE711, 0x94B5,0xE712, 0x94B6,0xE713,
0x94B7,0xE714, 0x94B8,0xE715, 0x94B9,0xE716, 0x94BA,0xE717,
0x94BB,0xE718, 0x94BC,0xE719, 0x94BD,0xE71A, 0x94BE,0xE71B,
0x94BF,0xE71C, 0x94C0,0xE71D, 0x94C1,0xE71E, 0x94C2,0xE71F,
0x94C3,0xE720, 0x94C4,0xE721, 0x94C5,0xE722, 0x94C6,0xE723,
0x94C7,0xE724, 0x94C8,0xE725, 0x94C9,0xE726, 0x94CA,0xE727,
0x94CB,0xE728, 0x94CC,0xE729, 0x94CD,0xE72A, 0x94CE,0xE72B,
0x94CF,0xE72C, 0x94D0,0xE72D, 0x94D1,0xE72E, 0x94D3,0xE730,
0x94D4,0xE731, 0x94D5,0xE732, 0x94D6,0xE733, 0x94D7,0xE734,
0x94D8,0xE735, 0x94D9,0xE736, 0x94DA,0xE737, 0x94DB,0xE738,
0x94DC,0xE739, 0x94DD,0xE73A, 0x94DE,0xE73B, 0x94DF,0xE73C,
0x94E0,0xE73D, 0x94E1,0xE73E, 0x94E2,0xE73F, 0x94E3,0xE740,
0x94E4,0xE741, 0x94E5,0xE742, 0x94E6,0xE743, 0x94E7,0xE744,
0x94E8,0xE745, 0x94E9,0xE746, 0x94EA,0xE747, 0x94EB,0xE748,
0x94EC,0xE749, 0x94ED,0xE74A, 0x94EE,0xE74B, 0x94EF,0xE74C,
0x94F0,0xE74D, 0x94F1,0xE74E, 0x94F2,0xE74F, 0x94F3,0xE750,
0x94F4,0xE751, 0x94F5,0xE752, 0x94F6,0xE753, 0x94F7,0xE754,
0x94F8,0xE755, 0x94F9,0xE756, 0x94FA,0xE757, 0x94FB,0xE758,
0x94FC,0xE759, 0x94FD,0xE75A, 0x94FE,0xE75B, 0x9540,0xE75C,
0x9541,0xE75D, 0x9542,0xE75E, 0x9543,0xE75F, 0x9544,0xE760,
0x9545,0xE761, 0x9546,0xE762, 0x9547,0xE763, 0x9548,0xE764,
0x9549,0xE765, 0x954A,0xE766, 0x954B,0xE767, 0x954C,0xE768,
0x954D,0xE769, 0x954E,0xE76A, 0x954F,0xE76B, 0x9550,0xE76C,
0x9551,0xE76D, 0x9552,0xE76E, 0x9553,0xE76F, 0x9554,0xE770,
0x9555,0xE771, 0x9556,0xE772, 0x9557,0xE773, 0x9558,0xE774,
0x9559,0xE775, 0x955A,0xE776, 0x955B,0xE777, 0x955C,0xE778,
0x955D,0xE779, 0x955E,0xE77A, 0x955F,0xE77B, 0x9560,0xE77C,
0x9561,0xE77D, 0x9562,0xE77E, 0x9563,0xE77F, 0x9564,0xE780,
0x9565,0xE781, 0x9566,0xE782, 0x9567,0xE783, 0x9568,0xE784,
0x9569,0xE785, 0x956A,0xE786, 0x956B,0xE787, 0x956C,0xE788,
0x956D,0xE789, 0x956E,0xE78A, 0x956F,0xE78B, 0x9570,0xE78C,
0x9571,0xE78D, 0x9572,0xE78E, 0x9573,0xE78F, 0x9574,0xE790,
0x9575,0xE791, 0x9576,0xE792, 0x9577,0xE793, 0x9578,0xE794,
0x9579,0xE795, 0x957A,0xE796, 0x957B,0xE797, 0x957C,0xE798,
0x957D,0xE799, 0x957E,0xE79A, 0x95A1,0xE79B, 0x95A2,0xE79C,
0x95A3,0xE79D, 0x95A4,0xE79E, 0x95A5,0xE79F, 0x95A6,0xE7A0,
0x95A7,0xE7A1, 0x95A8,0xE7A2, 0x95A9,0xE7A3, 0x95AA,0xE7A4,
0x95AB,0xE7A5, 0x95AC,0xE7A6, 0x95AD,0xE7A7, 0x95AE,0xE7A8,
0x95AF,0xE7A9, 0x95B0,0xE7AA, 0x95B1,0xE7AB, 0x95B2,0xE7AC,
0x95B3,0xE7AD, 0x95B4,0xE7AE, 0x95B5,0xE7AF, 0x95B6,0xE7B0,
0x95B7,0xE7B1, 0x95B8,0xE7B2, 0x95B9,0xE7B3, 0x95BA,0xE7B4,
0x95BB,0xE7B5, 0x95BC,0xE7B6, 0x95BD,0xE7B7, 0x95BE,0xE7B8,
0x95BF,0xE7B9, 0x95C0,0xE7BA, 0x95C1,0xE7BB, 0x95C2,0xE7BC,
0x95C3,0xE7BD, 0x95C4,0xE7BE, 0x95C5,0xE7BF, 0x95C6,0xE7C0,
0x95C7,0xE7C1, 0x95C8,0xE7C2, 0x95C9,0xE7C3, 0x95CA,0xE7C4,
0x95CB,0xE7C5, 0x95CC,0xE7C6, 0x95CD,0xE7C7, 0x95CE,0xE7C8,
0x95CF,0xE7C9, 0x95D1,0xE7CB, 0x95D2,0xE7CC, 0x95D3,0xE7CD,
0x95D5,0xE7CF, 0x95D6,0xE7D0, 0x95D7,0xE7D1, 0x95D8,0xE7D2,
0x95D9,0xE7D3, 0x95DA,0xE7D4, 0x95DB,0xE7D5, 0x95DC,0xE7D6,
0x95DD,0xE7D7, 0x95DE,0xE7D8, 0x95DF,0xE7D9, 0x95E0,0xE7DA,
0x95E1,0xE7DB, 0x95E2,0xE7DC, 0x95E3,0xE7DD, 0x95E4,0xE7DE,
0x95E5,0xE7DF, 0x95E7,0xE7E1, 0x95E8,0xE7E2, 0x95E9,0xE7E3,
0x95EA,0xE7E4, 0x95EB,0xE7E5, 0x95EC,0xE7E6, 0x95ED,0xE7E7,
0x95EE,0xE7E8, 0x95EF,0xE7E9, 0x95F0,0xE7EA, 0x95F1,0xE7EB,
0x95F2,0xE7EC, 0x95F3,0xE7ED, 0x95F5,0xE7EF, 0x95F6,0xE7F0,
0x95F7,0xE7F1, 0x95F8,0xE7F2, 0x95F9,0xE7F3, 0x95FA,0xE7F4,
0x95FB,0xE7F5, 0x95FC,0xE7F6, 0x95FD,0xE7F7, 0x95FE,0xE7F8,
0x9640,0xE7F9, 0x9641,0xE7FA, 0x9642,0xE7FB, 0x9643,0xE7FC,
0x9644,0xE7FD, 0x9649,0xE802, 0x964A,0xE803, 0x964B,0xE804,
0x964C,0xE805, 0x964D,0xE806, 0x964E,0xE807, 0x964F,0xE808,
0x9650,0xE809, 0x9651,0xE80A, 0x9652,0xE80B, 0x9653,0xE80C,
0x9654,0xE80D, 0x9655,0xE80E, 0x9656,0xE80F, 0x9657,0xE810,
0x9658,0xE811, 0x9659,0xE812, 0x965A,0xE813, 0x965B,0xE814,
0x965C,0xE815, 0x965E,0xE817, 0x965F,0xE818, 0x9660,0xE819,
0x9661,0xE81A, 0x9662,0xE81B, 0x9663,0xE81C, 0x9664,0xE81D,
0x9665,0xE81E, 0x9666,0xE81F, 0x9667,0xE820, 0x9668,0xE821,
0x9669,0xE822, 0x966A,0xE823, 0x966B,0xE824, 0x966C,0xE825,
0x966D,0xE826, 0x966E,0xE827, 0x966F,0xE828, 0x9670,0xE829,
0x9671,0xE82A, 0x9672,0xE82B, 0x9673,0xE82C, 0x9674,0xE82D,
0x9675,0xE82E, 0x9676,0xE82F, 0x9677,0xE830, 0x9678,0xE831,
0x9679,0xE832, 0x967A,0xE833, 0x967B,0xE834, 0x967C,0xE835,
0x967D,0xE836, 0x967E,0xE837, 0x96A1,0xE838, 0x96A2,0xE839,
0x96A3,0xE83A, 0x96A4,0xE83B, 0x96A5,0xE83C, 0x96A6,0xE83D,
0x96A7,0xE83E, 0x96A8,0xE83F, 0x96A9,0xE840, 0x96AA,0xE841,
0x96AB,0xE842, 0x96AD,0xE844, 0x96AE,0xE845, 0x96AF,0xE846,
0x96B1,0xE848, 0x96B2,0xE849, 0x96B3,0xE84A, 0x96B4,0xE84B,
0x96B5,0xE84C, 0x96B6,0xE84D, 0x96B8,0xE84F, 0x96B9,0xE850,
0x96BA,0xE851, 0x96BC,0xE853, 0x96BD,0xE854, 0x96BE,0xE855,
0x96C0,0xE857, 0x96C1,0xE858, 0x96C3,0xE85A, 0x96C6,0xE85D,
0x96C7,0xE85E, 0x96C8,0xE85F, 0x96C9,0xE860, 0x96CA,0xE861,
0x96CB,0xE862, 0x96CD,0xE864, 0x96CE,0xE865, 0x96CF,0xE866,
0x96D0,0xE867, 0x96D1,0xE868, 0x96D2,0xE869, 0x96D3,0xE86A,
0x96D4,0xE86B, 0x96D5,0xE86C, 0x96D6,0xE86D, 0x96D7,0xE86E,
0x96D8,0xE86F, 0x96D9,0xE870, 0x96DA,0xE871, 0x96DB,0xE872,
0x96DC,0xE873, 0x96DD,0xE874, 0x96DE,0xE875, 0x96DF,0xE876,
0x96E1,0xE878, 0x96E2,0xE879, 0x96E3,0xE87A, 0x96E4,0xE87B,
0x96E5,0xE87C, 0x96E6,0xE87D, 0x96E7,0xE87E, 0x96E8,0xE87F,
0x96E9,0xE880, 0x96EA,0xE881, 0x96EB,0xE882, 0x96EC,0xE883,
0x96ED,0xE884, 0x96EE,0xE885, 0x96EF,0xE886, 0x96F8,0xE88F,
0x96F9,0xE890, 0x96FC,0xE893, 0x96FD,0xE894, 0x96FE,0xE895,
0x9740,0xE896, 0x9741,0xE897, 0x9742,0xE898, 0x9743,0xE899,
0x9744,0xE89A, 0x9745,0xE89B, 0x9746,0xE89C, 0x9747,0xE89D,
0x9748,0xE89E, 0x9749,0xE89F, 0x974A,0xE8A0, 0x974B,0xE8A1,
0x974C,0xE8A2, 0x974D,0xE8A3, 0x974E,0xE8A4, 0x974F,0xE8A5,
0x9750,0xE8A6, 0x9751,0xE8A7, 0x9752,0xE8A8, 0x9753,0xE8A9,
0x9754,0xE8AA, 0x9755,0xE8AB, 0x9756,0xE8AC, 0x9757,0xE8AD,
0x9758,0xE8AE, 0x9759,0xE8AF, 0x975A,0xE8B0, 0x975B,0xE8B1,
0x975C,0xE8B2, 0x975D,0xE8B3, 0x975E,0xE8B4, 0x975F,0xE8B5,
0x9760,0xE8B6, 0x9761,0xE8B7, 0x9762,0xE8B8, 0x9763,0xE8B9,
0x9764,0xE8BA, 0x9765,0xE8BB, 0x9766,0xE8BC, 0x9767,0xE8BD,
0x9768,0xE8BE, 0x9769,0xE8BF, 0x976A,0xE8C0, 0x976B,0xE8C1,
0x976C,0xE8C2, 0x976D,0xE8C3, 0x976E,0xE8C4, 0x976F,0xE8C5,
0x9770,0xE8C6, 0x9771,0xE8C7, 0x9772,0xE8C8, 0x9773,0xE8C9,
0x9774,0xE8CA, 0x9775,0xE8CB, 0x9776,0xE8CC, 0x9777,0xE8CD,
0x9778,0xE8CE, 0x9779,0xE8CF, 0x977A,0xE8D0, 0x977B,0xE8D1,
0x977C,0xE8D2, 0x977D,0xE8D3, 0x977E,0xE8D4, 0x97A1,0xE8D5,
0x97A2,0xE8D6, 0x97A3,0xE8D7, 0x97A4,0xE8D8, 0x97A5,0xE8D9,
0x97A6,0xE8DA, 0x97A7,0xE8DB, 0x97A8,0xE8DC, 0x97A9,0xE8DD,
0x97AA,0xE8DE, 0x97AB,0xE8DF, 0x97AC,0xE8E0, 0x97AD,0xE8E1,
0x97AE,0xE8E2, 0x97AF,0xE8E3, 0x97B0,0xE8E4, 0x97B1,0xE8E5,
0x97B2,0xE8E6, 0x97B3,0xE8E7, 0x97B4,0xE8E8, 0x97B5,0xE8E9,
0x97B6,0xE8EA, 0x97B7,0xE8EB, 0x97B8,0xE8EC, 0x97B9,0xE8ED,
0x97BA,0xE8EE, 0x97BB,0xE8EF, 0x97BC,0xE8F0, 0x97BD,0xE8F1,
0x97BE,0xE8F2, 0x97BF,0xE8F3, 0x97C0,0xE8F4, 0x97C1,0xE8F5,
0x97C2,0xE8F6, 0x97C3,0xE8F7, 0x97C4,0xE8F8, 0x97C5,0xE8F9,
0x97C6,0xE8FA, 0x97C7,0xE8FB, 0x97C8,0xE8FC, 0x97C9,0xE8FD,
0x97CA,0xE8FE, 0x97CB,0xE8FF, 0x97CC,0xE900, 0x97CD,0xE901,
0x97CE,0xE902, 0x97CF,0xE903, 0x97D0,0xE904, 0x97D1,0xE905,
0x97D2,0xE906, 0x97D3,0xE907, 0x97D4,0xE908, 0x97D5,0xE909,
0x97D6,0xE90A, 0x97D7,0xE90B, 0x97D8,0xE90C, 0x97D9,0xE90D,
0x97DA,0xE90E, 0x97DB,0xE90F, 0x97DC,0xE910, 0x97DD,0xE911,
0x97DE,0xE912, 0x97DF,0xE913, 0x97E0,0xE914, 0x97E1,0xE915,
0x97E2,0xE916, 0x97E3,0xE917, 0x97E4,0xE918, 0x97E5,0xE919,
0x97E6,0xE91A, 0x97E7,0xE91B, 0x97E8,0xE91C, 0x97E9,0xE91D,
0x97EA,0xE91E, 0x97EB,0xE91F, 0x97EC,0xE920, 0x97ED,0xE921,
0x97EE,0xE922, 0x97EF,0xE923, 0x97F0,0xE924, 0x97F1,0xE925,
0x97F2,0xE926, 0x97F3,0xE927, 0x97F4,0xE928, 0x97F5,0xE929,
0x97F6,0xE92A, 0x97F7,0xE92B, 0x97F8,0xE92C, 0x97F9,0xE92D,
0x97FA,0xE92E, 0x97FB,0xE92F, 0x97FC,0xE930, 0x9840,0xE933,
0x9841,0xE934, 0x9842,0xE935, 0x9843,0xE936, 0x9844,0xE937,
0x9845,0xE938, 0x9846,0xE939, 0x9847,0xE93A, 0x9848,0xE93B,
0x9849,0xE93C, 0x984A,0xE93D, 0x984B,0xE93E, 0x984C,0xE93F,
0x984D,0xE940, 0x984E,0xE941, 0x984F,0xE942, 0x9850,0xE943,
0x9851,0xE944, 0x9852,0xE945, 0x9853,0xE946, 0x9854,0xE947,
0x9855,0xE948, 0x9856,0xE949, 0x9857,0xE94A, 0x9858,0xE94B,
0x9859,0xE94C, 0x985A,0xE94D, 0x985B,0xE94E, 0x985C,0xE94F,
0x985D,0xE950, 0x985E,0xE951, 0x985F,0xE952, 0x9860,0xE953,
0x9861,0xE954, 0x9862,0xE955, 0x9863,0xE956, 0x9864,0xE957,
0x9865,0xE958, 0x9866,0xE959, 0x9867,0xE95A, 0x9868,0xE95B,
0x9869,0xE95C, 0x986A,0xE95D, 0x986B,0xE95E, 0x986C,0xE95F,
0x986D,0xE960, 0x986E,0xE961, 0x986F,0xE962, 0x9870,0xE963,
0x9871,0xE964, 0x9872,0xE965, 0x9873,0xE966, 0x9874,0xE967,
0x9875,0xE968, 0x9876,0xE969, 0x9877,0xE96A, 0x9878,0xE96B,
0x9879,0xE96C, 0x987A,0xE96D, 0x987B,0xE96E, 0x987C,0xE96F,
0x987D,0xE970, 0x987E,0xE971, 0x98A1,0xE972, 0x98A2,0xE973,
0x98A3,0xE974, 0x98A4,0xE975, 0x98A5,0xE976, 0x98A6,0xE977,
0x98A7,0xE978, 0x98A8,0xE979, 0x98A9,0xE97A, 0x98AA,0xE97B,
0x98AB,0xE97C, 0x98AC,0xE97D, 0x98AD,0xE97E, 0x98AE,0xE97F,
0x98AF,0xE980, 0x98B0,0xE981, 0x98B1,0xE982, 0x98B2,0xE983,
0x98B3,0xE984, 0x98B4,0xE985, 0x98B5,0xE986, 0x98B6,0xE987,
0x98B7,0xE988, 0x98B8,0xE989, 0x98B9,0xE98A, 0x98BA,0xE98B,
0x98BB,0xE98C, 0x98BC,0xE98D, 0x98BD,0xE98E, 0x98BE,0xE98F,
0x98BF,0xE990, 0x98C0,0xE991, 0x98C1,0xE992, 0x98C2,0xE993,
0x98C3,0xE994, 0x98C4,0xE995, 0x98C5,0xE996, 0x98C6,0xE997,
0x98C7,0xE998, 0x98C8,0xE999, 0x98C9,0xE99A, 0x98CA,0xE99B,
0x98CB,0xE99C, 0x98CC,0xE99D, 0x98CD,0xE99E, 0x98CE,0xE99F,
0x98CF,0xE9A0, 0x98D0,0xE9A1, 0x98D1,0xE9A2, 0x98D2,0xE9A3,
0x98D3,0xE9A4, 0x98D4,0xE9A5, 0x98D5,0xE9A6, 0x98D6,0xE9A7,
0x98D7,0xE9A8, 0x98D8,0xE9A9, 0x98D9,0xE9AA, 0x98DA,0xE9AB,
0x98DB,0xE9AC, 0x98DC,0xE9AD, 0x98DD,0xE9AE, 0x98DE,0xE9AF,
0x98DF,0xE9B0, 0x98E0,0xE9B1, 0x98E1,0xE9B2, 0x98E2,0xE9B3,
0x98E3,0xE9B4, 0x98E4,0xE9B5, 0x98E5,0xE9B6, 0x98E6,0xE9B7,
0x98E7,0xE9B8, 0x98E8,0xE9B9, 0x98E9,0xE9BA, 0x98EA,0xE9BB,
0x98EB,0xE9BC, 0x98EC,0xE9BD, 0x98ED,0xE9BE, 0x98EE,0xE9BF,
0x98EF,0xE9C0, 0x98F0,0xE9C1, 0x98F1,0xE9C2, 0x98F2,0xE9C3,
0x98F3,0xE9C4, 0x98F4,0xE9C5, 0x98F5,0xE9C6, 0x98F6,0xE9C7,
0x98F7,0xE9C8, 0x98F8,0xE9C9, 0x98F9,0xE9CA, 0x98FA,0xE9CB,
0x98FC,0xE9CD, 0x9940,0xE9D0, 0x9941,0xE9D1, 0x9942,0xE9D2,
0x9943,0xE9D3, 0x9944,0xE9D4, 0x9945,0xE9D5, 0x9946,0xE9D6,
0x9947,0xE9D7, 0x9948,0xE9D8, 0x9949,0xE9D9, 0x994A,0xE9DA,
0x994B,0xE9DB, 0x994C,0xE9DC, 0x994D,0xE9DD, 0x994E,0xE9DE,
0x994F,0xE9DF, 0x9950,0xE9E0, 0x9951,0xE9E1, 0x9952,0xE9E2,
0x9953,0xE9E3, 0x9954,0xE9E4, 0x9955,0xE9E5, 0x9956,0xE9E6,
0x9957,0xE9E7, 0x9958,0xE9E8, 0x9959,0xE9E9, 0x995A,0xE9EA,
0x995B,0xE9EB, 0x995C,0xE9EC, 0x995D,0xE9ED, 0x995E,0xE9EE,
0x995F,0xE9EF, 0x9960,0xE9F0, 0x9961,0xE9F1, 0x9962,0xE9F2,
0x9963,0xE9F3, 0x9964,0xE9F4, 0x9965,0xE9F5, 0x9966,0xE9F6,
0x9967,0xE9F7, 0x9968,0xE9F8, 0x9969,0xE9F9, 0x996A,0xE9FA,
0x996B,0xE9FB, 0x996C,0xE9FC, 0x996D,0xE9FD, 0x996E,0xE9FE,
0x996F,0xE9FF, 0x9970,0xEA00, 0x9971,0xEA01, 0x9972,0xEA02,
0x9973,0xEA03, 0x9974,0xEA04, 0x9975,0xEA05, 0x9976,0xEA06,
0x9977,0xEA07, 0x9978,0xEA08, 0x9979,0xEA09, 0x997A,0xEA0A,
0x997B,0xEA0B, 0x997C,0xEA0C, 0x997D,0xEA0D, 0x997E,0xEA0E,
0x99A1,0xEA0F, 0x99A2,0xEA10, 0x99A3,0xEA11, 0x99A4,0xEA12,
0x99A5,0xEA13, 0x99A6,0xEA14, 0x99A7,0xEA15, 0x99A8,0xEA16,
0x99A9,0xEA17, 0x99AA,0xEA18, 0x99AB,0xEA19, 0x99AC,0xEA1A,
0x99AD,0xEA1B, 0x99AE,0xEA1C, 0x99AF,0xEA1D, 0x99B0,0xEA1E,
0x99B1,0xEA1F, 0x99B2,0xEA20, 0x99B3,0xEA21, 0x99B4,0xEA22,
0x99B5,0xEA23, 0x99B6,0xEA24, 0x99B7,0xEA25, 0x99B8,0xEA26,
0x99B9,0xEA27, 0x99BA,0xEA28, 0x99BB,0xEA29, 0x99BC,0xEA2A,
0x99BD,0xEA2B, 0x99BE,0xEA2C, 0x99BF,0xEA2D, 0x99C0,0xEA2E,
0x99C1,0xEA2F, 0x99C2,0xEA30, 0x99C3,0xEA31, 0x99C4,0xEA32,
0x99C5,0xEA33, 0x99C6,0xEA34, 0x99C7,0xEA35, 0x99C8,0xEA36,
0x99C9,0xEA37, 0x99CA,0xEA38, 0x99CB,0xEA39, 0x99CC,0xEA3A,
0x99CD,0xEA3B, 0x99CE,0xEA3C, 0x99CF,0xEA3D, 0x99D0,0xEA3E,
0x99D1,0xEA3F, 0x99D2,0xEA40, 0x99D3,0xEA41, 0x99D4,0xEA42,
0x99D5,0xEA43, 0x99D6,0xEA44, 0x99D7,0xEA45, 0x99D8,0xEA46,
0x99D9,0xEA47, 0x99DA,0xEA48, 0x99DB,0xEA49, 0x99DC,0xEA4A,
0x99DD,0xEA4B, 0x99DE,0xEA4C, 0x99DF,0xEA4D, 0x99E0,0xEA4E,
0x99E1,0xEA4F, 0x99E2,0xEA50, 0x99E3,0xEA51, 0x99E4,0xEA52,
0x99E5,0xEA53, 0x99E6,0xEA54, 0x99E7,0xEA55, 0x99E8,0xEA56,
0x99E9,0xEA57, 0x99EA,0xEA58, 0x99EB,0xEA59, 0x99EC,0xEA5A,
0x99ED,0xEA5B, 0x99EE,0xEA5C, 0x99EF,0xEA5D, 0x99F0,0xEA5E,
0x99F1,0xEA5F, 0x99F2,0xEA60, 0x99F3,0xEA61, 0x99F4,0xEA62,
0x99F5,0xEA63, 0x99F6,0xEA64, 0x99F7,0xEA65, 0x99F8,0xEA66,
0x99F9,0xEA67, 0x99FA,0xEA68, 0x99FC,0xEA6A, 0x99FD,0xEA6B,
0x99FE,0xEA6C, 0x9A40,0xEA6D, 0x9A41,0xEA6E, 0x9A42,0xEA6F,
0x9A43,0xEA70, 0x9A44,0xEA71, 0x9A45,0xEA72, 0x9A46,0xEA73,
0x9A47,0xEA74, 0x9A48,0xEA75, 0x9A49,0xEA76, 0x9A4A,0xEA77,
0x9A4B,0xEA78, 0x9A4C,0xEA79, 0x9A4D,0xEA7A, 0x9A4E,0xEA7B,
0x9A4F,0xEA7C, 0x9A50,0xEA7D, 0x9A51,0xEA7E, 0x9A52,0xEA7F,
0x9A53,0xEA80, 0x9A54,0xEA81, 0x9A55,0xEA82, 0x9A56,0xEA83,
0x9A57,0xEA84, 0x9A58,0xEA85, 0x9A59,0xEA86, 0x9A5A,0xEA87,
0x9A5B,0xEA88, 0x9A5C,0xEA89, 0x9A5D,0xEA8A, 0x9A5E,0xEA8B,
0x9A5F,0xEA8C, 0x9A60,0xEA8D, 0x9A61,0xEA8E, 0x9A62,0xEA8F,
0x9A63,0xEA90, 0x9A64,0xEA91, 0x9A65,0xEA92, 0x9A66,0xEA93,
0x9A67,0xEA94, 0x9A68,0xEA95, 0x9A69,0xEA96, 0x9A6A,0xEA97,
0x9A6B,0xEA98, 0x9A6C,0xEA99, 0x9A6D,0xEA9A, 0x9A6E,0xEA9B,
0x9A6F,0xEA9C, 0x9A70,0xEA9D, 0x9A71,0xEA9E, 0x9A72,0xEA9F,
0x9A73,0xEAA0, 0x9A74,0xEAA1, 0x9A75,0xEAA2, 0x9A76,0xEAA3,
0x9A77,0xEAA4, 0x9A78,0xEAA5, 0x9A79,0xEAA6, 0x9A7A,0xEAA7,
0x9A7B,0xEAA8, 0x9A7C,0xEAA9, 0x9A7D,0xEAAA, 0x9A7E,0xEAAB,
0x9AA1,0xEAAC, 0x9AA2,0xEAAD, 0x9AA3,0xEAAE, 0x9AA4,0xEAAF,
0x9AA5,0xEAB0, 0x9AA6,0xEAB1, 0x9AA7,0xEAB2, 0x9AA8,0xEAB3,
0x9AA9,0xEAB4, 0x9AAA,0xEAB5, 0x9AAB,0xEAB6, 0x9AAC,0xEAB7,
0x9AAD,0xEAB8, 0x9AAE,0xEAB9, 0x9AAF,0xEABA, 0x9AB0,0xEABB,
0x9AB1,0xEABC, 0x9AB2,0xEABD, 0x9AB3,0xEABE, 0x9AB4,0xEABF,
0x9AB5,0xEAC0, 0x9AB6,0xEAC1, 0x9AB7,0xEAC2, 0x9AB8,0xEAC3,
0x9AB9,0xEAC4, 0x9ABA,0xEAC5, 0x9ABB,0xEAC6, 0x9ABC,0xEAC7,
0x9ABD,0xEAC8, 0x9ABE,0xEAC9, 0x9ABF,0xEACA, 0x9AC0,0xEACB,
0x9AC1,0xEACC, 0x9AC2,0xEACD, 0x9AC3,0xEACE, 0x9AC4,0xEACF,
0x9AC5,0xEAD0, 0x9AC6,0xEAD1, 0x9AC7,0xEAD2, 0x9AC8,0xEAD3,
0x9AC9,0xEAD4, 0x9ACA,0xEAD5, 0x9ACB,0xEAD6, 0x9ACC,0xEAD7,
0x9ACD,0xEAD8, 0x9ACE,0xEAD9, 0x9ACF,0xEADA, 0x9AD0,0xEADB,
0x9AD1,0xEADC, 0x9AD2,0xEADD, 0x9AD3,0xEADE, 0x9AD4,0xEADF,
0x9AD5,0xEAE0, 0x9AD6,0xEAE1, 0x9AD7,0xEAE2, 0x9AD8,0xEAE3,
0x9AD9,0xEAE4, 0x9ADA,0xEAE5, 0x9ADB,0xEAE6, 0x9ADC,0xEAE7,
0x9ADD,0xEAE8, 0x9ADE,0xEAE9, 0x9ADF,0xEAEA, 0x9AE0,0xEAEB,
0x9AE1,0xEAEC, 0x9AE2,0xEAED, 0x9AE3,0xEAEE, 0x9AE4,0xEAEF,
0x9AE5,0xEAF0, 0x9AE6,0xEAF1, 0x9AE7,0xEAF2, 0x9AE8,0xEAF3,
0x9AE9,0xEAF4, 0x9AEA,0xEAF5, 0x9AEB,0xEAF6, 0x9AEC,0xEAF7,
0x9AED,0xEAF8, 0x9AEE,0xEAF9, 0x9AEF,0xEAFA, 0x9AF0,0xEAFB,
0x9AF1,0xEAFC, 0x9AF2,0xEAFD, 0x9AF3,0xEAFE, 0x9AF4,0xEAFF,
0x9AF5,0xEB00, 0x9AF6,0xEB01, 0x9AF7,0xEB02, 0x9AF8,0xEB03,
0x9AF9,0xEB04, 0x9AFA,0xEB05, 0x9AFB,0xEB06, 0x9AFC,0xEB07,
0x9AFD,0xEB08, 0x9AFE,0xEB09, 0x9B40,0xEB0A, 0x9B41,0xEB0B,
0x9B42,0xEB0C, 0x9B43,0xEB0D, 0x9B44,0xEB0E, 0x9B45,0xEB0F,
0x9B46,0xEB10, 0x9B47,0xEB11, 0x9B48,0xEB12, 0x9B49,0xEB13,
0x9B4A,0xEB14, 0x9B4B,0xEB15, 0x9B4C,0xEB16, 0x9B4D,0xEB17,
0x9B4E,0xEB18, 0x9B4F,0xEB19, 0x9B50,0xEB1A, 0x9B51,0xEB1B,
0x9B52,0xEB1C, 0x9B53,0xEB1D, 0x9B54,0xEB1E, 0x9B55,0xEB1F,
0x9B56,0xEB20, 0x9B57,0xEB21, 0x9B58,0xEB22, 0x9B59,0xEB23,
0x9B5A,0xEB24, 0x9B5B,0xEB25, 0x9B5C,0xEB26, 0x9B5D,0xEB27,
0x9B5E,0xEB28, 0x9B5F,0xEB29, 0x9B60,0xEB2A, 0x9B61,0xEB2B,
0x9B62,0xEB2C, 0x9B63,0xEB2D, 0x9B64,0xEB2E, 0x9B65,0xEB2F,
0x9B66,0xEB30, 0x9B67,0xEB31, 0x9B68,0xEB32, 0x9B69,0xEB33,
0x9B6A,0xEB34, 0x9B6B,0xEB35, 0x9B6C,0xEB36, 0x9B6D,0xEB37,
0x9B6E,0xEB38, 0x9B6F,0xEB39, 0x9B70,0xEB3A, 0x9B71,0xEB3B,
0x9B72,0xEB3C, 0x9B73,0xEB3D, 0x9B74,0xEB3E, 0x9B75,0xEB3F,
0x9B76,0xEB40, 0x9B77,0xEB41, 0x9B78,0xEB42, 0x9B79,0xEB43,
0x9B7A,0xEB44, 0x9B7B,0xEB45, 0x9B7C,0xEB46, 0x9B7D,0xEB47,
0x9B7E,0xEB48, 0x9BA1,0xEB49, 0x9BA2,0xEB4A, 0x9BA3,0xEB4B,
0x9BA4,0xEB4C, 0x9BA5,0xEB4D, 0x9BA6,0xEB4E, 0x9BA7,0xEB4F,
0x9BA8,0xEB50, 0x9BA9,0xEB51, 0x9BAA,0xEB52, 0x9BAB,0xEB53,
0x9BAC,0xEB54, 0x9BAD,0xEB55, 0x9BAE,0xEB56, 0x9BAF,0xEB57,
0x9BB0,0xEB58, 0x9BB1,0xEB59, 0x9BB2,0xEB5A, 0x9BB3,0xEB5B,
0x9BB4,0xEB5C, 0x9BB5,0xEB5D, 0x9BB6,0xEB5E, 0x9BB7,0xEB5F,
0x9BB8,0xEB60, 0x9BB9,0xEB61, 0x9BBA,0xEB62, 0x9BBB,0xEB63,
0x9BBC,0xEB64, 0x9BBD,0xEB65, 0x9BBE,0xEB66, 0x9BBF,0xEB67,
0x9BC0,0xEB68, 0x9BC1,0xEB69, 0x9BC2,0xEB6A, 0x9BC3,0xEB6B,
0x9BC4,0xEB6C, 0x9BC5,0xEB6D, 0x9BC6,0xEB6E, 0x9BC7,0xEB6F,
0x9BC8,0xEB70, 0x9BC9,0xEB71, 0x9BCA,0xEB72, 0x9BCB,0xEB73,
0x9BCC,0xEB74, 0x9BCD,0xEB75, 0x9BCE,0xEB76, 0x9BCF,0xEB77,
0x9BD0,0xEB78, 0x9BD1,0xEB79, 0x9BD2,0xEB7A, 0x9BD3,0xEB7B,
0x9BD4,0xEB7C, 0x9BD5,0xEB7D, 0x9BD6,0xEB7E, 0x9BD7,0xEB7F,
0x9BD8,0xEB80, 0x9BD9,0xEB81, 0x9BDA,0xEB82, 0x9BDB,0xEB83,
0x9BDC,0xEB84, 0x9BDD,0xEB85, 0x9BE0,0xEB88, 0x9BE1,0xEB89,
0x9BE2,0xEB8A, 0x9BE4,0xEB8C, 0x9BE5,0xEB8D, 0x9BE6,0xEB8E,
0x9BE7,0xEB8F, 0x9BE8,0xEB90, 0x9BE9,0xEB91, 0x9BEA,0xEB92,
0x9BEB,0xEB93, 0x9BEC,0xEB94, 0x9BED,0xEB95, 0x9BEE,0xEB96,
0x9BEF,0xEB97, 0x9BF0,0xEB98, 0x9BF1,0xEB99, 0x9BF2,0xEB9A,
0x9BF3,0xEB9B, 0x9BF4,0xEB9C, 0x9BF5,0xEB9D, 0x9BF6,0xEB9E,
0x9BF7,0xEB9F, 0x9BF8,0xEBA0, 0x9BF9,0xEBA1, 0x9BFA,0xEBA2,
0x9BFB,0xEBA3, 0x9BFC,0xEBA4, 0x9BFD,0xEBA5, 0x9BFE,0xEBA6,
0x9C40,0xEBA7, 0x9C41,0xEBA8, 0x9C42,0xEBA9, 0x9C43,0xEBAA,
0x9C44,0xEBAB, 0x9C45,0xEBAC, 0x9C46,0xEBAD, 0x9C47,0xEBAE,
0x9C48,0xEBAF, 0x9C49,0xEBB0, 0x9C4A,0xEBB1, 0x9C4B,0xEBB2,
0x9C4C,0xEBB3, 0x9C4D,0xEBB4, 0x9C4E,0xEBB5, 0x9C4F,0xEBB6,
0x9C50,0xEBB7, 0x9C51,0xEBB8, 0x9C52,0xEBB9, 0x9C53,0xEBBA,
0x9C54,0xEBBB, 0x9C55,0xEBBC, 0x9C56,0xEBBD, 0x9C57,0xEBBE,
0x9C58,0xEBBF, 0x9C59,0xEBC0, 0x9C5A,0xEBC1, 0x9C5B,0xEBC2,
0x9C5C,0xEBC3, 0x9C5D,0xEBC4, 0x9C5E,0xEBC5, 0x9C5F,0xEBC6,
0x9C60,0xEBC7, 0x9C61,0xEBC8, 0x9C62,0xEBC9, 0x9C63,0xEBCA,
0x9C64,0xEBCB, 0x9C65,0xEBCC, 0x9C66,0xEBCD, 0x9C67,0xEBCE,
0x9C68,0xEBCF, 0x9C69,0xEBD0, 0x9C6A,0xEBD1, 0x9C6B,0xEBD2,
0x9C6C,0xEBD3, 0x9C6D,0xEBD4, 0x9C6E,0xEBD5, 0x9C6F,0xEBD6,
0x9C70,0xEBD7, 0x9C71,0xEBD8, 0x9C72,0xEBD9, 0x9C73,0xEBDA,
0x9C74,0xEBDB, 0x9C75,0xEBDC, 0x9C76,0xEBDD, 0x9C77,0xEBDE,
0x9C78,0xEBDF, 0x9C79,0xEBE0, 0x9C7A,0xEBE1, 0x9C7B,0xEBE2,
0x9C7C,0xEBE3, 0x9C7D,0xEBE4, 0x9C7E,0xEBE5, 0x9CA1,0xEBE6,
0x9CA2,0xEBE7, 0x9CA3,0xEBE8, 0x9CA4,0xEBE9, 0x9CA5,0xEBEA,
0x9CA6,0xEBEB, 0x9CA7,0xEBEC, 0x9CA8,0xEBED, 0x9CA9,0xEBEE,
0x9CAA,0xEBEF, 0x9CAB,0xEBF0, 0x9CAC,0xEBF1, 0x9CAD,0xEBF2,
0x9CAE,0xEBF3, 0x9CAF,0xEBF4, 0x9CB0,0xEBF5, 0x9CB1,0xEBF6,
0x9CB2,0xEBF7, 0x9CB3,0xEBF8, 0x9CB4,0xEBF9, 0x9CB5,0xEBFA,
0x9CB6,0xEBFB, 0x9CB7,0xEBFC, 0x9CB8,0xEBFD, 0x9CB9,0xEBFE,
0x9CBA,0xEBFF, 0x9CBB,0xEC00, 0x9CBC,0xEC01, 0x9CBD,0xEC02,
0x9CBE,0xEC03, 0x9CBF,0xEC04, 0x9CC0,0xEC05, 0x9CC1,0xEC06,
0x9CC2,0xEC07, 0x9CC3,0xEC08, 0x9CC4,0xEC09, 0x9CC5,0xEC0A,
0x9CC6,0xEC0B, 0x9CC7,0xEC0C, 0x9CC8,0xEC0D, 0x9CC9,0xEC0E,
0x9CCA,0xEC0F, 0x9CCB,0xEC10, 0x9CCC,0xEC11, 0x9CCD,0xEC12,
0x9CCE,0xEC13, 0x9CD0,0xEC15, 0x9CD1,0xEC16, 0x9CD2,0xEC17,
0x9CD3,0xEC18, 0x9CD4,0xEC19, 0x9CD5,0xEC1A, 0x9CD6,0xEC1B,
0x9CD8,0xEC1D, 0x9CDB,0xEC20, 0x9CDE,0xEC23, 0x9CDF,0xEC24,
0x9CE0,0xEC25, 0x9CE1,0xEC26, 0x9CE2,0xEC27, 0x9CE3,0xEC28,
0x9CE5,0xEC2A, 0x9CE8,0xEC2D, 0x9CE9,0xEC2E, 0x9CEA,0xEC2F,
0x9CEB,0xEC30, 0x9CEC,0xEC31, 0x9CED,0xEC32, 0x9CEE,0xEC33,
0x9CEF,0xEC34, 0x9CF0,0xEC35, 0x9CF1,0xEC36, 0x9CF2,0xEC37,
0x9CF3,0xEC38, 0x9CF4,0xEC39, 0x9CF5,0xEC3A, 0x9CF6,0xEC3B,
0x9CF7,0xEC3C, 0x9CF8,0xEC3D, 0x9CF9,0xEC3E, 0x9CFA,0xEC3F,
0x9CFB,0xEC40, 0x9CFC,0xEC41, 0x9CFD,0xEC42, 0x9CFE,0xEC43,
0x9D40,0xEC44, 0x9D41,0xEC45, 0x9D42,0xEC46, 0x9D43,0xEC47,
0x9D44,0xEC48, 0x9D45,0xEC49, 0x9D46,0xEC4A, 0x9D47,0xEC4B,
0x9D48,0xEC4C, 0x9D49,0xEC4D, 0x9D4A,0xEC4E, 0x9D4B,0xEC4F,
0x9D4C,0xEC50, 0x9D4D,0xEC51, 0x9D4E,0xEC52, 0x9D4F,0xEC53,
0x9D50,0xEC54, 0x9D51,0xEC55, 0x9D52,0xEC56, 0x9D53,0xEC57,
0x9D54,0xEC58, 0x9D55,0xEC59, 0x9D56,0xEC5A, 0x9D57,0xEC5B,
0x9D58,0xEC5C, 0x9D59,0xEC5D, 0x9D5A,0xEC5E, 0x9D5B,0xEC5F,
0x9D5C,0xEC60, 0x9D5D,0xEC61, 0x9D5E,0xEC62, 0x9D64,0xEC68,
0x9D65,0xEC69, 0x9D66,0xEC6A, 0x9D67,0xEC6B, 0x9D68,0xEC6C,
0x9D69,0xEC6D, 0x9D6B,0xEC6F, 0x9D6C,0xEC70, 0x9D71,0xEC75,
0x9D72,0xEC76, 0x9D73,0xEC77, 0x9D74,0xEC78, 0x9D75,0xEC79,
0x9D76,0xEC7A, 0x9D77,0xEC7B, 0x9D7A,0xEC7E, 0x9D7B,0xEC7F,
0x9D7D,0xEC81, 0x9D7E,0xEC82, 0x9DB0,0xEC92, 0x9DB1,0xEC93,
0x9DB2,0xEC94, 0x9DB3,0xEC95, 0x9DB4,0xEC96, 0x9DB5,0xEC97,
0x9DB6,0xEC98, 0x9DB7,0xEC99, 0x9DB8,0xEC9A, 0x9DB9,0xEC9B,
0x9DBA,0xEC9C, 0x9DBB,0xEC9D, 0x9DBC,0xEC9E, 0x9DC0,0xECA2,
0x9DC8,0xECAA, 0x9DC9,0xECAB, 0x9DCA,0xECAC, 0x9DCB,0xECAD,
0x9DCD,0xECAF, 0x9DCE,0xECB0, 0x9DCF,0xECB1, 0x9DD0,0xECB2,
0x9DD1,0xECB3, 0x9DD2,0xECB4, 0x9DD5,0xECB7, 0x9DD7,0xECB9,
0x9DD8,0xECBA, 0x9DD9,0xECBB, 0x9DDA,0xECBC, 0x9DDB,0xECBD,
0x9DDC,0xECBE, 0x9DDD,0xECBF, 0x9DDE,0xECC0, 0x9DE1,0xECC3,
0x9DE2,0xECC4, 0x9DE3,0xECC5, 0x9DE4,0xECC6, 0x9DE5,0xECC7,
0x9DE7,0xECC9, 0x9DED,0xECCF, 0x9DEE,0xECD0, 0x9DEF,0xECD1,
0x9DF0,0xECD2, 0x9DF1,0xECD3, 0x9DF2,0xECD4, 0x9DF3,0xECD5,
0x9DF4,0xECD6, 0x9DF5,0xECD7, 0x9DF6,0xECD8, 0x9DF7,0xECD9,
0x9DF8,0xECDA, 0x9DF9,0xECDB, 0x9DFA,0xECDC, 0x9DFB,0xECDD,
0x9DFC,0xECDE, 0x9DFD,0xECDF, 0x9DFE,0xECE0, 0x9E40,0xECE1,
0x9E41,0xECE2, 0x9E42,0xECE3, 0x9E43,0xECE4, 0x9E44,0xECE5,
0x9E45,0xECE6, 0x9E46,0xECE7, 0x9E47,0xECE8, 0x9E48,0xECE9,
0x9E49,0xECEA, 0x9E4A,0xECEB, 0x9E4B,0xECEC, 0x9E4C,0xECED,
0x9E4D,0xECEE, 0x9E4E,0xECEF, 0x9E4F,0xECF0, 0x9E50,0xECF1,
0x9E51,0xECF2, 0x9E52,0xECF3, 0x9E53,0xECF4, 0x9E54,0xECF5,
0x9E55,0xECF6, 0x9E56,0xECF7, 0x9E57,0xECF8, 0x9E58,0xECF9,
0x9E59,0xECFA, 0x9E5A,0xECFB, 0x9E5B,0xECFC, 0x9E5C,0xECFD,
0x9E5D,0xECFE, 0x9E5E,0xECFF, 0x9E5F,0xED00, 0x9E60,0xED01,
0x9E61,0xED02, 0x9E62,0xED03, 0x9E63,0xED04, 0x9E64,0xED05,
0x9E65,0xED06, 0x9E66,0xED07, 0x9E67,0xED08, 0x9E68,0xED09,
0x9E69,0xED0A, 0x9E6A,0xED0B, 0x9E6B,0xED0C, 0x9E6C,0xED0D,
0x9E6D,0xED0E, 0x9E6E,0xED0F, 0x9E6F,0xED10, 0x9E70,0xED11,
0x9E71,0xED12, 0x9E72,0xED13, 0x9E73,0xED14, 0x9E74,0xED15,
0x9E75,0xED16, 0x9E76,0xED17, 0x9E77,0xED18, 0x9E78,0xED19,
0x9E79,0xED1A, 0x9E7A,0xED1B, 0x9E7B,0xED1C, 0x9E7C,0xED1D,
0x9E7D,0xED1E, 0x9E7E,0xED1F, 0x9EA1,0xED20, 0x9EA2,0xED21,
0x9EA3,0xED22, 0x9EA4,0xED23, 0x9EA5,0xED24, 0x9EA6,0xED25,
0x9EA7,0xED26, 0x9EA8,0xED27, 0x9EA9,0xED28, 0x9EAA,0xED29,
0x9EAB,0xED2A, 0x9EAC,0xED2B, 0x9EAD,0xED2C, 0x9EAE,0xED2D,
0x9EAF,0xED2E, 0x9EB0,0xED2F, 0x9EB1,0xED30, 0x9EB2,0xED31,
0x9EB3,0xED32, 0x9EB4,0xED33, 0x9EB5,0xED34, 0x9EB6,0xED35,
0x9EB7,0xED36, 0x9EB8,0xED37, 0x9EB9,0xED38, 0x9EBA,0xED39,
0x9EBB,0xED3A, 0x9EBC,0xED3B, 0x9EBD,0xED3C, 0x9EBE,0xED3D,
0x9EBF,0xED3E, 0x9EC0,0xED3F, 0x9EC1,0xED40, 0x9EC2,0xED41,
0x9EC3,0xED42, 0x9EC4,0xED43, 0x9EC5,0xED44, 0x9EC6,0xED45,
0x9EC7,0xED46, 0x9EC8,0xED47, 0x9EC9,0xED48, 0x9ECA,0xED49,
0x9ECB,0xED4A, 0x9ECC,0xED4B, 0x9ECD,0xED4C, 0x9ECE,0xED4D,
0x9ECF,0xED4E, 0x9ED0,0xED4F, 0x9ED1,0xED50, 0x9ED2,0xED51,
0x9ED3,0xED52, 0x9ED4,0xED53, 0x9ED5,0xED54, 0x9ED6,0xED55,
0x9ED7,0xED56, 0x9ED8,0xED57, 0x9ED9,0xED58, 0x9EDA,0xED59,
0x9EDB,0xED5A, 0x9EDC,0xED5B, 0x9EDD,0xED5C, 0x9EDE,0xED5D,
0x9EDF,0xED5E, 0x9EE0,0xED5F, 0x9EE1,0xED60, 0x9EE2,0xED61,
0x9EE3,0xED62, 0x9EE4,0xED63, 0x9EE5,0xED64, 0x9EE6,0xED65,
0x9EE7,0xED66, 0x9EE8,0xED67, 0x9EE9,0xED68, 0x9EEA,0xED69,
0x9EEB,0xED6A, 0x9EEC,0xED6B, 0x9EED,0xED6C, 0x9EEE,0xED6D,
0x9EEF,0xED6E, 0x9EF0,0xED6F, 0x9EF1,0xED70, 0x9EF2,0xED71,
0x9EF3,0xED72, 0x9EF4,0xED73, 0x9EF5,0xED74, 0x9EF6,0xED75,
0x9EF7,0xED76, 0x9EF8,0xED77, 0x9EF9,0xED78, 0x9EFA,0xED79,
0x9EFB,0xED7A, 0x9EFC,0xED7B, 0x9EFD,0xED7C, 0x9EFE,0xED7D,
0x9F40,0xED7E, 0x9F41,0xED7F, 0x9F42,0xED80, 0x9F43,0xED81,
0x9F44,0xED82, 0x9F45,0xED83, 0x9F46,0xED84, 0x9F47,0xED85,
0x9F48,0xED86, 0x9F49,0xED87, 0x9F4A,0xED88, 0x9F4B,0xED89,
0x9F4C,0xED8A, 0x9F4D,0xED8B, 0x9F4E,0xED8C, 0x9F4F,0xED8D,
0x9F50,0xED8E, 0x9F51,0xED8F, 0x9F52,0xED90, 0x9F55,0xED93,
0x9F56,0xED94, 0x9F57,0xED95, 0x9F58,0xED96, 0x9F59,0xED97,
0x9F5A,0xED98, 0x9F5B,0xED99, 0x9F5C,0xED9A, 0x9F5D,0xED9B,
0x9F5E,0xED9C, 0x9F5F,0xED9D, 0x9F60,0xED9E, 0x9F61,0xED9F,
0x9F62,0xEDA0, 0x9F63,0xEDA1, 0x9F64,0xEDA2, 0x9F65,0xEDA3,
0x9F66,0xEDA4, 0x9F67,0xEDA5, 0x9F68,0xEDA6, 0x9F69,0xEDA7,
0x9F6A,0xEDA8, 0x9F6B,0xEDA9, 0x9F6C,0xEDAA, 0x9F6D,0xEDAB,
0x9F6E,0xEDAC, 0x9F6F,0xEDAD, 0x9F70,0xEDAE, 0x9F71,0xEDAF,
0x9F72,0xEDB0, 0x9F73,0xEDB1, 0x9F74,0xEDB2, 0x9F75,0xEDB3,
0x9F76,0xEDB4, 0x9F77,0xEDB5, 0x9F78,0xEDB6, 0x9F79,0xEDB7,
0x9F7A,0xEDB8, 0x9F7B,0xEDB9, 0x9F7C,0xEDBA, 0x9F7D,0xEDBB,
0x9F7E,0xEDBC, 0x9FA1,0xEDBD, 0x9FA2,0xEDBE, 0x9FA3,0xEDBF,
0x9FA4,0xEDC0, 0x9FA5,0xEDC1, 0x9FA6,0xEDC2, 0x9FA7,0xEDC3,
0x9FA8,0xEDC4, 0x9FA9,0xEDC5, 0x9FAA,0xEDC6, 0x9FAB,0xEDC7,
0x9FAC,0xEDC8, 0x9FAD,0xEDC9, 0x9FAE,0xEDCA, 0x9FAF,0xEDCB,
0x9FB0,0xEDCC, 0x9FB1,0xEDCD, 0x9FB2,0xEDCE, 0x9FB3,0xEDCF,
0x9FB4,0xEDD0, 0x9FB5,0xEDD1, 0x9FB6,0xEDD2, 0x9FB7,0xEDD3,
0x9FB8,0xEDD4, 0x9FB9,0xEDD5, 0x9FBA,0xEDD6, 0x9FBB,0xEDD7,
0x9FBC,0xEDD8, 0x9FBD,0xEDD9, 0x9FBE,0xEDDA, 0x9FBF,0xEDDB,
0x9FC0,0xEDDC, 0x9FC1,0xEDDD, 0x9FC2,0xEDDE, 0x9FC3,0xEDDF,
0x9FC4,0xEDE0, 0x9FC5,0xEDE1, 0x9FC6,0xEDE2, 0x9FC7,0xEDE3,
0x9FC8,0xEDE4, 0x9FC9,0xEDE5, 0x9FCA,0xEDE6, 0x9FCB,0xEDE7,
0x9FCC,0xEDE8, 0x9FCD,0xEDE9, 0x9FCE,0xEDEA, 0x9FCF,0xEDEB,
0x9FD0,0xEDEC, 0x9FD1,0xEDED, 0x9FD2,0xEDEE, 0x9FD3,0xEDEF,
0x9FD4,0xEDF0, 0x9FD5,0xEDF1, 0x9FD6,0xEDF2, 0x9FD7,0xEDF3,
0x9FD8,0xEDF4, 0x9FD9,0xEDF5, 0x9FDA,0xEDF6, 0x9FDB,0xEDF7,
0x9FDC,0xEDF8, 0x9FDD,0xEDF9, 0x9FDE,0xEDFA, 0x9FDF,0xEDFB,
0x9FE0,0xEDFC, 0x9FE1,0xEDFD, 0x9FE2,0xEDFE, 0x9FE3,0xEDFF,
0x9FE4,0xEE00, 0x9FE5,0xEE01, 0x9FE6,0xEE02, 0x9FE7,0xEE03,
0x9FE8,0xEE04, 0x9FE9,0xEE05, 0x9FEA,0xEE06, 0x9FEB,0xEE07,
0x9FEC,0xEE08, 0x9FED,0xEE09, 0x9FEE,0xEE0A, 0x9FEF,0xEE0B,
0x9FF0,0xEE0C, 0x9FF1,0xEE0D, 0x9FF2,0xEE0E, 0x9FF3,0xEE0F,
0x9FF4,0xEE10, 0x9FF5,0xEE11, 0x9FF6,0xEE12, 0x9FF7,0xEE13,
0x9FF8,0xEE14, 0x9FF9,0xEE15, 0x9FFA,0xEE16, 0x9FFB,0xEE17,
0x9FFC,0xEE18, 0x9FFD,0xEE19, 0x9FFE,0xEE1A, 0xA040,0xEE1B,
0xA041,0xEE1C, 0xA042,0xEE1D, 0xA044,0xEE1F, 0xA045,0xEE20,
0xA046,0xEE21, 0xA048,0xEE23, 0xA049,0xEE24, 0xA04A,0xEE25,
0xA04B,0xEE26, 0xA04C,0xEE27, 0xA04D,0xEE28, 0xA04E,0xEE29,
0xA04F,0xEE2A, 0xA050,0xEE2B, 0xA051,0xEE2C, 0xA052,0xEE2D,
0xA053,0xEE2E, 0xA054,0xEE2F, 0xA055,0xEE30, 0xA056,0xEE31,
0xA057,0xEE32, 0xA058,0xEE33, 0xA059,0xEE34, 0xA05A,0xEE35,
0xA05B,0xEE36, 0xA05C,0xEE37, 0xA05D,0xEE38, 0xA05E,0xEE39,
0xA05F,0xEE3A, 0xA060,0xEE3B, 0xA061,0xEE3C, 0xA062,0xEE3D,
0xA063,0xEE3E, 0xA064,0xEE3F, 0xA065,0xEE40, 0xA066,0xEE41,
0xA067,0xEE42, 0xA068,0xEE43, 0xA069,0xEE44, 0xA06A,0xEE45,
0xA06B,0xEE46, 0xA06C,0xEE47, 0xA06D,0xEE48, 0xA06E,0xEE49,
0xA06F,0xEE4A, 0xA070,0xEE4B, 0xA071,0xEE4C, 0xA072,0xEE4D,
0xA073,0xEE4E, 0xA074,0xEE4F, 0xA075,0xEE50, 0xA076,0xEE51,
0xA077,0xEE52, 0xA078,0xEE53, 0xA079,0xEE54, 0xA07A,0xEE55,
0xA07B,0xEE56, 0xA07C,0xEE57, 0xA07E,0xEE59, 0xA0A2,0xEE5B,
0xA0A4,0xEE5D, 0xA0A7,0xEE60, 0xA0A8,0xEE61, 0xA0A9,0xEE62,
0xA0AA,0xEE63, 0xA0AB,0xEE64, 0xA0AC,0xEE65, 0xA0AD,0xEE66,
0xA0AE,0xEE67, 0xA0AF,0xEE68, 0xA0B0,0xEE69, 0xA0B1,0xEE6A,
0xA0B2,0xEE6B, 0xA0B3,0xEE6C, 0xA0B4,0xEE6D, 0xA0B5,0xEE6E,
0xA0B6,0xEE6F, 0xA0B7,0xEE70, 0xA0B8,0xEE71, 0xA0B9,0xEE72,
0xA0BA,0xEE73, 0xA0BB,0xEE74, 0xA0BC,0xEE75, 0xA0BD,0xEE76,
0xA0BE,0xEE77, 0xA0BF,0xEE78, 0xA0C0,0xEE79, 0xA0C1,0xEE7A,
0xA0C2,0xEE7B, 0xA0C3,0xEE7C, 0xA0C4,0xEE7D, 0xA0C5,0xEE7E,
0xA0C6,0xEE7F, 0xA0C7,0xEE80, 0xA0C8,0xEE81, 0xA0C9,0xEE82,
0xA0CA,0xEE83, 0xA0CB,0xEE84, 0xA0CC,0xEE85, 0xA0CD,0xEE86,
0xA0CE,0xEE87, 0xA0CF,0xEE88, 0xA0D0,0xEE89, 0xA0D1,0xEE8A,
0xA0D2,0xEE8B, 0xA0D3,0xEE8C, 0xA0D4,0xEE8D, 0xA0D5,0xEE8E,
0xA0D6,0xEE8F, 0xA0D7,0xEE90, 0xA0D8,0xEE91, 0xA0D9,0xEE92,
0xA0DA,0xEE93, 0xA0DB,0xEE94, 0xA0DC,0xEE95, 0xA0DD,0xEE96,
0xA0DE,0xEE97, 0xA0DF,0xEE98, 0xA0E0,0xEE99, 0xA0E1,0xEE9A,
0xA0E2,0xEE9B, 0xA0E3,0xEE9C, 0xA0E4,0xEE9D, 0xA0E5,0xEE9E,
0xA0E6,0xEE9F, 0xA0E7,0xEEA0, 0xA0E8,0xEEA1, 0xA0E9,0xEEA2,
0xA0EA,0xEEA3, 0xA0EB,0xEEA4, 0xA0EC,0xEEA5, 0xA0ED,0xEEA6,
0xA0EE,0xEEA7, 0xA0EF,0xEEA8, 0xA0F0,0xEEA9, 0xA0F1,0xEEAA,
0xA0F2,0xEEAB, 0xA0F3,0xEEAC, 0xA0F4,0xEEAD, 0xA0F5,0xEEAE,
0xA0F6,0xEEAF, 0xA0F7,0xEEB0, 0xA0F8,0xEEB1, 0xA0F9,0xEEB2,
0xA0FA,0xEEB3, 0xA0FB,0xEEB4, 0xA0FC,0xEEB5, 0xA0FE,0xEEB7,
0x8140,0xEEB8, 0x8141,0xEEB9, 0x8142,0xEEBA, 0x8143,0xEEBB,
0x8144,0xEEBC, 0x8145,0xEEBD, 0x8146,0xEEBE, 0x8147,0xEEBF,
0x8148,0xEEC0, 0x8149,0xEEC1, 0x814A,0xEEC2, 0x814B,0xEEC3,
0x814C,0xEEC4, 0x814D,0xEEC5, 0x814E,0xEEC6, 0x814F,0xEEC7,
0x8150,0xEEC8, 0x8151,0xEEC9, 0x8152,0xEECA, 0x8153,0xEECB,
0x8154,0xEECC, 0x8155,0xEECD, 0x8156,0xEECE, 0x8157,0xEECF,
0x8158,0xEED0, 0x8159,0xEED1, 0x815A,0xEED2, 0x815B,0xEED3,
0x815C,0xEED4, 0x815D,0xEED5, 0x815E,0xEED6, 0x815F,0xEED7,
0x8160,0xEED8, 0x8161,0xEED9, 0x8162,0xEEDA, 0x8163,0xEEDB,
0x8164,0xEEDC, 0x8165,0xEEDD, 0x8166,0xEEDE, 0x8167,0xEEDF,
0x8168,0xEEE0, 0x8169,0xEEE1, 0x816A,0xEEE2, 0x816B,0xEEE3,
0x816C,0xEEE4, 0x816D,0xEEE5, 0x816E,0xEEE6, 0x816F,0xEEE7,
0x8170,0xEEE8, 0x8171,0xEEE9, 0x8172,0xEEEA, 0x8173,0xEEEB,
0x8174,0xEEEC, 0x8175,0xEEED, 0x8176,0xEEEE, 0x8177,0xEEEF,
0x8178,0xEEF0, 0x8179,0xEEF1, 0x817A,0xEEF2, 0x817B,0xEEF3,
0x817C,0xEEF4, 0x817D,0xEEF5, 0x817E,0xEEF6, 0x81A1,0xEEF7,
0x81A2,0xEEF8, 0x81A3,0xEEF9, 0x81A4,0xEEFA, 0x81A5,0xEEFB,
0x81A6,0xEEFC, 0x81A7,0xEEFD, 0x81A8,0xEEFE, 0x81A9,0xEEFF,
0x81AA,0xEF00, 0x81AB,0xEF01, 0x81AC,0xEF02, 0x81AD,0xEF03,
0x81AE,0xEF04, 0x81AF,0xEF05, 0x81B0,0xEF06, 0x81B1,0xEF07,
0x81B2,0xEF08, 0x81B3,0xEF09, 0x81B4,0xEF0A, 0x81B5,0xEF0B,
0x81B6,0xEF0C, 0x81B7,0xEF0D, 0x81B8,0xEF0E, 0x81B9,0xEF0F,
0x81BA,0xEF10, 0x81BB,0xEF11, 0x81BC,0xEF12, 0x81BD,0xEF13,
0x81BE,0xEF14, 0x81BF,0xEF15, 0x81C0,0xEF16, 0x81C1,0xEF17,
0x81C2,0xEF18, 0x81C3,0xEF19, 0x81C4,0xEF1A, 0x81C5,0xEF1B,
0x81C6,0xEF1C, 0x81C7,0xEF1D, 0x81C8,0xEF1E, 0x81C9,0xEF1F,
0x81CA,0xEF20, 0x81CB,0xEF21, 0x81CC,0xEF22, 0x81CD,0xEF23,
0x81CE,0xEF24, 0x81CF,0xEF25, 0x81D0,0xEF26, 0x81D1,0xEF27,
0x81D2,0xEF28, 0x81D3,0xEF29, 0x81D4,0xEF2A, 0x81D5,0xEF2B,
0x81D6,0xEF2C, 0x81D7,0xEF2D, 0x81D8,0xEF2E, 0x81D9,0xEF2F,
0x81DA,0xEF30, 0x81DB,0xEF31, 0x81DC,0xEF32, 0x81DD,0xEF33,
0x81DE,0xEF34, 0x81DF,0xEF35, 0x81E0,0xEF36, 0x81E1,0xEF37,
0x81E2,0xEF38, 0x81E3,0xEF39, 0x81E4,0xEF3A, 0x81E5,0xEF3B,
0x81E6,0xEF3C, 0x81E7,0xEF3D, 0x81E8,0xEF3E, 0x81E9,0xEF3F,
0x81EA,0xEF40, 0x81EB,0xEF41, 0x81EC,0xEF42, 0x81ED,0xEF43,
0x81EE,0xEF44, 0x81EF,0xEF45, 0x81F0,0xEF46, 0x81F1,0xEF47,
0x81F2,0xEF48, 0x81F3,0xEF49, 0x81F4,0xEF4A, 0x81F5,0xEF4B,
0x81F6,0xEF4C, 0x81F7,0xEF4D, 0x81F8,0xEF4E, 0x81F9,0xEF4F,
0x81FA,0xEF50, 0x81FB,0xEF51, 0x81FC,0xEF52, 0x81FD,0xEF53,
0x81FE,0xEF54, 0x8240,0xEF55, 0x8241,0xEF56, 0x8242,0xEF57,
0x8243,0xEF58, 0x8244,0xEF59, 0x8245,0xEF5A, 0x8246,0xEF5B,
0x8247,0xEF5C, 0x8248,0xEF5D, 0x8249,0xEF5E, 0x824A,0xEF5F,
0x824B,0xEF60, 0x824C,0xEF61, 0x824D,0xEF62, 0x824E,0xEF63,
0x824F,0xEF64, 0x8250,0xEF65, 0x8251,0xEF66, 0x8252,0xEF67,
0x8253,0xEF68, 0x8254,0xEF69, 0x8255,0xEF6A, 0x8256,0xEF6B,
0x8257,0xEF6C, 0x8258,0xEF6D, 0x8259,0xEF6E, 0x825A,0xEF6F,
0x825B,0xEF70, 0x825C,0xEF71, 0x825D,0xEF72, 0x825E,0xEF73,
0x825F,0xEF74, 0x8260,0xEF75, 0x8261,0xEF76, 0x8262,0xEF77,
0x8263,0xEF78, 0x8265,0xEF7A, 0x8266,0xEF7B, 0x8267,0xEF7C,
0x8268,0xEF7D, 0x8269,0xEF7E, 0x826A,0xEF7F, 0x826B,0xEF80,
0x826C,0xEF81, 0x826D,0xEF82, 0x826E,0xEF83, 0x826F,0xEF84,
0x8270,0xEF85, 0x8271,0xEF86, 0x8272,0xEF87, 0x8273,0xEF88,
0x8274,0xEF89, 0x8275,0xEF8A, 0x8276,0xEF8B, 0x8277,0xEF8C,
0x8278,0xEF8D, 0x8279,0xEF8E, 0x827A,0xEF8F, 0x827B,0xEF90,
0x827C,0xEF91, 0x827D,0xEF92, 0x827E,0xEF93, 0x82A1,0xEF94,
0x82A2,0xEF95, 0x82A3,0xEF96, 0x82A4,0xEF97, 0x82A5,0xEF98,
0x82A6,0xEF99, 0x82A7,0xEF9A, 0x82A8,0xEF9B, 0x82A9,0xEF9C,
0x82AA,0xEF9D, 0x82AB,0xEF9E, 0x82AC,0xEF9F, 0x82AD,0xEFA0,
0x82AE,0xEFA1, 0x82AF,0xEFA2, 0x82B0,0xEFA3, 0x82B1,0xEFA4,
0x82B2,0xEFA5, 0x82B3,0xEFA6, 0x82B4,0xEFA7, 0x82B5,0xEFA8,
0x82B6,0xEFA9, 0x82B7,0xEFAA, 0x82B8,0xEFAB, 0x82B9,0xEFAC,
0x82BA,0xEFAD, 0x82BB,0xEFAE, 0x82BC,0xEFAF, 0x82BD,0xEFB0,
0x82BE,0xEFB1, 0x82BF,0xEFB2, 0x82C0,0xEFB3, 0x82C1,0xEFB4,
0x82C2,0xEFB5, 0x82C3,0xEFB6, 0x82C4,0xEFB7, 0x82C5,0xEFB8,
0x82C6,0xEFB9, 0x82C7,0xEFBA, 0x82C8,0xEFBB, 0x82C9,0xEFBC,
0x82CA,0xEFBD, 0x82CB,0xEFBE, 0x82CC,0xEFBF, 0x82CD,0xEFC0,
0x82CE,0xEFC1, 0x82CF,0xEFC2, 0x82D0,0xEFC3, 0x82D1,0xEFC4,
0x82D2,0xEFC5, 0x82D3,0xEFC6, 0x82D4,0xEFC7, 0x82D5,0xEFC8,
0x82D6,0xEFC9, 0x82D7,0xEFCA, 0x82D8,0xEFCB, 0x82D9,0xEFCC,
0x82DA,0xEFCD, 0x82DB,0xEFCE, 0x82DC,0xEFCF, 0x82DD,0xEFD0,
0x82DE,0xEFD1, 0x82DF,0xEFD2, 0x82E0,0xEFD3, 0x82E1,0xEFD4,
0x82E2,0xEFD5, 0x82E3,0xEFD6, 0x82E4,0xEFD7, 0x82E5,0xEFD8,
0x82E6,0xEFD9, 0x82E7,0xEFDA, 0x82E8,0xEFDB, 0x82E9,0xEFDC,
0x82EA,0xEFDD, 0x82EB,0xEFDE, 0x82EC,0xEFDF, 0x82ED,0xEFE0,
0x82EE,0xEFE1, 0x82EF,0xEFE2, 0x82F0,0xEFE3, 0x82F1,0xEFE4,
0x82F2,0xEFE5, 0x82F3,0xEFE6, 0x82F4,0xEFE7, 0x82F5,0xEFE8,
0x82F6,0xEFE9, 0x82F7,0xEFEA, 0x82F8,0xEFEB, 0x82F9,0xEFEC,
0x82FA,0xEFED, 0x82FB,0xEFEE, 0x82FC,0xEFEF, 0x82FD,0xEFF0,
0x82FE,0xEFF1, 0x8340,0xEFF2, 0x8341,0xEFF3, 0x8342,0xEFF4,
0x8343,0xEFF5, 0x8344,0xEFF6, 0x8345,0xEFF7, 0x8346,0xEFF8,
0x8347,0xEFF9, 0x8348,0xEFFA, 0x8349,0xEFFB, 0x834A,0xEFFC,
0x834B,0xEFFD, 0x834C,0xEFFE, 0x834D,0xEFFF, 0x834E,0xF000,
0x834F,0xF001, 0x8350,0xF002, 0x8351,0xF003, 0x8352,0xF004,
0x8353,0xF005, 0x8354,0xF006, 0x8355,0xF007, 0x8356,0xF008,
0x8357,0xF009, 0x8358,0xF00A, 0x8359,0xF00B, 0x835A,0xF00C,
0x835B,0xF00D, 0x835C,0xF00E, 0x835D,0xF00F, 0x835E,0xF010,
0x835F,0xF011, 0x8360,0xF012, 0x8361,0xF013, 0x8362,0xF014,
0x8363,0xF015, 0x8364,0xF016, 0x8365,0xF017, 0x8366,0xF018,
0x8367,0xF019, 0x8368,0xF01A, 0x8369,0xF01B, 0x836A,0xF01C,
0x836B,0xF01D, 0x836C,0xF01E, 0x836D,0xF01F, 0x836E,0xF020,
0x836F,0xF021, 0x8370,0xF022, 0x8371,0xF023, 0x8372,0xF024,
0x8373,0xF025, 0x8374,0xF026, 0x8375,0xF027, 0x8376,0xF028,
0x8377,0xF029, 0x8378,0xF02A, 0x8379,0xF02B, 0x837A,0xF02C,
0x837B,0xF02D, 0x837C,0xF02E, 0x837D,0xF02F, 0x837E,0xF030,
0x83A1,0xF031, 0x83A2,0xF032, 0x83A3,0xF033, 0x83A4,0xF034,
0x83A5,0xF035, 0x83A6,0xF036, 0x83A7,0xF037, 0x83A8,0xF038,
0x83A9,0xF039, 0x83AA,0xF03A, 0x83AB,0xF03B, 0x83AC,0xF03C,
0x83AD,0xF03D, 0x83AE,0xF03E, 0x83AF,0xF03F, 0x83B0,0xF040,
0x83B1,0xF041, 0x83B2,0xF042, 0x83B3,0xF043, 0x83B4,0xF044,
0x83B5,0xF045, 0x83B6,0xF046, 0x83B7,0xF047, 0x83B8,0xF048,
0x83B9,0xF049, 0x83BA,0xF04A, 0x83BB,0xF04B, 0x83BC,0xF04C,
0x83BD,0xF04D, 0x83BE,0xF04E, 0x83BF,0xF04F, 0x83C0,0xF050,
0x83C1,0xF051, 0x83C2,0xF052, 0x83C3,0xF053, 0x83C4,0xF054,
0x83C5,0xF055, 0x83C6,0xF056, 0x83C7,0xF057, 0x83C8,0xF058,
0x83C9,0xF059, 0x83CA,0xF05A, 0x83CB,0xF05B, 0x83CC,0xF05C,
0x83CD,0xF05D, 0x83CE,0xF05E, 0x83CF,0xF05F, 0x83D0,0xF060,
0x83D1,0xF061, 0x83D2,0xF062, 0x83D3,0xF063, 0x83D4,0xF064,
0x83D5,0xF065, 0x83D6,0xF066, 0x83D7,0xF067, 0x83D8,0xF068,
0x83D9,0xF069, 0x83DA,0xF06A, 0x83DB,0xF06B, 0x83DC,0xF06C,
0x83DD,0xF06D, 0x83DE,0xF06E, 0x83DF,0xF06F, 0x83E0,0xF070,
0x83E1,0xF071, 0x83E2,0xF072, 0x83E3,0xF073, 0x83E4,0xF074,
0x83E5,0xF075, 0x83E6,0xF076, 0x83E7,0xF077, 0x83E8,0xF078,
0x83E9,0xF079, 0x83EA,0xF07A, 0x83EB,0xF07B, 0x83EC,0xF07C,
0x83ED,0xF07D, 0x83EE,0xF07E, 0x83EF,0xF07F, 0x83F0,0xF080,
0x83F1,0xF081, 0x83F2,0xF082, 0x83F3,0xF083, 0x83F4,0xF084,
0x83F5,0xF085, 0x83F6,0xF086, 0x83F7,0xF087, 0x83F8,0xF088,
0x83F9,0xF089, 0x83FA,0xF08A, 0x83FB,0xF08B, 0x83FC,0xF08C,
0x83FD,0xF08D, 0x83FE,0xF08E, 0x8440,0xF08F, 0x8441,0xF090,
0x8442,0xF091, 0x8443,0xF092, 0x8444,0xF093, 0x8445,0xF094,
0x8446,0xF095, 0x8447,0xF096, 0x8448,0xF097, 0x8449,0xF098,
0x844A,0xF099, 0x844B,0xF09A, 0x844C,0xF09B, 0x844D,0xF09C,
0x844E,0xF09D, 0x844F,0xF09E, 0x8450,0xF09F, 0x8451,0xF0A0,
0x8452,0xF0A1, 0x8453,0xF0A2, 0x8454,0xF0A3, 0x8455,0xF0A4,
0x8456,0xF0A5, 0x8457,0xF0A6, 0x8458,0xF0A7, 0x8459,0xF0A8,
0x845A,0xF0A9, 0x845B,0xF0AA, 0x845C,0xF0AB, 0x845D,0xF0AC,
0x845E,0xF0AD, 0x845F,0xF0AE, 0x8460,0xF0AF, 0x8461,0xF0B0,
0x8462,0xF0B1, 0x8463,0xF0B2, 0x8464,0xF0B3, 0x8465,0xF0B4,
0x8466,0xF0B5, 0x8467,0xF0B6, 0x8468,0xF0B7, 0x8469,0xF0B8,
0x846A,0xF0B9, 0x846B,0xF0BA, 0x846C,0xF0BB, 0x846D,0xF0BC,
0x846E,0xF0BD, 0x846F,0xF0BE, 0x8470,0xF0BF, 0x8471,0xF0C0,
0x8472,0xF0C1, 0x8473,0xF0C2, 0x8474,0xF0C3, 0x8475,0xF0C4,
0x8476,0xF0C5, 0x8477,0xF0C6, 0x8478,0xF0C7, 0x8479,0xF0C8,
0x847A,0xF0C9, 0x847B,0xF0CA, 0x847C,0xF0CB, 0x847D,0xF0CC,
0x847E,0xF0CD, 0x84A1,0xF0CE, 0x84A2,0xF0CF, 0x84A3,0xF0D0,
0x84A4,0xF0D1, 0x84A5,0xF0D2, 0x84A6,0xF0D3, 0x84A7,0xF0D4,
0x84A8,0xF0D5, 0x84A9,0xF0D6, 0x84AA,0xF0D7, 0x84AB,0xF0D8,
0x84AC,0xF0D9, 0x84AD,0xF0DA, 0x84AE,0xF0DB, 0x84AF,0xF0DC,
0x84B0,0xF0DD, 0x84B1,0xF0DE, 0x84B2,0xF0DF, 0x84B3,0xF0E0,
0x84B4,0xF0E1, 0x84B5,0xF0E2, 0x84B6,0xF0E3, 0x84B7,0xF0E4,
0x84B8,0xF0E5, 0x84B9,0xF0E6, 0x84BA,0xF0E7, 0x84BB,0xF0E8,
0x84BC,0xF0E9, 0x84BD,0xF0EA, 0x84BE,0xF0EB, 0x84BF,0xF0EC,
0x84C0,0xF0ED, 0x84C1,0xF0EE, 0x84C2,0xF0EF, 0x84C3,0xF0F0,
0x84C4,0xF0F1, 0x84C5,0xF0F2, 0x84C6,0xF0F3, 0x84C7,0xF0F4,
0x84C8,0xF0F5, 0x84C9,0xF0F6, 0x84CA,0xF0F7, 0x84CB,0xF0F8,
0x84CC,0xF0F9, 0x84CD,0xF0FA, 0x84CE,0xF0FB, 0x84CF,0xF0FC,
0x84D0,0xF0FD, 0x84D1,0xF0FE, 0x84D2,0xF0FF, 0x84D3,0xF100,
0x84D4,0xF101, 0x84D5,0xF102, 0x84D6,0xF103, 0x84D7,0xF104,
0x84D8,0xF105, 0x84D9,0xF106, 0x84DA,0xF107, 0x84DB,0xF108,
0x84DC,0xF109, 0x84DD,0xF10A, 0x84DE,0xF10B, 0x84DF,0xF10C,
0x84E0,0xF10D, 0x84E1,0xF10E, 0x84E2,0xF10F, 0x84E3,0xF110,
0x84E4,0xF111, 0x84E5,0xF112, 0x84E6,0xF113, 0x84E7,0xF114,
0x84E8,0xF115, 0x84E9,0xF116, 0x84EA,0xF117, 0x84EB,0xF118,
0x84EC,0xF119, 0x84ED,0xF11A, 0x84EE,0xF11B, 0x84EF,0xF11C,
0x84F0,0xF11D, 0x84F1,0xF11E, 0x84F2,0xF11F, 0x84F3,0xF120,
0x84F4,0xF121, 0x84F5,0xF122, 0x84F6,0xF123, 0x84F7,0xF124,
0x84F8,0xF125, 0x84F9,0xF126, 0x84FA,0xF127, 0x84FB,0xF128,
0x84FC,0xF129, 0x84FD,0xF12A, 0x84FE,0xF12B, 0x8540,0xF12C,
0x8541,0xF12D, 0x8542,0xF12E, 0x8543,0xF12F, 0x8544,0xF130,
0x8545,0xF131, 0x8546,0xF132, 0x8547,0xF133, 0x8548,0xF134,
0x8549,0xF135, 0x854A,0xF136, 0x854B,0xF137, 0x854C,0xF138,
0x854D,0xF139, 0x854E,0xF13A, 0x854F,0xF13B, 0x8550,0xF13C,
0x8551,0xF13D, 0x8552,0xF13E, 0x8553,0xF13F, 0x8554,0xF140,
0x8555,0xF141, 0x8556,0xF142, 0x8557,0xF143, 0x8558,0xF144,
0x8559,0xF145, 0x855A,0xF146, 0x855B,0xF147, 0x855C,0xF148,
0x855D,0xF149, 0x855E,0xF14A, 0x855F,0xF14B, 0x8560,0xF14C,
0x8561,0xF14D, 0x8562,0xF14E, 0x8563,0xF14F, 0x8564,0xF150,
0x8565,0xF151, 0x8566,0xF152, 0x8567,0xF153, 0x8568,0xF154,
0x8569,0xF155, 0x856A,0xF156, 0x856B,0xF157, 0x856C,0xF158,
0x856D,0xF159, 0x856E,0xF15A, 0x856F,0xF15B, 0x8570,0xF15C,
0x8571,0xF15D, 0x8572,0xF15E, 0x8573,0xF15F, 0x8574,0xF160,
0x8575,0xF161, 0x8576,0xF162, 0x8577,0xF163, 0x8578,0xF164,
0x8579,0xF165, 0x857A,0xF166, 0x857B,0xF167, 0x857C,0xF168,
0x857D,0xF169, 0x857E,0xF16A, 0x85A1,0xF16B, 0x85A2,0xF16C,
0x85A3,0xF16D, 0x85A4,0xF16E, 0x85A5,0xF16F, 0x85A6,0xF170,
0x85A7,0xF171, 0x85A8,0xF172, 0x85A9,0xF173, 0x85AA,0xF174,
0x85AB,0xF175, 0x85AC,0xF176, 0x85AD,0xF177, 0x85AE,0xF178,
0x85AF,0xF179, 0x85B0,0xF17A, 0x85B1,0xF17B, 0x85B2,0xF17C,
0x85B3,0xF17D, 0x85B4,0xF17E, 0x85B5,0xF17F, 0x85B6,0xF180,
0x85B7,0xF181, 0x85B8,0xF182, 0x85B9,0xF183, 0x85BA,0xF184,
0x85BB,0xF185, 0x85BC,0xF186, 0x85BD,0xF187, 0x85BE,0xF188,
0x85BF,0xF189, 0x85C0,0xF18A, 0x85C1,0xF18B, 0x85C2,0xF18C,
0x85C3,0xF18D, 0x85C4,0xF18E, 0x85C5,0xF18F, 0x85C6,0xF190,
0x85C7,0xF191, 0x85C8,0xF192, 0x85C9,0xF193, 0x85CA,0xF194,
0x85CB,0xF195, 0x85CC,0xF196, 0x85CD,0xF197, 0x85CE,0xF198,
0x85CF,0xF199, 0x85D0,0xF19A, 0x85D1,0xF19B, 0x85D2,0xF19C,
0x85D3,0xF19D, 0x85D4,0xF19E, 0x85D5,0xF19F, 0x85D6,0xF1A0,
0x85D7,0xF1A1, 0x85D8,0xF1A2, 0x85D9,0xF1A3, 0x85DA,0xF1A4,
0x85DB,0xF1A5, 0x85DC,0xF1A6, 0x85DD,0xF1A7, 0x85DE,0xF1A8,
0x85DF,0xF1A9, 0x85E0,0xF1AA, 0x85E1,0xF1AB, 0x85E2,0xF1AC,
0x85E3,0xF1AD, 0x85E4,0xF1AE, 0x85E5,0xF1AF, 0x85E6,0xF1B0,
0x85E7,0xF1B1, 0x85E8,0xF1B2, 0x85E9,0xF1B3, 0x85EA,0xF1B4,
0x85EB,0xF1B5, 0x85EC,0xF1B6, 0x85ED,0xF1B7, 0x85EE,0xF1B8,
0x85EF,0xF1B9, 0x85F0,0xF1BA, 0x85F1,0xF1BB, 0x85F2,0xF1BC,
0x85F3,0xF1BD, 0x85F4,0xF1BE, 0x85F5,0xF1BF, 0x85F6,0xF1C0,
0x85F7,0xF1C1, 0x85F8,0xF1C2, 0x85F9,0xF1C3, 0x85FA,0xF1C4,
0x85FB,0xF1C5, 0x85FC,0xF1C6, 0x85FD,0xF1C7, 0x85FE,0xF1C8,
0x8640,0xF1C9, 0x8641,0xF1CA, 0x8642,0xF1CB, 0x8643,0xF1CC,
0x8644,0xF1CD, 0x8645,0xF1CE, 0x8646,0xF1CF, 0x8647,0xF1D0,
0x8648,0xF1D1, 0x8649,0xF1D2, 0x864A,0xF1D3, 0x864B,0xF1D4,
0x864C,0xF1D5, 0x864D,0xF1D6, 0x864E,0xF1D7, 0x864F,0xF1D8,
0x8650,0xF1D9, 0x8651,0xF1DA, 0x8652,0xF1DB, 0x8653,0xF1DC,
0x8654,0xF1DD, 0x8655,0xF1DE, 0x8656,0xF1DF, 0x8657,0xF1E0,
0x8658,0xF1E1, 0x8659,0xF1E2, 0x865A,0xF1E3, 0x865B,0xF1E4,
0x865C,0xF1E5, 0x865D,0xF1E6, 0x865E,0xF1E7, 0x865F,0xF1E8,
0x8660,0xF1E9, 0x8661,0xF1EA, 0x8662,0xF1EB, 0x8663,0xF1EC,
0x8664,0xF1ED, 0x8665,0xF1EE, 0x8666,0xF1EF, 0x8667,0xF1F0,
0x8668,0xF1F1, 0x8669,0xF1F2, 0x866A,0xF1F3, 0x866B,0xF1F4,
0x866C,0xF1F5, 0x866D,0xF1F6, 0x866E,0xF1F7, 0x866F,0xF1F8,
0x8670,0xF1F9, 0x8671,0xF1FA, 0x8672,0xF1FB, 0x8673,0xF1FC,
0x8674,0xF1FD, 0x8675,0xF1FE, 0x8676,0xF1FF, 0x8677,0xF200,
0x8678,0xF201, 0x8679,0xF202, 0x867A,0xF203, 0x867B,0xF204,
0x867C,0xF205, 0x867D,0xF206, 0x867E,0xF207, 0x86A1,0xF208,
0x86A2,0xF209, 0x86A3,0xF20A, 0x86A4,0xF20B, 0x86A5,0xF20C,
0x86A6,0xF20D, 0x86A7,0xF20E, 0x86A8,0xF20F, 0x86A9,0xF210,
0x86AA,0xF211, 0x86AB,0xF212, 0x86AC,0xF213, 0x86AD,0xF214,
0x86AE,0xF215, 0x86AF,0xF216, 0x86B0,0xF217, 0x86B1,0xF218,
0x86B2,0xF219, 0x86B3,0xF21A, 0x86B4,0xF21B, 0x86B5,0xF21C,
0x86B6,0xF21D, 0x86B7,0xF21E, 0x86B8,0xF21F, 0x86B9,0xF220,
0x86BA,0xF221, 0x86BB,0xF222, 0x86BC,0xF223, 0x86BD,0xF224,
0x86BE,0xF225, 0x86BF,0xF226, 0x86C0,0xF227, 0x86C1,0xF228,
0x86C2,0xF229, 0x86C3,0xF22A, 0x86C4,0xF22B, 0x86C5,0xF22C,
0x86C6,0xF22D, 0x86C7,0xF22E, 0x86C8,0xF22F, 0x86C9,0xF230,
0x86CA,0xF231, 0x86CB,0xF232, 0x86CC,0xF233, 0x86CD,0xF234,
0x86CE,0xF235, 0x86CF,0xF236, 0x86D0,0xF237, 0x86D1,0xF238,
0x86D2,0xF239, 0x86D3,0xF23A, 0x86D4,0xF23B, 0x86D5,0xF23C,
0x86D6,0xF23D, 0x86D7,0xF23E, 0x86D8,0xF23F, 0x86D9,0xF240,
0x86DA,0xF241, 0x86DB,0xF242, 0x86DC,0xF243, 0x86DD,0xF244,
0x86DE,0xF245, 0x86DF,0xF246, 0x86E0,0xF247, 0x86E1,0xF248,
0x86E2,0xF249, 0x86E3,0xF24A, 0x86E4,0xF24B, 0x86E5,0xF24C,
0x86E6,0xF24D, 0x86E7,0xF24E, 0x86E8,0xF24F, 0x86E9,0xF250,
0x86EA,0xF251, 0x86EB,0xF252, 0x86EC,0xF253, 0x86ED,0xF254,
0x86EE,0xF255, 0x86EF,0xF256, 0x86F0,0xF257, 0x86F1,0xF258,
0x86F2,0xF259, 0x86F3,0xF25A, 0x86F4,0xF25B, 0x86F5,0xF25C,
0x86F6,0xF25D, 0x86F7,0xF25E, 0x86F8,0xF25F, 0x86F9,0xF260,
0x86FA,0xF261, 0x86FB,0xF262, 0x86FC,0xF263, 0x86FD,0xF264,
0x86FE,0xF265, 0x8740,0xF266, 0x8741,0xF267, 0x8742,0xF268,
0x8743,0xF269, 0x8744,0xF26A, 0x8745,0xF26B, 0x8746,0xF26C,
0x8747,0xF26D, 0x8748,0xF26E, 0x8749,0xF26F, 0x874A,0xF270,
0x874B,0xF271, 0x874C,0xF272, 0x874D,0xF273, 0x874E,0xF274,
0x874F,0xF275, 0x8750,0xF276, 0x8751,0xF277, 0x8752,0xF278,
0x8753,0xF279, 0x8754,0xF27A, 0x8755,0xF27B, 0x8756,0xF27C,
0x8757,0xF27D, 0x8758,0xF27E, 0x8759,0xF27F, 0x875A,0xF280,
0x875B,0xF281, 0x875C,0xF282, 0x875D,0xF283, 0x875E,0xF284,
0x875F,0xF285, 0x8760,0xF286, 0x8761,0xF287, 0x8762,0xF288,
0x8763,0xF289, 0x8764,0xF28A, 0x8765,0xF28B, 0x8766,0xF28C,
0x8767,0xF28D, 0x8768,0xF28E, 0x8769,0xF28F, 0x876A,0xF290,
0x876B,0xF291, 0x876C,0xF292, 0x876D,0xF293, 0x876E,0xF294,
0x876F,0xF295, 0x8770,0xF296, 0x8771,0xF297, 0x8772,0xF298,
0x8773,0xF299, 0x8774,0xF29A, 0x8775,0xF29B, 0x8776,0xF29C,
0x8777,0xF29D, 0x8778,0xF29E, 0x8779,0xF29F, 0x877A,0xF2A0,
0x877B,0xF2A1, 0x877C,0xF2A2, 0x877D,0xF2A3, 0x877E,0xF2A4,
0x87A1,0xF2A5, 0x87A2,0xF2A6, 0x87A3,0xF2A7, 0x87A4,0xF2A8,
0x87A5,0xF2A9, 0x87A6,0xF2AA, 0x87A7,0xF2AB, 0x87A8,0xF2AC,
0x87A9,0xF2AD, 0x87AA,0xF2AE, 0x87AB,0xF2AF, 0x87AC,0xF2B0,
0x87AD,0xF2B1, 0x87AE,0xF2B2, 0x87AF,0xF2B3, 0x87B0,0xF2B4,
0x87B1,0xF2B5, 0x87B2,0xF2B6, 0x87B3,0xF2B7, 0x87B4,0xF2B8,
0x87B5,0xF2B9, 0x87B6,0xF2BA, 0x87B7,0xF2BB, 0x87B8,0xF2BC,
0x87B9,0xF2BD, 0x87BA,0xF2BE, 0x87BB,0xF2BF, 0x87BC,0xF2C0,
0x87BD,0xF2C1, 0x87BE,0xF2C2, 0x87BF,0xF2C3, 0x87C0,0xF2C4,
0x87C1,0xF2C5, 0x87C2,0xF2C6, 0x87C3,0xF2C7, 0x87C4,0xF2C8,
0x87C5,0xF2C9, 0x87C6,0xF2CA, 0x87C7,0xF2CB, 0x87C8,0xF2CC,
0x87C9,0xF2CD, 0x87CA,0xF2CE, 0x87CB,0xF2CF, 0x87CC,0xF2D0,
0x87CD,0xF2D1, 0x87CE,0xF2D2, 0x87CF,0xF2D3, 0x87D0,0xF2D4,
0x87D1,0xF2D5, 0x87D2,0xF2D6, 0x87D3,0xF2D7, 0x87D4,0xF2D8,
0x87D5,0xF2D9, 0x87D6,0xF2DA, 0x87D7,0xF2DB, 0x87D8,0xF2DC,
0x87D9,0xF2DD, 0x87DA,0xF2DE, 0x87DB,0xF2DF, 0x87DC,0xF2E0,
0x87DD,0xF2E1, 0x87DE,0xF2E2, 0x87DF,0xF2E3, 0x87E0,0xF2E4,
0x87E1,0xF2E5, 0x87E2,0xF2E6, 0x87E3,0xF2E7, 0x87E4,0xF2E8,
0x87E5,0xF2E9, 0x87E6,0xF2EA, 0x87E7,0xF2EB, 0x87E8,0xF2EC,
0x87E9,0xF2ED, 0x87EA,0xF2EE, 0x87EB,0xF2EF, 0x87EC,0xF2F0,
0x87ED,0xF2F1, 0x87EE,0xF2F2, 0x87EF,0xF2F3, 0x87F0,0xF2F4,
0x87F1,0xF2F5, 0x87F2,0xF2F6, 0x87F3,0xF2F7, 0x87F4,0xF2F8,
0x87F5,0xF2F9, 0x87F6,0xF2FA, 0x87F7,0xF2FB, 0x87F8,0xF2FC,
0x87F9,0xF2FD, 0x87FA,0xF2FE, 0x87FB,0xF2FF, 0x87FC,0xF300,
0x87FD,0xF301, 0x87FE,0xF302, 0x8840,0xF303, 0x8841,0xF304,
0x8842,0xF305, 0x8843,0xF306, 0x8844,0xF307, 0x8845,0xF308,
0x8846,0xF309, 0x8847,0xF30A, 0x8848,0xF30B, 0x8849,0xF30C,
0x884A,0xF30D, 0x884B,0xF30E, 0x884C,0xF30F, 0x884D,0xF310,
0x884E,0xF311, 0x884F,0xF312, 0x8850,0xF313, 0x8851,0xF314,
0x8852,0xF315, 0x8853,0xF316, 0x8854,0xF317, 0x8855,0xF318,
0x8856,0xF319, 0x8857,0xF31A, 0x8858,0xF31B, 0x8859,0xF31C,
0x885A,0xF31D, 0x885B,0xF31E, 0x885C,0xF31F, 0x885D,0xF320,
0x885E,0xF321, 0x885F,0xF322, 0x8860,0xF323, 0x8861,0xF324,
0x8862,0xF325, 0x8863,0xF326, 0x8864,0xF327, 0x8865,0xF328,
0x8866,0xF329, 0x8867,0xF32A, 0x8868,0xF32B, 0x8869,0xF32C,
0x886A,0xF32D, 0x886B,0xF32E, 0x886C,0xF32F, 0x886D,0xF330,
0x886E,0xF331, 0x886F,0xF332, 0x8870,0xF333, 0x8871,0xF334,
0x8872,0xF335, 0x8873,0xF336, 0x8874,0xF337, 0x8875,0xF338,
0x8876,0xF339, 0x8877,0xF33A, 0x8878,0xF33B, 0x8879,0xF33C,
0x887A,0xF33D, 0x887B,0xF33E, 0x887C,0xF33F, 0x887D,0xF340,
0x887E,0xF341, 0x88A1,0xF342, 0x88A2,0xF343, 0x88A3,0xF344,
0x88A4,0xF345, 0x88A5,0xF346, 0x88A6,0xF347, 0x88A7,0xF348,
0x88A8,0xF349, 0x88A9,0xF34A, 0x88AA,0xF34B, 0x88AB,0xF34C,
0x88AC,0xF34D, 0x88AD,0xF34E, 0x88AE,0xF34F, 0x88AF,0xF350,
0x88B0,0xF351, 0x88B1,0xF352, 0x88B2,0xF353, 0x88B3,0xF354,
0x88B4,0xF355, 0x88B5,0xF356, 0x88B6,0xF357, 0x88B7,0xF358,
0x88B8,0xF359, 0x88B9,0xF35A, 0x88BA,0xF35B, 0x88BB,0xF35C,
0x88BC,0xF35D, 0x88BD,0xF35E, 0x88BE,0xF35F, 0x88BF,0xF360,
0x88C0,0xF361, 0x88C1,0xF362, 0x88C2,0xF363, 0x88C3,0xF364,
0x88C4,0xF365, 0x88C5,0xF366, 0x88C6,0xF367, 0x88C7,0xF368,
0x88C8,0xF369, 0x88C9,0xF36A, 0x88CA,0xF36B, 0x88CB,0xF36C,
0x88CC,0xF36D, 0x88CD,0xF36E, 0x88CE,0xF36F, 0x88CF,0xF370,
0x88D0,0xF371, 0x88D1,0xF372, 0x88D2,0xF373, 0x88D3,0xF374,
0x88D4,0xF375, 0x88D5,0xF376, 0x88D6,0xF377, 0x88D7,0xF378,
0x88D8,0xF379, 0x88D9,0xF37A, 0x88DA,0xF37B, 0x88DB,0xF37C,
0x88DC,0xF37D, 0x88DD,0xF37E, 0x88DE,0xF37F, 0x88DF,0xF380,
0x88E0,0xF381, 0x88E1,0xF382, 0x88E2,0xF383, 0x88E3,0xF384,
0x88E4,0xF385, 0x88E5,0xF386, 0x88E6,0xF387, 0x88E7,0xF388,
0x88E8,0xF389, 0x88E9,0xF38A, 0x88EA,0xF38B, 0x88EB,0xF38C,
0x88EC,0xF38D, 0x88ED,0xF38E, 0x88EE,0xF38F, 0x88EF,0xF390,
0x88F0,0xF391, 0x88F1,0xF392, 0x88F2,0xF393, 0x88F3,0xF394,
0x88F4,0xF395, 0x88F5,0xF396, 0x88F6,0xF397, 0x88F7,0xF398,
0x88F8,0xF399, 0x88F9,0xF39A, 0x88FA,0xF39B, 0x88FB,0xF39C,
0x88FC,0xF39D, 0x88FD,0xF39E, 0x88FE,0xF39F, 0x8940,0xF3A0,
0x8941,0xF3A1, 0x8942,0xF3A2, 0x8943,0xF3A3, 0x8944,0xF3A4,
0x8945,0xF3A5, 0x8946,0xF3A6, 0x8947,0xF3A7, 0x8948,0xF3A8,
0x8949,0xF3A9, 0x894A,0xF3AA, 0x894B,0xF3AB, 0x894C,0xF3AC,
0x894D,0xF3AD, 0x894E,0xF3AE, 0x894F,0xF3AF, 0x8950,0xF3B0,
0x8951,0xF3B1, 0x8952,0xF3B2, 0x8953,0xF3B3, 0x8954,0xF3B4,
0x8955,0xF3B5, 0x8956,0xF3B6, 0x8957,0xF3B7, 0x8958,0xF3B8,
0x8959,0xF3B9, 0x895A,0xF3BA, 0x895B,0xF3BB, 0x895C,0xF3BC,
0x895D,0xF3BD, 0x895E,0xF3BE, 0x895F,0xF3BF, 0x8960,0xF3C0,
0x8961,0xF3C1, 0x8962,0xF3C2, 0x8963,0xF3C3, 0x8964,0xF3C4,
0x8965,0xF3C5, 0x8966,0xF3C6, 0x8967,0xF3C7, 0x8968,0xF3C8,
0x8969,0xF3C9, 0x896A,0xF3CA, 0x896B,0xF3CB, 0x896C,0xF3CC,
0x896D,0xF3CD, 0x896E,0xF3CE, 0x896F,0xF3CF, 0x8970,0xF3D0,
0x8971,0xF3D1, 0x8972,0xF3D2, 0x8973,0xF3D3, 0x8974,0xF3D4,
0x8975,0xF3D5, 0x8976,0xF3D6, 0x8977,0xF3D7, 0x8978,0xF3D8,
0x8979,0xF3D9, 0x897A,0xF3DA, 0x897B,0xF3DB, 0x897C,0xF3DC,
0x897D,0xF3DD, 0x897E,0xF3DE, 0x89A1,0xF3DF, 0x89A2,0xF3E0,
0x89A3,0xF3E1, 0x89A4,0xF3E2, 0x89A5,0xF3E3, 0x89A6,0xF3E4,
0x89A7,0xF3E5, 0x89A8,0xF3E6, 0x89A9,0xF3E7, 0x89AA,0xF3E8,
0x89AB,0xF3E9, 0x89AC,0xF3EA, 0x89AD,0xF3EB, 0x89AE,0xF3EC,
0x89AF,0xF3ED, 0x89B0,0xF3EE, 0x89B1,0xF3EF, 0x89B2,0xF3F0,
0x89B3,0xF3F1, 0x89B4,0xF3F2, 0x89B5,0xF3F3, 0x89B6,0xF3F4,
0x89B7,0xF3F5, 0x89B8,0xF3F6, 0x89B9,0xF3F7, 0x89BA,0xF3F8,
0x89BB,0xF3F9, 0x89BC,0xF3FA, 0x89BD,0xF3FB, 0x89BE,0xF3FC,
0x89BF,0xF3FD, 0x89C0,0xF3FE, 0x89C1,0xF3FF, 0x89C2,0xF400,
0x89C3,0xF401, 0x89C4,0xF402, 0x89C5,0xF403, 0x89C6,0xF404,
0x89C7,0xF405, 0x89C8,0xF406, 0x89C9,0xF407, 0x89CA,0xF408,
0x89CB,0xF409, 0x89CC,0xF40A, 0x89CD,0xF40B, 0x89CE,0xF40C,
0x89CF,0xF40D, 0x89D0,0xF40E, 0x89D1,0xF40F, 0x89D2,0xF410,
0x89D3,0xF411, 0x89D4,0xF412, 0x89D5,0xF413, 0x89D6,0xF414,
0x89D7,0xF415, 0x89D8,0xF416, 0x89D9,0xF417, 0x89DA,0xF418,
0x89DB,0xF419, 0x89DC,0xF41A, 0x89DD,0xF41B, 0x89DE,0xF41C,
0x89DF,0xF41D, 0x89E0,0xF41E, 0x89E1,0xF41F, 0x89E2,0xF420,
0x89E3,0xF421, 0x89E4,0xF422, 0x89E5,0xF423, 0x89E6,0xF424,
0x89E7,0xF425, 0x89E8,0xF426, 0x89E9,0xF427, 0x89EA,0xF428,
0x89EB,0xF429, 0x89EC,0xF42A, 0x89ED,0xF42B, 0x89EE,0xF42C,
0x89EF,0xF42D, 0x89F0,0xF42E, 0x89F1,0xF42F, 0x89F2,0xF430,
0x89F3,0xF431, 0x89F4,0xF432, 0x89F5,0xF433, 0x89F6,0xF434,
0x89F7,0xF435, 0x89F8,0xF436, 0x89F9,0xF437, 0x89FA,0xF438,
0x89FB,0xF439, 0x89FC,0xF43A, 0x89FD,0xF43B, 0x89FE,0xF43C,
0x8A40,0xF43D, 0x8A41,0xF43E, 0x8A42,0xF43F, 0x8A43,0xF440,
0x8A44,0xF441, 0x8A45,0xF442, 0x8A46,0xF443, 0x8A47,0xF444,
0x8A48,0xF445, 0x8A49,0xF446, 0x8A4A,0xF447, 0x8A4B,0xF448,
0x8A4C,0xF449, 0x8A4D,0xF44A, 0x8A4E,0xF44B, 0x8A4F,0xF44C,
0x8A50,0xF44D, 0x8A51,0xF44E, 0x8A52,0xF44F, 0x8A53,0xF450,
0x8A54,0xF451, 0x8A55,0xF452, 0x8A56,0xF453, 0x8A57,0xF454,
0x8A58,0xF455, 0x8A59,0xF456, 0x8A5A,0xF457, 0x8A5B,0xF458,
0x8A5C,0xF459, 0x8A5D,0xF45A, 0x8A5E,0xF45B, 0x8A5F,0xF45C,
0x8A60,0xF45D, 0x8A61,0xF45E, 0x8A62,0xF45F, 0x8A63,0xF460,
0x8A64,0xF461, 0x8A65,0xF462, 0x8A66,0xF463, 0x8A67,0xF464,
0x8A68,0xF465, 0x8A69,0xF466, 0x8A6A,0xF467, 0x8A6B,0xF468,
0x8A6C,0xF469, 0x8A6D,0xF46A, 0x8A6E,0xF46B, 0x8A6F,0xF46C,
0x8A70,0xF46D, 0x8A71,0xF46E, 0x8A72,0xF46F, 0x8A73,0xF470,
0x8A74,0xF471, 0x8A75,0xF472, 0x8A76,0xF473, 0x8A77,0xF474,
0x8A78,0xF475, 0x8A79,0xF476, 0x8A7A,0xF477, 0x8A7B,0xF478,
0x8A7C,0xF479, 0x8A7D,0xF47A, 0x8A7E,0xF47B, 0x8AA1,0xF47C,
0x8AA2,0xF47D, 0x8AA3,0xF47E, 0x8AA4,0xF47F, 0x8AA5,0xF480,
0x8AA6,0xF481, 0x8AA7,0xF482, 0x8AA8,0xF483, 0x8AA9,0xF484,
0x8AAA,0xF485, 0x8AAB,0xF486, 0x8AAC,0xF487, 0x8AAD,0xF488,
0x8AAE,0xF489, 0x8AAF,0xF48A, 0x8AB0,0xF48B, 0x8AB1,0xF48C,
0x8AB2,0xF48D, 0x8AB3,0xF48E, 0x8AB4,0xF48F, 0x8AB5,0xF490,
0x8AB6,0xF491, 0x8AB7,0xF492, 0x8AB8,0xF493, 0x8AB9,0xF494,
0x8ABA,0xF495, 0x8ABB,0xF496, 0x8ABC,0xF497, 0x8ABD,0xF498,
0x8ABE,0xF499, 0x8ABF,0xF49A, 0x8AC0,0xF49B, 0x8AC1,0xF49C,
0x8AC2,0xF49D, 0x8AC3,0xF49E, 0x8AC4,0xF49F, 0x8AC5,0xF4A0,
0x8AC6,0xF4A1, 0x8AC7,0xF4A2, 0x8AC8,0xF4A3, 0x8AC9,0xF4A4,
0x8ACA,0xF4A5, 0x8ACB,0xF4A6, 0x8ACC,0xF4A7, 0x8ACD,0xF4A8,
0x8ACE,0xF4A9, 0x8ACF,0xF4AA, 0x8AD0,0xF4AB, 0x8AD1,0xF4AC,
0x8AD2,0xF4AD, 0x8AD3,0xF4AE, 0x8AD4,0xF4AF, 0x8AD5,0xF4B0,
0x8AD6,0xF4B1, 0x8AD7,0xF4B2, 0x8AD8,0xF4B3, 0x8AD9,0xF4B4,
0x8ADA,0xF4B5, 0x8ADB,0xF4B6, 0x8ADC,0xF4B7, 0x8ADD,0xF4B8,
0x8ADE,0xF4B9, 0x8ADF,0xF4BA, 0x8AE0,0xF4BB, 0x8AE1,0xF4BC,
0x8AE2,0xF4BD, 0x8AE3,0xF4BE, 0x8AE4,0xF4BF, 0x8AE5,0xF4C0,
0x8AE6,0xF4C1, 0x8AE7,0xF4C2, 0x8AE8,0xF4C3, 0x8AE9,0xF4C4,
0x8AEA,0xF4C5, 0x8AEB,0xF4C6, 0x8AEC,0xF4C7, 0x8AED,0xF4C8,
0x8AEE,0xF4C9, 0x8AEF,0xF4CA, 0x8AF0,0xF4CB, 0x8AF1,0xF4CC,
0x8AF2,0xF4CD, 0x8AF3,0xF4CE, 0x8AF4,0xF4CF, 0x8AF5,0xF4D0,
0x8AF6,0xF4D1, 0x8AF7,0xF4D2, 0x8AF8,0xF4D3, 0x8AF9,0xF4D4,
0x8AFA,0xF4D5, 0x8AFB,0xF4D6, 0x8AFC,0xF4D7, 0x8AFD,0xF4D8,
0x8AFE,0xF4D9, 0x8B40,0xF4DA, 0x8B41,0xF4DB, 0x8B42,0xF4DC,
0x8B43,0xF4DD, 0x8B44,0xF4DE, 0x8B45,0xF4DF, 0x8B46,0xF4E0,
0x8B47,0xF4E1, 0x8B48,0xF4E2, 0x8B49,0xF4E3, 0x8B4A,0xF4E4,
0x8B4B,0xF4E5, 0x8B4C,0xF4E6, 0x8B4D,0xF4E7, 0x8B4E,0xF4E8,
0x8B4F,0xF4E9, 0x8B50,0xF4EA, 0x8B51,0xF4EB, 0x8B52,0xF4EC,
0x8B53,0xF4ED, 0x8B54,0xF4EE, 0x8B55,0xF4EF, 0x8B56,0xF4F0,
0x8B57,0xF4F1, 0x8B58,0xF4F2, 0x8B59,0xF4F3, 0x8B5A,0xF4F4,
0x8B5B,0xF4F5, 0x8B5C,0xF4F6, 0x8B5D,0xF4F7, 0x8B5E,0xF4F8,
0x8B5F,0xF4F9, 0x8B60,0xF4FA, 0x8B61,0xF4FB, 0x8B62,0xF4FC,
0x8B63,0xF4FD, 0x8B64,0xF4FE, 0x8B65,0xF4FF, 0x8B66,0xF500,
0x8B67,0xF501, 0x8B68,0xF502, 0x8B69,0xF503, 0x8B6A,0xF504,
0x8B6B,0xF505, 0x8B6C,0xF506, 0x8B6D,0xF507, 0x8B6E,0xF508,
0x8B6F,0xF509, 0x8B70,0xF50A, 0x8B71,0xF50B, 0x8B72,0xF50C,
0x8B73,0xF50D, 0x8B74,0xF50E, 0x8B75,0xF50F, 0x8B76,0xF510,
0x8B77,0xF511, 0x8B78,0xF512, 0x8B79,0xF513, 0x8B7A,0xF514,
0x8B7B,0xF515, 0x8B7C,0xF516, 0x8B7D,0xF517, 0x8B7E,0xF518,
0x8BA1,0xF519, 0x8BA2,0xF51A, 0x8BA3,0xF51B, 0x8BA4,0xF51C,
0x8BA5,0xF51D, 0x8BA6,0xF51E, 0x8BA7,0xF51F, 0x8BA8,0xF520,
0x8BA9,0xF521, 0x8BAA,0xF522, 0x8BAB,0xF523, 0x8BAC,0xF524,
0x8BAD,0xF525, 0x8BAE,0xF526, 0x8BAF,0xF527, 0x8BB0,0xF528,
0x8BB1,0xF529, 0x8BB2,0xF52A, 0x8BB3,0xF52B, 0x8BB4,0xF52C,
0x8BB5,0xF52D, 0x8BB6,0xF52E, 0x8BB7,0xF52F, 0x8BB8,0xF530,
0x8BB9,0xF531, 0x8BBA,0xF532, 0x8BBB,0xF533, 0x8BBC,0xF534,
0x8BBD,0xF535, 0x8BBE,0xF536, 0x8BBF,0xF537, 0x8BC0,0xF538,
0x8BC1,0xF539, 0x8BC2,0xF53A, 0x8BC3,0xF53B, 0x8BC4,0xF53C,
0x8BC5,0xF53D, 0x8BC6,0xF53E, 0x8BC7,0xF53F, 0x8BC8,0xF540,
0x8BC9,0xF541, 0x8BCA,0xF542, 0x8BCB,0xF543, 0x8BCC,0xF544,
0x8BCD,0xF545, 0x8BCE,0xF546, 0x8BCF,0xF547, 0x8BD0,0xF548,
0x8BD1,0xF549, 0x8BD2,0xF54A, 0x8BD3,0xF54B, 0x8BD4,0xF54C,
0x8BD5,0xF54D, 0x8BD6,0xF54E, 0x8BD7,0xF54F, 0x8BD8,0xF550,
0x8BD9,0xF551, 0x8BDA,0xF552, 0x8BDB,0xF553, 0x8BDC,0xF554,
0x8BDD,0xF555, 0x8BDE,0xF556, 0x8BDF,0xF557, 0x8BE0,0xF558,
0x8BE1,0xF559, 0x8BE2,0xF55A, 0x8BE3,0xF55B, 0x8BE4,0xF55C,
0x8BE5,0xF55D, 0x8BE6,0xF55E, 0x8BE7,0xF55F, 0x8BE8,0xF560,
0x8BE9,0xF561, 0x8BEA,0xF562, 0x8BEB,0xF563, 0x8BEC,0xF564,
0x8BED,0xF565, 0x8BEE,0xF566, 0x8BEF,0xF567, 0x8BF0,0xF568,
0x8BF1,0xF569, 0x8BF2,0xF56A, 0x8BF3,0xF56B, 0x8BF4,0xF56C,
0x8BF5,0xF56D, 0x8BF6,0xF56E, 0x8BF7,0xF56F, 0x8BF8,0xF570,
0x8BF9,0xF571, 0x8BFA,0xF572, 0x8BFB,0xF573, 0x8BFC,0xF574,
0x8BFD,0xF575, 0x8BFE,0xF576, 0x8C40,0xF577, 0x8C41,0xF578,
0x8C42,0xF579, 0x8C43,0xF57A, 0x8C44,0xF57B, 0x8C45,0xF57C,
0x8C46,0xF57D, 0x8C47,0xF57E, 0x8C48,0xF57F, 0x8C49,0xF580,
0x8C4A,0xF581, 0x8C4B,0xF582, 0x8C4C,0xF583, 0x8C4D,0xF584,
0x8C4E,0xF585, 0x8C4F,0xF586, 0x8C50,0xF587, 0x8C51,0xF588,
0x8C52,0xF589, 0x8C53,0xF58A, 0x8C54,0xF58B, 0x8C55,0xF58C,
0x8C56,0xF58D, 0x8C57,0xF58E, 0x8C58,0xF58F, 0x8C59,0xF590,
0x8C5A,0xF591, 0x8C5B,0xF592, 0x8C5C,0xF593, 0x8C5D,0xF594,
0x8C5E,0xF595, 0x8C5F,0xF596, 0x8C60,0xF597, 0x8C61,0xF598,
0x8C62,0xF599, 0x8C63,0xF59A, 0x8C64,0xF59B, 0x8C65,0xF59C,
0x8C66,0xF59D, 0x8C67,0xF59E, 0x8C68,0xF59F, 0x8C69,0xF5A0,
0x8C6A,0xF5A1, 0x8C6B,0xF5A2, 0x8C6C,0xF5A3, 0x8C6D,0xF5A4,
0x8C6E,0xF5A5, 0x8C6F,0xF5A6, 0x8C70,0xF5A7, 0x8C71,0xF5A8,
0x8C72,0xF5A9, 0x8C73,0xF5AA, 0x8C74,0xF5AB, 0x8C75,0xF5AC,
0x8C76,0xF5AD, 0x8C77,0xF5AE, 0x8C78,0xF5AF, 0x8C79,0xF5B0,
0x8C7A,0xF5B1, 0x8C7B,0xF5B2, 0x8C7C,0xF5B3, 0x8C7D,0xF5B4,
0x8C7E,0xF5B5, 0x8CA1,0xF5B6, 0x8CA2,0xF5B7, 0x8CA3,0xF5B8,
0x8CA4,0xF5B9, 0x8CA5,0xF5BA, 0x8CA6,0xF5BB, 0x8CA7,0xF5BC,
0x8CA8,0xF5BD, 0x8CA9,0xF5BE, 0x8CAA,0xF5BF, 0x8CAB,0xF5C0,
0x8CAC,0xF5C1, 0x8CAD,0xF5C2, 0x8CAE,0xF5C3, 0x8CAF,0xF5C4,
0x8CB0,0xF5C5, 0x8CB1,0xF5C6, 0x8CB2,0xF5C7, 0x8CB3,0xF5C8,
0x8CB4,0xF5C9, 0x8CB5,0xF5CA, 0x8CB6,0xF5CB, 0x8CB7,0xF5CC,
0x8CB8,0xF5CD, 0x8CB9,0xF5CE, 0x8CBA,0xF5CF, 0x8CBB,0xF5D0,
0x8CBC,0xF5D1, 0x8CBD,0xF5D2, 0x8CBE,0xF5D3, 0x8CBF,0xF5D4,
0x8CC0,0xF5D5, 0x8CC1,0xF5D6, 0x8CC2,0xF5D7, 0x8CC3,0xF5D8,
0x8CC4,0xF5D9, 0x8CC5,0xF5DA, 0x8CC6,0xF5DB, 0x8CC7,0xF5DC,
0x8CC8,0xF5DD, 0x8CC9,0xF5DE, 0x8CCA,0xF5DF, 0x8CCB,0xF5E0,
0x8CCC,0xF5E1, 0x8CCD,0xF5E2, 0x8CCE,0xF5E3, 0x8CCF,0xF5E4,
0x8CD0,0xF5E5, 0x8CD1,0xF5E6, 0x8CD2,0xF5E7, 0x8CD3,0xF5E8,
0x8CD4,0xF5E9, 0x8CD5,0xF5EA, 0x8CD6,0xF5EB, 0x8CD7,0xF5EC,
0x8CD8,0xF5ED, 0x8CD9,0xF5EE, 0x8CDA,0xF5EF, 0x8CDB,0xF5F0,
0x8CDC,0xF5F1, 0x8CDD,0xF5F2, 0x8CDE,0xF5F3, 0x8CDF,0xF5F4,
0x8CE0,0xF5F5, 0x8CE1,0xF5F6, 0x8CE2,0xF5F7, 0x8CE3,0xF5F8,
0x8CE4,0xF5F9, 0x8CE5,0xF5FA, 0x8CE6,0xF5FB, 0x8CE7,0xF5FC,
0x8CE8,0xF5FD, 0x8CE9,0xF5FE, 0x8CEA,0xF5FF, 0x8CEB,0xF600,
0x8CEC,0xF601, 0x8CED,0xF602, 0x8CEE,0xF603, 0x8CEF,0xF604,
0x8CF0,0xF605, 0x8CF1,0xF606, 0x8CF2,0xF607, 0x8CF3,0xF608,
0x8CF4,0xF609, 0x8CF5,0xF60A, 0x8CF6,0xF60B, 0x8CF7,0xF60C,
0x8CF8,0xF60D, 0x8CF9,0xF60E, 0x8CFA,0xF60F, 0x8CFB,0xF610,
0x8CFC,0xF611, 0x8CFD,0xF612, 0x8CFE,0xF613, 0x8D40,0xF614,
0x8D41,0xF615, 0x8D42,0xF616, 0x8D43,0xF617, 0x8D44,0xF618,
0x8D45,0xF619, 0x8D46,0xF61A, 0x8D47,0xF61B, 0x8D48,0xF61C,
0x8D49,0xF61D, 0x8D4A,0xF61E, 0x8D4B,0xF61F, 0x8D4C,0xF620,
0x8D4D,0xF621, 0x8D4E,0xF622, 0x8D4F,0xF623, 0x8D50,0xF624,
0x8D51,0xF625, 0x8D52,0xF626, 0x8D53,0xF627, 0x8D54,0xF628,
0x8D55,0xF629, 0x8D56,0xF62A, 0x8D57,0xF62B, 0x8D58,0xF62C,
0x8D59,0xF62D, 0x8D5A,0xF62E, 0x8D5B,0xF62F, 0x8D5C,0xF630,
0x8D5D,0xF631, 0x8D5E,0xF632, 0x8D5F,0xF633, 0x8D60,0xF634,
0x8D61,0xF635, 0x8D62,0xF636, 0x8D63,0xF637, 0x8D64,0xF638,
0x8D65,0xF639, 0x8D66,0xF63A, 0x8D67,0xF63B, 0x8D68,0xF63C,
0x8D69,0xF63D, 0x8D6A,0xF63E, 0x8D6B,0xF63F, 0x8D6C,0xF640,
0x8D6D,0xF641, 0x8D6E,0xF642, 0x8D6F,0xF643, 0x8D70,0xF644,
0x8D71,0xF645, 0x8D72,0xF646, 0x8D73,0xF647, 0x8D74,0xF648,
0x8D75,0xF649, 0x8D76,0xF64A, 0x8D77,0xF64B, 0x8D78,0xF64C,
0x8D79,0xF64D, 0x8D7A,0xF64E, 0x8D7B,0xF64F, 0x8D7C,0xF650,
0x8D7D,0xF651, 0x8D7E,0xF652, 0x8DA1,0xF653, 0x8DA2,0xF654,
0x8DA3,0xF655, 0x8DA4,0xF656, 0x8DA5,0xF657, 0x8DA6,0xF658,
0x8DA7,0xF659, 0x8DA8,0xF65A, 0x8DA9,0xF65B, 0x8DAA,0xF65C,
0x8DAB,0xF65D, 0x8DAC,0xF65E, 0x8DAD,0xF65F, 0x8DAE,0xF660,
0x8DAF,0xF661, 0x8DB0,0xF662, 0x8DB1,0xF663, 0x8DB2,0xF664,
0x8DB3,0xF665, 0x8DB4,0xF666, 0x8DB5,0xF667, 0x8DB6,0xF668,
0x8DB7,0xF669, 0x8DB8,0xF66A, 0x8DB9,0xF66B, 0x8DBA,0xF66C,
0x8DBB,0xF66D, 0x8DBC,0xF66E, 0x8DBD,0xF66F, 0x8DBE,0xF670,
0x8DBF,0xF671, 0x8DC0,0xF672, 0x8DC1,0xF673, 0x8DC2,0xF674,
0x8DC3,0xF675, 0x8DC4,0xF676, 0x8DC5,0xF677, 0x8DC6,0xF678,
0x8DC7,0xF679, 0x8DC8,0xF67A, 0x8DC9,0xF67B, 0x8DCA,0xF67C,
0x8DCB,0xF67D, 0x8DCC,0xF67E, 0x8DCD,0xF67F, 0x8DCE,0xF680,
0x8DCF,0xF681, 0x8DD0,0xF682, 0x8DD1,0xF683, 0x8DD2,0xF684,
0x8DD3,0xF685, 0x8DD4,0xF686, 0x8DD5,0xF687, 0x8DD6,0xF688,
0x8DD7,0xF689, 0x8DD8,0xF68A, 0x8DD9,0xF68B, 0x8DDA,0xF68C,
0x8DDB,0xF68D, 0x8DDC,0xF68E, 0x8DDD,0xF68F, 0x8DDE,0xF690,
0x8DDF,0xF691, 0x8DE0,0xF692, 0x8DE1,0xF693, 0x8DE2,0xF694,
0x8DE3,0xF695, 0x8DE4,0xF696, 0x8DE5,0xF697, 0x8DE6,0xF698,
0x8DE7,0xF699, 0x8DE8,0xF69A, 0x8DE9,0xF69B, 0x8DEA,0xF69C,
0x8DEB,0xF69D, 0x8DEC,0xF69E, 0x8DED,0xF69F, 0x8DEE,0xF6A0,
0x8DEF,0xF6A1, 0x8DF0,0xF6A2, 0x8DF1,0xF6A3, 0x8DF2,0xF6A4,
0x8DF3,0xF6A5, 0x8DF4,0xF6A6, 0x8DF5,0xF6A7, 0x8DF6,0xF6A8,
0x8DF7,0xF6A9, 0x8DF8,0xF6AA, 0x8DF9,0xF6AB, 0x8DFA,0xF6AC,
0x8DFB,0xF6AD, 0x8DFC,0xF6AE, 0x8DFD,0xF6AF, 0x8DFE,0xF6B0,
0xC6A1,0xF6B1, 0xC6A2,0xF6B2, 0xC6A3,0xF6B3, 0xC6A4,0xF6B4,
0xC6A5,0xF6B5, 0xC6A6,0xF6B6, 0xC6A7,0xF6B7, 0xC6A8,0xF6B8,
0xC6A9,0xF6B9, 0xC6AA,0xF6BA, 0xC6AB,0xF6BB, 0xC6AC,0xF6BC,
0xC6AD,0xF6BD, 0xC6AE,0xF6BE, 0xC6AF,0xF6BF, 0xC6B0,0xF6C0,
0xC6B1,0xF6C1, 0xC6B2,0xF6C2, 0xC6B3,0xF6C3, 0xC6B4,0xF6C4,
0xC6B5,0xF6C5, 0xC6B6,0xF6C6, 0xC6B7,0xF6C7, 0xC6B8,0xF6C8,
0xC6B9,0xF6C9, 0xC6BA,0xF6CA, 0xC6BB,0xF6CB, 0xC6BC,0xF6CC,
0xC6BD,0xF6CD, 0xC6BE,0xF6CE, 0xC6BF,0xF6CF, 0xC6C0,0xF6D0,
0xC6C1,0xF6D1, 0xC6C2,0xF6D2, 0xC6C3,0xF6D3, 0xC6C4,0xF6D4,
0xC6C5,0xF6D5, 0xC6C6,0xF6D6, 0xC6C7,0xF6D7, 0xC6C8,0xF6D8,
0xC6C9,0xF6D9, 0xC6CA,0xF6DA, 0xC6CB,0xF6DB, 0xC6CC,0xF6DC,
0xC6CD,0xF6DD, 0xC6CE,0xF6DE, 0xC6CF,0xF6DF, 0xC6D0,0xF6E0,
0xC6D1,0xF6E1, 0xC6D2,0xF6E2, 0xC6D3,0xF6E3, 0xC6D4,0xF6E4,
0xC6D5,0xF6E5, 0xC6D6,0xF6E6, 0xC6D7,0xF6E7, 0xC6D8,0xF6E8,
0xC6D9,0xF6E9, 0xC6DA,0xF6EA, 0xC6DB,0xF6EB, 0xC6DC,0xF6EC,
0xC6DD,0xF6ED, 0xC6DE,0xF6EE, 0xC6DF,0xF6EF, 0xC6E0,0xF6F0,
0xC6E1,0xF6F1, 0xC6E2,0xF6F2, 0xC6E3,0xF6F3, 0xC6E4,0xF6F4,
0xC6E5,0xF6F5, 0xC6E6,0xF6F6, 0xC6E7,0xF6F7, 0xC6E8,0xF6F8,
0xC6E9,0xF6F9, 0xC6EA,0xF6FA, 0xC6EB,0xF6FB, 0xC6EC,0xF6FC,
0xC6ED,0xF6FD, 0xC6EE,0xF6FE, 0xC6EF,0xF6FF, 0xC6F0,0xF700,
0xC6F1,0xF701, 0xC6F2,0xF702, 0xC6F3,0xF703, 0xC6F4,0xF704,
0xC6F5,0xF705, 0xC6F6,0xF706, 0xC6F7,0xF707, 0xC6F8,0xF708,
0xC6F9,0xF709, 0xC6FA,0xF70A, 0xC6FB,0xF70B, 0xC6FC,0xF70C,
0xC6FD,0xF70D, 0xC6FE,0xF70E, 0xC740,0xF70F, 0xC741,0xF710,
0xC742,0xF711, 0xC743,0xF712, 0xC744,0xF713, 0xC745,0xF714,
0xC746,0xF715, 0xC747,0xF716, 0xC748,0xF717, 0xC749,0xF718,
0xC74A,0xF719, 0xC74B,0xF71A, 0xC74C,0xF71B, 0xC74D,0xF71C,
0xC74E,0xF71D, 0xC74F,0xF71E, 0xC750,0xF71F, 0xC751,0xF720,
0xC752,0xF721, 0xC753,0xF722, 0xC754,0xF723, 0xC755,0xF724,
0xC756,0xF725, 0xC757,0xF726, 0xC758,0xF727, 0xC759,0xF728,
0xC75A,0xF729, 0xC75B,0xF72A, 0xC75C,0xF72B, 0xC75D,0xF72C,
0xC75E,0xF72D, 0xC75F,0xF72E, 0xC760,0xF72F, 0xC761,0xF730,
0xC762,0xF731, 0xC763,0xF732, 0xC764,0xF733, 0xC765,0xF734,
0xC766,0xF735, 0xC767,0xF736, 0xC768,0xF737, 0xC769,0xF738,
0xC76A,0xF739, 0xC76B,0xF73A, 0xC76C,0xF73B, 0xC76D,0xF73C,
0xC76E,0xF73D, 0xC76F,0xF73E, 0xC770,0xF73F, 0xC771,0xF740,
0xC772,0xF741, 0xC773,0xF742, 0xC774,0xF743, 0xC775,0xF744,
0xC776,0xF745, 0xC777,0xF746, 0xC778,0xF747, 0xC779,0xF748,
0xC77A,0xF749, 0xC77B,0xF74A, 0xC77C,0xF74B, 0xC77D,0xF74C,
0xC77E,0xF74D, 0xC7A1,0xF74E, 0xC7A2,0xF74F, 0xC7A3,0xF750,
0xC7A4,0xF751, 0xC7A5,0xF752, 0xC7A6,0xF753, 0xC7A7,0xF754,
0xC7A8,0xF755, 0xC7A9,0xF756, 0xC7AA,0xF757, 0xC7AB,0xF758,
0xC7AC,0xF759, 0xC7AD,0xF75A, 0xC7AE,0xF75B, 0xC7AF,0xF75C,
0xC7B0,0xF75D, 0xC7B1,0xF75E, 0xC7B2,0xF75F, 0xC7B3,0xF760,
0xC7B4,0xF761, 0xC7B5,0xF762, 0xC7B6,0xF763, 0xC7B7,0xF764,
0xC7B8,0xF765, 0xC7B9,0xF766, 0xC7BA,0xF767, 0xC7BB,0xF768,
0xC7BC,0xF769, 0xC7BD,0xF76A, 0xC7BE,0xF76B, 0xC7BF,0xF76C,
0xC7C0,0xF76D, 0xC7C1,0xF76E, 0xC7C2,0xF76F, 0xC7C3,0xF770,
0xC7C4,0xF771, 0xC7C5,0xF772, 0xC7C6,0xF773, 0xC7C7,0xF774,
0xC7C8,0xF775, 0xC7C9,0xF776, 0xC7CA,0xF777, 0xC7CB,0xF778,
0xC7CC,0xF779, 0xC7CD,0xF77A, 0xC7CE,0xF77B, 0xC7CF,0xF77C,
0xC7D0,0xF77D, 0xC7D1,0xF77E, 0xC7D2,0xF77F, 0xC7D3,0xF780,
0xC7D4,0xF781, 0xC7D5,0xF782, 0xC7D6,0xF783, 0xC7D7,0xF784,
0xC7D8,0xF785, 0xC7D9,0xF786, 0xC7DA,0xF787, 0xC7DB,0xF788,
0xC7DC,0xF789, 0xC7DD,0xF78A, 0xC7DE,0xF78B, 0xC7DF,0xF78C,
0xC7E0,0xF78D, 0xC7E1,0xF78E, 0xC7E2,0xF78F, 0xC7E3,0xF790,
0xC7E4,0xF791, 0xC7E5,0xF792, 0xC7E6,0xF793, 0xC7E7,0xF794,
0xC7E8,0xF795, 0xC7E9,0xF796, 0xC7EA,0xF797, 0xC7EB,0xF798,
0xC7EC,0xF799, 0xC7ED,0xF79A, 0xC7EE,0xF79B, 0xC7EF,0xF79C,
0xC7F0,0xF79D, 0xC7F1,0xF79E, 0xC7F2,0xF79F, 0xC7F3,0xF7A0,
0xC7F4,0xF7A1, 0xC7F5,0xF7A2, 0xC7F6,0xF7A3, 0xC7F7,0xF7A4,
0xC7F8,0xF7A5, 0xC7F9,0xF7A6, 0xC7FA,0xF7A7, 0xC7FB,0xF7A8,
0xC7FC,0xF7A9, 0xC7FD,0xF7AA, 0xC7FE,0xF7AB, 0xC840,0xF7AC,
0xC841,0xF7AD, 0xC842,0xF7AE, 0xC843,0xF7AF, 0xC844,0xF7B0,
0xC845,0xF7B1, 0xC846,0xF7B2, 0xC847,0xF7B3, 0xC848,0xF7B4,
0xC849,0xF7B5, 0xC84A,0xF7B6, 0xC84B,0xF7B7, 0xC84C,0xF7B8,
0xC84D,0xF7B9, 0xC84E,0xF7BA, 0xC84F,0xF7BB, 0xC850,0xF7BC,
0xC851,0xF7BD, 0xC852,0xF7BE, 0xC853,0xF7BF, 0xC854,0xF7C0,
0xC855,0xF7C1, 0xC856,0xF7C2, 0xC857,0xF7C3, 0xC858,0xF7C4,
0xC859,0xF7C5, 0xC85A,0xF7C6, 0xC85B,0xF7C7, 0xC85C,0xF7C8,
0xC85D,0xF7C9, 0xC85E,0xF7CA, 0xC85F,0xF7CB, 0xC860,0xF7CC,
0xC861,0xF7CD, 0xC862,0xF7CE, 0xC863,0xF7CF, 0xC864,0xF7D0,
0xC865,0xF7D1, 0xC866,0xF7D2, 0xC867,0xF7D3, 0xC868,0xF7D4,
0xC869,0xF7D5, 0xC86A,0xF7D6, 0xC86B,0xF7D7, 0xC86C,0xF7D8,
0xC86D,0xF7D9, 0xC86E,0xF7DA, 0xC86F,0xF7DB, 0xC870,0xF7DC,
0xC871,0xF7DD, 0xC872,0xF7DE, 0xC873,0xF7DF, 0xC874,0xF7E0,
0xC875,0xF7E1, 0xC876,0xF7E2, 0xC877,0xF7E3, 0xC878,0xF7E4,
0xC879,0xF7E5, 0xC87B,0xF7E7, 0xC87D,0xF7E9, 0xC87E,0xF7EA,
0xC8A1,0xF7EB, 0xC8A2,0xF7EC, 0xC8A3,0xF7ED, 0xC8B1,0xF7FB,
0xC8B2,0xF7FC, 0xC8B3,0xF7FD, 0xC8B4,0xF7FE, 0xC8B5,0xF7FF,
0xC8B6,0xF800, 0xC8B7,0xF801, 0xC8B8,0xF802, 0xC8B9,0xF803,
0xC8BA,0xF804, 0xC8BB,0xF805, 0xC8BC,0xF806, 0xC8BD,0xF807,
0xC8BE,0xF808, 0xC8BF,0xF809, 0xC8C0,0xF80A, 0xC8C1,0xF80B,
0xC8C2,0xF80C, 0xC8C3,0xF80D, 0xC8C4,0xF80E, 0xC8C5,0xF80F,
0xC8C6,0xF810, 0xC8C7,0xF811, 0xC8C8,0xF812, 0xC8C9,0xF813,
0xC8CA,0xF814, 0xC8CB,0xF815, 0xC8CC,0xF816, 0xC8CD,0xF817,
0xC8CE,0xF818, 0xC8CF,0xF819, 0xC8D0,0xF81A, 0xC8D1,0xF81B,
0xC8D2,0xF81C, 0xC8D3,0xF81D, 0xC8D4,0xF81E, 0xC8D5,0xF81F,
0xC8D6,0xF820, 0xC8D7,0xF821, 0xC8D8,0xF822, 0xC8D9,0xF823,
0xC8DA,0xF824, 0xC8DB,0xF825, 0xC8DC,0xF826, 0xC8DD,0xF827,
0xC8DE,0xF828, 0xC8DF,0xF829, 0xC8E0,0xF82A, 0xC8E1,0xF82B,
0xC8E2,0xF82C, 0xC8E3,0xF82D, 0xC8E4,0xF82E, 0xC8E5,0xF82F,
0xC8E6,0xF830, 0xC8E7,0xF831, 0xC8E8,0xF832, 0xC8E9,0xF833,
0xC8EA,0xF834, 0xC8EB,0xF835, 0xC8EC,0xF836, 0xC8ED,0xF837,
0xC8EE,0xF838, 0xC8EF,0xF839, 0xC8F0,0xF83A, 0xC8F1,0xF83B,
0xC8F2,0xF83C, 0xC8F3,0xF83D, 0xC8F4,0xF83E, 0xC8F5,0xF83F,
0xC8F6,0xF840, 0xC8F7,0xF841, 0xC8F8,0xF842, 0xC8F9,0xF843,
0xC8FA,0xF844, 0xC8FB,0xF845, 0xC8FC,0xF846, 0xC8FD,0xF847,
0xC8FE,0xF848, 0xC6DE,0xF866, 0xC6DF,0xF867, 0x00FF,0xF8F8,
0xB05A,0xF900, 0xA7F3,0xF901, 0xA8AE,0xF902, 0xB8EB,0xF903,
0xB7C6,0xF904, 0xA6EA,0xF905, 0xA579,0xF906, 0xC074,0xF907,
0xC074,0xF908, 0xABB4,0xF909, 0xAAF7,0xF90A, 0xB3E2,0xF90B,
0xA960,0xF90C, 0xC369,0xF90D, 0xC4EE,0xF90E, 0xC3B9,0xF90F,
0xC5DA,0xF910, 0xC1B3,0xF911, 0xBB72,0xF912, 0xC5DE,0xF913,
0xBCD6,0xF914, 0xACA5,0xF915, 0xAF4F,0xF916, 0xAF5F,0xF917,
0xB8A8,0xF918, 0xB954,0xF919, 0xC064,0xF91A, 0xB6C3,0xF91B,
0xA75A,0xF91C, 0xC4E6,0xF91D, 0xC4EA,0xF91E, 0xC4F5,0xF91F,
0xC67D,0xF920, 0xB450,0xF921, 0xC0DD,0xF922, 0xC2C5,0xF923,
0xC4B0,0xF924, 0xA9D4,0xF925, 0xC3BE,0xF926, 0xC4FA,0xF927,
0xB459,0xF928, 0xAED4,0xF929, 0xAEF6,0xF92A, 0xAF54,0xF92B,
0xADA6,0xF92C, 0xA8D3,0xF92D, 0xA74E,0xF92E, 0xB3D2,0xF92F,
0xBEDB,0xF930, 0xC372,0xF931, 0xC46C,0xF932, 0xBF63,0xF933,
0xA6D1,0xF934, 0xC4AA,0xF935, 0xB8B8,0xF936, 0xB8F4,0xF937,
0xC553,0xF938, 0xBE7C,0xF939, 0xC64F,0xF93A, 0xB84C,0xF93B,
0xB853,0xF93C, 0xBAF1,0xF93D, 0xDB77,0xF93E, 0xBFFD,0xF93F,
0xB3C0,0xF940, 0xBDD7,0xF941, 0xC362,0xF942, 0xA7CB,0xF943,
0xC5A2,0xF944, 0xC5A4,0xF945, 0xA863,0xF946, 0xBD55,0xF947,
0xB8EF,0xF948, 0xB970,0xF949, 0xC253,0xF94A, 0xB9F0,0xF94B,
0xBCD3,0xF94C, 0xB25C,0xF94D, 0xBA7C,0xF94E, 0xB2D6,0xF94F,
0xC15C,0xF950, 0xADAE,0xF951, 0xB0C7,0xF952, 0xA6D8,0xF953,
0xBBFE,0xF954, 0xADE2,0xF955, 0xB857,0xF956, 0xBAF0,0xF957,
0xB5D9,0xF958, 0xB3AE,0xF959, 0xC5AA,0xF95A, 0xCED4,0xF95B,
0xBCD6,0xF95C, 0xBFD5,0xF95D, 0xA4A6,0xF95E, 0xB9E7,0xF95F,
0xABE3,0xF960, 0xB276,0xF961, 0xB2A7,0xF962, 0xA55F,0xF963,
0xEDA8,0xF964, 0xAB4B,0xF965, 0xB45F,0xF966, 0xA4A3,0xF967,
0xAA63,0xF968, 0xBCC6,0xF969, 0xAFC1,0xF96A, 0xB0D1,0xF96B,
0xB6EB,0xF96C, 0xACD9,0xF96D, 0xB8AD,0xF96E, 0xBBA1,0xF96F,
0xB1FE,0xF970, 0xA8B0,0xF971, 0xA848,0xF972, 0xAC42,0xF973,
0xAD59,0xF974, 0xB1B0,0xF975, 0xB2A4,0xF976, 0xAB47,0xF977,
0xA8E2,0xF978, 0x845B,0xF979, 0xB1E7,0xF97A, 0xC2B3,0xF97B,
0xA87D,0xF97C, 0xBDCC,0xF97D, 0xB671,0xF97E, 0xC079,0xF97F,
0xA766,0xF980, 0xA46B,0xF981, 0xC366,0xF982, 0xAEC8,0xF983,
0xC26F,0xF984, 0xC472,0xF985, 0xBE5B,0xF986, 0xC67A,0xF987,
0xC452,0xF988, 0xBEA4,0xF989, 0xA44F,0xF98A, 0xBEE4,0xF98B,
0xBEFA,0xF98C, 0xF765,0xF98D, 0xA67E,0xF98E, 0xBCA6,0xF98F,
0xC5CA,0xF990, 0xBCBF,0xF991, 0xBAA7,0xF992, 0xB7D2,0xF993,
0xE6A3,0xF994, 0x9DCE,0xF995, 0xBD6D,0xF996, 0xC170,0xF997,
0xBDFB,0xF998, 0xBDAC,0xF999, 0xB373,0xF99A, 0xC1E5,0xF99B,
0xA643,0xF99C, 0xA648,0xF99D, 0xAB7C,0xF99E, 0xAF50,0xF99F,
0xB5F5,0xF9A0, 0xBBA1,0xF9A1, 0xB747,0xF9A2, 0xA9C0,0xF9A3,
0xB1C9,0xF9A4, 0xC0D4,0xF9A5, 0xC3AE,0xF9A6, 0xC279,0xF9A7,
0xA54F,0xF9A8, 0xCBF1,0xF9A9, 0xB9E7,0xF9AA, 0xC0AD,0xF9AB,
0xCCB0,0xF9AC, 0xACC2,0xF9AD, 0xBCFC,0xF9AE, 0xB2DC,0xF9AF,
0xB2E2,0xF9B0, 0xB961,0xF9B1, 0xB973,0xF9B2, 0xC646,0xF9B3,
0xBBE2,0xF9B4, 0xA8D2,0xF9B5, 0xC2A7,0xF9B6, 0xC4BF,0xF9B7,
0xC1F5,0xF9B8, 0xB463,0xF9B9, 0xA446,0xF9BA, 0xB9B1,0xF9BB,
0xBC64,0xF9BC, 0xA7BF,0xF9BD, 0xAEC6,0xF9BE, 0xBCD6,0xF9BF,
0xBF52,0xF9C0, 0xC0F8,0xF9C1, 0xE764,0xF9C2, 0xBFF1,0xF9C3,
0xC073,0xF9C4, 0xB777,0xF9C5, 0xA8BF,0xF9C6, 0xBC42,0xF9C7,
0xCCD8,0xF9C8, 0xAC68,0xF9C9, 0xAC79,0xF9CA, 0xB7C8,0xF9CB,
0xAF5B,0xF9CC, 0xAF64,0xF9CD, 0xB2B8,0xF9CE, 0xAFC3,0xF9CF,
0xC3FE,0xF9D0, 0xA4BB,0xF9D1, 0xBCAE,0xF9D2, 0xB3B0,0xF9D3,
0xADDB,0xF9D4, 0xB15B,0xF9D5, 0xB25F,0xF9D6, 0xBDFC,0xF9D7,
0xABDF,0xF9D8, 0xB758,0xF9D9, 0xAEDF,0xF9DA, 0xB276,0xF9DB,
0xB6A9,0xF9DC, 0xA751,0xF9DD, 0xA64F,0xF9DE, 0xBC69,0xF9DF,
0xA9F6,0xF9E0, 0xA7F5,0xF9E1, 0xB1F9,0xF9E2, 0xAA64,0xF9E3,
0xB27A,0xF9E4, 0xB567,0xF9E5, 0xBFA9,0xF9E6, 0xF9D8,0xF9E7,
0xB8CC,0xF9E8, 0xA8BD,0xF9E9, 0xC2F7,0xF9EA, 0xB0CE,0xF9EB,
0xB7C4,0xF9EC, 0xA75B,0xF9ED, 0xBF4D,0xF9EE, 0xBF5A,0xF9EF,
0xC4A9,0xF9F0, 0x95F9,0xF9F1, 0xC5EC,0xF9F2, 0xC5EF,0xF9F3,
0xAA4C,0xF9F4, 0xB24F,0xF9F5, 0xC17B,0xF9F6, 0xA5DF,0xF9F7,
0xB2C1,0xF9F8, 0xB2C9,0xF9F9, 0xAAAC,0xF9FA, 0xAAA5,0xF9FB,
0xC3D1,0xF9FC, 0xA4B0,0xF9FD, 0xAFF9,0xF9FE, 0xA8EB,0xF9FF,
0xA4C1,0xFA00, 0xABD7,0xFA01, 0xA9DD,0xFA02, 0xBF7D,0xFA03,
0xA676,0xFA04, 0xAC7D,0xFA05, 0xBCC9,0xFA06, 0xBFE7,0xFA07,
0xA6E6,0xFA08, 0xADB0,0xFA09, 0xA8A3,0xFA0A, 0xB9F8,0xFA0B,
0xB6EF,0xFA10, 0xB4B8,0xFA12, 0xE8F9,0xFA15, 0x95BD,0xFA16,
0xAF71,0xFA17, 0xAFAB,0xFA19, 0xB2BB,0xFA1A, 0xBAD6,0xFA1B,
0xB974,0xFA1C, 0xBAEB,0xFA1D, 0xA6D0,0xFA1E, 0xBDD1,0xFA22,
0xB668,0xFA25, 0xB3A3,0xFA26, 0xB6BA,0xFA2A, 0xB97D,0xFA2B,
0xC05D,0xFA2C, 0xC562,0xFA2D, 0xAB56,0xFA30, 0xB9AC,0xFA31,
0xA74B,0xFA32, 0xAB6A,0xFA33, 0xB6D4,0xFA34, 0xA8F5,0xFA35,
0xB3DC,0xFA36, 0xB9C4,0xFA37, 0xBEB9,0xFA38, 0x9459,0xFA39,
0xBEA5,0xFA3A, 0xBC68,0xFA3B, 0xC94B,0xFA3C, 0xAEAC,0xFA3D,
0xB46E,0xFA3E, 0xBCA8,0xFA3F, 0xC367,0xFA40, 0xB1D3,0xFA41,
0xAC4A,0xFA42, 0xB4BB,0xFA43, 0xB1F6,0xFA44, 0xAEFC,0xFA45,
0xB25A,0xFA46, 0xBA7E,0xFA47, 0xB54E,0xFA48, 0x9C70,0xFA49,
0xB55A,0xFA4A, 0xB84F,0xFA4B, 0xAAC0,0xFA4C, 0xACE7,0xFA4D,
0xACE8,0xFA4E, 0xAFA7,0xFA4F, 0xAFAA,0xFA50, 0xAFAC,0xFA51,
0xBAD7,0xFA52, 0xBAD5,0xFA53, 0xBD5C,0xFA54, 0xACF0,0xFA55,
0xB860,0xFA56, 0xBD6D,0xFA57, 0xBFA7,0xFA58, 0xC163,0xFA59,
0xB870,0xFA5A, 0xAACC,0xFA5B, 0xAFE4,0xFA5C, 0x9CD2,0xFA5D,
0x9CD2,0xFA5E, 0xB5DB,0xFA5F, 0xBDC5,0xFA60, 0xB5F8,0xFA61,
0xBFD6,0xFA62, 0xC2D4,0xFA63, 0xBBAB,0xFA64, 0xC3D8,0xFA65,
0x9CE0,0xFA66, 0xB668,0xFA67, 0xC3F8,0xFA68, 0xC554,0xFA69,
0xC057,0xFA6A, 0x91C2,0xFF07, 0x5E20,0xFF3E, 0xA1AB,0xFF40,
0xA278,0xFFE8, 0xA1F6,0xFFE9, 0xA1F4,0xFFEA, 0xA1F7,0xFFEB,
0xA1F5,0xFFEC, 0xA1BD,0xFFED, 0xA1B3,0xFFEE,
0x0000,0x0000
};

unsigned short iso8859_1e_uni_byte[128] = {
  0x0080,0x0081,0x0082,0x0083,0x0084,0x0085,0x0086,0x0087,
  0x0088,0x0089,0x008a,0x008b,0x008c,0x008d,0x008e,0x008f,
  0x0090,0x0091,0x0092,0x0093,0x0094,0x0095,0x0096,0x0097,
  0x0098,0x0099,0x009a,0x009b,0x009c,0x009d,0x009e,0x009f,
  0x00a0,0x00a1,0x00a2,0x00a3,0x20ac,0x00a5,0x00a6,0x00a7,
  0x00a8,0x00a9,0x00aa,0x00ab,0x00ac,0x00ad,0x00ae,0x00af,
  0x00b0,0x00b1,0x00b2,0x00b3,0x00b4,0x00b5,0x00b6,0x00b7,
  0x00b8,0x00b9,0x00ba,0x00bb,0x00bc,0x00bd,0x00be,0x00bf,
  0x00c0,0x00c1,0x00c2,0x00c3,0x00c4,0x00c5,0x00c6,0x00c7,
  0x00c8,0x00c9,0x00ca,0x00cb,0x00cc,0x00cd,0x00ce,0x00cf,
  0x00d0,0x00d1,0x00d2,0x00d3,0x00d4,0x00d5,0x00d6,0x00d7,
  0x00d8,0x00d9,0x00da,0x00db,0x00dc,0x00dd,0x00de,0x00df,
  0x00e0,0x00e1,0x00e2,0x00e3,0x00e4,0x00e5,0x00e6,0x00e7,
  0x00e8,0x00e9,0x00ea,0x00eb,0x00ec,0x00ed,0x00ee,0x00ef,
  0x00f0,0x00f1,0x00f2,0x00f3,0x00f4,0x00f5,0x00f6,0x00f7,
  0x00f8,0x00f9,0x00fa,0x00fb,0x00fc,0x00fd,0x00fe,0x00ff
};
unsigned short iso8859_4e_uni_byte[128] = {
  0x0080,0x0081,0x0082,0x0083,0x0084,0x0085,0x0086,0x0087,
  0x0088,0x0089,0x008a,0x008b,0x008c,0x008d,0x008e,0x008f,
  0x0090,0x0091,0x0092,0x0093,0x0094,0x0095,0x0096,0x0097,
  0x0098,0x0099,0x009a,0x009b,0x009c,0x009d,0x009e,0x009f,
  0x00a0,0x0104,0x0138,0x0156,0x20ac,0x0128,0x013b,0x00a7,
  0x00a8,0x0160,0x0112,0x0122,0x0166,0x00ad,0x017d,0x00af,
  0x00b0,0x0105,0x02db,0x0157,0x00b4,0x0129,0x013c,0x02c7,
  0x00b8,0x0161,0x0113,0x0123,0x0167,0x014a,0x017e,0x014b,
  0x0100,0x00c1,0x00c2,0x00c3,0x00c4,0x0139,0x00c6,0x012e,
  0x010c,0x00c9,0x0118,0x00cb,0x0116,0x00cd,0x00ce,0x012a,
  0x0110,0x0145,0x014c,0x0136,0x00d4,0x00d5,0x00d6,0x00d7,
  0x00d8,0x0172,0x00da,0x00db,0x00dc,0x0168,0x016a,0x00df,
  0x0101,0x00e1,0x00e2,0x00e3,0x00e4,0x013a,0x00e6,0x012f,
  0x010d,0x00e9,0x0119,0x00eb,0x0117,0x00ed,0x00ee,0x012b,
  0x0111,0x0146,0x014d,0x0137,0x00f4,0x00f5,0x00f6,0x00f7,
  0x00f8,0x0173,0x00fa,0x00fb,0x00fc,0x0169,0x016b,0x02d9
};
unsigned short iso8859_13e_uni_byte[128] = {
  0x0080,0x0081,0x0082,0x0083,0x0084,0x0085,0x0086,0x0087,
  0x0088,0x0089,0x008a,0x008b,0x008c,0x008d,0x008e,0x008f,
  0x0090,0x0091,0x0092,0x0093,0x0094,0x0095,0x0096,0x0097,
  0x0098,0x0099,0x009a,0x009b,0x009c,0x009d,0x009e,0x009f,
  0x00a0,0x201d,0x00a2,0x00a3,0x20ac,0x201e,0x00a6,0x00a7,
  0x00d8,0x00a9,0x0156,0x00ab,0x00ac,0x00ad,0x00ae,0x00c6,
  0x00b0,0x00b1,0x00b2,0x00b3,0x201c,0x00b5,0x00b6,0x00b7,
  0x00f8,0x00b9,0x0157,0x00bb,0x00bc,0x00bd,0x00be,0x00e6,
  0x0104,0x012e,0x0100,0x0106,0x00c4,0x00c5,0x0118,0x0112,
  0x010c,0x00c9,0x0179,0x0116,0x0122,0x0136,0x012a,0x013b,
  0x0160,0x0143,0x0145,0x00d3,0x014c,0x00d5,0x00d6,0x00d7,
  0x0172,0x0141,0x015a,0x016a,0x00dc,0x017b,0x017d,0x00df,
  0x0105,0x012f,0x0101,0x0107,0x00e4,0x00e5,0x0119,0x0113,
  0x010d,0x00e9,0x017a,0x0117,0x0123,0x0137,0x012b,0x013c,
  0x0161,0x0144,0x0146,0x00f3,0x014d,0x00f5,0x00f6,0x00f7,
  0x0173,0x0142,0x015b,0x016b,0x00fc,0x017c,0x017e,0x2019
};

unsigned short cuban_uni_byte[128] = {
  0x0000,0x0001,0x0002,0x0003,0x0004,0x0005,0x0006,0x0007,
  0x0008,0x0009,0x000a,0x000b,0x000c,0x000d,0x000e,0x000f,
  0x0010,0x0011,0x0012,0x0013,0x0014,0x0015,0x0016,0x0017,
  0x0018,0x0019,0x001a,0x001b,0x001c,0x001d,0x001e,0x001f,
  0x0020,0x0021,0x0022,0x0023,0x00a4,0x0025,0x0026,0x0027,
  0x0028,0x0029,0x002a,0x002b,0x002c,0x002d,0x002e,0x002f,
  0x0030,0x0031,0x0032,0x0033,0x0034,0x0035,0x0036,0x0037,
  0x0038,0x0039,0x003a,0x003b,0x003c,0x003d,0x003e,0x003f,
  0x0040,0x0041,0x0042,0x0043,0x0044,0x0045,0x0046,0x0047,
  0x0048,0x0049,0x004a,0x004b,0x004c,0x004d,0x004e,0x004f,
  0x0050,0x0051,0x0052,0x0053,0x0054,0x0055,0x0056,0x0057,
  0x0058,0x0059,0x005a,0x00a1,0x00d1,0x005d,0x00bf,0x005f,
  0x0060,0x0061,0x0062,0x0063,0x0064,0x0065,0x0066,0x0067,
  0x0068,0x0069,0x006a,0x006b,0x006c,0x006d,0x006e,0x006f,
  0x0070,0x0071,0x0072,0x0073,0x0074,0x0075,0x0076,0x0077,
  0x0078,0x0079,0x007a,0x00b4,0x00f1,0x005b,0x00a8,0x007f
};

unsigned short gost19768_uni_byte[128] = {
  0x0080,0x0081,0x0082,0x0083,0x0084,0x0085,0x0086,0x0087,
  0x0088,0x0089,0x008a,0x008b,0x008c,0x008d,0x008e,0x008f,
  0x0090,0x0091,0x0092,0x0093,0x0094,0x0095,0x0096,0x0097,
  0x0098,0x0099,0x009a,0x009b,0x009c,0x009d,0x009e,0x009f,
  0x00a0,0x0401,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x00ad,0x0000,0x0000,
  0x0410,0x0411,0x0412,0x0413,0x0414,0x0415,0x0416,0x0417,
  0x0418,0x0419,0x041a,0x041b,0x041c,0x041d,0x041e,0x041f,
  0x0420,0x0421,0x0422,0x0423,0x0424,0x0425,0x0426,0x0427,
  0x0428,0x0429,0x042a,0x042b,0x042c,0x042d,0x042e,0x042f,
  0x0430,0x0431,0x0432,0x0433,0x0434,0x0435,0x0436,0x0437,
  0x0438,0x0439,0x043a,0x043b,0x043c,0x043d,0x043e,0x043f,
  0x0440,0x0441,0x0442,0x0443,0x0444,0x0445,0x0446,0x0447,
  0x0448,0x0449,0x044a,0x044b,0x044c,0x044d,0x044e,0x044f,
  0x0000,0x0451,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x00ad,0x0000,0x0000
};

unsigned short iso4873_sami_uni_byte[128] = { /* Lappish */
  0x0080,0x0081,0x0082,0x0083,0x0084,0x0085,0x0086,0x0087,
  0x0088,0x0089,0x008a,0x008b,0x008c,0x008d,0x008e,0x008f,
  0x0090,0x0091,0x0092,0x0093,0x0094,0x0095,0x0096,0x0097,
  0x0098,0x0099,0x009a,0x009b,0x009c,0x009d,0x009e,0x009f,
  0x00b4,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x00ad,0x0000,0x0000,
  0x0309,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0102,0x00c0,0x01de,0x01e0,0x01e2,0x0114,0x00c8,0x01e4,
  0x01e6,0x01e8,0x014e,0x00d2,0x01ea,0x01ec,0x01b7,0x01ee,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0103,0x00e0,0x01df,0x01e1,0x01e3,0x0115,0x00e8,0x01e5,
  0x01e7,0x01e9,0x014f,0x00f2,0x01eb,0x01ed,0x0292,0x01ef,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000
};

unsigned short is434_uni_byte[128] = { /* Ogham */
  0x0080,0x0081,0x0082,0x0083,0x0084,0x0085,0x0086,0x0087,
  0x0088,0x0089,0x008a,0x008b,0x008c,0x008d,0x008e,0x008f,
  0x0090,0x0091,0x0092,0x0093,0x0094,0x0095,0x0096,0x0097,
  0x0098,0x0099,0x009a,0x009b,0x009c,0x009d,0x009e,0x009f,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x1680,0x1681,0x1682,0x1683,0x1684,0x1685,0x1686,0x1687,
  0x1688,0x1689,0x168a,0x168b,0x168c,0x168d,0x168e,0x168f,
  0x1690,0x1691,0x1692,0x1693,0x1694,0x1695,0x1696,0x1697,
  0x1698,0x1699,0x169a,0x169b,0x169c,0x0000,0x0000,0x0000
};

unsigned short ir197_uni_byte[128] = { /* Latin-Hebrew */
  0x0080,0x0081,0x0082,0x0083,0x0084,0x0085,0x0086,0x0087,
  0x0088,0x0089,0x008a,0x008b,0x008c,0x008d,0x008e,0x008f,
  0x0090,0x0091,0x0092,0x0093,0x0094,0x0095,0x0096,0x0097,
  0x0098,0x0099,0x009a,0x009b,0x009c,0x009d,0x009e,0x009f,
  0x00a0,0x0000,0x00a2,0x00a3,0x00a4,0x00a5,0x00a6,0x00a7,
  0x00a8,0x00a9,0x00d7,0x00ab,0x00ac,0x00ad,0x00ae,0x00af,
  0x00b0,0x00b1,0x00b2,0x00b3,0x00b4,0x00b5,0x00b6,0x00b7,
  0x00b8,0x00b9,0x00f7,0x00bb,0x00bc,0x00bd,0x00be,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x2017,
  0x05d0,0x05d1,0x05d2,0x05d3,0x05d4,0x05d5,0x05d6,0x05d7,
  0x05d8,0x05d9,0x05da,0x05db,0x05dc,0x05dd,0x05de,0x05df,
  0x05e0,0x05e1,0x05e2,0x05e3,0x05e4,0x05e5,0x05e6,0x05e7,
  0x05e8,0x05e9,0x05ea,0x0000,0x0000,0x200e,0x200f,0x0000
};

unsigned short iso6937_2_uni_byte[128] = {
  0x0000,0x0001,0x0002,0x0003,0x0004,0x0005,0x0006,0x0007,
  0x0008,0x0009,0x000a,0x000b,0x000c,0x000d,0x000e,0x000f,
  0x0010,0x0011,0x0012,0x0013,0x0014,0x0015,0x0016,0x0017,
  0x0018,0x0019,0x001a,0x001b,0x001c,0x001d,0x001e,0x001f,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x201c,0x0000,0x2190,0x2191,0x2192,0x2193,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x201d,0x0000,0x0000,0x0000,0x0000,0x0000,

  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x2122,0x266a,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000,0x215b,0x215c,0x215d,0x215e,
  0x2126,0x0000,0x0000,0x0000,0x0000,0x0000,0x0132,0x013f,
  0x0000,0x0000,0x0152,0x0000,0x0174,0x0176,0x0178,0x0149,
  0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0133,0x0140,
  0x0000,0x0000,0x0153,0x0000,0x0175,0x0177,0x0000,0x0000
};

unsigned short iso8859_1w_uni_byte[128] = {
  0x0080,0x0081,0x0082,0x0083,0x0084,0x0085,0x0086,0x0087,
  0x0088,0x0089,0x008a,0x008b,0x008c,0x008d,0x008e,0x008f,
  0x0090,0x0091,0x0092,0x0093,0x0094,0x0095,0x0096,0x0097,
  0x0098,0x0099,0x009a,0x009b,0x009c,0x009d,0x009e,0x009f,
  0x00a0,0x00a1,0x00a2,0x00a3,0x00a4,0x00a5,0x00a6,0x00a7,
  0x1e80,0x00a9,0x1e82,0x00ab,0x1ef2,0x00ad,0x00ae,0x0178,
  0x00b0,0x00b1,0x00b2,0x00b3,0x00b4,0x00b5,0x00b6,0x00b7,
  0x1e81,0x00b9,0x1e83,0x00bb,0x1ef3,0x1e84,0x1e85,0x00bf,
  0x00c0,0x00c1,0x00c2,0x00c3,0x00c4,0x00c5,0x00c6,0x00c7,
  0x00c8,0x00c9,0x00ca,0x00cb,0x00cc,0x00cd,0x00ce,0x00cf,
  0x0174,0x00d1,0x00d2,0x00d3,0x00d4,0x00d5,0x00d6,0x00d7,
  0x00d8,0x00d9,0x00da,0x00db,0x00dc,0x00dd,0x0176,0x00df,
  0x00e0,0x00e1,0x00e2,0x00e3,0x00e4,0x00e5,0x00e6,0x00e7,
  0x00e8,0x00e9,0x00ea,0x00eb,0x00ec,0x00ed,0x00ee,0x00ef,
  0x0175,0x00f1,0x00f2,0x00f3,0x00f4,0x00f5,0x00f6,0x00f7,
  0x00f8,0x00f9,0x00fa,0x00fb,0x00fc,0x00fd,0x0177,0x00ff
};

unsigned short iso646_inv_uni_byte[128] = {
  0x0000,0x0001,0x0002,0x0003,0x0004,0x0005,0x0006,0x0007,
  0x0008,0x0009,0x000a,0x000b,0x000c,0x000d,0x000e,0x000f,
  0x0010,0x0011,0x0012,0x0013,0x0014,0x0015,0x0016,0x0017,
  0x0018,0x0019,0x001a,0x001b,0x001c,0x001d,0x001e,0x001f,
  0x0020,0x0021,0x0022,0x0000,0x0000,0x0025,0x0026,0x0027,
  0x0028,0x0029,0x002a,0x002b,0x002c,0x002d,0x002e,0x002f,
  0x0030,0x0031,0x0032,0x0033,0x0034,0x0035,0x0036,0x0037,
  0x0038,0x0039,0x003a,0x003b,0x003c,0x003d,0x003e,0x003f,
  0x0000,0x0041,0x0042,0x0043,0x0044,0x0045,0x0046,0x0047,
  0x0048,0x0049,0x004a,0x004b,0x004c,0x004d,0x004e,0x004f,
  0x0050,0x0051,0x0052,0x0053,0x0054,0x0055,0x0056,0x0057,
  0x0058,0x0059,0x005a,0x0000,0x0000,0x0000,0x0000,0x005f,
  0x0000,0x0061,0x0062,0x0063,0x0064,0x0065,0x0066,0x0067,
  0x0068,0x0069,0x006a,0x006b,0x006c,0x006d,0x006e,0x006f,
  0x0070,0x0071,0x0072,0x0073,0x0074,0x0075,0x0076,0x0077,
  0x0078,0x0079,0x007a,0x0000,0x0000,0x0000,0x0000,0x007f
};

unsigned short iso_turk_uni_byte[128] = {
  0x0000,0x0001,0x0002,0x0003,0x0004,0x0005,0x0006,0x0007,
  0x0008,0x0009,0x000a,0x000b,0x000c,0x000d,0x000e,0x000f,
  0x0010,0x0011,0x0012,0x0013,0x0014,0x0015,0x0016,0x0017,
  0x0018,0x0019,0x001a,0x001b,0x001c,0x001d,0x001e,0x001f,
  0x0020,0x0021,0x0022,0x0023,0x0024,0x0025,0x0026,0x0027,
  0x0028,0x0029,0x002a,0x002b,0x002c,0x002d,0x002e,0x002f,
  0x0030,0x0031,0x0032,0x0033,0x0034,0x0035,0x0036,0x0037,
  0x0038,0x0039,0x003a,0x003b,0x003c,0x003d,0x003e,0x003f,
  0x0040,0x0041,0x0042,0x00c7,0x0044,0x0045,0x00c4,0x0046,
  0x0047,0x0048,0x0049,0x004a,0x017d,0x004b,0x004c,0x004d,
  0x004e,0x0147,0x004f,0x00d6,0x0050,0x0052,0x0053,0x015e,
  0x0054,0x0055,0x00dc,0x0057,0x0059,0x00dd,0x005a,0x005f,
  0x2116,0x0061,0x0062,0x00e7,0x0064,0x0065,0x00e4,0x0066,
  0x0067,0x0068,0x0069,0x006a,0x017e,0x006b,0x006c,0x006d,
  0x006e,0x0148,0x006f,0x00f6,0x0070,0x0072,0x0073,0x015f,
  0x0074,0x0075,0x00fc,0x0077,0x0079,0x00fd,0x007a,0x007f
};

unsigned short ecma114_gr_uni_byte[128] = {
  0x0000,0x0001,0x0002,0x0003,0x0004,0x0005,0x0006,0x0007,
  0x0008,0x0009,0x000a,0x000b,0x000c,0x000d,0x000e,0x000f,
  0x0010,0x0011,0x0012,0x0013,0x0014,0x0015,0x0016,0x0017,
  0x0018,0x0019,0x001a,0x001b,0x001c,0x001d,0x001e,0x001f,
  0x0020,0x039e,0x0022,0x0393,0x00a4,0x0025,0x0026,0x0027,
  0x0028,0x0029,0x002a,0x002b,0x002c,0x002d,0x002e,0x002f,
  0x0030,0x0031,0x0032,0x0033,0x0034,0x0035,0x0036,0x0037,
  0x0038,0x0039,0x03a8,0x003b,0x003c,0x003d,0x003e,0x03a0,
  0x0394,0x0041,0x0042,0x0043,0x0044,0x0045,0x0046,0x0047,
  0x0048,0x0049,0x004a,0x004b,0x004c,0x004d,0x004e,0x004f,
  0x0050,0x0051,0x0052,0x0053,0x0054,0x0055,0x0056,0x0057,
  0x0058,0x0059,0x005a,0x03a9,0x0398,0x03a6,0x039b,0x03a3,
  0x0060,0x0061,0x0062,0x0063,0x0064,0x0065,0x0066,0x0067,
  0x0068,0x0069,0x006a,0x006b,0x006c,0x006d,0x006e,0x006f,
  0x0070,0x0071,0x0072,0x0073,0x0074,0x0075,0x0076,0x0077,
  0x0078,0x0079,0x007a,0x007b,0x007c,0x007d,0x00af,0x007f
};

unsigned short iso5427_uni_byte[128] = {
  0x0000,0x0001,0x0002,0x0003,0x0004,0x0005,0x0006,0x0007,
  0x0008,0x0009,0x000a,0x000b,0x000c,0x000d,0x000e,0x000f,
  0x0010,0x0011,0x0012,0x0013,0x0014,0x0015,0x0016,0x0017,
  0x0018,0x0019,0x001a,0x001b,0x001c,0x001d,0x001e,0x001f,
  0x0020,0x0021,0x0022,0x0023,0x00a4,0x0025,0x0026,0x0027,
  0x0028,0x0029,0x002a,0x002b,0x002c,0x002d,0x002e,0x002f,
  0x0030,0x0031,0x0032,0x0033,0x0034,0x0035,0x0036,0x0037,
  0x0038,0x0039,0x003a,0x003b,0x003c,0x003d,0x003e,0x003f,

  0x044e,0x0430,0x0431,0x0446,0x0434,0x0435,0x0444,0x0433,
  0x0445,0x0438,0x0439,0x043a,0x043b,0x043c,0x043d,0x043e,
  0x043f,0x044f,0x0440,0x0441,0x0442,0x0443,0x0436,0x0432,
  0x044c,0x044b,0x0437,0x0448,0x044d,0x0449,0x0447,0x044a,
  0x042e,0x0410,0x0411,0x0426,0x0414,0x0415,0x0424,0x0413,
  0x0415,0x0428,0x0419,0x041a,0x041b,0x041c,0x041d,0x041e,
  0x041f,0x042f,0x0420,0x0421,0x0422,0x0423,0x0416,0x0412,
  0x042c,0x042b,0x0417,0x0428,0x042d,0x0429,0x0427,0x007f
};

unsigned short iso646_it_o_uni_byte[128] = {
  0x0000,0x0001,0x0002,0x0003,0x0004,0x0005,0x0006,0x0007,
  0x0008,0x0009,0x000a,0x000b,0x000c,0x000d,0x000e,0x000f,
  0x0010,0x0011,0x0012,0x0013,0x0014,0x0015,0x0016,0x0017,
  0x0018,0x0019,0x001a,0x001b,0x001c,0x001d,0x001e,0x001f,
  0x0020,0x0021,0x0022,0x00a3,0x0024,0x0025,0x0026,0x0027,
  0x0028,0x0029,0x002a,0x002b,0x002c,0x002d,0x002e,0x002f,
  0x0030,0x0031,0x0032,0x0033,0x0034,0x0035,0x0036,0x0037,
  0x0038,0x0039,0x003a,0x003b,0x003c,0x003d,0x003e,0x003f,
  0x00a7,0x0041,0x0042,0x0043,0x0044,0x0045,0x0046,0x0047,
  0x0048,0x0049,0x004a,0x004b,0x004c,0x004d,0x004e,0x004f,
  0x0050,0x0051,0x0052,0x0053,0x0054,0x0055,0x0056,0x0057,
  0x0058,0x0059,0x005a,0x00b0,0x00e7,0x00e9,0x005e,0x005f,
  0x00f9,0x0061,0x0062,0x0063,0x0064,0x0065,0x0066,0x0067,
  0x0068,0x0069,0x006a,0x006b,0x006c,0x006d,0x006e,0x006f,
  0x0070,0x0071,0x0072,0x0073,0x0074,0x0075,0x0076,0x0077,
  0x0078,0x0079,0x007a,0x00e0,0x00f2,0x00e8,0x00ec,0x007f
};

unsigned short iso646_po_o_uni_byte[128] = { /* Portuguise */
  0x0000,0x0001,0x0002,0x0003,0x0004,0x0005,0x0006,0x0007,
  0x0008,0x0009,0x000a,0x000b,0x000c,0x000d,0x000e,0x000f,
  0x0010,0x0011,0x0012,0x0013,0x0014,0x0015,0x0016,0x0017,
  0x0018,0x0019,0x001a,0x001b,0x001c,0x001d,0x001e,0x001f,
  0x0020,0x0021,0x0022,0x0023,0x0024,0x0025,0x0026,0x0027,
  0x0028,0x0029,0x002a,0x002b,0x002c,0x002d,0x002e,0x002f,
  0x0030,0x0031,0x0032,0x0033,0x0034,0x0035,0x0036,0x0037,
  0x0038,0x0039,0x003a,0x003b,0x003c,0x003d,0x003e,0x003f,
  0x00a7,0x0041,0x0042,0x0043,0x0044,0x0045,0x0046,0x0047,
  0x0048,0x0049,0x004a,0x004b,0x004c,0x004d,0x004e,0x004f,
  0x0050,0x0051,0x0052,0x0053,0x0054,0x0055,0x0056,0x0057,
  0x0058,0x0059,0x005a,0x00c3,0x00c7,0x00d5,0x005e,0x005f,
  0x0060,0x0061,0x0062,0x0063,0x0064,0x0065,0x0066,0x0067,
  0x0068,0x0069,0x006a,0x006b,0x006c,0x006d,0x006e,0x006f,
  0x0070,0x0071,0x0072,0x0073,0x0074,0x0075,0x0076,0x0077,
  0x0078,0x0079,0x007a,0x00e3,0x00e7,0x00f5,0x00b0,0x007f
};

unsigned short din31624_uni_byte[128] = { /* Bibliographic extend */
  0x0000,0x0001,0x0002,0x0003, 0x0004,0x0005,0x0006,0x0007,
  0x0008,0x0009,0x000a,0x000b, 0x000c,0x000d,0x000e,0x000f,
  0x0010,0x0011,0x0012,0x0013, 0x0014,0x0015,0x0016,0x0017,
  0x0018,0x0019,0x001a,0x001b, 0x001c,0x001d,0x001e,0x001f,
  0x0020,0x00a1,0x301f,0x00a3, 0x00a4,0x2030,0x2020,0x0040,
  0x00b0,0x005b,0x007b,0x00ab, 0x266d,0x00a9,0x24c5,0x00ae,
  0x02bf,0x02be,0x201a,0x0000, 0x005c,0x030d,0x2021,0x00b7,
  0x2192,0x005d,0x007d,0x00bb, 0x266f,0x02b9,0x02ba,0x00bf,

  0x0309,0x0300,0x0301,0x0302, 0x0303,0x0304,0x0306,0x0307,
  0x0308,0x0335,0x030a,0x0315, 0x0312,0x030b,0x031b,0x030c,
  0x0327,0x0328,0x0321,0x0322, 0x0325,0x032e,0x0323,0x0338,
  0x0332,0x0333,0x0329,0x032d, 0x0000,0x0361,0x0361,0x0360,
  0x0000,0x00c6,0x0110,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0141,0x00d8,0x0152,0x0000, 0x00de,0x0000,0x0000,0x0000,
  0x0000,0x00e6,0x0111,0x00f0, 0x0000,0x0131,0x0000,0x0000,
  0x0142,0x00f8,0x0153,0x01a6, 0x00fe,0x0000,0x0000,0x0000
};

unsigned short iso5426_80_uni_byte[128] = { /* Bibliographic extend */
  0x0000,0x0001,0x0002,0x0003, 0x0004,0x0005,0x0006,0x0007,
  0x0008,0x0009,0x000a,0x000b, 0x000c,0x000d,0x000e,0x000f,
  0x0010,0x0011,0x0012,0x0013, 0x0014,0x0015,0x0016,0x0017,
  0x0018,0x0019,0x001a,0x001b, 0x001c,0x001d,0x001e,0x001f,
  0x0020,0x00a1,0x301f,0x00a3, 0x00a4,0x2030,0x2020,0x00a7,
  0x2032,0x2018,0x201c,0x00ab, 0x266d,0x00a9,0x24c5,0x00ae,
  0x02bf,0x02be,0x201a,0x0000, 0x0000,0x0000,0x2021,0x00b7,
  0x2033,0x2019,0x201d,0x00bb, 0x266f,0x02b9,0x02ba,0x00bf,

  0x0309,0x0300,0x0301,0x0302, 0x0303,0x0304,0x0306,0x0307,
  0x0308,0x0335,0x030a,0x0315, 0x0312,0x030b,0x031b,0x030c,
  0x0327,0x0328,0x0321,0x0322, 0x0325,0x032e,0x0323,0x0338,
  0x0332,0x0333,0x0329,0x032d, 0x0000,0x0361,0x0361,0x0360,
  0x0000,0x00c6,0x0110,0x0000, 0x0000,0x0000,0x0132,0x0000,
  0x0141,0x00d8,0x0152,0x0000, 0x00de,0x0000,0x0000,0x0000,
  0x0000,0x00e6,0x0111,0x00f0, 0x0000,0x0131,0x0133,0x0000,
  0x0142,0x00f8,0x0153,0x00df, 0x00fe,0x0000,0x0000,0x0000
};

unsigned short din31625_uni_byte[128] = { /* African */
  0x0000,0x0001,0x0002,0x0003, 0x0004,0x0005,0x0006,0x0007,
  0x0008,0x0009,0x000a,0x000b, 0x000c,0x000d,0x000e,0x000f,
  0x0010,0x0011,0x0012,0x0013, 0x0014,0x0015,0x0016,0x0017,
  0x0018,0x0019,0x001a,0x001b, 0x001c,0x001d,0x001e,0x001f,
  0x0020,0x0000,0x0181,0x0187, 0x018a,0x0189,0x0000,0x0190,
  0x018e,0x0000,0x0191,0x0193, 0x0194,0x0126,0x0000,0x0197,
  0x0000,0x0000,0x0182,0x0188, 0x018b,0x0256,0x0000,0x025b,
  0x018f,0x0000,0x0192,0x0260, 0x0263,0x0127,0x0000,0x026a,
  0x0198,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x014a,
  0x0000,0x019f,0x0186,0x01a4, 0x0000,0x0000,0x0000,0x01a9,
  0x0199,0x026c,0x0000,0x0271, 0x0000,0x0273,0x0272,0x014b,
  0x0000,0x0275,0x0254,0x01a5, 0x0000,0x027d,0x0000,0x0283,
  0x01ac,0x01ae,0x0000,0x01b1, 0x01b2,0x03a7,0x01b3,0x01b7,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x01ad,0x0288,0x0000,0x028a, 0x028b,0x03c7,0x01b4,0x0292,
  0x0295,0x0294,0x0298,0x01c0, 0x01c2,0x01c3,0x01c1,0x007f
};

unsigned short iso646_ns4551_2_uni_byte[128] = {
  0x0000,0x0001,0x0002,0x0003,0x0004,0x0005,0x0006,0x0007,
  0x0008,0x0009,0x000a,0x000b,0x000c,0x000d,0x000e,0x000f,
  0x0010,0x0011,0x0012,0x0013,0x0014,0x0015,0x0016,0x0017,
  0x0018,0x0019,0x001a,0x001b,0x001c,0x001d,0x001e,0x001f,
  0x0020,0x0021,0x00a7,0x0023,0x0024,0x0025,0x0026,0x0027,
  0x0028,0x0029,0x002a,0x002b,0x002c,0x002d,0x002e,0x002f,
  0x0030,0x0031,0x0032,0x0033,0x0034,0x0035,0x0036,0x0037,
  0x0038,0x0039,0x003a,0x003b,0x003c,0x003d,0x003e,0x003f,
  0x0040,0x0041,0x0042,0x0043,0x0044,0x0045,0x0046,0x0047,
  0x0048,0x0049,0x004a,0x004b,0x004c,0x004d,0x004e,0x004f,
  0x0050,0x0051,0x0052,0x0053,0x0054,0x0055,0x0056,0x0057,
  0x0058,0x0059,0x005a,0x00c6,0x00d8,0x00c5,0x005e,0x005f,
  0x0060,0x0061,0x0062,0x0063,0x0064,0x0065,0x0066,0x0067,
  0x0068,0x0069,0x006a,0x006b,0x006c,0x006d,0x006e,0x006f,
  0x0070,0x0071,0x0072,0x0073,0x0074,0x0075,0x0076,0x0077,
  0x0078,0x0079,0x007a,0x00e6,0x00f8,0x00e5,0x00af,0x007f
};

unsigned short iso646_ns4551_uni_byte[128] = {
  0x0000,0x0001,0x0002,0x0003,0x0004,0x0005,0x0006,0x0007,
  0x0008,0x0009,0x000a,0x000b,0x000c,0x000d,0x000e,0x000f,
  0x0010,0x0011,0x0012,0x0013,0x0014,0x0015,0x0016,0x0017,
  0x0018,0x0019,0x001a,0x001b,0x001c,0x001d,0x001e,0x001f,
  0x0020,0x0021,0x0022,0x0023,0x0024,0x0025,0x0026,0x0027,
  0x0028,0x0029,0x002a,0x002b,0x002c,0x002d,0x002e,0x002f,
  0x0030,0x0031,0x0032,0x0033,0x0034,0x0035,0x0036,0x0037,
  0x0038,0x0039,0x003a,0x003b,0x003c,0x003d,0x003e,0x003f,
  0x0040,0x0041,0x0042,0x0043,0x0044,0x0045,0x0046,0x0047,
  0x0048,0x0049,0x004a,0x004b,0x004c,0x004d,0x004e,0x004f,
  0x0050,0x0051,0x0052,0x0053,0x0054,0x0055,0x0056,0x0057,
  0x0058,0x0059,0x005a,0x00c6,0x00d8,0x00c5,0x005e,0x005f,
  0x0060,0x0061,0x0062,0x0063,0x0064,0x0065,0x0066,0x0067,
  0x0068,0x0069,0x006a,0x006b,0x006c,0x006d,0x006e,0x006f,
  0x0070,0x0071,0x0072,0x0073,0x0074,0x0075,0x0076,0x0077,
  0x0078,0x0079,0x007a,0x00e6,0x00f8,0x00e5,0x00af,0x007f
};

unsigned short msz7795_uni_byte[128] = { /* Hungarian */
  0x0000,0x0001,0x0002,0x0003,0x0004,0x0005,0x0006,0x0007,
  0x0008,0x0009,0x000a,0x000b,0x000c,0x000d,0x000e,0x000f,
  0x0010,0x0011,0x0012,0x0013,0x0014,0x0015,0x0016,0x0017,
  0x0018,0x0019,0x001a,0x001b,0x001c,0x001d,0x001e,0x001f,
  0x0020,0x0021,0x0022,0x0023,0x00a4,0x0025,0x0026,0x0027,
  0x0028,0x0029,0x002a,0x002b,0x002c,0x002d,0x002e,0x002f,
  0x0030,0x0031,0x0032,0x0033,0x0034,0x0035,0x0036,0x0037,
  0x0038,0x0039,0x003a,0x003b,0x003c,0x003d,0x003e,0x003f,
  0x00c1,0x0041,0x0042,0x0043,0x0044,0x0045,0x0046,0x0047,
  0x0048,0x0049,0x004a,0x004b,0x004c,0x004d,0x004e,0x004f,
  0x0050,0x0051,0x0052,0x0053,0x0054,0x0055,0x0056,0x0057,
  0x0058,0x0059,0x005a,0x00c9,0x00d6,0x00dc,0x005e,0x005f,
  0x00e1,0x0061,0x0062,0x0063,0x0064,0x0065,0x0066,0x0067,
  0x0068,0x0069,0x006a,0x006b,0x006c,0x006d,0x006e,0x006f,
  0x0070,0x0071,0x0072,0x0073,0x0074,0x0075,0x0076,0x0077,
  0x0078,0x0079,0x007a,0x00e9,0x00f6,0x00fc,0x02ba,0x007f
};

unsigned short iso9036_uni_byte[128] = { /* Arabic */
  0x0000,0x0001,0x0002,0x0003,0x0004,0x0005,0x0006,0x0007,
  0x0008,0x0009,0x000a,0x000b,0x000c,0x000d,0x000e,0x000f,
  0x0010,0x0011,0x0012,0x0013,0x0014,0x0015,0x0016,0x0017,
  0x0018,0x0019,0x001a,0x001b,0x001c,0x001d,0x001e,0x001f,
  0x0020,0x0021,0x0022,0x0023,0x00a4,0x0025,0x0026,0x0027,
  0x0028,0x0029,0x002a,0x002b,0x002c,0x002d,0x002e,0x002f,
  0x0030,0x0031,0x0032,0x0033,0x0034,0x0035,0x0036,0x0037,
  0x0038,0x0039,0x003a,0x003b,0x003c,0x003d,0x003e,0x061f,
  0x0040,0x0621,0x0622,0x0623,0x0624,0x0625,0x0626,0x0627,
  0x0628,0x0629,0x062a,0x062b,0x062c,0x062d,0x062e,0x062f,
  0x0630,0x0631,0x0632,0x0633,0x0634,0x0635,0x0636,0x0637,
  0x0638,0x0639,0x063a,0x005b,0x005c,0x005d,0x005e,0x005f,
  0x0640,0x0641,0x0642,0x0643,0x0644,0x0645,0x0646,0x0647,
  0x0648,0x0649,0x064a,0x064b,0x064c,0x064d,0x064e,0x064f,
  0x0650,0x0651,0x0652,0x0000,0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x007b,0x007c,0x007d,0x007e,0x007f
};

unsigned short uk_tele_uni_byte[128] = {
  0x0000,0x0001,0x0002,0x0003,0x0004,0x0005,0x0006,0x0007,
  0x0008,0x0009,0x000a,0x000b,0x000c,0x000d,0x000e,0x000f,
  0x0010,0x0011,0x0012,0x0013,0x0014,0x0015,0x0016,0x0017,
  0x0018,0x0019,0x001a,0x001b,0x001c,0x001d,0x001e,0x001f,
  0x0020,0x0021,0x0022,0x00a3,0x0024,0x0025,0x0026,0x0027,
  0x0028,0x0029,0x002a,0x002b,0x002c,0x002d,0x002e,0x002f,
  0x0030,0x0031,0x0032,0x0033,0x0034,0x0035,0x0036,0x0037,
  0x0038,0x0039,0x003a,0x003b,0x003c,0x003d,0x003e,0x003f,
  0x0040,0x0041,0x0042,0x0043,0x0044,0x0045,0x0046,0x0047,
  0x0048,0x0049,0x004a,0x004b,0x004c,0x004d,0x004e,0x004f,
  0x0050,0x0051,0x0052,0x0053,0x0054,0x0055,0x0056,0x0057,
  0x0058,0x0059,0x005a,0x2190,0x00bd,0x2192,0x2191,0x2317,
  0x2014,0x0061,0x0062,0x0063,0x0064,0x0065,0x0066,0x0067,
  0x0068,0x0069,0x006a,0x006b,0x006c,0x006d,0x006e,0x006f,
  0x0070,0x0071,0x0072,0x0073,0x0074,0x0075,0x0076,0x0077,
  0x0078,0x0079,0x007a,0x00bc,0x2016,0x00be,0x00f7,0x007f
};

unsigned short nats_add_uni_byte[128] = {
  0x0000,0x0001,0x0002,0x0003, 0x0004,0x0005,0x0006,0x0007,
  0x0008,0x0009,0x000a,0x000b, 0x000c,0x000d,0x000e,0x000f,
  0x0010,0x0011,0x0012,0x0013, 0x0014,0x0015,0x0016,0x0017,
  0x0018,0x0019,0x001a,0x001b, 0x001c,0x001d,0x001e,0x001f,
  0x0020,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,

  0x0000,0x00c0,0x0000,0x0000, 0x0110,0x00c9,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x00de,0x0000,0x0000,0x0000, 0x0000,0x00dc,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x00c6, 0x00d8,0x0000,0x0000,0x0000,
  0x0000,0x00e0,0x0000,0x0000, 0x0111,0x00e9,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x00fe,0x0000,0x0000,0x0000, 0x0000,0x00fc,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x00e6, 0x00f8,0x0000,0x0000,0x007f
};

unsigned short nats_add_den_uni_byte[128] = {
  0x0000,0x0001,0x0002,0x0003, 0x0004,0x0005,0x0006,0x0007,
  0x0008,0x0009,0x000a,0x000b, 0x000c,0x000d,0x000e,0x000f,
  0x0010,0x0011,0x0012,0x0013, 0x0014,0x0015,0x0016,0x0017,
  0x0018,0x0019,0x001a,0x001b, 0x001c,0x001d,0x001e,0x001f,
  0x0020,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,

  0x0000,0x00c0,0x0000,0x0000, 0x0110,0x00c9,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x00de,0x0000,0x0000,0x0000, 0x0000,0x00dc,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x00c4, 0x00d6,0x0000,0x0000,0x0000,
  0x0000,0x00e0,0x0000,0x0000, 0x0111,0x00e9,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x00fe,0x0000,0x0000,0x0000, 0x0000,0x00fc,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x00e4, 0x00f6,0x0000,0x0000,0x007f
};

unsigned short ir167_uni_byte[128] = { /* Arabic/French */
  0x0080,0x0081,0x0082,0x0083, 0x0084,0x0085,0x0086,0x0087,
  0x0088,0x0089,0x008a,0x008b, 0x008c,0x008d,0x008e,0x008f,
  0x0090,0x0091,0x0092,0x0093, 0x0094,0x0095,0x0096,0x0097,
  0x0098,0x0099,0x009a,0x009b, 0x009c,0x009d,0x009e,0x009f,
  0x00a0,0x0000,0x0000,0x0000, 0x00a4,0x0000,0x0000,0x0000,
  0x00c8,0x00c9,0x00ca,0x00cb, 0x060c,0x00ad,0x00ce,0x00cf,
  0x00c0,0x00c2,0x00e2,0x00c4, 0x00df,0x00e4,0x00c7,0x00e7,
  0x00e8,0x00e9,0x00ea,0x061b, 0x00eb,0x00ee,0x00ef,0x061f,

  0x00e0,0x0621,0x0622,0x0623, 0x0624,0x0625,0x0626,0x0627,
  0x0628,0x0629,0x062a,0x062b, 0x062c,0x062d,0x062e,0x062f,
  0x0630,0x0631,0x0632,0x0633, 0x0634,0x0635,0x0636,0x0637,
  0x0638,0x0639,0x063a,0x00d4, 0x00d6,0x00da,0x00db,0x00dc,
  0x0640,0x0641,0x0642,0x0643, 0x0644,0x0645,0x0646,0x0647,
  0x0648,0x0649,0x064a,0x064b, 0x064c,0x064d,0x064e,0x064f,
  0x0650,0x0651,0x0652,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x00f4, 0x00f6,0x00fa,0x00fb,0x00fc
};

unsigned short oli_greek_uni_byte[128] = {
  0x0000,0x0001,0x0002,0x0003,0x0004,0x0005,0x0006,0x0007,
  0x0008,0x0009,0x000a,0x000b,0x000c,0x000d,0x000e,0x000f,
  0x0010,0x0011,0x0012,0x0013,0x0014,0x0015,0x0016,0x0017,
  0x0018,0x0019,0x001a,0x001b,0x001c,0x001d,0x001e,0x001f,
  0x0020,0x0021,0x0022,0x00a3,0x0024,0x0025,0x0026,0x0027,
  0x0028,0x0029,0x002a,0x002b,0x002c,0x002d,0x002e,0x002f,
  0x0030,0x0031,0x0032,0x0033,0x0034,0x0035,0x0036,0x0037,
  0x0038,0x0039,0x003a,0x003b,0x003c,0x003d,0x003e,0x003f,
  0x0040,0x0041,0x0042,0x0043,0x0044,0x0045,0x0046,0x0047,
  0x0048,0x0049,0x004a,0x004b,0x004c,0x004d,0x004e,0x004f,
  0x0050,0x0051,0x0052,0x0053,0x0054,0x0055,0x0056,0x0057,
  0x0058,0x0059,0x005a,0x005b,0x005c,0x005d,0x005e,0x005f,
  0x0060,0x0391,0x0392,0x03a8,0x0394,0x0395,0x0396,0x0393,
  0x0397,0x0399,0x039e,0x039a,0x039b,0x039c,0x039d,0x039f,
  0x03a0,0x0000,0x03a1,0x03a3,0x03a4,0x0398,0x03a9,0x0387,
  0x03a7,0x03a5,0x0396,0x007b,0x007c,0x007d,0x00a8,0x007f
};

unsigned short csa_z243_uni_byte[128] = {
  0x0080,0x0081,0x0082,0x0083, 0x0084,0x0085,0x0086,0x0087,
  0x0088,0x0089,0x008a,0x008b, 0x008c,0x008d,0x008e,0x008f,
  0x0090,0x0091,0x0092,0x0093, 0x0094,0x0095,0x0096,0x0097,
  0x0098,0x0099,0x009a,0x009b, 0x009c,0x009d,0x009e,0x009f,
  0x00a0,0x00a1,0x00a8,0x00a3, 0x00a2,0x00a5,0x00b1,0x00b4,
  0x207d,0x207e,0x00bd,0x207a, 0x00b8,0x00ad,0x00b7,0x00af,
  0x2070,0x00b9,0x00b2,0x00b3, 0x2074,0x2075,0x2076,0x2077,
  0x2078,0x2079,0x00bc,0x00be, 0x2264,0x2260,0x2265,0x00bf,

  0x00c0,0x00c1,0x00c2,0x00c7, 0x00c8,0x00c9,0x00ca,0x00cb,
  0x00cd,0x00ce,0x00cf,0x00d1, 0x00d3,0x00d4,0x00d9,0x00da,
  0x00db,0x00dc,0x00ae,0x00a7, 0x00b6,0x00b5,0x00aa,0x00ba,
  0x2018,0x2019,0x201c,0x201d, 0x00ab,0x00bb,0x00b0,0x00a6,
  0x00e0,0x00e1,0x00e2,0x00e7, 0x00e8,0x00e9,0x00ea,0x00eb,
  0x00ed,0x00ee,0x00ef,0x00f1, 0x00f3,0x00f4,0x00f9,0x00fa,
  0x00fb,0x00fc,0x00a9,0x2500, 0x2502,0x2514,0x2518,0x2510,
  0x250c,0x251c,0x2534,0x2524, 0x252c,0x253c,0x00ac,0x2588
};

unsigned short ecma114_gr2_uni_byte[128] = {
  0x0000,0x0001,0x0002,0x0003, 0x0004,0x0005,0x0006,0x0007,
  0x0008,0x0009,0x000a,0x000b, 0x000c,0x000d,0x000e,0x000f,
  0x0010,0x0011,0x0012,0x0013, 0x0014,0x0015,0x0016,0x0017,
  0x0018,0x0019,0x001a,0x001b, 0x001c,0x001d,0x001e,0x001f,
  0x0020,0x0021,0x0022,0x00a3, 0x0024,0x0025,0x0026,0x0027,
  0x0028,0x0029,0x002a,0x002b, 0x002c,0x002d,0x002e,0x002f,
  0x0030,0x0031,0x0032,0x0033, 0x0034,0x0035,0x0036,0x0037,
  0x0038,0x0039,0x003a,0x003b, 0x003c,0x003d,0x003e,0x003f,

  0x0301,0x03b1,0x03b2,0x03c8, 0x03b4,0x03b5,0x03c6,0x03b3,
  0x03b7,0x03b9,0x03be,0x03ba, 0x03bb,0x03bc,0x03bd,0x03bf,
  0x03c0,0x0345,0x03c1,0x03c3, 0x03c4,0x03b8,0x03c9,0x03c2,
  0x03c7,0x03c5,0x03b6,0x1fcf, 0x1fbf,0x1fce,0x0342,0x005f,

  0x0300,0x0391,0x0392,0x03a8, 0x0394,0x0395,0x03a6,0x0393,
  0x0397,0x0399,0x039e,0x039a, 0x039b,0x039c,0x039d,0x039f,
  0x03a0,0x0370,0x03a1,0x03a3, 0x03a4,0x0398,0x03a9,0x0387,
  0x03a7,0x03a5,0x0396,0x1fdf, 0x1ffe,0x1fde,0x00a8,0x007f
};

unsigned short macd_uni_byte[128] = {
  0x0000,0x0001,0x0002,0x0003,0x0004,0x0005,0x0006,0x0007,
  0x0008,0x0009,0x000a,0x000b,0x000c,0x000d,0x000e,0x000f,
  0x0010,0x0011,0x0012,0x0013,0x0014,0x0015,0x0016,0x0017,
  0x0018,0x0019,0x001a,0x001b,0x001c,0x001d,0x001e,0x001f,
  0x0020,0x0021,0x0022,0x0023,0x0024,0x0025,0x0026,0x0027,
  0x0028,0x0029,0x002a,0x002b,0x002c,0x002d,0x002e,0x002f,
  0x0030,0x0031,0x0032,0x0033,0x0034,0x0035,0x0036,0x0037,
  0x0038,0x0039,0x003a,0x003b,0x003c,0x003d,0x003e,0x003f,

  0x0416,0x0410,0x0411,0x0426,0x0414,0x0415,0x0424,0x0413,
  0x0425,0x0418,0x0408,0x041a,0x041b,0x041c,0x041d,0x041e,
  0x041f,0x0409,0x0420,0x0421,0x0422,0x0423,0x0412,0x040a,
  0x040f,0x0405,0x0417,0x0428,0x0403,0x040c,0x0427,0x005f,
  0x0436,0x0430,0x0431,0x0446,0x0434,0x0435,0x0444,0x0433,
  0x0445,0x0438,0x0458,0x043a,0x043b,0x043c,0x043d,0x043e,
  0x043f,0x0459,0x0440,0x0441,0x0442,0x0443,0x0432,0x045a,
  0x045f,0x0455,0x0437,0x0448,0x0453,0x045c,0x0447,0x007f
};

unsigned short serb_uni_byte[128] = {
  0x0000,0x0001,0x0002,0x0003,0x0004,0x0005,0x0006,0x0007,
  0x0008,0x0009,0x000a,0x000b,0x000c,0x000d,0x000e,0x000f,
  0x0010,0x0011,0x0012,0x0013,0x0014,0x0015,0x0016,0x0017,
  0x0018,0x0019,0x001a,0x001b,0x001c,0x001d,0x001e,0x001f,
  0x0020,0x0021,0x0022,0x0023,0x0024,0x0025,0x0026,0x0027,
  0x0028,0x0029,0x002a,0x002b,0x002c,0x002d,0x002e,0x002f,
  0x0030,0x0031,0x0032,0x0033,0x0034,0x0035,0x0036,0x0037,
  0x0038,0x0039,0x003a,0x003b,0x003c,0x003d,0x003e,0x003f,

  0x0416,0x0410,0x0411,0x0426,0x0414,0x0415,0x0424,0x0413,
  0x0425,0x0418,0x0408,0x041a,0x041b,0x041c,0x041d,0x041e,
  0x041f,0x0409,0x0420,0x0421,0x0422,0x0423,0x0412,0x040a,
  0x040f,0x0405,0x0417,0x0428,0x0402,0x040b,0x0427,0x005f,
  0x0436,0x0430,0x0431,0x0446,0x0434,0x0435,0x0444,0x0433,
  0x0445,0x0438,0x0458,0x043a,0x043b,0x043c,0x043d,0x043e,
  0x043f,0x0459,0x0440,0x0441,0x0442,0x0443,0x0432,0x045a,
  0x045f,0x0455,0x0437,0x0448,0x0452,0x045b,0x0447,0x007f
};

unsigned short serb_slov_uni_byte[128] = {
  0x0000,0x0001,0x0002,0x0003, 0x0004,0x0005,0x0006,0x0007,
  0x0008,0x0009,0x000a,0x000b, 0x000c,0x000d,0x000e,0x000f,
  0x0010,0x0011,0x0012,0x0013, 0x0014,0x0015,0x0016,0x0017,
  0x0018,0x0019,0x001a,0x001b, 0x001c,0x001d,0x001e,0x001f,
  0x0020,0x0021,0x0022,0x0023, 0x0024,0x0025,0x0026,0x0027,
  0x0028,0x0029,0x002a,0x002b, 0x002c,0x002d,0x002e,0x002f,
  0x0030,0x0031,0x0032,0x0033, 0x0034,0x0035,0x0036,0x0037,
  0x0038,0x0039,0x003a,0x003b, 0x003c,0x003d,0x003e,0x003f,

  0x017d,0x0041,0x0042,0x0043, 0x0044,0x0045,0x0046,0x0047,
  0x0048,0x0049,0x004a,0x004b, 0x004c,0x004d,0x004e,0x004f,
  0x0050,0x0051,0x0052,0x0053, 0x0054,0x0055,0x0056,0x0057,
  0x0058,0x0059,0x005a,0x0160, 0x0110,0x0106,0x010c,0x005f,
  0x017e,0x0061,0x0062,0x0063, 0x0064,0x0065,0x0066,0x0067,
  0x0068,0x0069,0x006a,0x006b, 0x006c,0x006d,0x006e,0x006f,
  0x0070,0x0071,0x0072,0x0073, 0x0074,0x0075,0x0076,0x0077,
  0x0078,0x0079,0x007a,0x0161, 0x0111,0x0107,0x010d,0x007f
};

unsigned short x9010_h_uni_byte[128] = {
  0x0000,0x0001,0x0002,0x0003, 0x0004,0x0005,0x0006,0x0007,
  0x0008,0x0009,0x000a,0x000b, 0x000c,0x000d,0x000e,0x000f,
  0x0010,0x0011,0x0012,0x0013, 0x0014,0x0015,0x0016,0x0017,
  0x0018,0x0019,0x001a,0x001b, 0x001c,0x001d,0x001e,0x001f,
  0x0020,0x0021,0x0022,0x0023, 0x0024,0x0025,0x0026,0x0027,
  0x0028,0x0029,0x002a,0x002b, 0x002c,0x002d,0x002e,0x002f,
  0x0030,0x0031,0x0032,0x0033, 0x0034,0x0035,0x0036,0x0037,
  0x0038,0x0039,0x003a,0x003b, 0x003c,0x003d,0x003e,0x003f,

  0x0040,0x0041,0x0042,0x0043, 0x0044,0x0045,0x0046,0x0047,
  0x0048,0x0049,0x004a,0x004b, 0x004c,0x004d,0x004e,0x004f,
  0x0050,0x0051,0x0052,0x0053, 0x0054,0x0055,0x0056,0x0057,
  0x0058,0x0059,0x005a,0x005b, 0x005c,0x005d,0x005e,0x005f,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x007c,0x0000,0x0000,0x007f
};

unsigned short x9010_oa_uni_byte[128] = {
  0x0000,0x0001,0x0002,0x0003, 0x0004,0x0005,0x0006,0x0007,
  0x0008,0x0009,0x000a,0x000b, 0x000c,0x000d,0x000e,0x000f,
  0x0010,0x0011,0x0012,0x0013, 0x0014,0x0015,0x0016,0x0017,
  0x0018,0x0019,0x001a,0x001b, 0x001c,0x001d,0x001e,0x001f,
  0x0020,0x0000,0x0000,0x0000, 0x0000,0x244a,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,

  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x007f
};

unsigned short rh_greek_uni_byte[128] = {
  0x0080,0x0081,0x0082,0x0083, 0x0084,0x0085,0x0086,0x0087,
  0x0088,0x0089,0x008a,0x008b, 0x008c,0x008d,0x008e,0x008f,
  0x0090,0x0091,0x0092,0x0093, 0x0094,0x0095,0x0096,0x0097,
  0x0098,0x0099,0x009a,0x009b, 0x009c,0x009d,0x009e,0x009f,
  0x00a0,0x0312,0x0313,0x00a3, 0x20ac,0x20af,0x00a6,0x00a7,
  0x00a8,0x00a9,0x0375,0x00ab, 0x00ac,0x00ad,0x0000,0x00af,
  0x00b0,0x00b1,0x00b2,0x00b3, 0x00b4,0x0385,0x0386,0x0387,
  0x0388,0x0389,0x038a,0x00bb, 0x038c,0x00bd,0x038e,0x038f,

  0x0390,0x0391,0x0392,0x0393, 0x0394,0x0395,0x0396,0x0397,
  0x0398,0x0399,0x039a,0x039b, 0x039c,0x039d,0x039e,0x039f,
  0x03a0,0x03a1,0x0000,0x03a3, 0x03a4,0x03a5,0x03a6,0x03a7,
  0x03a8,0x03a9,0x03aa,0x03ab, 0x03ac,0x03ad,0x03ae,0x03af,
  0x03b0,0x03b1,0x03b2,0x03b3, 0x03b4,0x03b5,0x03b6,0x03b7,
  0x03b8,0x03b9,0x03ba,0x03bb, 0x03bc,0x03bd,0x03be,0x03bf,
  0x03c0,0x03c1,0x03c2,0x03c3, 0x03c4,0x03c5,0x03c6,0x03c7,
  0x03c8,0x03c9,0x03ca,0x03cb, 0x03cc,0x03cd,0x03ce,0x0000
};

unsigned short uralic_uni_byte[128] = {
  0x0080,0x0081,0x0082,0x0083, 0x0084,0x0085,0x0086,0x0087,
  0x0088,0x0089,0x008a,0x008b, 0x008c,0x008d,0x008e,0x008f,
  0x0090,0x0091,0x0092,0x0093, 0x0094,0x0095,0x0096,0x0097,
  0x0098,0x0099,0x009a,0x009b, 0x009c,0x009d,0x009e,0x009f,
  0x00a0,0x0401,0x04c7,0x04d2, 0x04ec,0x0462,0x0406,0x04e6,
  0x048a,0x04c5,0x04a2,0x00ab, 0x04cd,0x00ad,0x048e,0x02bc,
  0x0410,0x0411,0x0412,0x0413, 0x0414,0x0415,0x0416,0x0417,
  0x0418,0x0419,0x041a,0x041b, 0x041c,0x041d,0x041e,0x041f,

  0x0420,0x0421,0x0422,0x0423, 0x0424,0x0425,0x0426,0x0427,
  0x0428,0x0429,0x042a,0x042b, 0x042c,0x042d,0x042e,0x042f,
  0x0430,0x0431,0x0432,0x0433, 0x0434,0x0435,0x0436,0x0437,
  0x0438,0x0439,0x043a,0x043b, 0x043c,0x043d,0x043e,0x043f,
  0x0440,0x0441,0x0442,0x0443, 0x0444,0x0445,0x0446,0x0447,
  0x0448,0x0449,0x044a,0x044b, 0x044c,0x044d,0x044e,0x044f,
  0x2116,0x0451,0x04c8,0x04d3, 0x04ed,0x048d,0x0456,0x04e7,
  0x048b,0x04c6,0x04a3,0x00bb, 0x04ce,0x00a7,0x048f,0x02ba
};

unsigned short volg_uni_byte[128] = {
  0x0080,0x0081,0x0082,0x0083, 0x0084,0x0085,0x0086,0x0087,
  0x0088,0x0089,0x008a,0x008b, 0x008c,0x008d,0x008e,0x008f,
  0x0090,0x0091,0x0092,0x0093, 0x0094,0x0095,0x0096,0x0097,
  0x0098,0x0099,0x009a,0x009b, 0x009c,0x009d,0x009e,0x009f,
  0x00a0,0x0401,0x04d0,0x04d2, 0x04d6,0x04aa,0x0406,0x04e6,
  0x04e4,0x04dc,0x04a4,0x04f8, 0x04de,0x00ad,0x04f0,0x04f4,
  0x0410,0x0411,0x0412,0x0413, 0x0414,0x0415,0x0416,0x0417,
  0x0418,0x0419,0x041a,0x041b, 0x041c,0x041d,0x041e,0x041f,

  0x0420,0x0421,0x0422,0x0423, 0x0424,0x0425,0x0426,0x0427,
  0x0428,0x0429,0x042a,0x042b, 0x042c,0x042d,0x042e,0x042f,
  0x0430,0x0431,0x0432,0x0433, 0x0434,0x0435,0x0436,0x0437,
  0x0438,0x0439,0x043a,0x043b, 0x043c,0x043d,0x043e,0x043f,
  0x0440,0x0441,0x0442,0x0443, 0x0444,0x0445,0x0446,0x0447,
  0x0448,0x0449,0x044a,0x044b, 0x044c,0x044d,0x044e,0x044f,
  0x2116,0x0451,0x04d1,0x04d3, 0x04d7,0x04ab,0x0456,0x04e7,
  0x04e5,0x04dd,0x04a5,0x04f9, 0x04df,0x00a7,0x04f1,0x04f5
};

unsigned short ir_gl_uni_byte[128] = {
  0x0000,0x0001,0x0002,0x0003, 0x0004,0x0005,0x0006,0x0007,
  0x0008,0x0009,0x000a,0x000b, 0x000c,0x000d,0x000e,0x000f,
  0x0010,0x0011,0x0012,0x0013, 0x0014,0x0015,0x0016,0x0017,
  0x0018,0x0019,0x001a,0x001b, 0x001c,0x001d,0x001e,0x001f,
  0x0020,0x0021,0x0022,0x00a3, 0x0024,0x0025,0x0026,0x0027,
  0x0028,0x0029,0x002a,0x002b, 0x002c,0x002d,0x002e,0x002f,
  0x0030,0x0031,0x0032,0x0033, 0x0034,0x0035,0x0036,0x0037,
  0x0038,0x0039,0x003a,0x003b, 0x003c,0x003d,0x003e,0x003f,

  0x00d3,0x0041,0x0042,0x0043, 0x0044,0x0045,0x0046,0x0047,
  0x0048,0x0049,0x004a,0x004b, 0x004c,0x004d,0x004e,0x004f,
  0x0050,0x0051,0x0052,0x0053, 0x0054,0x0055,0x0056,0x0057,
  0x0058,0x0059,0x005a,0x00c9, 0x00cd,0x00da,0x00c1,0x005f,
  0x00f3,0x0061,0x0062,0x0063, 0x0064,0x0065,0x0066,0x0067,
  0x0068,0x0069,0x006a,0x006b, 0x006c,0x006d,0x006e,0x006f,
  0x0070,0x0071,0x0072,0x0073, 0x0074,0x0075,0x0076,0x0077,
  0x0078,0x0079,0x007a,0x00e9, 0x00ed,0x00fa,0x00e1,0x007f
};

unsigned short iso8859_sp_uni_byte[128] = {
  0x0080,0x0081,0x0082,0x0083, 0x0084,0x0085,0x0086,0x0087,
  0x0088,0x0089,0x008a,0x008b, 0x008c,0x008d,0x008e,0x008f,
  0x0090,0x0091,0x0092,0x0093, 0x0094,0x0095,0x0096,0x0097,
  0x0098,0x0099,0x009a,0x009b, 0x009c,0x009d,0x009e,0x009f,
  0x0000,0x0000,0x0100,0x0108, 0x010a,0x0000,0x0116,0x0112,
  0x011c,0x2018,0x201c,0x2122, 0x2190,0x2191,0x2192,0x2193,
  0x0000,0x0000,0x0101,0x0109, 0x010b,0x00f0,0x0117,0x0113,
  0x011d,0x2019,0x201d,0x266a, 0x215b,0x215c,0x215d,0x215e,

  0x0000,0x011e,0x0120,0x0122, 0x0124,0x0126,0x0128,0x0130,
  0x012a,0x012e,0x0132,0x0134, 0x0136,0x013b,0x013f,0x0145,
  0x2015,0x014a,0x014c,0x0152, 0x0156,0x015c,0x0166,0x00de,
  0x0168,0x016c,0x016a,0x0172, 0x0174,0x00dd,0x0176,0x0178,
  0x03a9,0x011f,0x0121,0x0123, 0x0125,0x0127,0x0129,0x0131,
  0x012b,0x012f,0x0133,0x0135, 0x0137,0x013c,0x0140,0x0146,
  0x0138,0x014b,0x014d,0x0153, 0x0157,0x015d,0x0167,0x00fe,
  0x0169,0x016d,0x016b,0x0173, 0x0175,0x00fd,0x0177,0x0149
};

unsigned short iso6937_a1_uni_byte[128] = {
  0x0080,0x0081,0x0082,0x0083, 0x0084,0x0085,0x0086,0x0087,
  0x0088,0x0089,0x008a,0x008b, 0x008c,0x008d,0x008e,0x008f,
  0x0090,0x0091,0x0092,0x0093, 0x0094,0x0095,0x0096,0x0097,
  0x0098,0x0099,0x009a,0x009b, 0x009c,0x009d,0x009e,0x009f,
  0x00a0,0x00a1,0x00a2,0x00a3, 0x0024,0x00a5,0x0000,0x00a7,
  0x0000,0x2018,0x201c,0x00ab, 0x2190,0x2191,0x2192,0x2193,
  0x00b0,0x00b1,0x00b2,0x00b3, 0x00d7,0x00b5,0x00b6,0x00b7,
  0x00f7,0x2019,0x201d,0x00bb, 0x00bc,0x00bd,0x00be,0x00bf,

  0x0000,0x0300,0x0301,0x0302, 0x0303,0x0304,0x0306,0x0307,
  0x0308,0x0000,0x030a,0x0327, 0x0332,0x030b,0x0328,0x030c,
  0x2015,0x00b9,0x00ae,0x00a9, 0x2122,0x266a,0x00ac,0x00a6,
  0x0000,0x0000,0x0000,0x0000, 0x215b,0x215c,0x215d,0x215e,
  0x03a9,0x00c6,0x0110,0x00aa, 0x0126,0x0000,0x0132,0x013f,
  0x0141,0x00d8,0x0152,0x00ba, 0x00de,0x0166,0x014a,0x0149,
  0x0138,0x00e6,0x0111,0x00f0, 0x0127,0x0131,0x0133,0x0140,
  0x0142,0x00f8,0x0153,0x00df, 0x00fe,0x0167,0x014b,0x00ad
};

unsigned short iso6937_sp_uni_byte[128] = {
  0x0080,0x0081,0x0082,0x0083, 0x0084,0x0085,0x0086,0x0087,
  0x0088,0x0089,0x008a,0x008b, 0x008c,0x008d,0x008e,0x008f,
  0x0090,0x0091,0x0092,0x0093, 0x0094,0x0095,0x0096,0x0097,
  0x0098,0x0099,0x009a,0x009b, 0x009c,0x009d,0x009e,0x009f,
  0x00a0,0x00a1,0x00a2,0x00a3, 0x0000,0x00a5,0x0000,0x00a7,
  0x00a4,0x2018,0x201c,0x00ab, 0x2190,0x2191,0x2192,0x2193,
  0x00b0,0x00b1,0x00b2,0x00b3, 0x00d7,0x00b5,0x00b6,0x00b7,
  0x00f7,0x2019,0x201d,0x00bb, 0x00bc,0x00bd,0x00be,0x00bf,

  0x0000,0x0300,0x0301,0x0302, 0x0303,0x0304,0x0306,0x0307,
  0x0308,0x0000,0x030a,0x0327, 0x0000,0x030b,0x0328,0x030c,
  0x2015,0x00b9,0x00ae,0x00a9, 0x2122,0x266a,0x00ac,0x00a6,
  0x0000,0x0000,0x0000,0x0000, 0x215b,0x215c,0x215d,0x215e,
  0x03a9,0x00c6,0x0110,0x00aa, 0x0126,0x0000,0x0132,0x013f,
  0x0141,0x00d8,0x0152,0x00ba, 0x00de,0x0166,0x014a,0x0149,
  0x0138,0x00e6,0x0111,0x00f0, 0x0127,0x0131,0x0133,0x0140,
  0x0142,0x00f8,0x0153,0x00df, 0x00fe,0x0167,0x014b,0x00ad
};

unsigned short ccitt_mt101_2_uni_byte[128] = {
  0x0000,0x0001,0x0002,0x0003, 0x0004,0x0005,0x0006,0x0007,
  0x0008,0x0009,0x000a,0x000b, 0x000c,0x000d,0x000e,0x000f,
  0x0010,0x0011,0x0012,0x0013, 0x0014,0x0015,0x0016,0x0017,
  0x0018,0x0019,0x001a,0x001b, 0x001c,0x001d,0x001e,0x001f,
  0x0020,0x00a1,0x00a2,0x00a3, 0x0024,0x00a5,0x0023,0x00a7,
  0x00a4,0x2018,0x201c,0x00ab, 0x2190,0x2191,0x2192,0x2193,
  0x00b0,0x00b1,0x00b2,0x00b3, 0x00d7,0x00b5,0x00b6,0x00b7,
  0x00f7,0x2019,0x201d,0x00bb, 0x00bc,0x00bd,0x00be,0x00bf,

  0x20d7,0x0300,0x0301,0x0302, 0x0303,0x0304,0x0306,0x0307,
  0x0308,0x002f,0x030a,0x0327, 0x005f,0x030b,0x0328,0x030c,
  0x2015,0x00b9,0x00ae,0x00a9, 0x2122,0x266a,0x2501,0x2503,
  0x2571,0x2572,0x25e2,0x25e3, 0x215b,0x215c,0x215d,0x215e,
  0x03a9,0x00c6,0x0110,0x00aa, 0x0126,0x254b,0x0132,0x013f,
  0x0141,0x00d8,0x0152,0x00ba, 0x00de,0x0166,0x014a,0x0149,
  0x0138,0x00e6,0x0111,0x00f0, 0x0127,0x0131,0x0133,0x0140,
  0x0142,0x00f8,0x0153,0x00df, 0x00fe,0x0167,0x014b,0x007f
};

unsigned short inis_cyl_uni_byte[128] = {
  0x0000,0x0001,0x0002,0x0003, 0x0004,0x0005,0x0006,0x0007,
  0x0008,0x0009,0x000a,0x000b, 0x000c,0x000d,0x000e,0x000f,
  0x0010,0x0011,0x0012,0x0013, 0x0014,0x0015,0x0016,0x0017,
  0x0018,0x0019,0x001a,0x001b, 0x001c,0x001d,0x001e,0x001f,
  0x0020,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x221a,0x0000,0x2192,0x222b,
  0x03b1,0x03b2,0x03b3,0x03c3, 0x03a3,0x03bc,0x03bd,0x03c9,
  0x03c0,0x039e,0x0394,0x039b, 0x03a9,0x042a,0x207b,0x207a,

  0x044e,0x0430,0x0431,0x0446, 0x0434,0x0435,0x0444,0x0433,
  0x0445,0x0438,0x0439,0x043a, 0x043b,0x043c,0x043d,0x043e,
  0x043f,0x044f,0x0440,0x0441, 0x0442,0x0443,0x0436,0x0432,
  0x044c,0x044b,0x0437,0x0448, 0x044d,0x0449,0x0447,0x044a,

  0x042e,0x0410,0x0411,0x0426, 0x0414,0x0415,0x0424,0x0413,
  0x0425,0x0418,0x0419,0x041a, 0x041b,0x041c,0x041d,0x041e,
  0x041f,0x042f,0x0420,0x0421, 0x0422,0x0423,0x0416,0x0412,
  0x042c,0x042b,0x0417,0x0428, 0x042d,0x0429,0x0427,0x007f
};

unsigned short inis_ns_uni_byte[128] = {
  0x0000,0x0001,0x0002,0x0003, 0x0004,0x0005,0x0006,0x0007,
  0x0008,0x0009,0x000a,0x000b, 0x000c,0x000d,0x000e,0x000f,
  0x0010,0x0011,0x0012,0x0013, 0x0014,0x0015,0x0016,0x0017,
  0x0018,0x0019,0x001a,0x001b, 0x001c,0x001d,0x001e,0x001f,
  0x0020,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x03b1,0x03b2, 0x03b3,0x03c3,0x039e,0x0000,

  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x2192,0x222b,
  0x2070,0x00b9,0x00b2,0x00b3, 0x2074,0x2075,0x2076,0x2077,
  0x2078,0x2079,0x207a,0x207b, 0x221a,0x0394,0x039b,0x03a9,
  0x2080,0x2081,0x2082,0x2083, 0x2084,0x2085,0x2086,0x2087,
  0x2088,0x2089,0x03a3,0x03bc, 0x03bd,0x03c9,0x03c0,0x007f
};

unsigned short t61_1_uni_byte[128] = {
  0x0000,0x0001,0x0002,0x0003, 0x0004,0x0005,0x0006,0x0007,
  0x0008,0x0009,0x000a,0x000b, 0x000c,0x000d,0x000e,0x000f,
  0x0010,0x0011,0x0012,0x0013, 0x0014,0x0015,0x0016,0x0017,
  0x0018,0x0019,0x001a,0x001b, 0x001c,0x001d,0x001e,0x001f,
  0x0020,0x0021,0x0022,0x0023, 0x00a4,0x0025,0x0026,0x0027,
  0x0028,0x0029,0x002a,0x002b, 0x002c,0x002d,0x002e,0x002f,
  0x0030,0x0031,0x0032,0x0033, 0x0034,0x0035,0x0036,0x0037,
  0x0038,0x0039,0x003a,0x003b, 0x003c,0x003d,0x003e,0x003f,

  0x0040,0x0041,0x0042,0x0043, 0x0044,0x0045,0x0046,0x0047,
  0x0048,0x0049,0x004a,0x004b, 0x004c,0x004d,0x004e,0x004f,
  0x0050,0x0051,0x0052,0x0053, 0x0054,0x0055,0x0056,0x0057,
  0x0058,0x0059,0x005a,0x005b, 0x0000,0x005d,0x0000,0x005f,
  0x0000,0x0061,0x0062,0x0063, 0x0064,0x0065,0x0066,0x0067,
  0x0068,0x0069,0x006a,0x006b, 0x006c,0x006d,0x006e,0x006f,
  0x0070,0x0071,0x0072,0x0073, 0x0074,0x0075,0x0076,0x0077,
  0x0078,0x0079,0x007a,0x0000, 0x007c,0x0000,0x0000,0x007f
};

unsigned short t61_2_uni_byte[128] = {
  0x0000,0x0001,0x0002,0x0003, 0x0004,0x0005,0x0006,0x0007,
  0x0008,0x0009,0x000a,0x000b, 0x000c,0x000d,0x000e,0x000f,
  0x0010,0x0011,0x0012,0x0013, 0x0014,0x0015,0x0016,0x0017,
  0x0018,0x0019,0x001a,0x001b, 0x001c,0x001d,0x001e,0x001f,
  0x0020,0x00a1,0x00a2,0x00a3, 0x0024,0x00a5,0x0023,0x00a7,
  0x00a4,0x0000,0x0000,0x00ab, 0x0000,0x0000,0x0000,0x0000,
  0x00b0,0x00b1,0x00b2,0x00b3, 0x00d7,0x00b5,0x00b6,0x00b7,
  0x00f7,0x0000,0x0000,0x00bb, 0x00bc,0x00bd,0x00be,0x00bf,

  0x0000,0x0300,0x0301,0x0302, 0x0303,0x0304,0x0306,0x0307,
  0x0308,0x0000,0x030a,0x0327, 0x0332,0x030b,0x0328,0x030c,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x03a9,0x00c6,0x0110,0x00aa, 0x0126,0x0000,0x0132,0x013f,
  0x0141,0x00d8,0x0152,0x00ba, 0x00de,0x0166,0x014a,0x0149,
  0x0138,0x00e6,0x0111,0x00f0, 0x0127,0x0131,0x0133,0x0140,
  0x0142,0x00f8,0x0153,0x00df, 0x00fe,0x0167,0x014b,0x007f
};

unsigned short sami_sp1_uni_byte[128] = {
  0x0080,0x0081,0x0082,0x0083, 0x0084,0x0085,0x0086,0x0087,
  0x0088,0x0089,0x008a,0x008b, 0x008c,0x008d,0x008e,0x008f,
  0x0090,0x0091,0x0092,0x0093, 0x0094,0x0095,0x0096,0x0097,
  0x0098,0x0099,0x009a,0x009b, 0x009c,0x009d,0x009e,0x009f,
  0x00a0,0x010c,0x010d,0x0110, 0x0111,0x01e4,0x01e5,0x00a7,
  0x01e6,0x00a9,0x01e7,0x00ab, 0x01e8,0x00ad,0x01e9,0x014a,
  0x00b0,0x014b,0x0160,0x0161, 0x00b4,0x0166,0x00b6,0x00b7,
  0x0167,0x017d,0x017e,0x00bb, 0x01b7,0x0292,0x01ee,0x01ef,

  0x00c0,0x00c1,0x00c2,0x00c3, 0x00c4,0x00c5,0x00c6,0x00c7,
  0x00c8,0x00c9,0x00ca,0x00cb, 0x00cc,0x00cd,0x00ce,0x00cf,
  0x00d0,0x00d1,0x00d2,0x00d3, 0x00d4,0x00d5,0x00d6,0x00d7,
  0x00d8,0x00d9,0x00da,0x00db, 0x00dc,0x00dd,0x00de,0x00df,
  0x00e0,0x00e1,0x00e2,0x00e3, 0x00e4,0x00e5,0x00e6,0x00e7,
  0x00e8,0x00e9,0x00ea,0x00eb, 0x00ec,0x00ed,0x00ee,0x00ef,
  0x00f0,0x00f1,0x00f2,0x00f3, 0x00f4,0x00f5,0x00f6,0x00f7,
  0x00f8,0x00f9,0x00fa,0x00fb, 0x00fc,0x00fd,0x00fe,0x00ff
};

unsigned short sami_sp2_uni_byte[128] = {
  0x0080,0x0081,0x0082,0x0083, 0x0084,0x0085,0x0086,0x0087,
  0x0088,0x0089,0x008a,0x008b, 0x008c,0x008d,0x008e,0x008f,
  0x0090,0x0091,0x0092,0x0093, 0x0094,0x0095,0x0096,0x0097,
  0x0098,0x0099,0x009a,0x009b, 0x009c,0x009d,0x009e,0x009f,
  0x00a0,0x010c,0x010d,0x0110, 0x0111,0x01e4,0x01e5,0x00a7,
  0x01e6,0x00a9,0x01e7,0x021e, 0x01e8,0x00ad,0x01e9,0x014a,
  0x00b0,0x014b,0x0160,0x0161, 0x00b4,0x0166,0x00b6,0x00b7,
  0x0167,0x017d,0x017e,0x021f, 0x01b7,0x0292,0x01ee,0x01ef,

  0x00c0,0x00c1,0x00c2,0x00c3, 0x00c4,0x00c5,0x00c6,0x00c7,
  0x00c8,0x00c9,0x00ca,0x00cb, 0x00cc,0x00cd,0x00ce,0x00cf,
  0x00d0,0x00d1,0x00d2,0x00d3, 0x00d4,0x00d5,0x00d6,0x00d7,
  0x00d8,0x00d9,0x00da,0x00db, 0x00dc,0x00dd,0x00de,0x00df,
  0x00e0,0x00e1,0x00e2,0x00e3, 0x00e4,0x00e5,0x00e6,0x00e7,
  0x00e8,0x00e9,0x00ea,0x00eb, 0x00ec,0x00ed,0x00ee,0x00ef,
  0x00f0,0x00f1,0x00f2,0x00f3, 0x00f4,0x00f5,0x00f6,0x00f7,
  0x00f8,0x00f9,0x00fa,0x00fb, 0x00fc,0x00fd,0x00fe,0x00ff
};

unsigned short iso646_sp_i_uni_byte[128] = {
  0x0000,0x0001,0x0002,0x0003, 0x0004,0x0005,0x0006,0x0007,
  0x0008,0x0009,0x000a,0x000b, 0x000c,0x000d,0x000e,0x000f,
  0x0010,0x0011,0x0012,0x0013, 0x0014,0x0015,0x0016,0x0017,
  0x0018,0x0019,0x001a,0x001b, 0x001c,0x001d,0x001e,0x001f,
  0x0020,0x0021,0x0022,0x0023, 0x0024,0x0025,0x0026,0x0027,
  0x0028,0x0029,0x002a,0x002b, 0x002c,0x002d,0x002e,0x002f,
  0x0030,0x0031,0x0032,0x0033, 0x0034,0x0035,0x0036,0x0037,
  0x0038,0x0039,0x003a,0x003b, 0x003c,0x003d,0x003e,0x003f,

  0x00b7,0x0041,0x0042,0x0043, 0x0044,0x0045,0x0046,0x0047,
  0x0048,0x0049,0x004a,0x004b, 0x004c,0x004d,0x004e,0x004f,
  0x0050,0x0051,0x0052,0x0053, 0x0054,0x0055,0x0056,0x0057,
  0x0058,0x0059,0x005a,0x00a1, 0x00d1,0x00c7,0x00bf,0x005f,
  0x0060,0x0061,0x0062,0x0063, 0x0064,0x0065,0x0066,0x0067,
  0x0068,0x0069,0x006a,0x006b, 0x006c,0x006d,0x006e,0x006f,
  0x0070,0x0071,0x0072,0x0073, 0x0074,0x0075,0x0076,0x0077,
  0x0078,0x0079,0x007a,0x00b4, 0x00f1,0x00e7,0x00a8,0x007f
};

unsigned short iso646_po_i_uni_byte[128] = {
  0x0000,0x0001,0x0002,0x0003, 0x0004,0x0005,0x0006,0x0007,
  0x0008,0x0009,0x000a,0x000b, 0x000c,0x000d,0x000e,0x000f,
  0x0010,0x0011,0x0012,0x0013, 0x0014,0x0015,0x0016,0x0017,
  0x0018,0x0019,0x001a,0x001b, 0x001c,0x001d,0x001e,0x001f,
  0x0020,0x0021,0x0022,0x0023, 0x0024,0x0025,0x0026,0x0027,
  0x0028,0x0029,0x002a,0x002b, 0x002c,0x002d,0x002e,0x002f,
  0x0030,0x0031,0x0032,0x0033, 0x0034,0x0035,0x0036,0x0037,
  0x0038,0x0039,0x003a,0x003b, 0x003c,0x003d,0x003e,0x003f,

  0x00b4,0x0041,0x0042,0x0043, 0x0044,0x0045,0x0046,0x0047,
  0x0048,0x0049,0x004a,0x004b, 0x004c,0x004d,0x004e,0x004f,
  0x0050,0x0051,0x0052,0x0053, 0x0054,0x0055,0x0056,0x0057,
  0x0058,0x0059,0x005a,0x00c3, 0x00c7,0x00d5,0x005e,0x005f,
  0x0060,0x0061,0x0062,0x0063, 0x0064,0x0065,0x0066,0x0067,
  0x0068,0x0069,0x006a,0x006b, 0x006c,0x006d,0x006e,0x006f,
  0x0070,0x0071,0x0072,0x0073, 0x0074,0x0075,0x0076,0x0077,
  0x0078,0x0079,0x007a,0x00e3, 0x00e7,0x00f5,0x007e,0x007f
};

unsigned short csa_z243_1_uni_byte[128] = {
  0x0000,0x0001,0x0002,0x0003, 0x0004,0x0005,0x0006,0x0007,
  0x0008,0x0009,0x000a,0x000b, 0x000c,0x000d,0x000e,0x000f,
  0x0010,0x0011,0x0012,0x0013, 0x0014,0x0015,0x0016,0x0017,
  0x0018,0x0019,0x001a,0x001b, 0x001c,0x001d,0x001e,0x001f,
  0x0020,0x0021,0x0022,0x0023, 0x0024,0x0025,0x0026,0x0027,
  0x0028,0x0029,0x002a,0x002b, 0x002c,0x002d,0x002e,0x002f,
  0x0030,0x0031,0x0032,0x0033, 0x0034,0x0035,0x0036,0x0037,
  0x0038,0x0039,0x003a,0x003b, 0x003c,0x003d,0x003e,0x003f,

  0x00e0,0x0041,0x0042,0x0043, 0x0044,0x0045,0x0046,0x0047,
  0x0048,0x0049,0x004a,0x004b, 0x004c,0x004d,0x004e,0x004f,
  0x0050,0x0051,0x0052,0x0053, 0x0054,0x0055,0x0056,0x0057,
  0x0058,0x0059,0x005a,0x00e2, 0x00e7,0x00ea,0x00ee,0x005f,
  0x00d4,0x0061,0x0062,0x0063, 0x0064,0x0065,0x0066,0x0067,
  0x0068,0x0069,0x006a,0x006b, 0x006c,0x006d,0x006e,0x006f,
  0x0070,0x0071,0x0072,0x0073, 0x0074,0x0075,0x0076,0x0077,
  0x0078,0x0079,0x007a,0x00e9, 0x00f9,0x00e8,0x00fb,0x007f
};

unsigned short csa_z243_2_uni_byte[128] = {
  0x0000,0x0001,0x0002,0x0003, 0x0004,0x0005,0x0006,0x0007,
  0x0008,0x0009,0x000a,0x000b, 0x000c,0x000d,0x000e,0x000f,
  0x0010,0x0011,0x0012,0x0013, 0x0014,0x0015,0x0016,0x0017,
  0x0018,0x0019,0x001a,0x001b, 0x001c,0x001d,0x001e,0x001f,
  0x0020,0x0021,0x0022,0x0023, 0x0024,0x0025,0x0026,0x0027,
  0x0028,0x0029,0x002a,0x002b, 0x002c,0x002d,0x002e,0x002f,
  0x0030,0x0031,0x0032,0x0033, 0x0034,0x0035,0x0036,0x0037,
  0x0038,0x0039,0x003a,0x003b, 0x003c,0x003d,0x003e,0x003f,

  0x00e0,0x0041,0x0042,0x0043, 0x0044,0x0045,0x0046,0x0047,
  0x0048,0x0049,0x004a,0x004b, 0x004c,0x004d,0x004e,0x004f,
  0x0050,0x0051,0x0052,0x0053, 0x0054,0x0055,0x0056,0x0057,
  0x0058,0x0059,0x005a,0x00e2, 0x00e7,0x00ea,0x00c9,0x005f,
  0x00d4,0x0061,0x0062,0x0063, 0x0064,0x0065,0x0066,0x0067,
  0x0068,0x0069,0x006a,0x006b, 0x006c,0x006d,0x006e,0x006f,
  0x0070,0x0071,0x0072,0x0073, 0x0074,0x0075,0x0076,0x0077,
  0x0078,0x0079,0x007a,0x00e9, 0x00f9,0x00e8,0x00fb,0x007f
};

unsigned short box_uni_byte[128] = {
  0x0000,0x0001,0x0002,0x0003, 0x0004,0x0005,0x0006,0x0007,
  0x0008,0x0009,0x000a,0x000b, 0x000c,0x000d,0x000e,0x000f,
  0x0010,0x0011,0x0012,0x0013, 0x0014,0x0015,0x0016,0x0017,
  0x0018,0x0019,0x001a,0x001b, 0x001c,0x001d,0x001e,0x001f,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,

  0x2503,0x2501,0x250f,0x2513, 0x2517,0x251b,0x2523,0x252b,
  0x2533,0x253b,0x254b,0x2580, 0x2584,0x2588,0x25a0,0x0000,
  0x2502,0x2500,0x250c,0x2510, 0x2514,0x2518,0x251c,0x2524,
  0x252c,0x2534,0x253c,0x2591, 0x2592,0x2593,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000
};

unsigned short iso646_inis_s_uni_byte[128] = {
  0x0000,0x0001,0x0002,0x0003,0x0004,0x0005,0x0006,0x0007,
  0x0008,0x0009,0x000a,0x000b,0x000c,0x000d,0x000e,0x000f,
  0x0010,0x0011,0x0012,0x0013,0x0014,0x0015,0x0016,0x0017,
  0x0018,0x0019,0x001a,0x001b,0x001c,0x001d,0x001e,0x001f,
  0x0020,0x0000,0x0000,0x0000,0x0024,0x0025,0x0000,0x0027,
  0x0028,0x0029,0x002a,0x002b,0x002c,0x002d,0x002e,0x002f,
  0x0030,0x0031,0x0032,0x0033,0x0034,0x0035,0x0036,0x0037,
  0x0038,0x0039,0x003a,0x003b,0x003c,0x003d,0x003e,0x0000,
  0x0000,0x0041,0x0042,0x0043,0x0044,0x0045,0x0046,0x0047,
  0x0048,0x0049,0x004a,0x004b,0x004c,0x004d,0x004e,0x004f,
  0x0050,0x0051,0x0052,0x0053,0x0054,0x0055,0x0056,0x0057,
  0x0058,0x0059,0x005a,0x005b,0x0000,0x005d,0x0000,0x0000,
  0x0060,0x0061,0x0062,0x0063,0x0064,0x0065,0x0066,0x0067,
  0x0068,0x0069,0x006a,0x006b,0x006c,0x006d,0x006e,0x006f,
  0x0070,0x0071,0x0072,0x0073,0x0074,0x0075,0x0076,0x0077,
  0x0078,0x0079,0x007a,0x0000,0x007c,0x0000,0x0000,0x007f
};

unsigned short ir164_uni_byte[128] = {
  0x0000,0x0001,0x0002,0x0003, 0x0004,0x0005,0x0006,0x0007,
  0x0008,0x0009,0x000a,0x000b, 0x000c,0x000d,0x000e,0x000f,
  0x0010,0x0011,0x0012,0x0013, 0x0014,0x0015,0x0016,0x0017,
  0x0018,0x0019,0x001a,0x001b, 0x001c,0x001d,0x001e,0x001f,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,

  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x05d0,0x05d1,0x05d2,0x05d3, 0x05d4,0x05d5,0x05d6,0x05d7,
  0x05d8,0x05d9,0x05da,0x05db, 0x05dc,0x05dd,0x05de,0x05df,
  0x05e0,0x05e1,0x05e2,0x05e3, 0x05e4,0x05e5,0x05e6,0x05e7,
  0x05e8,0x05e9,0x05ea,0x0000, 0x0000,0x0000,0x0000,0x007f
};

unsigned short si1311_uni_byte[128] = {
  0x0080,0x0081,0x0082,0x0083, 0x0084,0x0085,0x0086,0x0087,
  0x0088,0x0089,0x008a,0x008b, 0x008c,0x008d,0x008e,0x008f,
  0x0090,0x0091,0x0092,0x0093, 0x0094,0x0095,0x0096,0x0097,
  0x0098,0x0099,0x009a,0x009b, 0x009c,0x009d,0x009e,0x009f,
  0x00a0,0x0000,0x00a2,0x00a3, 0x00a4,0x00a5,0x00a6,0x00a7,
  0x00a8,0x00a9,0x00d7,0x00ab, 0x00ac,0x00ad,0x00ae,0x00af,
  0x00b0,0x00b1,0x00b2,0x00b3, 0x00b4,0x00b5,0x00b6,0x00b7,
  0x00b8,0x00b9,0x00f7,0x00bb, 0x00bc,0x00bd,0x00be,0x0000,

  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x20ac,0x20aa,0x202d, 0x202e,0x202c,0x0000,0x2017,
  0x05d0,0x05d1,0x05d2,0x05d3, 0x05d4,0x05d5,0x05d6,0x05d7,
  0x05d8,0x05d9,0x05da,0x05db, 0x05dc,0x05dd,0x05de,0x05df,
  0x05e0,0x05e1,0x05e2,0x05e3, 0x05e4,0x05e5,0x05e6,0x05e7,
  0x05e8,0x05e9,0x05ea,0x202a, 0x202b,0x200e,0x200f,0x0000
};

unsigned short iso6937_sp2_uni_byte[128] = {
  0x0000,0x0001,0x0002,0x0003, 0x0004,0x0005,0x0006,0x0007,
  0x0008,0x0009,0x000a,0x000b, 0x000c,0x000d,0x000e,0x000f,
  0x0010,0x0011,0x0012,0x0013, 0x0014,0x0015,0x0016,0x0017,
  0x0018,0x0019,0x001a,0x001b, 0x001c,0x001d,0x001e,0x001f,
  0x0020,0x00a1,0x00a2,0x00a3, 0x0024,0x00a5,0x0000,0x00a7,
  0x0000,0x2018,0x201c,0x00ab, 0x2190,0x2191,0x2192,0x2193,
  0x00b0,0x00b1,0x00b2,0x00b3, 0x00d7,0x00b5,0x00b6,0x00b7,
  0x00f7,0x2019,0x201d,0x00bb, 0x00bc,0x00bd,0x00be,0x00bf,

  0x0000,0x0300,0x0301,0x0302, 0x0303,0x0304,0x0306,0x0307,
  0x0308,0x0000,0x030a,0x0327, 0x005f,0x030b,0x0328,0x030c,
  0x2015,0x00b9,0x00ae,0x00a9, 0x2122,0x266a,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x215b,0x215c,0x215d,0x215e,
  0x03a9,0x00c6,0x0110,0x00aa, 0x0126,0x0000,0x0132,0x013f,
  0x0141,0x00d8,0x0152,0x00ba, 0x00de,0x0166,0x014a,0x0149,
  0x0138,0x00e6,0x0111,0x00f0, 0x0127,0x0131,0x0133,0x0140,
  0x0142,0x00f8,0x0153,0x00df, 0x00fe,0x0167,0x014b,0x007f
};

unsigned short videotex_sp1_uni_byte[128] = {
  0x0000,0x0001,0x0002,0x0003, 0x0004,0x0005,0x0006,0x0007,
  0x0008,0x0009,0x000a,0x000b, 0x000c,0x000d,0x000e,0x000f,
  0x0010,0x0011,0x0012,0x0013, 0x0014,0x0015,0x0016,0x0017,
  0x0018,0x0019,0x001a,0x001b, 0x001c,0x001d,0x001e,0x001f,
  0x0020,0x00a1,0x00a2,0x00a3, 0x0024,0x00a5,0x0023,0x00a7,
  0x00a4,0x2018,0x201c,0x00ab, 0x2190,0x2191,0x2192,0x2193,
  0x00b0,0x00b1,0x00b2,0x00b3, 0x00d7,0x00b5,0x00b6,0x00b7,
  0x00f7,0x2019,0x201d,0x00bb, 0x00bc,0x00bd,0x00be,0x00bf,

  0x0344,0x0300,0x0301,0x0302, 0x0303,0x0304,0x0306,0x0307,
  0x0308,0x0000,0x030a,0x0327, 0x0000,0x030b,0x0328,0x030c,
  0x2015,0x00b9,0x00ae,0x00a9, 0x2122,0x266a,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x215b,0x215c,0x215d,0x215e,
  0x03a9,0x00c6,0x0110,0x00aa, 0x0126,0x0000,0x0132,0x013f,
  0x0141,0x00d8,0x0152,0x00ba, 0x00de,0x0166,0x014a,0x0149,
  0x0138,0x00e6,0x0111,0x00f0, 0x0127,0x0131,0x0133,0x0140,
  0x0142,0x00f8,0x0153,0x00df, 0x00fe,0x0167,0x014b,0x007f
};

unsigned short ccitt_gr_uni_byte[128] = {
  0x0000,0x0001,0x0002,0x0003, 0x0004,0x0005,0x0006,0x0007,
  0x0008,0x0009,0x000a,0x000b, 0x000c,0x000d,0x000e,0x000f,
  0x0010,0x0011,0x0012,0x0013, 0x0014,0x0015,0x0016,0x0017,
  0x0018,0x0019,0x001a,0x001b, 0x001c,0x001d,0x001e,0x001f,
  0x0020,0x0021,0x0022,0x0023, 0x00a4,0x0025,0x0026,0x0027,
  0x0028,0x0029,0x002a,0x002b, 0x002c,0x002d,0x002e,0x002f,
  0x0030,0x0031,0x0032,0x0033, 0x0034,0x0035,0x0036,0x0037,
  0x0038,0x0039,0x003a,0x003b, 0x003c,0x003d,0x003e,0x003f,

  0x0040,0x0391,0x0392,0x0393, 0x0394,0x0395,0x0396,0x0397,
  0x0398,0x0399,0x039a,0x039b, 0x039c,0x039d,0x039e,0x039f,
  0x03a0,0x03a1,0x0000,0x03a3, 0x03a4,0x03a5,0x03a6,0x03a7,
  0x03a8,0x03a9,0x0000,0x005b, 0x005c,0x005d,0x005e,0x005f,
  0x0000,0x03b1,0x03b2,0x03b3, 0x03b4,0x03b5,0x03b6,0x03b7,
  0x03b8,0x03b9,0x03ba,0x03bb, 0x03bc,0x03bd,0x03be,0x03bf,
  0x03c0,0x03c1,0x03c2,0x03c3, 0x03c4,0x03c5,0x03c6,0x03c7,
  0x03c8,0x03c9,0x0000,0x007b, 0x007c,0x007d,0x007e,0x007f
};

unsigned short ansel_uni_byte[128] = {
  0x0000,0x0001,0x0002,0x0003, 0x0004,0x0005,0x0006,0x0007,
  0x0008,0x0009,0x000a,0x000b, 0x000c,0x000d,0x000e,0x000f,
  0x0010,0x0011,0x0012,0x0013, 0x0014,0x0015,0x0016,0x0017,
  0x0018,0x0019,0x001a,0x001b, 0x001c,0x001d,0x001e,0x001f,
  0x0020,0x0141,0x00d8,0x0110, 0x00de,0x00c6,0x0152,0x02b9,
  0x00b7,0x266d,0x00ae,0x00b1, 0x01a0,0x01af,0x02be,0x0000,
  0x02bf,0x0142,0x00f8,0x0111, 0x00fe,0x00e6,0x0153,0x02ba,
  0x0131,0x00a3,0x00f0,0x0000, 0x01a1,0x01b0,0x0000,0x0000,

  0x00b0,0x2113,0x2117,0x00a9, 0x266f,0x00bf,0x00a1,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0309,0x0300,0x0301,0x0302, 0x0303,0x0304,0x0306,0x0307,
  0x0308,0x030c,0x030a,0x0361, 0x0361,0x0315,0x030b,0x0310,
  0x0327,0x0322,0x0323,0x0324, 0x0325,0x0333,0x0332,0x0321,
  0x0328,0x032e,0x0360,0x0360, 0x0000,0x0000,0x0313,0x007f
};

unsigned short codar_u_uni_byte[128] = {
  0x0000,0x0001,0x0002,0x0003, 0x0004,0x0005,0x0006,0x0007,
  0x0008,0x0009,0x000a,0x000b, 0x000c,0x000d,0x000e,0x000f,
  0x0010,0x0011,0x0012,0x0013, 0x0014,0x0015,0x0016,0x0017,
  0x0018,0x0019,0x001a,0x001b, 0x001c,0x001d,0x001e,0x001f,
  0x0020,0x0021,0x0022,0x0023, 0x00a4,0x0025,0x0026,0x0027,
  0x0028,0x0029,0x002a,0x002b, 0x002c,0x002d,0x002e,0x002f,
  0x0030,0x0031,0x0032,0x0033, 0x0034,0x0035,0x0036,0x0037,
  0x0038,0x0039,0x003a,0x061b, 0x003c,0x003d,0x003e,0x00bf,

  0x0040,0xfcf2,0xfc60,0xfcf3, 0xfc61,0xfcf4,0xfc62,0xfe77,
  0xfe76,0xfe70,0xfe79,0xfe78, 0xfe72,0xfe7b,0xfe7a,0xfe74,
  0xfe7f,0xfe7e,0xfe7d,0xfe7c, 0xfe83,0xfe81,0xfe85,0xfe89,
  0xfe8b,0xfe87,0xfef2,0xfb58, 0xfb6c,0xfb92,0xfe80,0xfe8d,
  0xfe91,0xfe97,0xfe93,0xfe9b, 0xfe9f,0xfea3,0xfea7,0xfea9,
  0xfeab,0xfead,0xfeaf,0xfeb3, 0xfeb7,0xfebb,0xfebf,0xfec1,
  0xfec5,0xfecb,0xfecf,0xfed3, 0xfed7,0xfedb,0xfedf,0xfee3,
  0xfee7,0xfeeb,0xfeed,0xfef3, 0x007c,0xfeef,0x00ac,0x007f
};

unsigned short iso5428_1_uni_byte[128] = {
  0x0000,0x0001,0x0002,0x0003, 0x0004,0x0005,0x0006,0x0007,
  0x0008,0x0009,0x000a,0x000b, 0x000c,0x000d,0x000e,0x000f,
  0x0010,0x0011,0x0012,0x0013, 0x0014,0x0015,0x0016,0x0017,
  0x0018,0x0019,0x001a,0x001b, 0x001c,0x001d,0x001e,0x001f,
  0x0020,0x0300,0x0301,0x0308, 0x0303,0x0313,0x0312,0x0370,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x00ab,0x00bb,0x201f,0x201e, 0x0374,0x0375,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0387, 0x0000,0x0000,0x0000,0x037e,

  0x0000,0x0391,0x0392,0x0000, 0x0393,0x0394,0x0395,0x03da,
  0x03dc,0x0396,0x0397,0x0398, 0x0399,0x039a,0x039b,0x039c,
  0x039d,0x039e,0x039f,0x03a0, 0x03de,0x03a1,0x03a3,0x0000,
  0x03a4,0x03a5,0x03a6,0x03a7, 0x03a8,0x03a9,0x03e0,0x0000, 
  0x0000,0x03b1,0x03b2,0x03d0, 0x03b3,0x03b4,0x03b5,0x03db,
  0x03dd,0x03b6,0x03b7,0x03b8, 0x03b9,0x03ba,0x03bb,0x03bc,
  0x03bd,0x03be,0x03bf,0x03c0, 0x03df,0x03c1,0x03c3,0x03c2,
  0x03c4,0x03c5,0x03c6,0x03c7, 0x03c8,0x03c9,0x03e1,0x007f 
};

unsigned short iso5427_s_uni_byte[128] = {
  0x0000,0x0001,0x0002,0x0003, 0x0004,0x0005,0x0006,0x0007,
  0x0008,0x0009,0x000a,0x000b, 0x000c,0x000d,0x000e,0x000f,
  0x0010,0x0011,0x0012,0x0013, 0x0014,0x0015,0x0016,0x0017,
  0x0018,0x0019,0x001a,0x001b, 0x001c,0x001d,0x001e,0x001f,
  0x0020,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,

  0x0491,0x0452,0x0453,0x0454, 0x0451,0x0455,0x0456,0x0457,
  0x0458,0x0459,0x045a,0x045b, 0x045c,0x045e,0x045f,0x0000,
  0x0463,0x0473,0x0475,0x046b, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x005b, 0x0000,0x005c,0x0000,0x005f,
  0x0490,0x0402,0x0403,0x0404, 0x0401,0x0405,0x0406,0x0407,
  0x0408,0x0409,0x040a,0x040b, 0x040c,0x040e,0x040f,0x0000,
  0x0462,0x0472,0x0474,0x046a, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x007f
};

unsigned short apl_uni_byte[128] = {
  0x0000,0x0001,0x0002,0x0003, 0x0004,0x0005,0x0006,0x0007,
  0x0008,0x0009,0x000a,0x000b, 0x000c,0x000d,0x000e,0x000f,
  0x0010,0x0011,0x0012,0x0013, 0x0014,0x0015,0x0016,0x0017,
  0x0018,0x0019,0x001a,0x001b, 0x001c,0x001d,0x001e,0x001f,
  0x0020,0x00a8,0x0029,0x003c, 0x2264,0x003d,0x003e,0x005d,
  0x2228,0x2227,0x2260,0x00f7, 0x002c,0x002b,0x002e,0x002f,
  0x0030,0x0031,0x0032,0x0033, 0x0034,0x0035,0x0036,0x0037,
  0x0038,0x0039,0x0028,0x005b, 0x003b,0x00d7,0x003a,0x005c,

  0x203e,0x03b1,0x22a5,0x00af, 0x230a,0x2208,0x005f,0x0394,
  0x2207,0x03b9,0x2218,0x0027, 0x2396,0x007c,0x22a4,0x25cb,
  0x002a,0x003f,0x03c1,0x2308, 0x223c,0x2193,0x222a,0x03c9,
  0x2283,0x2191,0x2282,0x2190, 0x22a2,0x2192,0x2265,0x002d,
  0x22c4,0x0041,0x0042,0x0043, 0x0044,0x0045,0x0046,0x0047,
  0x0048,0x0049,0x004a,0x004b, 0x004c,0x004d,0x004e,0x004f,
  0x0050,0x0051,0x0052,0x0053, 0x0054,0x0055,0x0056,0x0057,
  0x0058,0x0059,0x005a,0x007b, 0x22a3,0x007d,0x0024,0x007f
};

unsigned short tech_uni_byte[128] = {
  0x0080,0x0081,0x0082,0x0083, 0x0084,0x0085,0x0086,0x0087,
  0x0088,0x0089,0x008a,0x008b, 0x008c,0x008d,0x008e,0x008f,
  0x0090,0x0091,0x0092,0x0093, 0x0094,0x0095,0x0096,0x0097,
  0x0098,0x0099,0x009a,0x009b, 0x009c,0x009d,0x009e,0x009f,
  0x030c,0x2261,0x2227,0x2228, 0x2229,0x222a,0x2282,0x2283,
  0x21d0,0x21d2,0x2234,0x2235, 0x2208,0x220b,0x2286,0x2287,
  0x222b,0x222e,0x221e,0x2207, 0x2202,0x223c,0x2248,0x2243,
  0x2245,0x2264,0x2260,0x2265, 0x21d4,0x00ac,0x2200,0x2203,

  0x05d0,0x2395,0x2225,0x0393, 0x0394,0x22a5,0x2221,0x221f,
  0x0398,0x2329,0x232a,0x039b, 0x2032,0x2033,0x039e,0x2213,
  0x03a0,0x00b2,0x03a3,0x00d7, 0x00b3,0x03a5,0x03a6,0x00b7,
  0x03a8,0x03a9,0x2205,0x20d7, 0x221a,0x0192,0x221d,0x00b1,
  0x00b0,0x03b1,0x03b2,0x03b3, 0x03b4,0x03b5,0x03b6,0x03b7,
  0x03b8,0x03b9,0x03ba,0x03bb, 0x03bc,0x03bd,0x03be,0x2030,
  0x03c0,0x03c1,0x03c3,0x00f7, 0x03c4,0x03c5,0x03d5,0x03c7,
  0x03c8,0x03c9,0x2020,0x2190, 0x2191,0x2192,0x2193,0x00af
};

unsigned short iec1289_uni_byte[128] = {
  0x0080,0x0081,0x0082,0x0083, 0x0084,0x0085,0x0086,0x0087,
  0x0088,0x0089,0x008a,0x008b, 0x008c,0x008d,0x008e,0x008f,
  0x0090,0x0091,0x0092,0x0093, 0x0094,0x0095,0x0096,0x0097,
  0x0098,0x0099,0x009a,0x009b, 0x009c,0x009d,0x009e,0x009f,
  0x00a0,0x2510,0x238d,0x238e, 0x25c7,0x238f,0x2390,0x2391,
  0x2392,0x00a9,0x2264,0x226a, 0x00ac,0x00ad,0x00ae,0x0000,
  0x00b0,0x00b1,0x00f7,0x221e, 0x222b,0x22ef,0x2260,0x00b7,
  0x2248,0x2261,0x2265,0x226b, 0x2122,0x2104,0x2015,0x2393,

  0x2030,0x2190,0x0000,0x0393, 0x0394,0x22b2,0x2207,0x22b3,
  0x0398,0x2229,0x2394,0x039b, 0x0000,0x0000,0x039e,0x0000,
  0x03a0,0x2192,0x0000,0x03a3, 0x0000,0x03a5,0x03a6,0x00d7,
  0x03a8,0x03a9,0x25a1,0x2300, 0x2220,0x223f,0x2248,0x224b,
  0x0000,0x03b1,0x03b2,0x03b3, 0x03b4,0x03b5,0x03b6,0x03b7,
  0x03b8,0x03b9,0x03ba,0x03bb, 0x03bc,0x03bd,0x03be,0x0000,
  0x03c0,0x03c1,0x0000,0x03c3, 0x03c4,0x03c5,0x03c6,0x03c7,
  0x03c8,0x03c9,0x03d1,0x03d5, 0x025b,0x0000,0x0000,0x0000
};

/* ************************ */
/* DOS and Windows codepage */
/* ************************ */
unsigned short cp737_uni_byte[128] = {
  0x0391,0x0392,0x0393,0x0394, 0x0395,0x0396,0x0397,0x0398,
  0x0399,0x039a,0x039b,0x039c, 0x039d,0x039e,0x039f,0x03a0,
  0x03a1,0x03a3,0x03a4,0x03a5, 0x03a6,0x03a7,0x03a8,0x03a9,
  0x03b1,0x03b2,0x03b3,0x03b4, 0x03b5,0x03b6,0x03b7,0x03b8,
  0x03b9,0x03ba,0x03bb,0x03bc, 0x03bd,0x03be,0x03bf,0x03c0,
  0x03c1,0x03c3,0x03c2,0x03c4, 0x03c5,0x03c6,0x03c7,0x03c8,
  0x2591,0x2592,0x2593,0x2502, 0x2524,0x2561,0x2562,0x2556,
  0x2555,0x2563,0x2551,0x2557, 0x255d,0x255c,0x255b,0x2510,

  0x2514,0x2534,0x252c,0x251c, 0x2500,0x253c,0x255e,0x255f,
  0x255a,0x2554,0x2569,0x2566, 0x2560,0x2550,0x256c,0x2567,
  0x2568,0x2564,0x2565,0x2559, 0x2558,0x2552,0x2553,0x256b,
  0x256a,0x2518,0x250c,0x2588, 0x2584,0x258c,0x2590,0x2580,
  0x03c9,0x03ac,0x03ad,0x03ae, 0x03ca,0x03af,0x03cc,0x03cd,
  0x03cb,0x03ce,0x0386,0x0388, 0x0389,0x038a,0x038c,0x038e,
  0x038f,0x00b1,0x2265,0x2264, 0x03aa,0x03ab,0x00f7,0x2248,
  0x00b0,0x2219,0x00b7,0x221a, 0x207f,0x00b2,0x25a0,0x00a0
};

unsigned short cp775_uni_byte[128] = {
  0x0106,0x00fc,0x00e9,0x0101, 0x00e4,0x0123,0x00e5,0x0107,
  0x0142,0x0113,0x0156,0x0157, 0x012b,0x0179,0x00c4,0x00c5,
  0x00c9,0x00e6,0x00c6,0x014d, 0x00f6,0x0122,0x00a2,0x015a,
  0x015b,0x00d6,0x00dc,0x00f8, 0x00a3,0x00d8,0x00d7,0x00a4,
  0x0100,0x012a,0x00f3,0x017b, 0x017c,0x017a,0x201d,0x00a6,
  0x00a9,0x00ae,0x00ac,0x00bd, 0x00bc,0x0141,0x00ab,0x00bb,
  0x2591,0x2592,0x2593,0x2502, 0x2524,0x0104,0x010c,0x0118,
  0x0116,0x2563,0x2551,0x2557, 0x255d,0x012e,0x0160,0x2510,
  
  0x2514,0x2534,0x252c,0x251c, 0x2500,0x253c,0x0172,0x016a,
  0x255a,0x2554,0x2569,0x2566, 0x2560,0x2550,0x256c,0x017d,
  0x0105,0x010d,0x0119,0x0117, 0x012f,0x0161,0x0173,0x016b,
  0x017e,0x2518,0x250c,0x2588, 0x2584,0x258c,0x2590,0x2580,
  0x00d3,0x00df,0x014c,0x0143, 0x00f5,0x00d5,0x00b5,0x0144,
  0x0136,0x0137,0x013b,0x013c, 0x0146,0x0112,0x0145,0x2019,
  0x00ad,0x00b1,0x201c,0x00be, 0x00b6,0x00a7,0x00f7,0x201e,
  0x00b0,0x2219,0x00b7,0x00b9, 0x00b3,0x00b2,0x25a0,0x00a0
};

unsigned short cp1250_uni_byte[128] = {
  0x20ac,0x0000,0x201a,0x0000, 0x201e,0x2026,0x2020,0x2021,
  0x0000,0x2030,0x0160,0x2039, 0x015a,0x0164,0x017d,0x0179,
  0x0000,0x2018,0x2019,0x201c, 0x201d,0x2022,0x2013,0x2014,
  0x0000,0x2122,0x0161,0x203a, 0x015b,0x0165,0x017e,0x017a,
  0x00a0,0x02c7,0x02d8,0x0141, 0x00a4,0x0104,0x00a6,0x00a7,
  0x00a8,0x00a9,0x015e,0x00ab, 0x00ac,0x00ad,0x00ae,0x017b,
  0x00b0,0x00b1,0x02db,0x0142, 0x00b4,0x00b5,0x00b6,0x00b7,
  0x00b8,0x0105,0x015f,0x00bb, 0x013d,0x02dd,0x013e,0x017c,
  
  0x0154,0x00c1,0x00c2,0x0102, 0x00c4,0x0139,0x0106,0x00c7,
  0x010c,0x00c9,0x0118,0x00cb, 0x011a,0x00cd,0x00ce,0x010e,
  0x0110,0x0143,0x0147,0x00d3, 0x00d4,0x0150,0x00d6,0x00d7,
  0x0158,0x016e,0x00da,0x0170, 0x00dc,0x00dd,0x0162,0x00df,
  0x0155,0x00e1,0x00e2,0x0103, 0x00e4,0x013a,0x0107,0x00e7,
  0x010d,0x00e9,0x0119,0x00eb, 0x011b,0x00ed,0x00ee,0x010f,
  0x0111,0x0144,0x0148,0x00f3, 0x00f4,0x0151,0x00f6,0x00f7,
  0x0159,0x016f,0x00fa,0x0171, 0x00fc,0x00fd,0x0163,0x02d9
};

unsigned short cp850_uni_byte[128] = {
  0x00c7,0x00fc,0x00e9,0x00e2, 0x00e4,0x00e0,0x00e5,0x00e7,
  0x00ea,0x00eb,0x00e8,0x00ef, 0x00ee,0x00ec,0x00c4,0x00c5,
  0x00c9,0x00e6,0x00c6,0x00f4, 0x00f6,0x00f2,0x00fb,0x00f9,
  0x00ff,0x00d6,0x00dc,0x00f8, 0x00a3,0x00d8,0x00d7,0x0192,
  0x00e1,0x00ed,0x00f3,0x00fa, 0x00f1,0x00d1,0x00aa,0x00ba,
  0x00bf,0x00ae,0x00ac,0x00bd, 0x00bc,0x00a1,0x00ab,0x00bb,
  0x2591,0x2592,0x2593,0x2502, 0x2524,0x00c1,0x00c2,0x00c0,
  0x00a9,0x2563,0x2551,0x2557, 0x255d,0x00a2,0x00a5,0x2510,
  
  0x2514,0x2534,0x252c,0x251c, 0x2500,0x253c,0x00e3,0x00c3,
  0x255a,0x2554,0x2569,0x2566, 0x2560,0x2550,0x256c,0x00a4,
  0x00f0,0x00d0,0x00ca,0x00cb, 0x00c8,0x0131,0x00cd,0x00ce,
  0x00cf,0x2518,0x250c,0x2588, 0x2584,0x00a6,0x00cc,0x2580,
  0x00d3,0x00df,0x00d4,0x00d2, 0x00f5,0x00d5,0x00b5,0x00fe,
  0x00de,0x00da,0x00db,0x00d9, 0x00fd,0x00dd,0x00af,0x00b4,
  0x00ad,0x00b1,0x2017,0x00be, 0x00b6,0x00a7,0x00f7,0x00b8,
  0x00b0,0x00a8,0x00b7,0x00b9, 0x00b3,0x00b2,0x25a0,0x00a0
};

unsigned short cp851_uni_byte[128] = {
  0x00c7,0x00fc,0x00e9,0x00e2, 0x00e4,0x016f,0x0107,0x00e7,
  0x0142,0x00eb,0x0150,0x0151, 0x00ee,0x0179,0x00c4,0x0106,
  0x00c9,0x0139,0x013a,0x00f4, 0x00f6,0x013d,0x013e,0x015a,
  0x015b,0x00d6,0x00dc,0x0164, 0x0165,0x0141,0x00d7,0x010d,
  0x00e1,0x00ed,0x00f3,0x00fa, 0x0104,0x0105,0x017d,0x017e,
  0x0118,0x0119,0x0000,0x017a, 0x010c,0x015f,0x00ab,0x00bb,
  0x2591,0x2592,0x2593,0x2502, 0x2524,0x00c1,0x00c2,0x011a,
  0x015e,0x2563,0x2551,0x2557, 0x255d,0x017b,0x017c,0x2510,
  
  0x2514,0x2534,0x252c,0x251c, 0x2500,0x253c,0x0102,0x0103,
  0x255a,0x2554,0x2569,0x2566, 0x2560,0x2550,0x256c,0x00a4,
  0x0111,0x0110,0x010e,0x00cb, 0x010f,0x0147,0x00cd,0x00ce,
  0x011b,0x2518,0x250c,0x2588, 0x2584,0x0162,0x016e,0x2580,
  0x00d3,0x00df,0x00d4,0x0143, 0x0144,0x0148,0x0160,0x0161,
  0x0154,0x00da,0x0155,0x0170, 0x00fd,0x00dd,0x0163,0x00b4,
  0x00ad,0x02dd,0x02db,0x02c7, 0x02d8,0x00a7,0x00f7,0x00b8,
  0x00b0,0x00a8,0x02d9,0x0171, 0x0158,0x0159,0x25a0,0x00a0
};

unsigned short cp852_uni_byte[128] = {
  0x00c7,0x00fc,0x00e9,0x00e2, 0x00e4,0x016f,0x0107,0x00e7,
  0x0142,0x00eb,0x0150,0x0151, 0x00ee,0x0179,0x00c4,0x0106,
  0x00c9,0x0139,0x013a,0x00f4, 0x00f6,0x013d,0x013e,0x015a,
  0x015b,0x00d6,0x00dc,0x0164, 0x0165,0x0141,0x00d7,0x010d,
  0x00e1,0x00ed,0x00f3,0x00fa, 0x0104,0x0105,0x017d,0x017e,
  0x0118,0x0119,0x00ac,0x017a, 0x010c,0x015f,0x00ab,0x00bb,
  0x2591,0x2592,0x2593,0x2502, 0x2524,0x00c1,0x00c2,0x011a,
  0x015e,0x2563,0x2551,0x2557, 0x255d,0x017b,0x017c,0x2510,

  0x2514,0x2534,0x252c,0x251c, 0x2500,0x253c,0x0102,0x0103,
  0x255a,0x2554,0x2569,0x2566, 0x2560,0x2550,0x256c,0x00a4,
  0x0111,0x0110,0x010e,0x00cb, 0x010f,0x0147,0x00cd,0x00ce,
  0x011b,0x2518,0x250c,0x2588, 0x2584,0x0162,0x016e,0x2580,
  0x00d3,0x00df,0x00d4,0x0143, 0x0144,0x0148,0x0160,0x0161,
  0x0154,0x00da,0x0155,0x0170, 0x00fd,0x00dd,0x0163,0x00b4,
  0x00ad,0x02dd,0x02db,0x02c7, 0x02d8,0x00a7,0x00f7,0x00b8,
  0x00b0,0x00a8,0x02d9,0x0171, 0x0158,0x0159,0x25a0,0x00a0
};
  
unsigned short cp855_uni_byte[128] = {
  0x0452,0x0402,0x0453,0x0403, 0x0451,0x0401,0x0454,0x0404,
  0x0455,0x0405,0x0456,0x0406, 0x0457,0x0407,0x0458,0x0408,
  0x0459,0x0409,0x045a,0x040a, 0x045b,0x040b,0x045c,0x040c,
  0x045e,0x040e,0x045f,0x040f, 0x044e,0x042e,0x044a,0x042a,
  0x0430,0x0410,0x0431,0x0411, 0x0446,0x0426,0x0434,0x0414,
  0x0435,0x0415,0x0444,0x0424, 0x0433,0x0413,0x00ab,0x00bb,
  0x2591,0x2592,0x2593,0x2502, 0x2524,0x0445,0x0425,0x0438,
  0x0418,0x2563,0x2551,0x2557, 0x255d,0x0439,0x0419,0x2510,

  0x2514,0x2534,0x252c,0x251c, 0x2500,0x253c,0x043a,0x041a,
  0x255a,0x2554,0x2569,0x2566, 0x2560,0x2550,0x256c,0x00a4,
  0x043b,0x041b,0x043c,0x041c, 0x043d,0x041d,0x043e,0x041e,
  0x043f,0x2518,0x250c,0x2588, 0x2584,0x041f,0x044f,0x2580,
  0x042f,0x0440,0x0420,0x0441, 0x0421,0x0442,0x0422,0x0443,
  0x0423,0x0436,0x0416,0x0432, 0x0412,0x044c,0x042c,0x2116,
  0x00ad,0x044b,0x042b,0x0437, 0x0417,0x0448,0x0428,0x044d,
  0x042d,0x0449,0x0429,0x0447, 0x0427,0x00a7,0x25a0,0x00a0
};
  
unsigned short cp857_uni_byte[128] = {
  0x00c7,0x00fc,0x00e9,0x00e2, 0x00e4,0x00e0,0x00e5,0x00e7,
  0x00ea,0x00eb,0x00e8,0x00ef, 0x00ee,0x0131,0x00c4,0x00c5,
  0x00c9,0x00e6,0x00c6,0x00f4, 0x00f6,0x00f2,0x00fb,0x00f9,
  0x0130,0x00d6,0x00dc,0x00f8, 0x00a3,0x00d8,0x015e,0x015f,
  0x00e1,0x00ed,0x00f3,0x00fa, 0x00f1,0x00d1,0x011e,0x011f,
  0x00bf,0x00ae,0x00ac,0x00bd, 0x00bc,0x00a1,0x00ab,0x00bb,
  0x2591,0x2592,0x2593,0x2502, 0x2524,0x00c1,0x00c2,0x00c0,
  0x00a9,0x2563,0x2551,0x2557, 0x255d,0x00a2,0x00a5,0x2510,

  0x2514,0x2534,0x252c,0x251c, 0x2500,0x253c,0x00e3,0x00c3,
  0x255a,0x2554,0x2569,0x2566, 0x2560,0x2550,0x256c,0x00a4,
  0x00ba,0x00aa,0x00ca,0x00cb, 0x00c8,0x0000,0x00cd,0x00ce,
  0x00cf,0x2518,0x250c,0x2588, 0x2584,0x00a6,0x00cc,0x2580,
  0x00d3,0x00df,0x00d4,0x00d2, 0x00f5,0x00d5,0x00b5,0x0000,
  0x00d7,0x00da,0x00db,0x00d9, 0x00ec,0x00ff,0x00af,0x00b4,
  0x00ad,0x00b1,0x0000,0x00be, 0x00b6,0x00a7,0x00f7,0x00b8,
  0x00b0,0x00a8,0x00b7,0x00b9, 0x00b3,0x00b2,0x25a0,0x00a0
  };
  
/* Note that cp960 differs DEL location from ascii, code
   conversion don't care because input stream doesn't
   be supposed to include these characters
*/
unsigned short cp860_uni_byte[128] = { /* right */
  0x00c7,0x00fc,0x00e9,0x00e2,0x00e3,0x00e0,0x00c1,0x00e7,
  0x00ea,0x00ca,0x00e8,0x00cd,0x00d4,0x00ec,0x00c3,0x00c2,
  0x00c9,0x00c0,0x00c8,0x00f4,0x00f5,0x00f2,0x00da,0x00f9,
  0x00cc,0x00d5,0x00dc,0x00a2,0x00a3,0x00d9,0x20a7,0x00d3,
  0x00e1,0x00ed,0x00f3,0x00fa,0x00f1,0x00d1,0x00aa,0x00ba,
  0x00bf,0x00d2,0x00bc,0x00bd,0x00bc,0x00a1,0x00ab,0x00bb,
  0x2591,0x2592,0x2593,0x2502,0x2524,0x2561,0x2562,0x2556,
  0x2555,0x2563,0x2551,0x2557,0x255d,0x255c,0x255b,0x2510,

  0x2514,0x2534,0x252c,0x251c,0x2500,0x253c,0x255e,0x255f,
  0x255a,0x2554,0x2569,0x2566,0x2560,0x2550,0x256c,0x2567,
  0x2568,0x2564,0x2565,0x2559,0x2558,0x2552,0x2553,0x256b,
  0x256a,0x2518,0x250c,0x2588,0x2584,0x258c,0x2590,0x2580,
  0x03b1,0x00df,0x0393,0x03c0,0x03a3,0x03c3,0x03bc,0x03c4,
  0x03a6,0x0398,0x03a9,0x03b4,0x221e,0x03c6,0x03b5,0x2229,
  0x2261,0x00b1,0x2265,0x2264,0x2320,0x2321,0x00f7,0x2248,
  0x00b0,0x2219,0x00b7,0x221a,0x207f,0x00b2,0x25a0,0x00a0
};

unsigned short cp861_uni_byte[128] = {
  0x00c7,0x00fc,0x00e9,0x00e2, 0x00e4,0x00e0,0x00e5,0x00e7,
  0x00ea,0x00eb,0x00e8,0x00d0, 0x00f0,0x00de,0x00c4,0x00c5,
  0x00c9,0x00e6,0x00c6,0x00f4, 0x00f6,0x00fe,0x00fb,0x00dd,
  0x00fd,0x00d6,0x00dc,0x00f8, 0x00a3,0x00d8,0x20a7,0x0192,
  0x00e1,0x00ed,0x00f3,0x00fa, 0x00c1,0x00cd,0x00d3,0x00da,
  0x00bf,0x2310,0x00ac,0x00bd, 0x00bc,0x00a1,0x00ab,0x00bb,
  0x2591,0x2592,0x2593,0x2502, 0x2524,0x2561,0x2562,0x2556,
  0x2555,0x2563,0x2551,0x2557, 0x255d,0x255c,0x255b,0x2510,

  0x2514,0x2534,0x252c,0x251c, 0x2500,0x253c,0x255e,0x255f,
  0x255a,0x2554,0x2569,0x2566, 0x2560,0x2550,0x256c,0x2567,
  0x2568,0x2564,0x2565,0x2559, 0x2558,0x2552,0x2553,0x256b,
  0x256a,0x2518,0x250c,0x2588, 0x2584,0x258c,0x2590,0x2580,
  0x03b1,0x00df,0x0393,0x03c0, 0x03a3,0x03c3,0x00b5,0x03c4,
  0x03a6,0x0398,0x03a9,0x03b4, 0x221e,0x03c6,0x03b5,0x2229,
  0x2261,0x00b1,0x2265,0x2264, 0x2320,0x2321,0x00f7,0x2248,
  0x00b0,0x2219,0x00b7,0x221a, 0x207f,0x00b2,0x25a0,0x00a0
};
  
unsigned short cp862_uni_byte[128] = {
  0x05d0,0x05d1,0x05d2,0x05d3, 0x05d4,0x05d5,0x05d6,0x05d7,
  0x05d8,0x05d9,0x05da,0x05db, 0x05dc,0x05dd,0x05de,0x05df,
  0x05e0,0x05e1,0x05e2,0x05e3, 0x05e4,0x05e5,0x05e6,0x05e7,
  0x05e8,0x05e9,0x05ea,0x00a2, 0x00a3,0x00a5,0x20a7,0x0192,
  0x00e1,0x00ed,0x00f3,0x00fa, 0x00f1,0x00d1,0x00aa,0x00ba,
  0x00bf,0x2310,0x00ac,0x00bd, 0x00bc,0x00a1,0x00ab,0x00bb,
  0x2591,0x2592,0x2593,0x2502, 0x2524,0x2561,0x2562,0x2556,
  0x2555,0x2563,0x2551,0x2557, 0x255d,0x255c,0x255b,0x2510,

  0x2514,0x2534,0x252c,0x251c, 0x2500,0x253c,0x255e,0x255f,
  0x255a,0x2554,0x2569,0x2566, 0x2560,0x2550,0x256c,0x2567,
  0x2568,0x2564,0x2565,0x2559, 0x2558,0x2552,0x2553,0x256b,
  0x256a,0x2518,0x250c,0x2588, 0x2584,0x258c,0x2590,0x2580,
  0x03b1,0x00df,0x0393,0x03c0, 0x03a3,0x03c3,0x03bc,0x03c4,
  0x03a6,0x0398,0x03a9,0x03b4, 0x221e,0x03c6,0x03b5,0x2229,
  0x2261,0x00b1,0x2265,0x2264, 0x2320,0x2321,0x00f7,0x2248,
  0x00b0,0x2219,0x00b7,0x221a, 0x207f,0x00b2,0x25a0,0x00a0
};
  
unsigned short cp863_uni_byte[128] = {
  0x00c7,0x00fc,0x00e9,0x00e2, 0x00c2,0x00e0,0x00b6,0x00e7,
  0x00ea,0x00eb,0x00e8,0x00ef, 0x00ee,0x2017,0x00c0,0x00a7,
  0x00c9,0x00c8,0x00ca,0x00f4, 0x00cb,0x00cf,0x00fb,0x00f9,
  0x00a4,0x00d4,0x00dc,0x00a2, 0x00a3,0x00d9,0x00db,0x0192,
  0x00a6,0x00b4,0x00f3,0x00fa, 0x00a8,0x00b8,0x00b3,0x00af,
  0x00ce,0x2310,0x00ac,0x00bd, 0x00bc,0x00be,0x00ab,0x00bb,
  0x2591,0x2592,0x2593,0x2502, 0x2524,0x2561,0x2562,0x2556,
  0x2555,0x2563,0x2551,0x2557, 0x255d,0x255c,0x255b,0x2510,

  0x2514,0x2534,0x252c,0x251c, 0x2500,0x253c,0x255e,0x255f,
  0x255a,0x2554,0x2569,0x2566, 0x2560,0x2550,0x256c,0x2567,
  0x2568,0x2564,0x2565,0x2559, 0x2558,0x2552,0x2553,0x256b,
  0x256a,0x2518,0x250c,0x2588, 0x2584,0x258c,0x2590,0x2580,
  0x03b1,0x00df,0x0393,0x03c0, 0x03a3,0x03c3,0x03bc,0x03c4,
  0x03a6,0x0398,0x03a9,0x03b4, 0x221e,0x03c6,0x03b5,0x2229,
  0x2261,0x00b1,0x2265,0x2264, 0x2320,0x2321,0x00f7,0x2248,
  0x00b0,0x2219,0x00b7,0x221a, 0x207f,0x00b2,0x25a0,0x00a0
};
  
unsigned short cp864_uni_byte[128] = {
  0x00b0,0x00b7,0x2219,0x221a, 0x2592,0x2500,0x2502,0x253c,
  0x2524,0x252c,0x251c,0x2534, 0x2510,0x250c,0x2514,0x2518,
  0x03b2,0x221e,0x03c6,0x00b1, 0x00bd,0x00bc,0x2248,0x00ab,
  0x00bb,0xfef7,0xfef8,0x0000, 0x0000,0xfefb,0xfefc,0x0000,
  0x00a0,0x00ad,0xfe82,0x00a3, 0x00a4,0xfe84,0x0000,0x0000,
  0xfe8e,0xfe8f,0xfe95,0xfe99, 0x060c,0xfe9d,0xfea1,0xfea5,
  0x0660,0x0661,0x0662,0x0663, 0x0664,0x0665,0x0666,0x0667,
  0x0668,0x0669,0xfed1,0x061b, 0xfeb1,0xfeb5,0xfeb9,0x061f,

  0x00a2,0xfe80,0xfe81,0xfe83, 0xfe85,0xfeca,0xfe8b,0xfe8d,
  0xfe91,0xfe93,0xfe97,0xfe9b, 0xfe9f,0xfea3,0xfea7,0xfea9,
  0xfeab,0xfead,0xfeaf,0xfeb3, 0xfeb7,0xfebb,0xfebf,0xfec1,
  0xfec5,0xfecb,0xfecf,0x00a6, 0x00ac,0x00f7,0x00d7,0xfec9,
  0x0640,0xfed3,0xfed7,0xfedb, 0xfedf,0xfee3,0xfee7,0xfeeb,
  0xfeed,0xfeef,0xfef3,0xfebd, 0xfecc,0xfece,0xfecd,0xfee1,
  0xfe7d,0x0651,0xfee5,0xfee9, 0xfeec,0xfef0,0xfef2,0xfed0,
  0xfed5,0xfef5,0xfef6,0xfedd, 0xfed9,0xfef1,0x25a0,0x00a0
};
  
unsigned short cp865_uni_byte[128] = {
  0x00c7,0x00fc,0x00e9,0x00e2, 0x00e4,0x00e0,0x00e5,0x00e7,
  0x00ea,0x00eb,0x00e8,0x00ef, 0x00ee,0x00ec,0x00c4,0x00c5,
  0x00c9,0x00e6,0x00c6,0x00f4, 0x00f6,0x00f2,0x00fb,0x00f9,
  0x00ff,0x00d6,0x00dc,0x00f8, 0x00a3,0x00d8,0x20a7,0x0192,
  0x00e1,0x00ed,0x00f3,0x00fa, 0x00f1,0x00d1,0x00aa,0x00ba,
  0x00bf,0x2310,0x00ac,0x00bd, 0x00bc,0x00a1,0x00ab,0x00a4,
  0x2591,0x2592,0x2593,0x2502, 0x2524,0x2561,0x2562,0x2556,
  0x2555,0x2563,0x2551,0x2557, 0x255d,0x255c,0x255b,0x2510,

  0x2514,0x2534,0x252c,0x251c, 0x2500,0x253c,0x255e,0x255f,
  0x255a,0x2554,0x2569,0x2566, 0x2560,0x2550,0x256c,0x2567,
  0x2568,0x2564,0x2565,0x2559, 0x2558,0x2552,0x2553,0x256b,
  0x256a,0x2518,0x250c,0x2588, 0x2584,0x258c,0x2590,0x2580,
  0x03b1,0x00df,0x0393,0x03c0, 0x03a3,0x03c3,0x03bc,0x03c4,
  0x03a6,0x0398,0x03a9,0x03b4, 0x221e,0x03c6,0x03b5,0x2229,
  0x2261,0x00b1,0x2265,0x2264, 0x2320,0x2321,0x00f7,0x2248,
  0x00b0,0x2219,0x00b7,0x221a, 0x207f,0x00b2,0x25a0,0x00a0
};
  
unsigned short cp866_uni_byte[128] = {
  0x0410,0x0411,0x0412,0x0413, 0x0414,0x0415,0x0416,0x0417,
  0x0418,0x0419,0x041a,0x041b, 0x041c,0x041d,0x041e,0x041f,
  0x0420,0x0421,0x0422,0x0423, 0x0424,0x0425,0x0426,0x0427,
  0x0428,0x0429,0x042a,0x042b, 0x042c,0x042d,0x042e,0x042f,
  0x0430,0x0431,0x0432,0x0433, 0x0434,0x0435,0x0436,0x0437,
  0x0438,0x0439,0x043a,0x043b, 0x043c,0x043d,0x043e,0x043f,
  0x2591,0x2592,0x2593,0x2502, 0x2524,0x2561,0x2562,0x2556,
  0x2555,0x2563,0x2551,0x2557, 0x255d,0x255c,0x255b,0x2510,

  0x2514,0x2534,0x252c,0x251c, 0x2500,0x253c,0x255e,0x255f,
  0x255a,0x2554,0x2569,0x2566, 0x2560,0x2550,0x256c,0x2567,
  0x2568,0x2564,0x2565,0x2559, 0x2558,0x2552,0x2553,0x256b,
  0x256a,0x2518,0x250c,0x2588, 0x2584,0x258c,0x2590,0x2580,
  0x0440,0x0441,0x0442,0x0443, 0x0444,0x0445,0x0446,0x0447,
  0x0448,0x0449,0x044a,0x044b, 0x044c,0x044d,0x044e,0x044f,
  0x0401,0x0451,0x0404,0x0454, 0x0407,0x0457,0x040e,0x045e,
  0x00b0,0x2219,0x00b7,0x221a, 0x2116,0x00a4,0x25a0,0x00a0
};
  
/* indonesian */
unsigned short cp869_uni_byte[128] = {
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0386,0x0000,
  0x00b7,0x00ac,0x00a6,0x2018, 0x2019,0x0388,0x2015,0x0389,
  0x038a,0x03aa,0x038c,0x0000, 0x0000,0x038e,0x03ab,0x00a9,
  0x038f,0x00b2,0x00b3,0x03ac, 0x00a3,0x03ad,0x03ae,0x03af,
  0x03ca,0x0390,0x03cc,0x03cd, 0x0391,0x0392,0x0393,0x0394,
  0x0395,0x0396,0x0397,0x00bd, 0x0398,0x0399,0x00ab,0x00bb,
  0x2591,0x2592,0x2593,0x2502, 0x2524,0x039a,0x039b,0x039c,
  0x039d,0x2563,0x2551,0x2557, 0x255d,0x039e,0x039f,0x2510,

  0x2514,0x2534,0x252c,0x251c, 0x2500,0x253c,0x03a0,0x03a1,
  0x255a,0x2554,0x2569,0x2566, 0x2560,0x2550,0x256c,0x03a3,
  0x03a4,0x03a5,0x03a6,0x03a7, 0x03a8,0x03a9,0x03b1,0x03b2,
  0x03b3,0x2518,0x250c,0x2588, 0x2584,0x03b4,0x03b5,0x2580,
  0x03b6,0x03b7,0x03b8,0x03b9, 0x03ba,0x03bb,0x03bc,0x03bd,
  0x03be,0x03bf,0x03c0,0x03c1, 0x03c3,0x03c2,0x03c4,0x0384,
  0x00ad,0x00b1,0x03c5,0x03c6, 0x03c7,0x00a7,0x03c8,0x0385,
  0x00b0,0x00a8,0x03c9,0x03cb, 0x03b0,0x03ce,0x25a0,0x00a0
};
  
unsigned short cp874_uni_byte[128] = {
  0x20ac,0x0000,0x0000,0x0000, 0x0000,0x2026,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x2018,0x2019,0x201c, 0x201d,0x2022,0x2013,0x2014,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x00a0,0x0e01,0x0e02,0x0e03, 0x0e04,0x0e05,0x0e06,0x0e07,
  0x0e08,0x0e09,0x0e0a,0x0e0b, 0x0e0c,0x0e0d,0x0e0e,0x0e0f,
  0x0e10,0x0e11,0x0e12,0x0e13, 0x0e14,0x0e15,0x0e16,0x0e17,
  0x0e18,0x0e19,0x0e1a,0x0e1b, 0x0e1c,0x0e1d,0x0e1e,0x0e1f,

  0x0e20,0x0e21,0x0e22,0x0e23, 0x0e24,0x0e25,0x0e26,0x0e27,
  0x0e28,0x0e29,0x0e2a,0x0e2b, 0x0e2c,0x0e2d,0x0e2e,0x0e2f,
  0x0e30,0x0e31,0x0e32,0x0e33, 0x0e34,0x0e35,0x0e36,0x0e37,
  0x0e38,0x0e39,0x0e3a,0xf8c1, 0xf8c2,0xf8c3,0xf8c4,0x0e3f,
  0x0e40,0x0e41,0x0e42,0x0e43, 0x0e44,0x0e45,0x0e46,0x0e47,
  0x0e48,0x0e49,0x0e4a,0x0e4b, 0x0e4c,0x0e4d,0x0e4e,0x0e4f,
  0x0e50,0x0e51,0x0e52,0x0e53, 0x0e54,0x0e55,0x0e56,0x0e57,
  0x0e58,0x0e59,0x0e5a,0x0e5b, 0xf8c5,0xf8c6,0xf8c7,0xf8c8
};
  
unsigned short cp1255_uni_byte[128] = {
  0x20ac,0x0000,0x201a,0x0192, 0x201e,0x2026,0x2020,0x2021,
  0x02c6,0x2030,0x0000,0x2039, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x2018,0x2019,0x201c, 0x201d,0x2022,0x2013,0x2014,
  0x02dc,0x2122,0x0000,0x203a, 0x0000,0x0000,0x0000,0x0000,
  0x00a0,0x00a1,0x00a2,0x00a3, 0x20aa,0x00a5,0x00a6,0x00a7,
  0x00a8,0x00a9,0x00d7,0x00ab, 0x00ac,0x00ad,0x00ae,0x203e,
  0x00b0,0x00b1,0x00b2,0x00b3, 0x00b4,0x00b5,0x00b6,0x00b7,
  0x00b8,0x00b9,0x00f7,0x00bb, 0x00bc,0x00bd,0x00be,0x00bf,

  0x05b0,0x05b1,0x05b2,0x05b3, 0x05b4,0x05b5,0x05b6,0x05b7,
  0x05b8,0x05b9,0x0000,0x05bb, 0x05bc,0x05bd,0x05be,0x05bf,
  0x05c0,0x05c1,0x05c2,0x05c3, 0x05f0,0x05f1,0x05f2,0x05f3,
  0x05f4,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x2017,
  0x05d0,0x05d1,0x05d2,0x05d3, 0x05d4,0x05d5,0x05d6,0x05d7,
  0x05d8,0x05d9,0x05da,0x05db, 0x05dc,0x05dd,0x05de,0x05df,
  0x05e0,0x05e1,0x05e2,0x05e3, 0x05e4,0x05e5,0x05e6,0x05e7,
  0x05e8,0x05e9,0x05ea,0x0000, 0x0000,0x200e,0x200f,0x00a0
};

unsigned short cp1252_uni_byte[128] = {
  0x20ac,0x0000,0x201a,0x0192, 0x201e,0x2026,0x2020,0x2021,
  0x02c6,0x2030,0x0160,0x2039, 0x0152,0x0000,0x017d,0x0000,
  0x0000,0x2018,0x2019,0x201c, 0x201d,0x2022,0x2013,0x2014,
  0x02dc,0x2122,0x0161,0x203a, 0x0153,0x0000,0x017e,0x0178,
  0x00a0,0x00a1,0x00a2,0x00a3, 0x00a4,0x00a5,0x00a6,0x00a7,
  0x00a8,0x00a9,0x00aa,0x00ab, 0x00ac,0x00ad,0x00ae,0x00af,
  0x00b0,0x00b1,0x00b2,0x00b3, 0x00b4,0x00b5,0x00b6,0x00b7,
  0x00b8,0x00b9,0x00ba,0x00bb, 0x00bc,0x00bd,0x00be,0x00bf,

  0x00c0,0x00c1,0x00c2,0x00c3, 0x00c4,0x00c5,0x00c6,0x00c7,
  0x00c8,0x00c9,0x00ca,0x00cb, 0x00cc,0x00cd,0x00ce,0x00cf,
  0x00d0,0x00d1,0x00d2,0x00d3, 0x00d4,0x00d5,0x00d6,0x00d7,
  0x00d8,0x00d9,0x00da,0x00db, 0x00dc,0x00dd,0x00de,0x00df,
  0x00e0,0x00e1,0x00e2,0x00e3, 0x00e4,0x00e5,0x00e6,0x00e7,
  0x00e8,0x00e9,0x00ea,0x00eb, 0x00ec,0x00ed,0x00ee,0x00ef,
  0x00f0,0x00f1,0x00f2,0x00f3, 0x00f4,0x00f5,0x00f6,0x00f7,
  0x00f8,0x00f9,0x00fa,0x00fb, 0x00fc,0x00fd,0x00fe,0x00ff
};

unsigned short cp1253_uni_byte[128] = {
  0x20ac,0x0000,0x201a,0x0192, 0x201e,0x2026,0x2020,0x2021,
  0x0000,0x2030,0x0000,0x2039, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x2018,0x2019,0x201c, 0x201d,0x2022,0x2013,0x2014,
  0x0000,0x2122,0x0000,0x203a, 0x0000,0x0000,0x0000,0x0000,
  0x00a0,0x0385,0x0386,0x00a3, 0x00a4,0x00a5,0x00a6,0x00a7,
  0x00a8,0x00a9,0x0000,0x00ab, 0x00ac,0x00ad,0x00ae,0x2015,
  0x00b0,0x00b1,0x00b2,0x00b3, 0x0384,0x00b5,0x00b6,0x00b7,
  0x0388,0x0389,0x038a,0x00bb, 0x038c,0x00bd,0x038e,0x038f,

  0x0390,0x0391,0x0392,0x0393, 0x0394,0x0395,0x0396,0x0397,
  0x0398,0x0399,0x039a,0x039b, 0x039c,0x039d,0x039e,0x039f,
  0x03a0,0x03a1,0x0000,0x03a3, 0x03a4,0x03a5,0x03a6,0x03a7,
  0x03a8,0x03a9,0x03aa,0x03ab, 0x03ac,0x03ad,0x03ae,0x03af,
  0x03b0,0x03b1,0x03b2,0x03b3, 0x03b4,0x03b5,0x03b6,0x03b7,
  0x03b8,0x03b9,0x03ba,0x03bb, 0x03bc,0x03bd,0x03be,0x03bf,
  0x03c0,0x03c1,0x03c2,0x03c3, 0x03c4,0x03c5,0x03c6,0x03c7,
  0x03c8,0x03c9,0x03ca,0x03cb, 0x03cc,0x03cd,0x03ce,0x0000
};

unsigned short cp1254_uni_byte[128] = {
  0x20ac,0x0000,0x201a,0x0192, 0x201e,0x2026,0x2020,0x2021,
  0x02c6,0x2030,0x0160,0x2039, 0x0152,0x0000,0x0000,0x0000,
  0x0000,0x2018,0x2019,0x201c, 0x201d,0x2022,0x2013,0x2014,
  0x02dc,0x2122,0x0161,0x203a, 0x0153,0x0000,0x0000,0x0178,
  0x00a0,0x00a1,0x00a2,0x00a3, 0x00a4,0x00a5,0x00a6,0x00a7,
  0x00a8,0x00a9,0x00aa,0x00ab, 0x00ac,0x00ad,0x00ae,0x00af,
  0x00b0,0x00b1,0x00b2,0x00b3, 0x00b4,0x00b5,0x00b6,0x00b7,
  0x00b8,0x00b9,0x00ba,0x00bb, 0x00bc,0x00bd,0x00be,0x00bf,

  0x00c0,0x00c1,0x00c2,0x00c3, 0x00c4,0x00c5,0x00c6,0x00c7,
  0x00c8,0x00c9,0x00ca,0x00cb, 0x00cc,0x00cd,0x00ce,0x00cf,
  0x011e,0x00d1,0x00d2,0x00d3, 0x00d4,0x00d5,0x00d6,0x00d7,
  0x00d8,0x00d9,0x00da,0x00db, 0x00dc,0x0130,0x015e,0x00df,
  0x00e0,0x00e1,0x00e2,0x00e3, 0x00e4,0x00e5,0x00e6,0x00e7,
  0x00e8,0x00e9,0x00ea,0x00eb, 0x00ec,0x00ed,0x00ee,0x00ef,
  0x011f,0x00f1,0x00f2,0x00f3, 0x00f4,0x00f5,0x00f6,0x00f7,
  0x00f8,0x00f9,0x00fa,0x00fb, 0x00fc,0x0131,0x015f,0x00ff
};

unsigned short csn369103_uni_byte[128] = {
  0x0080,0x0081,0x0082,0x0083, 0x0084,0x0085,0x0086,0x0087,
  0x0088,0x0089,0x008a,0x008b, 0x008c,0x008d,0x008e,0x008f,
  0x0090,0x0091,0x0092,0x0093, 0x0094,0x0095,0x0096,0x0097,
  0x0098,0x0099,0x009a,0x009b, 0x009c,0x009d,0x009e,0x009f,
  0x00a0,0x0104,0x0306,0x0141, 0x0024,0x013d,0x015a,0x00a7,
  0x00a8,0x0160,0x015e,0x0164, 0x0179,0x00ad,0x017d,0x017b,
  0x030a,0x0105,0x0328,0x0142, 0x0301,0x013e,0x015b,0x030c,
  0x00b8,0x0161,0x015f,0x0165, 0x017a,0x030b,0x017e,0x017c,

  0x0154,0x00c1,0x00c2,0x0102, 0x00c4,0x0139,0x0106,0x00c7,
  0x010c,0x00c9,0x0118,0x00cb, 0x011a,0x00cd,0x00ce,0x010e,
  0x0110,0x0143,0x0147,0x00d3, 0x00d4,0x0150,0x00d6,0x00d7,
  0x0158,0x016e,0x00da,0x0170, 0x00dc,0x00dd,0x0162,0x00df,
  0x0155,0x00e1,0x00e2,0x0103, 0x00e4,0x013a,0x0107,0x00e7,
  0x010d,0x00e9,0x0119,0x00eb, 0x011b,0x00ed,0x00ee,0x010f,
  0x0111,0x0144,0x0148,0x00f3, 0x00f4,0x0151,0x00f6,0x00f7,
  0x0159,0x016f,0x00fa,0x0171, 0x00fc,0x00fd,0x0163,0x0307
};

unsigned short ds2089_uni_byte[128] = {
  0x0000,0x0001,0x0002,0x0003,0x0004,0x0005,0x0006,0x0007,
  0x0008,0x0009,0x000a,0x000b,0x000c,0x000d,0x000e,0x000f,
  0x0010,0x0011,0x0012,0x0013,0x0014,0x0015,0x0016,0x0017,
  0x0018,0x0019,0x001a,0x001b,0x001c,0x001d,0x001e,0x001f,
  0x0020,0x0021,0x0022,0x0023,0x0024,0x0025,0x0026,0x0027,
  0x0028,0x0029,0x002a,0x002b,0x002c,0x002d,0x002e,0x002f,
  0x0030,0x0031,0x0032,0x0033,0x0034,0x0035,0x0036,0x0037,
  0x0038,0x0039,0x003a,0x003b,0x003c,0x003d,0x003e,0x003f,
  0x0040,0x0041,0x0042,0x0043,0x0044,0x0045,0x0046,0x0047,
  0x0048,0x0049,0x004a,0x004b,0x004c,0x004d,0x004e,0x004f,
  0x0050,0x0051,0x0052,0x0053,0x0054,0x0055,0x0056,0x0057,
  0x0058,0x0059,0x005a,0x00c6,0x00d8,0x00c5,0x005e,0x005f,
  0x0060,0x0061,0x0062,0x0063,0x0064,0x0065,0x0066,0x0067,
  0x0068,0x0069,0x006a,0x006b,0x006c,0x006d,0x006e,0x006f,
  0x0070,0x0071,0x0072,0x0073,0x0074,0x0075,0x0076,0x0077,
  0x0078,0x0079,0x007a,0x00e6,0x00f8,0x00e5,0x007e,0x007f
};

/* modified cp866 */
unsigned short cp1125_uni_byte[128] = {
  0x0410,0x0411,0x0412,0x0413, 0x0414,0x0415,0x0416,0x0417,
  0x0418,0x0419,0x041a,0x041b, 0x041c,0x041d,0x041e,0x041f,
  0x0420,0x0421,0x0422,0x0423, 0x0424,0x0425,0x0426,0x0427,
  0x0428,0x0429,0x042a,0x042b, 0x042c,0x042d,0x042e,0x042f,
  0x0430,0x0431,0x0432,0x0433, 0x0434,0x0435,0x0436,0x0437,
  0x0438,0x0439,0x043a,0x043b, 0x043c,0x043d,0x043e,0x043f,
  0x2591,0x2592,0x2593,0x2502, 0x2524,0x2561,0x2562,0x2556,
  0x2555,0x2563,0x2551,0x2557, 0x255d,0x255c,0x255b,0x2510,
  0x2514,0x2534,0x252c,0x251c, 0x2500,0x253c,0x255e,0x255f,
  0x255a,0x2554,0x2569,0x2566, 0x2560,0x2550,0x256c,0x2567,
  0x2568,0x2564,0x2565,0x2559, 0x2558,0x2552,0x2553,0x256b,
  0x256a,0x2518,0x250c,0x2588, 0x2584,0x258c,0x2590,0x2580,
  0x0440,0x0441,0x0442,0x0443, 0x0444,0x0445,0x0446,0x0447,
  0x0448,0x0449,0x044a,0x044b, 0x044c,0x044d,0x044e,0x044f,
  0x0401,0x0451,0x0490,0x0491, 0x0404,0x0454,0x0406,0x0456,
  0x0407,0x0457,0x00f7,0x00b1, 0x2116,0x00a4,0x25a0,0x00a0
};

/* from http;//www.kostis.net/charset/cp853.html */
unsigned short cp853_uni_byte[128] = {
  0x00c7,0x00fc,0x00e9,0x00e2, 0x00e4,0x00e0,0x0109,0x00e7,
  0x00ea,0x00eb,0x00e8,0x00ef, 0x00ee,0x00ec,0x00c4,0x0108,
  0x00c9,0x010b,0x010a,0x00f4, 0x00f6,0x00f2,0x00fb,0x00f9,
  0x0130,0x00d6,0x00dc,0x011d, 0x00a3,0x011c,0x00d7,0x0135,
  0x00e1,0x00ed,0x00f3,0x00fa, 0x00f1,0x00d1,0x011e,0x011f,
  0x0124,0x0125,0x0000,0x00bd, 0x0134,0x015f,0x00ab,0x00bb,
  0x2591,0x2592,0x2593,0x2502, 0x2524,0x00c1,0x00c2,0x00c0,
  0x015e,0x2563,0x2551,0x2557, 0x255d,0x017b,0x017c,0x2510,

  0x2514,0x2534,0x252c,0x251c, 0x2500,0x253c,0x015c,0x015d,
  0x255a,0x2554,0x2569,0x2566, 0x2560,0x2550,0x256c,0x00a4,
  0x0000,0x0000,0x00ca,0x00cb, 0x00c8,0x0131,0x00cd,0x00ce,
  0x00cf,0x2518,0x250c,0x2588, 0x2584,0x0000,0x00cc,0x2580,
  0x00d3,0x00df,0x00d4,0x00d2, 0x0120,0x0121,0x00b5,0x0126,
  0x0127,0x00da,0x00db,0x00d9, 0x016c,0x016d,0x0000,0x00b4,
  0x00ad,0x0000,0x2113,0x0149, 0x02d8,0x00a7,0x00f7,0x00b8,
  0x00b0,0x00a8,0x02d9,0x0000, 0x00b3,0x00b2,0x25a0,0x00a0
};

/* from http;//www.kostis.net/charset/cp895.html */
unsigned short cp895_uni_byte[128] = {
  0x010c,0x00fc,0x00e9,0x010f, 0x00e4,0x010e,0x0164,0x010d,
  0x0115,0x0114,0x0139,0x00cd, 0x013e,0x013a,0x00c4,0x00c1,
  0x00c9,0x017e,0x017d,0x00f4, 0x00f6,0x00d3,0x016f,0x00da,
  0x00fd,0x00d6,0x00dc,0x0160, 0x013d,0x00dd,0x0158,0x0165,
  0x00e1,0x00ed,0x00f3,0x00fa, 0x0148,0x0147,0x016e,0x00d4,
  0x0161,0x0159,0x0155,0x0154, 0x00bc,0x00a1,0x00ab,0x00bb,
  0x2591,0x2592,0x2593,0x2502, 0x2524,0x2561,0x2562,0x2556,
  0x2555,0x2563,0x2551,0x2557, 0x255d,0x255c,0x255b,0x2510,
  0x2514,0x2534,0x252c,0x251c, 0x2500,0x253c,0x255e,0x255f,
  0x255a,0x2554,0x2569,0x2566, 0x2560,0x2550,0x256c,0x2567,
  0x2568,0x2564,0x2565,0x2559, 0x2558,0x2552,0x2553,0x256b,
  0x256a,0x2518,0x250c,0x2588, 0x2584,0x258c,0x2590,0x2580,
  0x03b1,0x00df,0x0393,0x03c0, 0x03a3,0x03c3,0x00b5,0x03c4,
  0x03a6,0x0398,0x03a9,0x03b4, 0x221e,0x03c6,0x03b5,0x2229,
  0x2261,0x00b1,0x2265,0x2264, 0x2320,0x2321,0x00f7,0x2248,
  0x00b0,0x2219,0x00b7,0x221a, 0x207f,0x00b2,0x25a0,0x00a0
};

/*
    Macint*sh code set
*/
unsigned short machebrew_uni_byte[128] = {
  0x00c4,0xfb1f,0x00c7,0x00c9, 0x00d1,0x00d6,0x00dc,0x00e1,
  0x00e0,0x00e2,0x00e4,0x00e3, 0x00e5,0x00e7,0x00e9,0x00e8,
  0x00ea,0x00eb,0x00ed,0x00ec, 0x00ee,0x00ef,0x00f1,0x00f3,
  0x00f2,0x00f4,0x00f6,0x00f5, 0x00fa,0x00f9,0x00fb,0x00fc,
  0x0020,0x0021,0x0022,0x0023, 0x0024,0x0025,0x20aa,0x0027,
  0x0028,0x0029,0x002a,0x002b, 0x002c,0x002d,0x002e,0x002f,
  0x0030,0x0031,0x0032,0x0033, 0x0034,0x0035,0x0036,0x0037,
  0x0038,0x0039,0x003a,0x003b, 0x003c,0x003d,0x003e,0x003f,

  0xd828,0x201e,0xf89b,0xf89c, 0xf89d,0xf89e,0x05bc,0xfb4b,
  0xfb35,0x2026,0x00a0,0x05b8, 0x05b7,0x05b5,0x05b6,0x05b4,
  0x2013,0x2014,0x201c,0x201d, 0x2018,0x2019,0xfb2a,0xfb2b,
  0x05bf,0x05b0,0x05b2,0x05b1, 0x05bb,0x05b9,0xd829,0x05b3,
  0x05d0,0x05d1,0x05d2,0x05d3, 0x05d4,0x05d5,0x05d6,0x05d7,
  0x05d8,0x05d9,0x05da,0x05db, 0x05dc,0x05dd,0x05de,0x05df,
  0x05e0,0x05e1,0x05e2,0x05e3, 0x05e4,0x05e5,0x05e6,0x05e7,
  0x05e8,0x05e9,0x05ea,0x007d, 0x005d,0x007b,0x005b,0x007c
};

unsigned short macfarsi_uni_byte[128] = {
  0x00c4,0x00a0,0x00c7,0x00c9, 0x00d1,0x00d6,0x00dc,0x00e1,
  0x00e0,0x00e2,0x00e4,0x06ba, 0x00ab,0x00e7,0x00e9,0x00e8,
  0x00ea,0x00eb,0x00ed,0x2026, 0x00ee,0x00ef,0x00f1,0x00f3,
  0x00bb,0x00f4,0x00f6,0x00f7, 0x00fa,0x00f9,0x00fb,0x00fc,
  0x0020,0x0021,0x0022,0x0023, 0x0024,0x066a,0x0026,0x0027,
  0x0028,0x0029,0x002a,0x002b, 0x060c,0x002d,0x002e,0x002f,
  0x06f0,0x06f1,0x06f2,0x06f3, 0x06f4,0x06f5,0x06f6,0x06f7,
  0x06f8,0x06f9,0x003a,0x061b, 0x003c,0x003d,0x003e,0x061f,

  0x274a,0x0621,0x0622,0x0623, 0x0624,0x0625,0x0626,0x0627,
  0x0628,0x0629,0x062a,0x062b, 0x062c,0x062d,0x062e,0x062f,
  0x0630,0x0631,0x0632,0x0633, 0x0634,0x0635,0x0636,0x0637,
  0x0638,0x0639,0x063a,0x005b, 0x005c,0x005d,0x005e,0x005f,
  0x0640,0x0641,0x0642,0x0643, 0x0644,0x0645,0x0646,0x0647,
  0x0648,0x0649,0x064a,0x064b, 0x064c,0x064d,0x064e,0x064f,
  0x0650,0x0651,0x0652,0x067e, 0x0679,0x0686,0x06d5,0x06a4,
  0x06af,0x0688,0x0691,0x007b, 0x007c,0x007d,0x0698,0x06d2
};

unsigned short macicelan_uni_byte[128] = {
  0x00c4,0x00c5,0x00c7,0x00c9, 0x00d1,0x00d6,0x00dc,0x00e1,
  0x00e0,0x00e2,0x00e4,0x00e3, 0x00e5,0x00e7,0x00e9,0x00e8,
  0x00ea,0x00eb,0x00ed,0x00ec, 0x00ee,0x00ef,0x00f1,0x00f3,
  0x00f2,0x00f4,0x00f6,0x00f5, 0x00fa,0x00f9,0x00fb,0x00fc,
  0x00dd,0x00b0,0x00a2,0x00a3, 0x00a7,0x2022,0x00b6,0x00df,
  0x00ae,0x00a9,0x2122,0x00b4, 0x00a8,0x2260,0x00c6,0x00d8,
  0x221e,0x00b1,0x2264,0x2265, 0x00a5,0x00b5,0x2202,0x2211,
  0x220f,0x03c0,0x222b,0x00aa, 0x00ba,0x03a9,0x00e6,0x00f8,

  0x00bf,0x00a1,0x00ac,0x221a, 0x0192,0x2248,0x2206,0x00ab,
  0x00bb,0x2026,0x00a0,0x00c0, 0x00c3,0x00d5,0x0152,0x0153,
  0x2013,0x2014,0x201c,0x201d, 0x2018,0x2019,0x00f7,0x25ca,
  0x00ff,0x0178,0x2044,0x20ac, 0x00d0,0x00f0,0x00de,0x00fe,
  0x00fd,0x00b7,0x201a,0x201e, 0x2030,0x00c2,0x00ca,0x00c1,
  0x00cb,0x00c8,0x00cd,0x00ce, 0x00cf,0x00cc,0x00d3,0x00d4,
  0xf8ff,0x00d2,0x00da,0x00db, 0x00d9,0x0131,0x02c6,0x02dc,
  0x00af,0x02d8,0x02d9,0x02da, 0x00b8,0x02dd,0x02db,0x02c7
};

unsigned short macczech_uni_byte[128] = {
  0x00c4,0x0100,0x0101,0x00c9, 0x0104,0x00d6,0x00dc,0x00e1,
  0x0105,0x010c,0x00e4,0x010d, 0x0106,0x0107,0x00e9,0x0179,
  0x017a,0x010e,0x00ed,0x010f, 0x0112,0x0113,0x0116,0x00f3,
  0x0117,0x00f4,0x00f6,0x00f5, 0x00fa,0x011a,0x011b,0x00fc,
  0x2020,0x00b0,0x0118,0x00a3, 0x00a7,0x2022,0x00b6,0x00df,
  0x00ae,0x00a9,0x2122,0x0119, 0x00a8,0x2260,0x0123,0x012e,
  0x012f,0x012a,0x2264,0x2265, 0x012b,0x0136,0x2202,0x2211,
  0x0142,0x013b,0x013c,0x013d, 0x013e,0x0139,0x013a,0x0145,

  0x0146,0x0143,0x00ac,0x221a, 0x0144,0x0147,0x2206,0x00ab,
  0x00bb,0x2026,0x00a0,0x0148, 0x0150,0x00d5,0x0151,0x014c,
  0x2013,0x2014,0x201c,0x201d, 0x2018,0x2019,0x00f7,0x25ca,
  0x014d,0x0154,0x0155,0x0158, 0x2039,0x203a,0x0159,0x0156,
  0x0157,0x0160,0x201a,0x201e, 0x0161,0x015a,0x015b,0x00c1,
  0x0164,0x0165,0x00cd,0x017d, 0x017e,0x016a,0x00d3,0x00d4,
  0x016b,0x016e,0x00da,0x016f, 0x0170,0x0171,0x0172,0x0173,
  0x00dd,0x00fd,0x0137,0x017b, 0x0141,0x017c,0x0122,0x02c7
};

unsigned short macgreek_uni_byte[128] = {
  0x00c4,0x00b9,0x00b2,0x00c9, 0x00b3,0x00d6,0x00dc,0x0385,
  0x00e0,0x00e2,0x00e4,0x0384, 0x00a8,0x00e7,0x00e9,0x00e8,
  0x00ea,0x00eb,0x00a3,0x2122, 0x00ee,0x00ef,0x2022,0x00bd,
  0x2030,0x00f4,0x00f6,0x00a6, 0x20ac,0x00f9,0x00fb,0x00fc,
  0x2020,0x0393,0x0394,0x0398, 0x039b,0x039e,0x03a0,0x00df,
  0x00ae,0x00a9,0x03a3,0x03aa, 0x00a7,0x2260,0x00b0,0x00b7,
  0x0391,0x00b1,0x2264,0x2265, 0x00a5,0x0392,0x0395,0x0396,
  0x0397,0x0399,0x039a,0x039c, 0x03a6,0x03ab,0x03a8,0x03a9,
  
  0x03ac,0x039d,0x00ac,0x039f, 0x03a1,0x2248,0x03a4,0x00ab,
  0x00bb,0x2026,0x00a0,0x03a5, 0x03a7,0x0386,0x0388,0x0153,
  0x2013,0x2014,0x201c,0x201d, 0x2018,0x2019,0x00f7,0x0389,
  0x038a,0x038c,0x038e,0x03ad, 0x03ae,0x03af,0x03cc,0x038f,
  0x03cd,0x03b1,0x03b2,0x03c8, 0x03b4,0x03b5,0x03c6,0x03b3,
  0x03b7,0x03b9,0x03be,0x03ba, 0x03bb,0x03bc,0x03bd,0x03bf,
  0x03c0,0x03ce,0x03c1,0x03c3, 0x03c4,0x03b8,0x03c9,0x03c2,
  0x03c7,0x03c5,0x03b6,0x03ca, 0x03cb,0x0390,0x03b0,0x00ad
};

unsigned short macgujarati_uni_byte[128] = {
  0x00d7,0x2212,0x2013,0x2014, 0x2018,0x2019,0x2026,0x2022,
  0x00a9,0x00ae,0x2122,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0965,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x00a0,0x0a81,0x0a82,0x0a83, 0x0a85,0x0a86,0x0a87,0x0a88,
  0x0a89,0x0a8a,0x0a8b,0x0000, 0x0a8f,0x0a90,0x0a8d,0x0000,
  0x0a93,0x0a94,0x0a91,0x0a95, 0x0a96,0x0a97,0x0a98,0x0a99,
  0x0a9a,0x0a9c,0x0a9d,0x0a9e, 0x0a9f,0x0aa0,0x0aa1,0x0aa2,

  0x0aa3,0x0aa4,0x0aa5,0x0aa6, 0x0aa7,0x0aa8,0x0aa9,0x0000,
  0x0aaa,0x0aab,0x0aac,0x0aad, 0x0aae,0x0aaf,0x0000,0x0ab0,
  0x0000,0x0ab2,0x0ab3,0x0000, 0x0ab5,0x0ab6,0x0ab7,0x0ab8,
  0x0ab9,0x200e,0x0abe,0x0abf, 0x0ac0,0x0ac1,0x0ac2,0x0ac3,
  0x0000,0x0ac7,0x0ac8,0x0ac5, 0x0000,0x0acb,0x0acc,0x0ac9,
  0x0acd,0x0abc,0x0964,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0ae6,0x0ae7,0x0ae8, 0x0ae9,0x0aea,0x0aeb,0x0aec,
  0x0aed,0x0aee,0x0aef,0x0000, 0x0000,0x0000,0x0000,0x0000
};

unsigned short macgurmukhi_uni_byte[128] = {
  0x00d7,0x2212,0x2013,0x2014, 0x2018,0x2019,0x2026,0x2022,
  0x00a9,0x00ae,0x2122,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0a71,0x0a5c,0x0a73,0x0a72, 0x0a74,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0a02,0x0000, 0x0a05,0x0a06,0x0a07,0x0a08,
  0x0a09,0x0a0a,0x0000,0x0000, 0x0a0f,0x0a10,0x0000,0x0000,
  0x0a13,0x0a14,0x0000,0x0a15, 0x0a16,0x0a17,0x0a18,0x0a19,
  0x0a1a,0x0a1b,0x0a1c,0x0a1d, 0x0a1e,0x0a1f,0x0a20,0x0a21,

  0x0a22,0x0a23,0x0a24,0x0a25, 0x0a26,0x0a27,0x0a28,0x0000,
  0x0a2a,0x0a2b,0x0a2c,0x0a2d, 0x0a2e,0x0a2f,0x0000,0x0a30,
  0x0000,0x0a32,0x0000,0x0000, 0x0a35,0xd82a,0x0000,0x0a38,
  0x0a39,0x200e,0x0a3e,0x0a3f, 0x0a40,0x0a41,0x0a42,0x0000,
  0x0000,0x0a47,0x0a48,0x0000, 0x0000,0x0a4b,0x0a4c,0x0000,
  0x0a4d,0x0a3c,0x0964,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0a66,0x0a67,0x0a68, 0x0a69,0x0a6a,0x0a6b,0x0a6c,
  0x0a6d,0x0a6e,0x0a6f,0x0000, 0x0000,0x0000,0x0000,0x0000
};

unsigned short macdevanaga_uni_byte[128] = {
  0x00d7,0x2212,0x2013,0x2014, 0x2018,0x2019,0x2026,0x2022,
  0x00a9,0x00ae,0x2122,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0965,0x0970,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x00a0,0x0901,0x0902,0x0903, 0x0905,0x0906,0x0907,0x0908,
  0x0909,0x090a,0x090b,0x090e, 0x090f,0x0910,0x090d,0x0912,
  0x0913,0x0914,0x0911,0x0915, 0x0916,0x0917,0x0918,0x0919,
  0x091a,0x091b,0x091c,0x091d, 0x091e,0x091f,0x0920,0x0921,

  0x0922,0x0923,0x0924,0x0925, 0x0926,0x0927,0x0928,0x0929,
  0x092a,0x092b,0x092c,0x092d, 0x092e,0x092f,0x095f,0x0930,
  0x0931,0x0932,0x0933,0x0934, 0x0935,0x0936,0x0937,0x0938,
  0x0939,0x200e,0x093e,0x093f, 0x0940,0x0941,0x0942,0x0943,
  0x0946,0x0947,0x0948,0x0945, 0x094a,0x094b,0x094c,0x0949,
  0x094d,0x093c,0x0964,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0966,0x0967,0x0968, 0x0969,0x096a,0x096b,0x096c,
  0x096d,0x096e,0x096f,0x0000, 0x0000,0x0000,0x0000,0x0000
};

unsigned short maccroat_uni_byte[128] = {
  0x00c4,0x00c5,0x00c7,0x00c9, 0x00d1,0x00d6,0x00dc,0x00e1,
  0x00e0,0x00e2,0x00e4,0x00e3, 0x00e5,0x00e7,0x00e9,0x00e8,
  0x00ea,0x00eb,0x00ed,0x00ec, 0x00ee,0x00ef,0x00f1,0x00f3,
  0x00f2,0x00f4,0x00f6,0x00f5, 0x00fa,0x00f9,0x00fb,0x00fc,
  0x2020,0x00b0,0x00a2,0x00a3, 0x00a7,0x2022,0x00b6,0x00df,
  0x00ae,0x0160,0x2122,0x00b4, 0x00a8,0x2260,0x017d,0x00d8,
  0x221e,0x00b1,0x2264,0x2265, 0x2206,0x00b5,0x2202,0x2211,
  0x220f,0x0161,0x222b,0x00aa, 0x00ba,0x03a9,0x017e,0x00f8,

  0x00bf,0x00a1,0x00ac,0x221a, 0x0192,0x2248,0x0106,0x00ab,
  0x010c,0x2026,0x00a0,0x00c0, 0x00c3,0x00d5,0x0152,0x0153,
  0x0110,0x2014,0x201c,0x201d, 0x2018,0x2019,0x00f7,0x25ca,
  0xf8ff,0x00a9,0x2044,0x20ac, 0x2039,0x203a,0x00c6,0x00bb,
  0x2013,0x00b7,0x201a,0x201e, 0x2030,0x00c2,0x0107,0x00c1,
  0x010d,0x00c8,0x00cd,0x00ce, 0x00cf,0x00cc,0x00d3,0x00d4,
  0x0111,0x00d2,0x00da,0x00db, 0x00d9,0x0131,0x02c6,0x02dc,
  0x00af,0x03c0,0x00cb,0x02da, 0x00b8,0x00ca,0x00e6,0x02c7
};

unsigned short macarabic_uni_byte[128] = {
  0x00c4,0x00a0,0x00c7,0x00c9, 0x00d1,0x00d6,0x00dc,0x00e1,
  0x00e0,0x00e2,0x00e4,0x06ba, 0x00ab,0x00e7,0x00e9,0x00e8,
  0x00ea,0x00eb,0x00ed,0x2026, 0x00ee,0x00ef,0x00f1,0x00f3,
  0x00bb,0x00f4,0x00f6,0x00f7, 0x00fa,0x00f9,0x00fb,0x00fc,
  0x0020,0x0021,0x0022,0x0023, 0x0024,0x066a,0x0026,0x0027,
  0x0028,0x0029,0x002a,0x002b, 0x060c,0x002d,0x002e,0x002f,
  0x0660,0x0661,0x0662,0x0663, 0x0664,0x0665,0x0666,0x0667,
  0x0668,0x0669,0x003a,0x061b, 0x003c,0x003d,0x003e,0x061f,

  0x274a,0x0621,0x0622,0x0623, 0x0624,0x0625,0x0626,0x0627,
  0x0628,0x0629,0x062a,0x062b, 0x062c,0x062d,0x062e,0x062f,
  0x0630,0x0631,0x0632,0x0633, 0x0634,0x0635,0x0636,0x0637,
  0x0638,0x0639,0x063a,0x005b, 0x005c,0x005d,0x005e,0x005f,
  0x0640,0x0641,0x0642,0x0643, 0x0644,0x0645,0x0646,0x0647,
  0x0648,0x0649,0x064a,0x064b, 0x064c,0x064d,0x064e,0x064f,
  0x0650,0x0651,0x0652,0x067e, 0x0679,0x0686,0x06d5,0x06a4,
  0x06af,0x0688,0x0691,0x007b, 0x007c,0x007d,0x0698,0x06d2
};

unsigned short macturki_uni_byte[128] = {
  0x00c4,0x00c5,0x00c7,0x00c9, 0x00d1,0x00d6,0x00dc,0x00e1,
  0x00e0,0x00e2,0x00e4,0x00e3, 0x00e5,0x00e7,0x00e9,0x00e8,
  0x00ea,0x00eb,0x00ed,0x00ec, 0x00ee,0x00ef,0x00f1,0x00f3,
  0x00f2,0x00f4,0x00f6,0x00f5, 0x00fa,0x00f9,0x00fb,0x00fc,
  0x2020,0x00b0,0x00a2,0x00a3, 0x00a7,0x2022,0x00b6,0x00df,
  0x00ae,0x00a9,0x2122,0x00b4, 0x00a8,0x2260,0x00c6,0x00d8,
  0x221e,0x00b1,0x2264,0x2265, 0x00a5,0x00b5,0x2202,0x2211,
  0x220f,0x03c0,0x222b,0x00aa, 0x00ba,0x03a9,0x00e6,0x00f8,

  0x00bf,0x00a1,0x00ac,0x221a, 0x0192,0x2248,0x2206,0x00ab,
  0x00bb,0x2026,0x00a0,0x00c0, 0x00c3,0x00d5,0x0152,0x0153,
  0x2013,0x2014,0x201c,0x201d, 0x2018,0x2019,0x00f7,0x25ca,
  0x00ff,0x0178,0x011e,0x011f, 0x0130,0x0131,0x015e,0x015f,
  0x2021,0x00b7,0x201a,0x201e, 0x2030,0x00c2,0x00ca,0x00c1,
  0x00cb,0x00c8,0x00cd,0x00ce, 0x00cf,0x00cc,0x00d3,0x00d4,
  0xf8ff,0x00d2,0x00da,0x00db, 0x00d9,0xf8a0,0x02c6,0x02dc,
  0x00af,0x02d8,0x02d9,0x02da, 0x00b8,0x02dd,0x02db,0x02c7
};

/* Note Mac cyrillic and Mac Ukrainian is same	*/
unsigned short maccyril_uni_byte[128] = {
  0x0410,0x0411,0x0412,0x0413, 0x0414,0x0415,0x0416,0x0417,
  0x0418,0x0419,0x041a,0x041b, 0x041c,0x041d,0x041e,0x041f,
  0x0420,0x0421,0x0422,0x0423, 0x0424,0x0425,0x0426,0x0427,
  0x0428,0x0429,0x042a,0x042b, 0x042c,0x042d,0x042e,0x042f,
  0x2020,0x00b0,0x0490,0x00a3, 0x00a7,0x2022,0x00b6,0x0406,
  0x00ae,0x00a9,0x2122,0x0402, 0x0452,0x2260,0x0403,0x0453,
  0x221e,0x00b1,0x2264,0x2265, 0x0456,0x00b5,0x0491,0x0408,
  0x0404,0x0454,0x0407,0x0457, 0x0409,0x0459,0x040a,0x045a,

  0x0458,0x0405,0x00ac,0x221a, 0x0192,0x2248,0x2206,0x00ab,
  0x00bb,0x2026,0x00a0,0x040b, 0x045b,0x040c,0x045c,0x0455,
  0x2013,0x2014,0x201c,0x201d, 0x2018,0x2019,0x00f7,0x201e,
  0x040e,0x045e,0x040f,0x045f, 0x2116,0x0401,0x0451,0x044f,
  0x0430,0x0431,0x0432,0x0433, 0x0434,0x0435,0x0436,0x0437,
  0x0438,0x0439,0x043a,0x043b, 0x043c,0x043d,0x043e,0x043f,
  0x0440,0x0441,0x0442,0x0443, 0x0444,0x0445,0x0446,0x0447,
  0x0448,0x0449,0x044a,0x044b, 0x044c,0x044d,0x044e,0x20ac
};

unsigned short macromanian_uni_byte[128] = {
  0x00c4,0x00c5,0x00c7,0x00c9, 0x00d1,0x00d6,0x00dc,0x00e1,
  0x00e0,0x00e2,0x00e4,0x00e3, 0x00e5,0x00e7,0x00e9,0x00e8,
  0x00ea,0x00eb,0x00ed,0x00ec, 0x00ee,0x00ef,0x00f1,0x00f3,
  0x00f2,0x00f4,0x00f6,0x00f5, 0x00fa,0x00f9,0x00fb,0x00fc,
  0x2020,0x00b0,0x00a2,0x00a3, 0x00a7,0x2022,0x00b6,0x00df,
  0x00ae,0x00a9,0x2122,0x00b4, 0x00a8,0x2260,0x0102,0x0218,
  0x221e,0x00b1,0x2264,0x2265, 0x00a5,0x00b5,0x2202,0x2211,
  0x220f,0x03c0,0x222b,0x00aa, 0x00ba,0x03a9,0x0103,0x0219,

  0x00bf,0x00a1,0x00ac,0x221a, 0x0192,0x2248,0x2206,0x00ab,
  0x00bb,0x2026,0x00a0,0x00c0, 0x00c3,0x00d5,0x0152,0x0153,
  0x2013,0x2014,0x201c,0x201d, 0x2018,0x2019,0x00f7,0x25ca,
  0x00ff,0x0178,0x2044,0x20ac, 0x2039,0x203a,0x021a,0x021b,
  0x2021,0x00b7,0x201a,0x201e, 0x2030,0x00c2,0x00ca,0x00c1,
  0x00cb,0x00c8,0x00cd,0x00ce, 0x00cf,0x00cc,0x00d3,0x00d4,
  0xf8ff,0x00d2,0x00da,0x00db, 0x00d9,0x0131,0x02c6,0x02dc,
  0x00af,0x02d8,0x02d9,0x02da, 0x00b8,0x02dd,0x02db,0x02c7
};
unsigned short macburgarian_uni_byte[128] = {
  0x00c4,0x00c5,0x00c7,0x00c9, 0x00d1,0x00d6,0x00dc,0x00e1,
  0x00e0,0x00e2,0x00e4,0x00e3, 0x00e5,0x00e7,0x00e9,0x00e8,
  0x00ea,0x00eb,0x00ed,0x00ec, 0x00ee,0x00ef,0x00f1,0x00f3,
  0x00f2,0x00f4,0x00f6,0x00f5, 0x00fa,0x00f9,0x00fb,0x00fc,
  0x2020,0x00b0,0x00a2,0x00a3, 0x00a7,0x2022,0x00b6,0x00df,
  0x00ae,0x00a9,0x2122,0x00b4, 0x00a8,0x2260,0x0102,0x0218,
  0x221e,0x00b1,0x2264,0x2265, 0x00a5,0x00b5,0x2202,0x2211,
  0x220f,0x03c0,0x222b,0x00aa, 0x00ba,0x03a9,0x0103,0x0219,

  0x00bf,0x00a1,0x00ac,0x221a, 0x0192,0x2248,0x2206,0x00ab,
  0x00bb,0x2026,0x00a0,0x00c0, 0x00c3,0x00d5,0x0152,0x0153,
  0x2013,0x2014,0x201c,0x201d, 0x2018,0x2019,0x00f7,0x25ca,
  0x00ff,0x0178,0x2044,0x20ac, 0x2039,0x203a,0x021a,0x021b,
  0x2021,0x00b7,0x201a,0x201e, 0x2030,0x00c2,0x00ca,0x00c1,
  0x00cb,0x00c8,0x00cd,0x00ce, 0x00cf,0x00cc,0x00d3,0x00d4,
  0xf8ff,0x00d2,0x00da,0x00db, 0x00d9,0x0131,0x02c6,0x02dc,
  0x00af,0x02d8,0x02d9,0x02da, 0x00b8,0x02dd,0x02db,0x02c7
};

unsigned short geostd8_uni_byte[128] = {
  0x20ac,0x0000,0x201a,0x0000, 0x201e,0x2026,0x2020,0x2021,
  0x0000,0x2030,0x0000,0x2039, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x2018,0x2019,0x201c, 0x201d,0x2022,0x2013,0x2014,
  0x0000,0x0000,0x0000,0x203a, 0x009c,0x009d,0x009e,0x009f,
  0x00a0,0x00a1,0x00a2,0x00a3, 0x00a4,0x00a5,0x00a6,0x00a7,
  0x00a8,0x00a9,0x00aa,0x00ab, 0x00ac,0x00ad,0x00ae,0x00af,
  0x00b0,0x00b1,0x00b2,0x00b3, 0x00b4,0x00b5,0x00b6,0x00b7,
  0x00b8,0x00b9,0x00ba,0x00bb, 0x00bc,0x00bd,0x00be,0x00bf,

  0x10d0,0x10d1,0x10d2,0x10d3, 0x10d4,0x10d5,0x10d6,0x10f1,
  0x10d7,0x10d8,0x10d9,0x10da, 0x10db,0x10dc,0x10f2,0x10dd,
  0x10de,0x10df,0x10e0,0x10e1, 0x10e2,0x10f3,0x10e3,0x10e4,
  0x10e5,0x10e6,0x10e7,0x10e8, 0x10e9,0x10ea,0x10eb,0x10ec,
  0x10ed,0x10ee,0x10f4,0x10ef, 0x10f0,0x10f5,0x00e6,0x00e7,
  0x00e8,0x00e9,0x00ea,0x00eb, 0x00ec,0x00ed,0x00ee,0x00ef,
  0x00f0,0x00f1,0x00f2,0x00f3, 0x00f4,0x00f5,0x00f6,0x00f7,
  0x00f8,0x00f9,0x00fa,0x00fb, 0x00fc,0x2116,0x00fe,0x00ff
};

unsigned short armiscii_uni_byte[128] = {
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x00a0,0x0000,0x0587,0x0589, 0x0029,0x0028,0x00bb,0x00ab,
  0x2014,0x002e,0x055d,0x002c, 0x002d,0x058a,0x2026,0x055c,
  0x055b,0x055e,0x0531,0x0561, 0x0532,0x0562,0x0533,0x0563,
  0x0534,0x0564,0x0535,0x0565, 0x0536,0x0566,0x0537,0x0567,

  0x0538,0x0568,0x0539,0x0569, 0x053a,0x056a,0x053b,0x056b,
  0x053c,0x056c,0x053d,0x056d, 0x053e,0x056e,0x053f,0x056f,
  0x0540,0x0570,0x0541,0x0571, 0x0542,0x0572,0x0543,0x0573,
  0x0544,0x0574,0x0545,0x0575, 0x0546,0x0576,0x0547,0x0577,
  0x0548,0x0578,0x0549,0x0579, 0x054a,0x057a,0x054b,0x057b,
  0x054c,0x057c,0x054d,0x057d, 0x054e,0x057e,0x054f,0x057f,
  0x0550,0x0580,0x0551,0x0581, 0x0552,0x0582,0x0553,0x0583,
  0x0554,0x0584,0x0555,0x0585, 0x0556,0x0586,0x055a,0x0000
};

unsigned short vpsl_uni_byte[128] = {
  0x0000,0x0001,0x1ea0,0x1eac,0x1eb6,0x1eb8,0x1ec6,0x0007,
  0x0008,0x0009,0x000a,0x000b,0x000c,0x000d,0x000e,0x000f,
  0x1eca,0x1ecc,0x1ed8,0x1ee2,0x1ee4,0x1ef0,0x0016,0x0017,
  0x0018,0x1ef4,0x001a,0x001b,0x1eaa,0x1eee,0x001e,0x001f,
  0x0020,0x0021,0x0022,0x0023,0x0024,0x0025,0x0026,0x0027,
  0x0028,0x0029,0x002a,0x002b,0x002c,0x002d,0x002e,0x002f,
  0x0030,0x0031,0x0032,0x0033,0x0034,0x0035,0x0036,0x0037,
  0x0038,0x0039,0x003a,0x003b,0x003c,0x003d,0x003e,0x003f,
  0x0040,0x0041,0x0042,0x0043,0x0044,0x0045,0x0046,0x0047,
  0x0048,0x0049,0x004a,0x004b,0x004c,0x004d,0x004e,0x004f,
  0x0050,0x0051,0x0052,0x0053,0x0054,0x0055,0x0056,0x0057,
  0x0058,0x0059,0x005a,0x005b,0x005c,0x005d,0x005e,0x005f,
  0x0060,0x0061,0x0062,0x0063,0x0064,0x0065,0x0066,0x0067,
  0x0068,0x0069,0x006a,0x006b,0x006c,0x006d,0x006e,0x006f,
  0x0070,0x0071,0x0072,0x0073,0x0074,0x0075,0x0076,0x0077,
  0x0078,0x0079,0x007a,0x007b,0x007c,0x007d,0x007e,0x007f
};

unsigned short vpsr_uni_byte[128] = {
  0x00c0,0x1ea2,0x00c3,0x1ea4,0x1ea6,0x1ea8,0x1ecd,0x1ed7,
  0x0102,0x1ebf,0x1ec1,0x1ec3,0x1ec7,0x1eae,0x1eb0,0x1eb2,
  0x1ebe,0x2018,0x2019,0x1ec0,0x1ec2,0x1ec4,0x1ed0,0x1ed2,
  0x1ed4,0x1ed6,0x00fd,0x1ef7,0x1ef5,0x1eda,0x1edc,0x1ede,
  0x00a0,0x1eaf,0x1eb1,0x1eb3,0x1eb5,0x1eb7,0x1ee0,0x1edb,
  0x00d9,0x1edd,0x1edf,0x1ee1,0x0168,0x1ee8,0x1ee3,0x1eea,
  0x1ed5,0x1eec,0x1ef2,0x1ef8,0x00cd,0x00cc,0x1ed9,0x1ec8,
  0x0128,0x00d3,0x1eed,0x1eef,0x00d2,0x1ece,0x00d5,0x1ef1,
  0x1ea7,0x00c1,0x00c2,0x1ea5,0x1ea9,0x1eab,0x1ead,0x0111,
  0x1ebb,0x00c9,0x00ca,0x1eb9,0x1ec9,0x1ec5,0x1ecb,0x1ef9,
  0x01af,0x1ee6,0x1ed3,0x1ed1,0x00d4,0x1ecf,0x01a1,0x00c8,
  0x1eeb,0x1ee9,0x00da,0x0169,0x01b0,0x00dd,0x1eba,0x00df,
  0x00e0,0x00e1,0x00e2,0x00e3,0x1ea3,0x1ea1,0x0103,0x00e7,
  0x00e8,0x00e9,0x00ea,0x1ebd,0x00ec,0x00ed,0x00ee,0x0129,
  0x1eb4,0x0110,0x00f2,0x00f3,0x00f4,0x00f5,0x00f6,0x01A0,
  0x1ee5,0x00f9,0x00fA,0x1ee7,0x00fc,0x1ef6,0x1ebc,0x1ef3
};

unsigned short cp1256_uni_byte[128] = {
  0x20ac,0x067e,0x201a,0x0192, 0x201e,0x2026,0x2020,0x2021,
  0x02c6,0x2030,0x0679,0x2039, 0x0152,0x0686,0x0698,0x0688,
  0x06af,0x2018,0x2019,0x201c, 0x201d,0x2022,0x2013,0x2014,
  0x06a9,0x2122,0x0691,0x203a, 0x0153,0x200c,0x200d,0x06ba,
  0x00a0,0x060c,0x00a2,0x00a3, 0x00a4,0x00a5,0x00a6,0x00a7,
  0x00a8,0x00a9,0x06be,0x00ab, 0x00ac,0x00ad,0x00ae,0x00af,
  0x00b0,0x00b1,0x00b2,0x00b3, 0x00b4,0x00b5,0x00b6,0x00b7,
  0x00b8,0x00b9,0x061b,0x00bb, 0x00bc,0x00bd,0x00be,0x061f,

  0x06c1,0x0621,0x0622,0x0623, 0x0624,0x0625,0x0626,0x0627,
  0x0628,0x0629,0x062a,0x062b, 0x062c,0x062d,0x062e,0x062f,
  0x0630,0x0631,0x0632,0x0633, 0x0634,0x0635,0x0636,0x00d7,
  0x0637,0x0638,0x0639,0x063a, 0x0640,0x0641,0x0642,0x0643,
  0x00e0,0x0644,0x00e2,0x0645, 0x0646,0x0647,0x0648,0x00e7,
  0x00e8,0x00e9,0x00ea,0x00eb, 0x0649,0x064a,0x00ee,0x00ef,
  0x064b,0x064c,0x064d,0x064e, 0x00f4,0x064f,0x0650,0x00f7,
  0x0651,0x00f9,0x0652,0x00fb, 0x00fc,0x200e,0x200f,0x06d2
};

unsigned short cp1257_uni_byte[128] = {
  0x20ac,0x0000,0x201a,0x0000, 0x201e,0x2026,0x2020,0x2021,
  0x0000,0x2030,0x0000,0x2039, 0x0000,0x00a8,0x02c7,0x00b8,
  0x0000,0x2018,0x2019,0x201c, 0x201d,0x2022,0x2013,0x2014,
  0x0000,0x2122,0x0000,0x203a, 0x0000,0x00af,0x02db,0x0000,
  0x00a0,0x0000,0x00a2,0x00a3, 0x00a4,0x0000,0x00a6,0x00a7,
  0x00d8,0x00a9,0x0156,0x00ab, 0x00ac,0x00ad,0x00ae,0x00c6,
  0x00b0,0x00b1,0x00b2,0x00b3, 0x00b4,0x00b5,0x00b6,0x00b7,
  0x00f8,0x00b9,0x0157,0x00bb, 0x00bc,0x00bd,0x00be,0x00e6,

  0x0104,0x012e,0x0100,0x0106, 0x00c4,0x00c5,0x0118,0x0112,
  0x010c,0x00c9,0x0179,0x0116, 0x0122,0x0136,0x012a,0x013b,
  0x0160,0x0143,0x0145,0x00d3, 0x014c,0x00d5,0x00d6,0x00d7,
  0x0172,0x0141,0x015a,0x016a, 0x00dc,0x017b,0x017d,0x00df,
  0x0105,0x012f,0x0101,0x0107, 0x00e4,0x00e5,0x0119,0x0113,
  0x010d,0x00e9,0x017a,0x0117, 0x0123,0x0137,0x012b,0x013c,
  0x0161,0x0144,0x0146,0x00f3, 0x014d,0x00f5,0x00f6,0x00f7,
  0x0173,0x0142,0x015b,0x016b, 0x00fc,0x017c,0x017e,0x02d9
};

unsigned short iscii_as_uni_byte[128] = {
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0981,0x0982,0x0983, 0x0985,0x0986,0x0987,0x0988,
  0x0989,0x098a,0x098b,0x098e, 0x098f,0x0910,0x098d,0x0991,
  0x0993,0x0994,0x0991,0x0995, 0x0996,0x0997,0x0998,0x0999,
  0x099a,0x099b,0x099c,0x099d, 0x099e,0x099f,0x09a0,0x09a1,

  0x09a2,0x09a3,0x09a4,0x09a5, 0x09a6,0x09a7,0x09a8,0x09a9,
  0x09aa,0x09ab,0x09ac,0x09ad, 0x09ae,0x09af,0x09df,0x09f0,
  0x09b1,0x09b2,0x09b3,0x09b4, 0x09f1,0x09b6,0x09b7,0x09b8,
  0x09b9,0x200c,0x09be,0x09bf, 0x09c0,0x09c1,0x09c2,0x09c3,
  0x09c6,0x09c7,0x09c8,0x09c5, 0x09ca,0x09cb,0x09cc,0x09c9,
  0x09cd,0x09bc,0x09e4,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x09e6,0x09e7,0x09e8, 0x09e9,0x09ea,0x09eb,0x09ec,
  0x09ed,0x09ee,0x09ef,0x0000, 0x0000,0x0000,0x0000,0x0000
};

unsigned short iscii_be_uni_byte[128] = {
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0981,0x0982,0x0983, 0x0985,0x0986,0x0987,0x0988,
  0x0989,0x098a,0x098b,0x098e, 0x098f,0x0910,0x098d,0x0991,
  0x0993,0x0994,0x0991,0x0995, 0x0996,0x0997,0x0998,0x0999,
  0x099a,0x099b,0x099c,0x099d, 0x099e,0x099f,0x09a0,0x09a1,

  0x09a2,0x09a3,0x09a4,0x09a5, 0x09a6,0x09a7,0x09a8,0x09a9,
  0x09aa,0x09ab,0x09ac,0x09ad, 0x09ae,0x09af,0x09df,0x09b0,
  0x09b1,0x09b2,0x09b3,0x09b4, 0x09b5,0x09b6,0x09b7,0x09b8,
  0x09b9,0x200c,0x09be,0x09bf, 0x09c0,0x09c1,0x09c2,0x09c3,
  0x09c6,0x09c7,0x09c8,0x09c5, 0x09ca,0x09cb,0x09cc,0x09c9,
  0x09cd,0x09bc,0x09e4,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x09e6,0x09e7,0x09e8, 0x09e9,0x09ea,0x09eb,0x09ec,
  0x09ed,0x09ee,0x09ef,0x0000, 0x0000,0x0000,0x0000,0x0000
};

unsigned short iscii_de_uni_byte[128] = {
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0901,0x0902,0x0903, 0x0905,0x0906,0x0907,0x0908,
  0x0909,0x090a,0x090b,0x090e, 0x090f,0x0910,0x090d,0x0911,
  0x0913,0x0914,0x0911,0x0915, 0x0916,0x0917,0x0918,0x0919,
  0x091a,0x091b,0x091c,0x091d, 0x091e,0x091f,0x0920,0x0921,

  0x0922,0x0923,0x0924,0x0925, 0x0926,0x0927,0x0928,0x0929,
  0x092a,0x092b,0x092c,0x092d, 0x092e,0x092f,0x095f,0x0930,
  0x0931,0x0932,0x0933,0x0934, 0x0935,0x0936,0x0937,0x0938,
  0x0939,0x200c,0x093e,0x093f, 0x0940,0x0941,0x0942,0x0943,
  0x0946,0x0947,0x0948,0x0945, 0x094a,0x094b,0x094c,0x0949,
  0x094d,0x093c,0x0964,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0966,0x0967,0x0968, 0x0969,0x096a,0x096b,0x096c,
  0x096d,0x096e,0x096f,0x0000, 0x0000,0x0000,0x0000,0x0000
};

unsigned short iscii_gu_uni_byte[128] = {
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0981,0x0982,0x0983, 0x0985,0x0986,0x0987,0x0988,
  0x0989,0x098a,0x098b,0x098e, 0x098f,0x0910,0x098d,0x0991,
  0x0993,0x0994,0x0991,0x0995, 0x0996,0x0997,0x0998,0x0999,
  0x099a,0x099b,0x099c,0x099d, 0x099e,0x099f,0x09a0,0x09a1,

  0x09a2,0x09a3,0x09a4,0x09a5, 0x09a6,0x09a7,0x09a8,0x09a9,
  0x09aa,0x09ab,0x09ac,0x09ad, 0x09ae,0x09af,0x09df,0x09b0,
  0x09b1,0x09b2,0x09b3,0x09b4, 0x09b5,0x09b6,0x09b7,0x09b8,
  0x09b9,0x200c,0x09be,0x09bf, 0x09c0,0x09c1,0x09c2,0x09c3,
  0x09c6,0x09c7,0x09c8,0x09c5, 0x09ca,0x09cb,0x09cc,0x09c9,
  0x09cd,0x09bc,0x09e4,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x09e6,0x09e7,0x09e8, 0x09e9,0x09ea,0x09eb,0x09ec,
  0x09ed,0x09ee,0x09ef,0x0000, 0x0000,0x0000,0x0000,0x0000
};

unsigned short iscii_ka_uni_byte[128] = {
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0c81,0x0c82,0x0c83, 0x0c85,0x0c86,0x0c87,0x0c88,
  0x0c89,0x0c8a,0x0c8b,0x0c8e, 0x0c8f,0x0c10,0x0c8d,0x0c91,
  0x0c93,0x0c94,0x0c91,0x0c95, 0x0c96,0x0c97,0x0c98,0x0c99,
  0x0c9a,0x0c9b,0x0c9c,0x0c9d, 0x0c9e,0x0c9f,0x0ca0,0x0ca1,

  0x0ca2,0x0ca3,0x0ca4,0x0ca5, 0x0ca6,0x0ca7,0x0ca8,0x0ca9,
  0x0caa,0x0cab,0x0cac,0x0cad, 0x0cae,0x0caf,0x0cdf,0x0cb0,
  0x0cb1,0x0cb2,0x0cb3,0x0cb4, 0x0cb5,0x0cb6,0x0cb7,0x0cb8,
  0x0cb9,0x200c,0x0cbe,0x0cbf, 0x0cc0,0x0cc1,0x0cc2,0x0cc3,
  0x0cc6,0x0cc7,0x0cc8,0x0cc5, 0x0cca,0x0ccb,0x0ccc,0x0cc9,
  0x0ccd,0x0cbc,0x0ce4,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0ce6,0x0ce7,0x0ce8, 0x0ce9,0x0cea,0x0ceb,0x0cec,
  0x0ced,0x0cee,0x0cef,0x0000, 0x0000,0x0000,0x0000,0x0000
};

unsigned short iscii_ma_uni_byte[128] = {
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0d01,0x0d02,0x0d03, 0x0d05,0x0d06,0x0d07,0x0d08,
  0x0d09,0x0d0a,0x0d0b,0x0d0e, 0x0d0f,0x0d10,0x0d0d,0x0d11,
  0x0d13,0x0d14,0x0d11,0x0d15, 0x0d16,0x0d17,0x0d18,0x0d19,
  0x0d1a,0x0d1b,0x0d1c,0x0d1d, 0x0d1e,0x0d1f,0x0d20,0x0d21,

  0x0d22,0x0d23,0x0d24,0x0d25, 0x0d26,0x0d27,0x0d28,0x0d29,
  0x0d2a,0x0d2b,0x0d2c,0x0d2d, 0x0d2e,0x0d2f,0x0d5f,0x0d30,
  0x0d31,0x0d32,0x0d33,0x0d34, 0x0d35,0x0d36,0x0d37,0x0d38,
  0x0d39,0x200c,0x0d3e,0x0d3f, 0x0d40,0x0d41,0x0d42,0x0d43,
  0x0d46,0x0d47,0x0d48,0x0d45, 0x0d4a,0x0d4b,0x0d4c,0x0d49,
  0x0d4d,0x0d3c,0x0d64,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0d66,0x0d67,0x0d68, 0x0d69,0x0d6a,0x0d6b,0x0d6c,
  0x0d6d,0x0d6e,0x0d6f,0x0000, 0x0000,0x0000,0x0000,0x0000
};

unsigned short iscii_or_uni_byte[128] = {
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0b01,0x0b02,0x0b03, 0x0b05,0x0b06,0x0b07,0x0b08,
  0x0b09,0x0b0a,0x0b0b,0x0b0e, 0x0b0f,0x0b10,0x0b0d,0x0b11,
  0x0b13,0x0b14,0x0b11,0x0b15, 0x0b16,0x0b17,0x0b18,0x0b19,
  0x0b1a,0x0b1b,0x0b1c,0x0b1d, 0x0b1e,0x0b1f,0x0b20,0x0b21,

  0x0b22,0x0b23,0x0b24,0x0b25, 0x0b26,0x0b27,0x0b28,0x0b29,
  0x0b2a,0x0b2b,0x0b2c,0x0b2d, 0x0b2e,0x0b2f,0x0b5f,0x0b30,
  0x0b31,0x0b32,0x0b33,0x0b34, 0x0b35,0x0b36,0x0b37,0x0b38,
  0x0b39,0x200c,0x0b3e,0x0b3f, 0x0b40,0x0b41,0x0b42,0x0b43,
  0x0b46,0x0b47,0x0b48,0x0b45, 0x0b4a,0x0b4b,0x0b4c,0x0b49,
  0x0b4d,0x0b3c,0x0b64,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0b66,0x0b67,0x0b68, 0x0b69,0x0b6a,0x0b6b,0x0b6c,
  0x0b6d,0x0b6e,0x0b6f,0x0000, 0x0000,0x0000,0x0000,0x0000
};

unsigned short iscii_pa_uni_byte[128] = {
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0a01,0x0a02,0x0a03, 0x0a05,0x0a06,0x0a07,0x0a08,
  0x0a09,0x0a0a,0x0a0b,0x0a0e, 0x0a0f,0x0a10,0x0a0d,0x0a11,
  0x0a13,0x0a14,0x0a11,0x0a15, 0x0a16,0x0a17,0x0a18,0x0a19,
  0x0a1a,0x0a1b,0x0a1c,0x0a1d, 0x0a1e,0x0a1f,0x0a20,0x0a21,

  0x0a22,0x0a23,0x0a24,0x0a25, 0x0a26,0x0a27,0x0a28,0x0a29,
  0x0a2a,0x0a2b,0x0a2c,0x0a2d, 0x0a2e,0x0a2f,0x0a5f,0x0a30,
  0x0a31,0x0a32,0x0a33,0x0a34, 0x0a35,0x0a36,0x0a37,0x0a38,
  0x0a39,0x200c,0x0a3e,0x0a3f, 0x0a40,0x0a41,0x0a42,0x0a43,
  0x0a46,0x0a47,0x0a48,0x0a45, 0x0a4a,0x0a4b,0x0a4c,0x0a49,
  0x0a4d,0x0a3c,0x0a64,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0a66,0x0a67,0x0a68, 0x0a69,0x0a6a,0x0a6b,0x0a6c,
  0x0a6d,0x0a6e,0x0a6f,0x0000, 0x0000,0x0000,0x0000,0x0000
};

unsigned short iscii_ta_uni_byte[128] = {
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0b81,0x0b82,0x0b83, 0x0b85,0x0b86,0x0b87,0x0b88,
  0x0b89,0x0b8a,0x0b8b,0x0b8e, 0x0b8f,0x0b10,0x0b8d,0x0b91,
  0x0b93,0x0b94,0x0b91,0x0b95, 0x0b96,0x0b97,0x0b98,0x0b99,
  0x0b9a,0x0b9b,0x0b9c,0x0b9d, 0x0b9e,0x0b9f,0x0ba0,0x0ba1,

  0x0ba2,0x0ba3,0x0ba4,0x0ba5, 0x0ba6,0x0ba7,0x0ba8,0x0ba9,
  0x0baa,0x0bab,0x0bac,0x0bad, 0x0bae,0x0baf,0x0bdf,0x0bb0,
  0x0bb1,0x0bb2,0x0bb3,0x0bb4, 0x0bb5,0x0bb6,0x0bb7,0x0bb8,
  0x0bb9,0x200c,0x0bbe,0x0bbf, 0x0bc0,0x0bc1,0x0bc2,0x0bc3,
  0x0bc6,0x0bc7,0x0bc8,0x0bc5, 0x0bca,0x0bcb,0x0bcc,0x0bc9,
  0x0bcd,0x0bbc,0x0be4,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0be6,0x0be7,0x0be8, 0x0be9,0x0bea,0x0beb,0x0bec,
  0x0bed,0x0bee,0x0bef,0x0000, 0x0000,0x0000,0x0000,0x0000
};

unsigned short iscii_te_uni_byte[128] = {
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0c01,0x0c02,0x0c03, 0x0c05,0x0c06,0x0c07,0x0c08,
  0x0c09,0x0c0a,0x0c0b,0x0c0e, 0x0c0f,0x0c10,0x0c0d,0x0c11,
  0x0c13,0x0c14,0x0c11,0x0c15, 0x0c16,0x0c17,0x0c18,0x0c19,
  0x0c1a,0x0c1b,0x0c1c,0x0c1d, 0x0c1e,0x0c1f,0x0c20,0x0c21,

  0x0c22,0x0c23,0x0c24,0x0c25, 0x0c26,0x0c27,0x0c28,0x0c29,
  0x0c2a,0x0c2b,0x0c2c,0x0c2d, 0x0c2e,0x0c2f,0x0c5f,0x0c30,
  0x0c31,0x0c32,0x0c33,0x0c34, 0x0c35,0x0c36,0x0c37,0x0c38,
  0x0c39,0x200c,0x0c3e,0x0c3f, 0x0c40,0x0c41,0x0c42,0x0c43,
  0x0c46,0x0c47,0x0c48,0x0c45, 0x0c4a,0x0c4b,0x0c4c,0x0c49,
  0x0c4d,0x0c3c,0x0c64,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0c66,0x0c67,0x0c68, 0x0c69,0x0c6a,0x0c6b,0x0c6c,
  0x0c6d,0x0c6e,0x0c6f,0x0000, 0x0000,0x0000,0x0000,0x0000
};

unsigned short winsami2_uni_byte[128] = {
  0x20ac,0x0000,0x010c,0x0192, 0x010d,0x01b7,0x0292,0x01ee,
  0x01ef,0x0110,0x0160,0x2039, 0x0152,0x0000,0x0000,0x0000,
  0x0000,0x2018,0x2019,0x201c, 0x201d,0x2022,0x2013,0x2014,
  0x0111,0x01e6,0x0161,0x203a, 0x0153,0x0000,0x0000,0x0178,
  0x00a0,0x01e7,0x01e4,0x00a3, 0x00a4,0x01e5,0x00a6,0x00a7,
  0x00a8,0x00a9,0x021e,0x00ab, 0x00ac,0x00ad,0x00ae,0x021f,
  0x00b0,0x00b1,0x01e8,0x01e9, 0x00b4,0x00b5,0x00b6,0x00b7,
  0x014a,0x014b,0x0166,0x00bb, 0x0167,0x00bd,0x017d,0x017e,

  0x00c0,0x00c1,0x00c2,0x00c3, 0x00c4,0x00c5,0x00c6,0x00c7,
  0x00c8,0x00c9,0x00ca,0x00cb, 0x00cc,0x00cd,0x00ce,0x00cf,
  0x00d0,0x00d1,0x00d2,0x00d3, 0x00d4,0x00d5,0x00d6,0x00d7,
  0x00d8,0x00d9,0x00da,0x00db, 0x00dc,0x00dd,0x00de,0x00df,
  0x00e0,0x00e1,0x00e2,0x00e3, 0x00e4,0x00e5,0x00e6,0x00e7,
  0x00e8,0x00e9,0x00ea,0x00eb, 0x00ec,0x00ed,0x00ee,0x00ef,
  0x00f0,0x00f1,0x00f2,0x00f3, 0x00f4,0x00f5,0x00f6,0x00f7,
  0x00f8,0x00f9,0x00fa,0x00fb, 0x00fc,0x00fd,0x00fe,0x00ff
};

unsigned short kz1048_uni_byte[128] = {
  0x0402,0x0403,0x201a,0x0453, 0x201e,0x2026,0x2020,0x2021,
  0x20ac,0x2030,0x0409,0x2039, 0x040a,0x049a,0x04ba,0x040f,
  0x0452,0x2018,0x2019,0x201c, 0x201d,0x2022,0x2013,0x2014,
  0x0000,0x2122,0x0459,0x203a, 0x045a,0x049b,0x04bb,0x045f,
  0x00a0,0x04b0,0x04b1,0x04d8, 0x00a4,0x04e8,0x00a6,0x00a7,
  0x0401,0x00a9,0x0492,0x00ab, 0x00ac,0x00ad,0x00ae,0x04ae,
  0x00b0,0x00b1,0x0406,0x0456, 0x04e9,0x00b5,0x00b6,0x00b7,
  0x0451,0x2116,0x0493,0x00bb, 0x04d9,0x04a2,0x04a3,0x04af,

  0x0410,0x0411,0x0412,0x0413, 0x0414,0x0415,0x0416,0x0417,
  0x0418,0x0419,0x041a,0x041b, 0x041c,0x041d,0x041e,0x041f,
  0x0420,0x0421,0x0422,0x0423, 0x0424,0x0425,0x0426,0x0427,
  0x0428,0x0429,0x042a,0x042b, 0x042c,0x042d,0x042e,0x042f,
  0x0430,0x0431,0x0432,0x0433, 0x0434,0x0435,0x0436,0x0437,
  0x0438,0x0439,0x043a,0x043b, 0x043c,0x043d,0x043e,0x043f,
  0x0440,0x0441,0x0442,0x0443, 0x0444,0x0445,0x0446,0x0447,
  0x0448,0x0449,0x044a,0x044b, 0x044c,0x044d,0x044e,0x044f
};

unsigned short iso11548_uni_byte[256] = {
  0x2800,0x2801,0x2802,0x2803,0x2804,0x2805,0x2806,0x2807,
  0x2808,0x2809,0x280a,0x280b,0x280c,0x280d,0x280e,0x280f,
  0x2810,0x2811,0x2812,0x2813,0x2814,0x2815,0x2816,0x2817,
  0x2818,0x2819,0x281a,0x281b,0x281c,0x281d,0x281e,0x281f,
  0x2820,0x2821,0x2822,0x2823,0x2824,0x2825,0x2826,0x2827,
  0x2828,0x2829,0x282a,0x282b,0x282c,0x282d,0x282e,0x282f,
  0x2830,0x2831,0x2832,0x2833,0x2834,0x2835,0x2836,0x2837,
  0x2838,0x2839,0x283a,0x283b,0x283c,0x283d,0x283e,0x283f,
  0x2840,0x2841,0x2842,0x2843,0x2844,0x2845,0x2846,0x2847,
  0x2848,0x2849,0x284a,0x284b,0x284c,0x284d,0x284e,0x284f,
  0x2850,0x2851,0x2852,0x2853,0x2854,0x2855,0x2856,0x2857,
  0x2858,0x2859,0x285a,0x285b,0x285c,0x285d,0x285e,0x285f,
  0x2860,0x2861,0x2862,0x2863,0x2864,0x2865,0x2866,0x2867,
  0x2868,0x2869,0x286a,0x286b,0x286c,0x286d,0x286e,0x286f,
  0x2870,0x2871,0x2872,0x2873,0x2874,0x2875,0x2876,0x2877,
  0x2878,0x2879,0x287a,0x287b,0x287c,0x287d,0x287e,0x287f,
  0x2880,0x2881,0x2882,0x2883,0x2884,0x2885,0x2886,0x2887,
  0x2888,0x2889,0x288a,0x288b,0x288c,0x288d,0x288e,0x288f,
  0x2890,0x2891,0x2892,0x2893,0x2894,0x2895,0x2896,0x2897,
  0x2898,0x2899,0x289a,0x289b,0x289c,0x289d,0x289e,0x289f,
  0x28a0,0x28a1,0x28a2,0x28a3,0x28a4,0x28a5,0x28a6,0x28a7,
  0x28a8,0x28a9,0x28aa,0x28ab,0x28ac,0x28ad,0x28ae,0x28af,
  0x28b0,0x28b1,0x28b2,0x28b3,0x28b4,0x28b5,0x28b6,0x28b7,
  0x28b8,0x28b9,0x28ba,0x28bb,0x28bc,0x28bd,0x28be,0x28bf,
  0x28c0,0x28c1,0x28c2,0x28c3,0x28c4,0x28c5,0x28c6,0x28c7,
  0x28c8,0x28c9,0x28ca,0x28cb,0x28cc,0x28cd,0x28ce,0x28cf,
  0x28d0,0x28d1,0x28d2,0x28d3,0x28d4,0x28d5,0x28d6,0x28d7,
  0x28d8,0x28d9,0x28da,0x28db,0x28dc,0x28dd,0x28de,0x28df,
  0x28e0,0x28e1,0x28e2,0x28e3,0x28e4,0x28e5,0x28e6,0x28e7,
  0x28e8,0x28e9,0x28ea,0x28eb,0x28ec,0x28ed,0x28ee,0x28ef,
  0x28f0,0x28f1,0x28f2,0x28f3,0x28f4,0x28f5,0x28f6,0x28f7,
  0x28f8,0x28f9,0x28fa,0x28fb,0x28fc,0x28fd,0x28fe,0x28ff
};

unsigned short brf_uni_byte[128] = {
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x2800,0x282e,0x2810,0x283c, 0x282b,0x2829,0x282f,0x2804,
  0x2837,0x283e,0x2821,0x282c, 0x2820,0x2824,0x2828,0x280c,
  0x2834,0x2802,0x2806,0x2812, 0x2832,0x2822,0x2816,0x2836,
  0x2826,0x2814,0x2831,0x2830, 0x2823,0x283f,0x281c,0x2839,

  0x2808,0x2801,0x2803,0x2809, 0x2819,0x2811,0x280b,0x281b,
  0x2813,0x280a,0x281a,0x2805, 0x2807,0x280d,0x281d,0x2815,
  0x280f,0x281f,0x2817,0x280e, 0x281e,0x2825,0x2827,0x283a,
  0x282d,0x283d,0x2835,0x282a, 0x2833,0x283b,0x2818,0x2838,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000
};

/* VISCII is standard support */
unsigned short viscii_uni_byte[128] = {
  0x0000,0x0001,0x1eb2,0x0003,0x0004,0x1eb4,0x1eaa,0x0007,
  0x0008,0x0009,0x000a,0x000b,0x000c,0x000d,0x000e,0x000f,
  0x0010,0x0011,0x0012,0x0013,0x1ef6,0x0015,0x0016,0x0017,
  0x0018,0x1ef8,0x001a,0x001b,0x001c,0x001d,0x1ef4,0x001f,
  0x0020,0x0021,0x0022,0x0023,0x0024,0x0025,0x0026,0x0027,
  0x0028,0x0029,0x002a,0x002b,0x002c,0x002d,0x002e,0x002f,
  0x0030,0x0031,0x0032,0x0033,0x0034,0x0035,0x0036,0x0037,
  0x0038,0x0039,0x003a,0x003b,0x003c,0x003d,0x003e,0x003f,
  0x0040,0x0041,0x0042,0x0043,0x0044,0x0045,0x0046,0x0047,
  0x0048,0x0049,0x004a,0x004b,0x004c,0x004d,0x004e,0x004f,
  0x0050,0x0051,0x0052,0x0053,0x0054,0x0055,0x0056,0x0057,
  0x0058,0x0059,0x005a,0x005b,0x005c,0x005d,0x005e,0x005f,
  0x0060,0x0061,0x0062,0x0063,0x0064,0x0065,0x0066,0x0067,
  0x0068,0x0069,0x006a,0x006b,0x006c,0x006d,0x006e,0x006f,
  0x0070,0x0071,0x0072,0x0073,0x0074,0x0075,0x0076,0x0077,
  0x0078,0x0079,0x007a,0x007b,0x007c,0x007d,0x007e,0x007f
};

unsigned short visciir_uni_byte[128] = { /* RFC1456	*/
  0x1ea0,0x1eae,0x1eb0,0x1eb6,0x1ea4,0x1ea6,0x1ea8,0x1eac,
  0x1ebc,0x1eb8,0x1ebe,0x1ec0,0x1ec2,0x1ec4,0x1ec6,0x1ed0,
  0x1ed2,0x1ed4,0x1ed6,0x1ed8,0x1ee2,0x1eda,0x1edc,0x1ede,
  0x1eca,0x1ece,0x1ecc,0x1ec8,0x1ee6,0x0168,0x1ee4,0x1ef2,

  0x00d5,0x1eaf,0x1eb1,0x1eb7,0x1ea5,0x1ea7,0x1ea9,0x1ead,
  0x1ebd,0x1eb9,0x1ebf,0x1ec1,0x1ec3,0x1ec5,0x1ec7,0x1ed1,
  0x1ed3,0x1ed5,0x1ed7,0x1ee0,0x01a0,0x1ed9,0x1edd,0x1edf,
  0x1ecb,0x1ef0,0x1ee8,0x1eea,0x1eec,0x01a1,0x1edb,0x01af,

  0x00c0,0x00c1,0x00c2,0x00c3,0x1ea2,0x0102,0x1eb3,0x1eb5,
  0x00c8,0x00c9,0x00ca,0x1eba,0x00cc,0x00cd,0x0128,0x1ef3,
  0x0110,0x1ee9,0x00d2,0x00d3,0x00d4,0x1ea1,0x1ef7,0x1eeb,
  0x1eed,0x00d9,0x00da,0x1ef9,0x1ef5,0x00dd,0x1ee1,0x01b0,

  0x00e0,0x00e1,0x00e2,0x00e3,0x1ea3,0x0103,0x1eef,0x1eab,
  0x00e8,0x00e9,0x00ea,0x1ebb,0x00ec,0x00ed,0x0129,0x1ec9,
  0x0111,0x1ef1,0x00f2,0x00f3,0x00f4,0x00f5,0x1ecf,0x1ecd,
  0x1ee5,0x00f9,0x00fa,0x0169,0x1ee7,0x00fd,0x1ee3,0x1eee
};

unsigned short cp1258_uni_byte[128] = { /* MS Vietnamese */
  0x20ac,0x0081,0x201a,0x0192,0x201e,0x2026,0x2020,0x2021,
  0x02c6,0x2030,0x008a,0x2039,0x0152,0x008d,0x008e,0x008f,
  0x0090,0x2018,0x2019,0x201c,0x201d,0x2022,0x2013,0x2014,
  0x02dc,0x2122,0x009a,0x203a,0x0153,0x009d,0x009e,0x0178,

  0x00a0,0x00a1,0x00a2,0x00a3,0x00a4,0x00a5,0x00a6,0x00a7,
  0x00a8,0x00a9,0x00aa,0x00ab,0x00ac,0x00ad,0x00ae,0x00af,
  0x00b0,0x00b1,0x00b2,0x00b3,0x00b4,0x00b5,0x00b6,0x00b7,
  0x00b8,0x00b9,0x00ba,0x00bb,0x00bc,0x00bd,0x00be,0x00bf,

  0x00c0,0x00c1,0x00c2,0x0102,0x00c4,0x00c5,0x00c6,0x00c7,
  0x00c8,0x00c9,0x00ca,0x00cb,0x0300,0x00cd,0x00ce,0x00cf,
  0x0110,0x00d1,0x0309,0x00d3,0x00d4,0x01a0,0x00d6,0x00d7,
  0x00d8,0x00d9,0x00da,0x00db,0x00dc,0x01af,0x0303,0x00df,

  0x00e0,0x00e1,0x00e2,0x0103,0x00e4,0x00e5,0x00e6,0x00e7,
  0x00e8,0x00e9,0x00ea,0x00eb,0x0301,0x00ed,0x00ee,0x00ef,
  0x0111,0x00f1,0x0323,0x00f3,0x00f4,0x01a1,0x00f6,0x00f7,
  0x00f8,0x00f9,0x00fa,0x00fb,0x00fc,0x01b0,0x20ab,0x00ff
};

unsigned short vni_uni_byte[192] = { /* VNI Vietnamese */
  /* 0x80 - 0xff */
  0x1ea0,0x1eae,0x1eb0,0x1eb6,0x1ea4,0x1ea6,0x1ea8,0x1eac,
  0x1ebc,0x1eb8,0x1ebe,0x1ec0,0x1ec2,0x1ec4,0x1ec6,0x1ed0,
  0x1ed2,0x1ed4,0x1ed6,0x1ed8,0x1ee2,0x1eda,0x1edc,0x1ede,
  0x1eca,0x1ece,0x1ecc,0x1ec8,0x1ee6,0x0168,0x1ee4,0x1ef2,

  0x00d5,0x1eaf,0x1eb1,0x1eb7,0x1ea5,0x1ea7,0x1ea9,0x1ead,
  0x1ebd,0x1eb9,0x1ebf,0x1ec1,0x1ec3,0x1ec5,0x1ec7,0x1ed1,
  0x1ed3,0x1ed5,0x1ed7,0x1ee0,0x01a0,0x1ed9,0x1edd,0x1edf,
  0x1ecb,0x1ef0,0x1ee8,0x1eea,0x1eec,0x01a1,0x1edb,0x01af,

  0x00c0,0x00c1,0x00c2,0x00c3,0x1ea2,0x0102,0x1ec8,0x1eb5,
  0x00c8,0x00c9,0x00ca,0x1eba,0x00cc,0x00cd,0x1ef4,0x1ef3,
  0x0110,0x0110,0x1eca,0x0128,0x0000,0x1ea1,0x0000,0x1eeb,
  0x1eed,0x00d9,0x00da,0x1ef9,0x1ef5,0x00dd,0x1ee1,0x01b0,

  0x00e0,0x00e1,0x00e2,0x00e3,0x1ea3,0x0103,0x1ec9,0x1eab,
  0x00e8,0x00e9,0x00ea,0x1ebb,0x00ec,0x00ed,0x1ef5,0x1ec9,
  0x0111,0x0111,0x1ecb,0x0129,0x0000,0x00f5,0x0000,0x1ecd,
  0x1ee5,0x00f9,0x00fa,0x0169,0x1ee7,0x00fd,0x1ee3,0x1ef5,

  /* offset 0xc0 - 0xff	 */
  0x0001,0x0002,0x0003,0x0004, 0x0005,0x0006,0x0000,0x0000,
  0x0007,0x0008,0x0009,0x000a, 0x0000,0x0000,0x0000,0x000b,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x000c,0x0000,0x0000,
  0x000d,0x000e,0x000f,0x0010, 0x0011,0x0000,0x0000,0x0000,

  0x0001,0x0002,0x0003,0x0004, 0x0005,0x0006,0x0000,0x0000,
  0x0007,0x0008,0x0009,0x000a, 0x0000,0x0000,0x0000,0x000b,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x000c,0x0000,0x0000,
  0x000d,0x000e,0x000f,0x0010, 0x0011,0x0000,0x0000,0x0000
};

unsigned short vni_expat_uni_byte[238] = {
  0x1ea6,0x1ea4,0x00c2,0x1eaa, 0x1eac,0x1ea8,0x1eb0,0x1eae,
  0x0102,0x1eb6,0x1ea0,0x00c3, 0x00c0,0x00c1,0x1eb2,0x1ea2,0x1eb4,
  0x1ec0,0x1ebe,0x00ca,0x1ec4, 0x1ec6,0x1ec2,0x0000,0x0000,
  0x0000,0x0000,0x1eb8,0x1ebc, 0x00c8,0x00c9,0x0000,0x1eba,0x0000,
  0x1ed2,0x1ed0,0x00d4,0x1ed6, 0x1ed8,0x1ed4,0x0000,0x0000,
  0x0000,0x0000,0x1ecc,0x00d5, 0x00d2,0x00d3,0x0000,0x1ece,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x1ee4,0x0168, 0x00d9,0x00da,0x0000,0x1ee6,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x1ef4,0x1ef8, 0x1ef2,0x00dd,0x0000,0x1ef6,0x0000,
  0x1ea7,0x1ea5,0x00e2,0x1eab, 0x1ead,0x1ea9,0x1eb1,0x1eaf,
  0x0103,0x1eb7,0x1ea1,0x00e3, 0x00e0,0x00e1,0x1eb3,0x1ea3,0x1eb5,
  0x1ec1,0x1ebf,0x00ea,0x1ec5, 0x1ec7,0x1ec3,0x0000,0x0000,
  0x0000,0x0000,0x1eb9,0x1ebd, 0x00e8,0x00e9,0x0000,0x1ebb,0x0000,
  0x1ed3,0x1ed1,0x00f4,0x1ed7, 0x1ed9,0x1ed5,0x0000,0x0000,
  0x0000,0x0000,0x1ecd,0x00f5, 0x00f2,0x00f3,0x0000,0x1ecf,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x1ee5,0x0169, 0x00f9,0x00fa,0x0000,0x1ee7,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x1ed5,0x1ef9, 0x1ef3,0x00fd,0x0000,0x1ef7,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x1ee2,0x1ee0, 0x1edc,0x1eda,0x0000,0x1ede,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x1ef0,0x1eee, 0x1eea,0x1ee8,0x0000,0x1eec,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x1ee3,0x1ee1, 0x1edd,0x1edb,0x0000,0x1edf,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x1ef1,0x1eef, 0x1eeb,0x1ee9,0x0000,0x1eed,0x0000
};

unsigned short visciiq_uni_byte[146] = { /* VIQR map	 */
/* base controls */
  0x0041,0x0061,0x0102,0x0103, 0x00c2,0x00e2,0x0045,0x0065,
  0x00ca,0x00ea,0x0049,0x0069, 0x004f,0x006f,0x00d4,0x00f4,
  0x01a0,0x01a1,0x0055,0x0075, 0x01af,0x01b0,0x0059,0x0079,

  0x00c0,0x00e0,0x1eb0,0x1eb1, 0x1ea6,0x1ea7,0x00c8,0x00e8,
  0x1ec0,0x1ec1,0x00cc,0x00ec, 0x00d2,0x00f2,0x1ed2,0x1ed3,
  0x1edc,0x1edd,0x00d9,0x00f9, 0x1eea,0x1eeb,0x1ef2,0x1ef3,

  0x1ea2,0x1ea3,0x1eb2,0x1eb3, 0x1ea8,0x1ea9,0x1eba,0x1ebb,
  0x1ec2,0x1ec3,0x1ec8,0x1ec9, 0x1ece,0x1ecf,0x1ed4,0x1ed5,
  0x1ede,0x1edf,0x1ee6,0x1ee7, 0x1eec,0x1eed,0x1ef6,0x1ef7,

  0x00c3,0x00e3,0x1eb4,0x1eb5, 0x1eaa,0x1eab,0x1ebc,0x1ebd,
  0x1ec4,0x1ec5,0x0128,0x0129, 0x00d5,0x00f5,0x1ed6,0x1ed7,
  0x1ee0,0x1ee1,0x0168,0x0169, 0x1eee,0x1eef,0x1ef8,0x1ef9,

  0x00c1,0x00e1,0x1eae,0x1eaf, 0x1ea4,0x1ea5,0x00c9,0x00e9,
  0x1ebe,0x1ebf,0x00cd,0x00ed, 0x00d3,0x00f3,0x1ed0,0x1ed1,
  0x1eda,0x1edb,0x00da,0x00fa, 0x1ee8,0x1ee9,0x00dd,0x00fd,

  0x1ea0,0x1ea1,0x1eb6,0x1eb7, 0x1eac,0x1ead,0x1eb8,0x1eb9,
  0x1ec6,0x1ec7,0x1eca,0x1ecb, 0x1ecc,0x1ecd,0x1ed8,0x1ed9,
  0x1ee2,0x1ee3,0x1ee4,0x1ee5, 0x1ef0,0x1ef1,0x1ef4,0x1ef5,

/* D */
  0x0110,0x0111
};

/* Braille 6-dot kana part	*/
/* Note: several non-assigned shift is defined
  U+2808:	you-on single shift
  U+2818:	small-kana single shift/You-dakuon single shift
  U+ff96:	yo/Small shift/Small lock shift
  U+ff9f/2820:	handakuon/Capital shift/Capital lock shift
  U+2828:	you-handakuon single shift/Italic

  U+ff64:	alphabet single shift/kuten
  U+2824:	corner-bracket/tilde (2 char)
  U+2834:	close alphabet shift
  U+ff9d/2826:	'n/open alphabet shift
  U+2836:	bracket
  U+2838:	shi-gyou shift
  U+283c:	number shift
  ---------------------------------------------------------------
  0x00-0x3f:		kana part
  0x40-0x7f:		digit part
  0x80-0xbf:		alphabet part
*/
unsigned short braille6_kana_uni_byte[256] = {
  0x0020,0xff71,0xff6f,0xff72, 0xff9c,0xff85,0x30f0,0xff86,
  0x2808,0xff73,0xff75,0xff74, 0xff94,0xff87,0xff89,0xff88,
  0xff9e,0xff97,0xff70,0xff98, 0xff66,0xff80,0x0021,0xff81,
  0x2818,0xff99,0xff9b,0xff9a, 0xff96,0xff82,0xff84,0xff83,

  0xff9f,0xff76,0x003f,0xff77, 0x2824,0xff8a,0x2826,0xff8b,
  0x2828,0xff78,0xff7a,0xff79, 0xff95,0xff8c,0xff8e,0xff8d,
  0xff64,0xff7b,0xff61,0xff7c, 0xff9d,0xff8f,0x2836,0xff90,
  0x2838,0xff7d,0xff7f,0xff7e, 0x283c,0xff91,0xff93,0xff92,

  0x0020,0x0031,0x002e,0x0032, 0x002c,0x0000,0x0000,0x0000,
  0x0000,0x0033,0x0039,0x0036, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0035,0x0000,0x0038, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0034,0x0030,0x0037, 0x0000,0x0000,0x0000,0x0000,

  0x0000,0x0000,0x0000,0x0000, 0x002d,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x283c,0x0000,0x0000,0x0000,

  0x0020,0x0061,0x002c,0x0062, 0x0027,0x006b,0x003b,0x006c,
  0x0060,0x0063,0x0069,0x0066, 0x003f,0x006d,0x0073,0x0070,
  0x0000,0x0065,0x003a,0x0068, 0x0000,0x006f,0x0021,0x0072,
  0x2818,0x0064,0x006a,0x0067, 0x0000,0x006e,0x0074,0x0071,

  0x2820,0x002a,0x0000,0x0000, 0x002d,0x0075,0x003f,0x0076,
  0x2828,0x0023,0x0000,0x0000, 0x0000,0x0078,0x0000,0x0026,
  0x2830,0x0000,0x002e,0x0000, 0x2834,0x007a,0x0000,0x0000,
  0x0000,0x0000,0x0077,0x0000, 0x283c,0x0079,0x0000,0x0000,

  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,

  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000
};

/* PHONE glyph is standard support */
unsigned short vodafone_p1_uni_byte[128] = {
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0xe001,0xe002,0xe003, 0xe004,0xe005,0xe006,0xe007,
  0xe008,0xe009,0xe00a,0xe00b, 0xe00c,0xe00d,0xe00e,0xe00f,
  0xe010,0xe011,0xe012,0xe013, 0xe014,0xe015,0xe016,0xe017,
  0xe018,0xe019,0xe01a,0xe01b, 0xe01c,0xe01d,0xe01e,0xe01f,
  0xe020,0xe021,0xe022,0xe023, 0xe024,0xe025,0xe026,0xe027,
  0xe028,0xe029,0xe02a,0xe02b, 0xe02c,0xe02d,0xe02e,0xe02f,
  0xe030,0xe031,0xe032,0xe033, 0xe034,0xe035,0xe036,0xe037,
  0xe038,0xe039,0xe03a,0xe03b, 0xe03c,0xe03d,0xe03e,0xe03f,
  0xe040,0xe041,0xe042,0xe043, 0xe044,0xe045,0xe046,0xe047,
  0xe048,0xe049,0xe04a,0xe04b, 0xe04c,0xe04d,0xe04e,0xe04f,
  0xe050,0xe051,0xe052,0xe053, 0xe054,0xe055,0xe056,0xe057,
  0xe058,0xe059,0xe05a,0x0000, 0x0000,0x0000,0x0000,0x0000
};  

unsigned short vodafone_p2_uni_byte[128] = {
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0xe101,0xe102,0xe103, 0xe104,0xe105,0xe106,0xe107,
  0xe108,0xe109,0xe10a,0xe10b, 0xe10c,0xe10d,0xe10e,0xe10f,
  0xe110,0xe111,0xe112,0xe113, 0xe114,0xe115,0xe116,0xe117,
  0xe118,0xe119,0xe11a,0xe11b, 0xe11c,0xe11d,0xe11e,0xe11f,
  0xe120,0xe121,0xe122,0xe123, 0xe124,0xe125,0xe126,0xe127,
  0xe128,0xe129,0xe12a,0xe12b, 0xe12c,0xe12d,0xe12e,0xe12f,
  0xe130,0xe131,0xe132,0xe133, 0xe134,0xe135,0xe136,0xe137,
  0xe138,0xe139,0xe13a,0xe13b, 0xe13c,0xe13d,0xe13e,0xe13f,
  0xe140,0xe141,0xe142,0xe143, 0xe144,0xe145,0xe146,0xe147,
  0xe148,0xe149,0xe14a,0xe14b, 0xe14c,0xe14d,0xe14e,0xe14f,
  0xe150,0xe151,0xe152,0xe153, 0xe154,0xe155,0xe156,0xe157,
  0xe158,0xe159,0xe15a,0x0000, 0x0000,0x0000,0x0000,0x0000
};  

unsigned short vodafone_p3_uni_byte[128] = {
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0xe201,0xe202,0xe203, 0xe204,0xe205,0xe206,0xe207,
  0xe208,0xe209,0xe20a,0xe20b, 0xe20c,0xe20d,0xe20e,0xe20f,
  0xe210,0xe211,0xe212,0xe213, 0xe214,0xe215,0xe216,0xe217,
  0xe218,0xe219,0xe21a,0xe21b, 0xe21c,0xe21d,0xe21e,0xe21f,
  0xe220,0xe221,0xe222,0xe223, 0xe224,0xe225,0xe226,0xe227,
  0xe228,0xe229,0xe22a,0xe22b, 0xe22c,0xe22d,0xe22e,0xe22f,
  0xe230,0xe231,0xe232,0xe233, 0xe234,0xe235,0xe236,0xe237,
  0xe238,0xe239,0xe23a,0xe23b, 0xe23c,0xe23d,0xe23e,0xe23f,
  0xe240,0xe241,0xe242,0xe243, 0xe244,0xe245,0xe246,0xe247,
  0xe248,0xe249,0xe24a,0xe24b, 0xe24c,0xe24d,0xe24e,0xe24f,
  0xe250,0xe251,0xe252,0xe253, 0xe254,0xe255,0xe256,0xe257,
  0xe258,0xe259,0xe25a,0x0000, 0x0000,0x0000,0x0000,0x0000
};  

unsigned short vodafone_p4_uni_byte[128] = {
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0xe301,0xe302,0xe303, 0xe304,0xe305,0xe306,0xe307,
  0xe308,0xe309,0xe30a,0xe30b, 0xe30c,0xe30d,0xe30e,0xe30f,
  0xe310,0xe311,0xe312,0xe313, 0xe314,0xe315,0xe316,0xe317,
  0xe318,0xe319,0xe31a,0xe31b, 0xe31c,0xe31d,0xe31e,0xe31f,
  0xe320,0xe321,0xe322,0xe323, 0xe324,0xe325,0xe326,0xe327,
  0xe328,0xe329,0xe32a,0xe32b, 0xe32c,0xe32d,0xe32e,0xe32f,
  0xe330,0xe331,0xe332,0xe333, 0xe334,0xe335,0xe336,0xe337,
  0xe338,0xe339,0xe33a,0xe33b, 0xe33c,0xe33d,0xe33e,0xe33f,
  0xe340,0xe341,0xe342,0xe343, 0xe344,0xe345,0xe346,0xe347,
  0xe348,0xe349,0xe34a,0xe34b, 0xe34c,0xe34d,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000
};  

unsigned short vodafone_p5_uni_byte[128] = {
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0xe401,0xe402,0xe403, 0xe404,0xe405,0xe406,0xe407,
  0xe408,0xe409,0xe40a,0xe40b, 0xe40c,0xe40d,0xe40e,0xe40f,
  0xe410,0xe411,0xe412,0xe413, 0xe414,0xe415,0xe416,0xe417,
  0xe418,0xe419,0xe41a,0xe41b, 0xe41c,0xe41d,0xe41e,0xe41f,
  0xe420,0xe421,0xe422,0xe423, 0xe424,0xe425,0xe426,0xe427,
  0xe428,0xe429,0xe42a,0xe42b, 0xe42c,0xe42d,0xe42e,0xe42f,
  0xe430,0xe431,0xe432,0xe433, 0xe434,0xe435,0xe436,0xe437,
  0xe438,0xe439,0xe43a,0xe43b, 0xe43c,0xe43d,0xe43e,0xe43f,
  0xe440,0xe441,0xe442,0xe443, 0xe444,0xe445,0xe446,0xe447,
  0xe448,0xe449,0xe44a,0xe44b, 0xe44c,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000
};  

unsigned short vodafone_p6_uni_byte[128] = {
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0xe501,0xe502,0xe503, 0xe504,0xe505,0xe506,0xe507,
  0xe508,0xe509,0xe50a,0xe50b, 0xe50c,0xe50d,0xe50e,0xe50f,
  0xe510,0xe511,0xe512,0xe513, 0xe514,0xe515,0xe516,0xe517,
  0xe518,0xe519,0xe51a,0xe51b, 0xe51c,0xe51d,0xe51e,0xe51f,
  0xe520,0xe521,0xe522,0xe523, 0xe524,0xe525,0xe526,0xe527,
  0xe528,0xe529,0xe52a,0xe52b, 0xe52c,0xe52d,0xe52e,0xe52f,
  0xe530,0xe531,0xe532,0xe533, 0xe534,0xe535,0xe536,0xe537,
  0xe538,0xe539,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000
};  

unsigned short hproman8_uni_byte[128] = {
  0x0080,0x0081,0x0082,0x0083,0x0084,0x0085,0x0086,0x0087,
  0x0088,0x0089,0x008a,0x008b,0x008c,0x008d,0x0000,0x0000,
  0x0090,0x0091,0x0092,0x0093,0x0094,0x0095,0x0096,0x0097,
  0x0098,0x0099,0x009a,0x009b,0x009c,0x009d,0x009e,0x009f,
  0x00a0,0x00c0,0x00c2,0x00c8,0x00ca,0x00cb,0x00ce,0x00cf,
  0x00b4,0x0300,0x0302,0x00a8,0x0303,0x00d9,0x00db,0x20a4,
  0x00af,0x00dd,0x00fd,0x00b0,0x00c7,0x00e7,0x00d1,0x00f1,
  0x00a1,0x00bf,0x00a4,0x00a3,0x00a5,0x00a7,0x0192,0x00a2,

  0x00e2,0x00ea,0x00f4,0x00fb,0x00e1,0x00e9,0x00f3,0x00fa,
  0x00e0,0x00e8,0x00f2,0x00f9,0x00e4,0x00eb,0x00f6,0x00fc,
  0x00c5,0x00ee,0x00d8,0x00c6,0x00e5,0x00ed,0x00f8,0x00e6,
  0x00c4,0x00ec,0x00d6,0x00dc,0x00c9,0x00ef,0x00df,0x00d4,
  0x00c1,0x00c3,0x00e3,0x00d0,0x00f0,0x00cd,0x00cc,0x00d3,
  0x00d2,0x00d5,0x00f5,0x0160,0x0161,0x00da,0x0178,0x00ff,
  0x00de,0x00fe,0x00b7,0x03bc,0x00b6,0x00be,0x00ad,0x00bc,
  0x00bd,0x00aa,0x00ba,0x00ab,0x2588,0x00bb,0x00b1,0x0000
};

unsigned short koi8ru_uni_byte[128] = {
  0x2500,0x2502,0x250c,0x2510,0x2514,0x2518,0x251c,0x2524,
  0x252c,0x2534,0x253c,0x2580,0x2584,0x2588,0x258c,0x2590,
  0x2591,0x2592,0x2593,0x201c,0x25a0,0x2219,0x201d,0x2015,
  0x2116,0x2122,0x00a0,0x00ab,0x00ae,0x00bb,0x00b7,0x00a4,
  0x2550,0x2551,0x2552,0x0451,0x0454,0x2554,0x0456,0x0457,
  0x2557,0x2558,0x2559,0x255a,0x255b,0x0491,0x045e,0x255e,
  0x255f,0x2560,0x2561,0x0401,0x0404,0x2563,0x0406,0x0407,
  0x2566,0x2567,0x2568,0x2569,0x256a,0x0492,0x040e,0x00a9,
  0x044e,0x0430,0x0431,0x0446,0x0434,0x0435,0x0444,0x0433,
  0x0445,0x0438,0x0439,0x043a,0x043b,0x043c,0x043d,0x043e,
  0x043f,0x044f,0x0440,0x0441,0x0442,0x0443,0x0436,0x0432,
  0x044c,0x044b,0x0437,0x0448,0x044d,0x0449,0x0447,0x044a,
  0x042e,0x0410,0x0411,0x0426,0x0414,0x0415,0x0424,0x0413,
  0x0425,0x0418,0x0419,0x041a,0x041b,0x041c,0x041d,0x041e,
  0x041f,0x042f,0x0420,0x0421,0x0422,0x0423,0x0416,0x0412,
  0x042c,0x042b,0x0417,0x0428,0x042d,0x0429,0x0427,0x042a
};

unsigned short cp922_uni_byte[128] = {
  0x0080,0x0081,0x0082,0x0083,0x0084,0x0085,0x0086,0x0087,
  0x0088,0x0089,0x008a,0x008b,0x008c,0x008d,0x008e,0x008f,
  0x0090,0x0091,0x0092,0x0093,0x0094,0x0095,0x0096,0x0097,
  0x0098,0x0099,0x009a,0x009b,0x009c,0x009d,0x009e,0x009f,
  0x00a0,0x00a1,0x00a2,0x00a3,0x00a4,0x00a5,0x00a6,0x00a7,
  0x00a8,0x00a9,0x00aa,0x00ab,0x00ac,0x00ad,0x00ae,0x00af,
  0x00b0,0x00b1,0x00b2,0x00b3,0x00b4,0x00b5,0x00b6,0x00b7,
  0x00b8,0x00b9,0x00ba,0x00bb,0x00bc,0x00bd,0x00be,0x00bf,
  0x00c0,0x00c1,0x00c2,0x00c3,0x00c4,0x00c5,0x00c6,0x00c7,
  0x00c8,0x00c9,0x00ca,0x00cb,0x00cc,0x00cd,0x00ce,0x00cf,
  0x0160,0x00d1,0x00d2,0x00d3,0x00d4,0x00d5,0x00d6,0x00d7,
  0x00d8,0x00d9,0x00da,0x00db,0x00dc,0x00dd,0x017d,0x00df,
  0x00e0,0x00e1,0x00e2,0x00e3,0x00e4,0x00e5,0x00e6,0x00e7,
  0x00e8,0x00e9,0x00ea,0x00eb,0x00ec,0x00ed,0x00ee,0x00ef,
  0x0161,0x00f1,0x00f2,0x00f3,0x00f4,0x00f5,0x00f6,0x00f7,
  0x00f8,0x00f9,0x00fa,0x00fb,0x00fc,0x00fd,0x017e,0x00ff
};

unsigned short koi8t_uni_byte[128] = {
  0x049b,0x0493,0x201a,0x0492,0x201e,0x2026,0x2020,0x2021,
  0x252c,0x2030,0x04b3,0x2039,0x04b2,0x04b7,0x04b6,0x2590,
  0x049a,0x2018,0x2019,0x201c,0x201d,0x2022,0x2013,0x2014,
  0x2591,0x2122,0x2593,0x203a,0x25a0,0x2219,0x201d,0x2015,
  0x2116,0x04ef,0x04ee,0x0451,0x00a4,0x04e3,0x00a6,0x00a7,
  0x2550,0x2551,0x2552,0x00ab,0x00ac,0x00ad,0x00ae,0x255e,
  0x00b0,0x00b1,0x00b2,0x0401,0x255b,0x04e2,0x00b6,0x00b7,
  0x255f,0x2116,0x2561,0x00bb,0x0404,0x2563,0x0406,0x00a9,

  0x044e,0x0430,0x0431,0x0446,0x0434,0x0435,0x0444,0x0433,
  0x0445,0x0438,0x0439,0x043a,0x043b,0x043c,0x043d,0x043e,
  0x043f,0x044f,0x0440,0x0441,0x0442,0x0443,0x0436,0x0432,
  0x044c,0x044b,0x0437,0x0448,0x044d,0x0449,0x0447,0x044a,
  0x042e,0x0410,0x0411,0x0426,0x0414,0x0415,0x0424,0x0413,
  0x0425,0x0418,0x0419,0x041a,0x041b,0x041c,0x041d,0x041e,
  0x041f,0x042f,0x0420,0x0421,0x0422,0x0423,0x0416,0x0412,
  0x042c,0x042b,0x0417,0x0428,0x042d,0x0429,0x0427,0x042a
};

unsigned short gsm0338_uni_byte[128] = {
  0x0040,0x00a3,0x0024,0x00a5,0x00e8,0x00e9,0x00f9,0x00ec,
  0x00f2,0x00e7,0x000a,0x00d8,0x00f8,0x000d,0x00c5,0x00e5,
  0x0394,0x005f,0x03a6,0x0393,0x039b,0x03a9,0x03a0,0x03a8,
  0x03a3,0x0398,0x039e,0x001b,0x00c6,0x00e6,0x00df,0x00c9,
  0x0020,0x0021,0x0022,0x0023,0x00a4,0x0025,0x0026,0x0027,
  0x0028,0x0029,0x002a,0x002b,0x002c,0x002d,0x002e,0x002f,
  0x0030,0x0031,0x0032,0x0033,0x0034,0x0035,0x0036,0x0037,
  0x0038,0x0039,0x003a,0x003b,0x003c,0x003d,0x003e,0x003f,
  0x00a1,0x0041,0x0042,0x0043,0x0044,0x0045,0x0046,0x0047,
  0x0048,0x0049,0x004a,0x004b,0x004c,0x004d,0x004e,0x004f,
  0x0050,0x0051,0x0052,0x0053,0x0054,0x0055,0x0056,0x0057,
  0x0058,0x0059,0x005a,0x00c4,0x00d6,0x00d1,0x00dc,0x00a7,
  0x00bf,0x0061,0x0062,0x0063,0x0064,0x0065,0x0066,0x0067,
  0x0068,0x0069,0x006a,0x006b,0x006c,0x006d,0x006e,0x006f,
  0x0070,0x0071,0x0072,0x0073,0x0074,0x0075,0x0076,0x0077,
  0x0078,0x0079,0x007a,0x00e4,0x00f6,0x00f1,0x00fc,0x00e0
};

unsigned short gsm0338_alt_uni_byte[128] = {
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x000c,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x005e,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0020, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x007b,0x007d,0x0000,0x0000, 0x0000,0x0000,0x0000,0x005c,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x005b,0x007e,0x005d,0x0000,

  0x007c,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x20ac,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000
};

unsigned short mule_lao_uni_byte[128] = {
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x005e,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0020, 0x0000,0x0000,0x0000,0x0000,
  0x00a0,0x0e81,0x0e82,0x0000, 0x0e84,0x0000,0x0000,0x0e87,
  0x0e88,0x0000,0x0e8a,0x0000, 0x0000,0x0e8d,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0e94,0x0e95,0x0e96,0x0e97,
  0x0000,0x0e99,0x0e9a,0x0e9b, 0x0e9c,0x0e9d,0x0e9e,0x0e9f,

  0x0000,0x0ea1,0x0ea2,0x0ea3, 0x0000,0x0ea5,0x0000,0x0ea7,
  0x0000,0x0000,0x0eaa,0x0eab, 0x0000,0x0ead,0x0eae,0x0eaf,
  0x0eb0,0x0eb1,0x0eb2,0x0eb3, 0x0eb4,0x0eb5,0x0eb6,0x0eb7,
  0x0eb8,0x0eb9,0x0000,0x0ebb, 0x0ebc,0x0ebd,0x0000,0x0000,
  0x0ec0,0x0ec1,0x0ec2,0x0ec3, 0x0ec4,0x0000,0x0ec6,0x0000,
  0x0ec8,0x0ec9,0x0eca,0x0ecb, 0x0ecc,0x0ecd,0x0000,0x0000,
  0x0ed0,0x0ed1,0x0ed2,0x0ed3, 0x0ed4,0x0ed5,0x0ed6,0x0ed7,
  0x0ed8,0x0ed9,0x0000,0x0000, 0x0edc,0x0edd,0x0000,0x0000
};

unsigned short pt154_uni_byte[128] = {
  0x0496,0x0492,0x04ee,0x0493, 0x201e,0x2026,0x04b6,0x04ae,
  0x04b2,0x04af,0x04a0,0x04e2, 0x04a2,0x049a,0x04ba,0x04b8,
  0x0497,0x2018,0x2019,0x201c, 0x201d,0x2022,0x2013,0x2014,
  0x04b3,0x04b7,0x04a1,0x04e3, 0x04a3,0x049b,0x04bb,0x04b9,
  0x00a0,0x040e,0x045e,0x0408, 0x04e8,0x0498,0x04b0,0x00a7,
  0x0401,0x00a9,0x04d8,0x00ab, 0x00ac,0x04ef,0x00ae,0x049c,
  0x00b0,0x04b1,0x0406,0x0456, 0x0499,0x04e9,0x00b6,0x00b7,
  0x0451,0x2116,0x04d9,0x00bb, 0x0458,0x04aa,0x04ab,0x049d,

  0x0410,0x0411,0x0412,0x0413, 0x0414,0x0415,0x0416,0x0417,
  0x0418,0x0419,0x041a,0x041b, 0x041c,0x041d,0x041e,0x041f,
  0x0420,0x0421,0x0422,0x0423, 0x0424,0x0425,0x0426,0x0427,
  0x0428,0x0429,0x042a,0x042b, 0x042c,0x042d,0x042e,0x042f,
  0x0430,0x0431,0x0432,0x0433, 0x0434,0x0435,0x0436,0x0437,
  0x0438,0x0439,0x043a,0x043b, 0x043c,0x043d,0x043e,0x043f,
  0x0440,0x0441,0x0442,0x0443, 0x0444,0x0445,0x0446,0x0447,
  0x0448,0x0449,0x044a,0x044b, 0x044c,0x044d,0x044e,0x044f
};

unsigned short tds616_uni_byte[128] = {
  0x0000,0x0001,0x0002,0x0003, 0x0004,0x0005,0x0006,0x0007,
  0x0008,0x0009,0x000a,0x000b, 0x000c,0x000d,0x000e,0x000f,
  0x0010,0x0011,0x0012,0x0013, 0x0014,0x0015,0x0016,0x0017,
  0x0018,0x0019,0x001a,0x001b, 0x001c,0x001d,0x001e,0x001f,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0041,0x0042,0x00c7, 0x0044,0x0045,0x00c4,0x0046,
  0x0047,0x0048,0x0049,0x004a, 0x017d,0x004b,0x004c,0x004d,
  0x004e,0x0147,0x004f,0x00d6, 0x0050,0x0052,0x0053,0x015e,
  0x0054,0x0055,0x00dc,0x0057, 0x0059,0x00dd,0x005a,0x0000,
  0x0000,0x0061,0x0062,0x00e7, 0x0064,0x0065,0x00e4,0x0066,
  0x0067,0x0068,0x0069,0x006a, 0x017e,0x006b,0x006c,0x006d,
  0x006e,0x0148,0x006f,0x00f6, 0x0070,0x0072,0x0073,0x015f,
  0x0074,0x0075,0x00fc,0x0077, 0x0079,0x00fd,0x007a,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000
};

unsigned short cp1133_uni_byte[128] = {
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x00a0,0x0e81,0x0e82,0x0e84, 0x0e87,0x0e88,0x0eaa,0x0e8a,
  0x0e8d,0x0e94,0x0e95,0x0e96, 0x0e97,0x0e99,0x0e9a,0x0e9b,
  0x0e9c,0x0e9d,0x0e9e,0x0e9f, 0x0ea1,0x0ea2,0x0ea3,0x0ea5,
  0x0ea7,0x0eab,0x0ead,0x0eae, 0x0000,0x0000,0x0000,0x0eaf,

  0x0eb0,0x0eb2,0x0eb3,0x0eb4, 0x0eb5,0x0eb6,0x0eb7,0x0eb8,
  0x0eb9,0x0ebc,0x0eb1,0x0ebb, 0x0ebd,0x0000,0x0000,0x0000,
  0x0ec0,0x0ec1,0x0ec2,0x0ec3, 0x0ec4,0x0ec8,0x0ec9,0x0eca,
  0x0ecb,0x0ecc,0x0ecd,0x0ec6, 0x0000,0x0edc,0x0edd,0x20ad,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x000c,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0ed0,0x0ed1,0x0ed2,0x0ed3, 0x0ed4,0x0ed5,0x0ed6,0x0ed7,
  0x0ed8,0x0ed9,0x0000,0x0000, 0x00a2,0x00ac,0x00a6,0x00a0
};

unsigned short cp858_uni_byte[128] = {
  0x00c7,0x00fc,0x00e9,0x00e2,0x00e4,0x00e0,0x00e5,0x00e7,
  0x00ea,0x00eb,0x00e8,0x00ef,0x00ee,0x00ec,0x00c4,0x00c5,
  0x00c9,0x00e6,0x00c6,0x00f4,0x00f6,0x00f2,0x00fb,0x00f9,
  0x00ff,0x00d6,0x00dc,0x00f8,0x00a3,0x00d8,0x00d7,0x0192,
  0x00e1,0x00ed,0x00f3,0x00fa,0x00f1,0x00d1,0x00aa,0x00ba,
  0x00bf,0x00ae,0x00ac,0x00bd,0x00bc,0x00a1,0x00ab,0x00bb,
  0x2591,0x2592,0x2593,0x2502,0x2524,0x00c1,0x00c2,0x00c0,
  0x00a9,0x2563,0x2551,0x2557,0x255d,0x00a2,0x00a5,0x2510,
  0x2514,0x2534,0x252c,0x251c,0x2500,0x253c,0x00e3,0x00c3,
  0x255a,0x2554,0x2569,0x2566,0x2560,0x2550,0x256c,0x00a4,
  0x00f0,0x00d0,0x00ca,0x00cb,0x00c8,0x20ac,0x00cd,0x00ce,
  0x00cf,0x2518,0x250c,0x2588,0x2584,0x00a6,0x00cc,0x2580,
  0x00d3,0x00df,0x00d4,0x00d2,0x00f5,0x00d5,0x00b5,0x00fe,
  0x00de,0x00da,0x00db,0x00d9,0x00fd,0x00dd,0x00af,0x00b4,
  0x00ad,0x00b1,0x2017,0x00be,0x00b6,0x00a7,0x00f7,0x00b8,
  0x00b0,0x00a8,0x00b7,0x00b9,0x00b3,0x00b2,0x25a0,0x00a0
};

unsigned short tscii_uni_byte[128] = {
  0xd880,0xd881,0xd882,0xd883, 0xd884,0xd885,0xd886,0xd887,
  0xd888,0xd889,0xd88a,0xd88b, 0xd88c,0xd88d,0xd88e,0xd88f,
  0xd890,0xd891,0xd892,0xd893, 0xd894,0xd895,0xd896,0xd897,
  0xd898,0xd899,0xd89a,0xd89b, 0xd89c,0xd89d,0xd89e,0xd89f,
  0xd8a0,0xd8a1,0xd8a2,0xd8a3, 0xd8a4,0xd8a5,0xd8a6,0xd8a7,
  0xd8a8,0xd8a9,0xd8aa,0xd8ab, 0xd8ac,0xd8ad,0xd8ae,0xd8af,
  0xd8b0,0xd8b1,0xd8b2,0xd8b3, 0xd8b4,0xd8b5,0xd8b6,0xd8b7,
  0xd8b8,0xd8b9,0xd8ba,0xd8bb, 0xd8bc,0xd8bd,0xd8be,0xd8bf,

  0xd8c0,0xd8c1,0xd8c2,0xd8c3, 0xd8c4,0xd8c5,0xd8c6,0xd8c7,
  0xd8c8,0xd8c9,0xd8ca,0xd8cb, 0xd8cc,0xd8cd,0xd8ce,0xd8cf,
  0xd8d0,0xd8d1,0xd8d2,0xd8d3, 0xd8d4,0xd8d5,0xd8d6,0xd8d7,
  0xd8d8,0xd8d9,0xd8da,0xd8db, 0xd8dc,0xd8dd,0xd8de,0xd8df,
  0xd8e0,0xd8e1,0xd8e2,0xd8e3, 0xd8e4,0xd8e5,0xd8e6,0xd8e7,
  0xd8e8,0xd8e9,0xd8ea,0xd8eb, 0xd8ec,0xd8ed,0xd8ee,0xd8ef,
  0xd8f0,0xd8f1,0xd8f2,0xd8f3, 0xd8f4,0xd8f5,0xd8f6,0xd8f7,
  0xd8f8,0xd8f9,0xd8fa,0xd8fb, 0xd8fc,0xd8fd,0xd8fe,0xd8ff
};

unsigned short uni_lig_tscii[256] = {
    0x0000,0x0000,0x0bcd,0x0000, 0x0000,0x0000,0x0000,0x0bcd,
    0x0bcd,0x0bcd,0x0bcd,0x0bcd, 0x0bcd,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0bc1,0x0bc1,0x0bc2, 0x0bc2,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,

    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0bbf,0x0bbf, 0x0bc1,0x0bc1,0x0bc1,0x0bc1,
    0x0bc1,0x0bc1,0x0bc1,0x0bc1, 0x0bc1,0x0bc1,0x0bc1,0x0bc1,
    0x0bc1,0x0bc1,0x0bc1,0x0bc1, 0x0bc2,0x0bc2,0x0bc2,0x0bc2,
    0x0bc2,0x0bc2,0x0bc2,0x0bc2, 0x0bc2,0x0bc2,0x0bc2,0x0bc2, 
    0x0bc2,0x0bc2,0x0bc2,0x0bc2, 0x0bcd,0x0bcd,0x0bcd,0x0bcd, 
    0x0bcd,0x0bcd,0x0bcd,0x0bcd, 0x0bcd,0x0bcd,0x0bcd,0x0bcd,
    0x0bcd,0x0bcd,0x0bcd,0x0bcd, 0x0000,0x0000,0x0000,0x0000,

    0x0be6,0x0be7,0x0bb6,0x0b9c, 0x0bb7,0x0bb8,0x0bb9,0x0b95,
    0x0b9c,0x0bb7,0x0bb8,0x0bb9, 0x0b95,0x0be8,0x0be9,0x0bea,
    0x0beb,0x2018,0x2019,0x201c, 0x201d,0x0bec,0x0bed,0x0bee,
    0x0bef,0x0b99,0x0b9e,0x0b99, 0x0b9e,0x0bf0,0x0bf1,0x0bf2,

    0x0000,0x0bbe,0x0bbf,0x0bc0, 0x0bc1,0x0bc2,0x0bc6,0x0bc7,
    0x0bc8,0x00a9,0x0000,0x0b85, 0x0b86,0x0b87,0x0b88,0x0b89,
    0x0b8a,0x0b8e,0x0b8f,0x0b90, 0x0b92,0x0b93,0x0b94,0x0b83,
    0x0b95,0x0b99,0x0b9a,0x0b9e, 0x0b9f,0x0ba3,0x0ba4,0x0ba8,

    0x0baa,0x0bae,0x0baf,0x0bb0, 0x0bb2,0x0bb5,0x0bb4,0x0bb3,
    0x0bb1,0x0ba9,0x0b9f,0x0b9f, 0x0b95,0x0b9a,0x0b9f,0x0ba3,
    0x0ba4,0x0ba8,0x0baa,0x0bae, 0x0baf,0x0bb0,0x0bb2,0x0bb5,
    0x0bb4,0x0bb3,0x0bb1,0x0ba9, 0x0b95,0x0b9a,0x0b9f,0x0ba3,
    0x0ba4,0x0ba8,0x0baa,0x0bae, 0x0baf,0x0bb0,0x0bb2,0x0bb5,
    0x0bb4,0x0bb3,0x0bb1,0x0ba9, 0x0b95,0x0b99,0x0b9a,0x0b9e,
    0x0b9f,0x0ba3,0x0ba4,0x0ba8, 0x0baa,0x0bae,0x0baf,0x0bb0,
    0x0bb2,0x0bb5,0x0bb4,0x0bb3, 0x0bb1,0x0ba9,0x0b87,0x0000
};

/* --------------------------------------------------------------- */
/* ntt doc*mo keitai glyphs					   */
/* --------------------------------------------------------------- */
unsigned short uni_f_nttglyph[] = {	/* u+e63e to e757	   */
  0xf89f,0xf8a0,
/* e640 */
  0xf8a1,0xf8a2,0xf8a3,0xf8a4, 0xf8a5,0xf8a6,0xf8a7,0xf8a8,
  0xf8a9,0xf8aa,0xf8ab,0xf8ac, 0xf8ad,0xf8ae,0xf8af,0xf8b0,
  0xf8b1,0xf8b2,0xf8b3,0xf8b4, 0xf8b5,0xf8b6,0xf8b7,0xf8b8,
  0xf8b9,0xf8ba,0xf8bb,0xf8bc, 0xf8bd,0xf8be,0xf8bf,0xf8c0,
  0xf8c1,0xf8c2,0xf8c3,0xf8c4, 0xf8c5,0xf8c6,0xf8c7,0xf8c8,
  0xf8c9,0xf8ca,0xf8cb,0xf8cc, 0xf8cd,0xf8ce,0xf8cf,0xf8d0,
  0xf8d1,0xf8d2,0xf8d3,0xf8d4, 0xf8d5,0xf8d6,0xf8d7,0xf8d8,
  0xf8d9,0xf8da,0xf8db,0xf8dc, 0xf8dd,0xf8de,0xf8df,0xf8e0,
/* e680 */
  0xf8e1,0xf8e2,0xf8e3,0xf8e4, 0xf8e5,0xf8e6,0xf8e7,0xf8e8,
  0xf8e9,0xf8ea,0xf8eb,0xf8ec, 0xf8ed,0xf8ee,0xf8ef,0xf8f0,
  0xf8f1,0xf8f2,0xf8f3,0xf8f4, 0xf8f5,0xf8f6,0xf8f7,0xf8f8,
  0xf8f9,0xf8fa,0xf8fb,0xf8fc, 0xf940,0xf941,0xf942,0xf943,
  0xf944,0xf945,0xf946,0xf947, 0xf948,0xf949,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0xf950,0xf951,0xf952,0x0000,
  0x0000,0xf955,0xf956,0xf957, 0x0000,0x0000,0x0000,0xf95b,
  0xf95c,0xf95d,0xf95e,0x0000, 0x0000,0x0000,0x0000,0x0000,
/* e6c0 */
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
  0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0xf972,0xf973,
  0xf974,0xf975,0xf976,0xf977, 0xf978,0xf979,0xf97a,0xf97b,
  0xf97c,0xf97d,0xf97e,0xf980, 0xf981,0xf982,0xf983,0xf984,
  0xf985,0xf986,0xf987,0xf988, 0xf989,0xf98a,0xf98b,0xf98c,
  0xf98d,0xf98e,0xf98f,0xf990, 0xf991,0xf992,0xf993,0xf994,
  0xf995,0xf996,0xf997,0xf998, 0xf999,0xf99a,0xf99b,0xf99c,
  0xf99d,0xf99e,0xf99f,0xf9a0, 0xf9a1,0xf9a2,0xf9a3,0xf9a4,
/* e700 */
  0xf9a5,0xf9a6,0xf9a7,0xf9a8, 0xf9a9,0xf9aa,0xf9ab,0xf9ac,
  0xf9ad,0xf9ae,0xf9af,0xf9b0, 0xf9b1,0xf9b2,0xf9b3,0xf9b4,
  0xf9b5,0xf9b6,0xf9b7,0xf9b8, 0xf9b9,0xf9ba,0xf9bb,0xf9bc,
  0xf9bd,0xf9be,0xf9bf,0xf9c0, 0xf9c1,0xf9c2,0xf9c3,0xf9c4,
  0xf9c5,0xf9c6,0xf9c7,0xf9c8, 0xf9c9,0xf9ca,0xf9cb,0xf9cc,
  0xf9cd,0xf9ce,0xf9cf,0xf9d0, 0xf9d1,0xf9d2,0xf9d3,0xf9d4,
  0xf9d5,0xf9d6,0xf9d7,0xf9d8, 0xf9d9,0xf9da,0xf9db,0xf9dc,
  0xf9dd,0xf9de,0xf9df,0xf9e0, 0xf9e1,0xf9e2,0xf9e3,0xf9e4,
/* e740 */
  0xf9e5,0xf9e6,0xf9e7,0xf9e8, 0xf9e9,0xf9ea,0xf9eb,0xf9ec,
  0xf9ed,0xf9ee,0xf9ef,0xf9f0, 0xf9f1,0xf9f2,0xf9f3,0xf9f4,
  0xf9f5,0xf9f6,0xf9f7,0xf9f8, 0xf9f9,0xf9fa,0xf9fb,0xf9fc
};

unsigned short	i_ntt_tbl[512];

/* table generated based on EmojiSource.txt in Unicode 6.0.0	 */
/* Unicode point, Docomo SJIS, KDDI SJIS, Vodafone/Softbank SJIS */
/* 0 in SJIS section means not defined.				 */
static skf_ucode uni_map_emoticon[]= {
  0xd850,0xF040,0xF041,0xF042,
  0xd851,0xF985,0xF489,0xF7B0,
  0xd852,0xF990,0xF7C9,0xF7C5,
  0xd853,0xF987,0xF6FB,0xF7BC,
  0xd854,0xF988,0xF6FC,0xF7BD,
  0xd855,0xF989,0xF740,0xF7BE,
  0xd856,0xF98A,0xF741,0xF7BF,
  0xd857,0xF98B,0xF742,0xF7C0,
  0xd858,0xF98C,0xF743,0xF7C1,
  0xd859,0xF98D,0xF744,0xF7C2,
  0xd85a,0xF98E,0xF745,0xF7C3,
  0xd85b,0xF98F,0xF746,0xF7C4,
  0x00A9,0xF9D6,0xF774,0xF7EE,
  0x00AE,0xF9DB,0xF775,0xF7EF,
  0x2002,0x0,0xF7AA,0x0,
  0x2003,0x0,0xF7A9,0x0,
  0x2005,0x0,0xF7AB,0x0,
  0x203C,0xF9A9,0xF3F1,0x0,
  0x2049,0xF9A8,0xF3F0,0x0,
  0x2122,0xF9D7,0xF76A,0xFBD7,
  0x2139,0x0,0xF74F,0x0,
  0x2194,0xF9E1,0xF47E,0x0,
  0x2195,0xF9E2,0xF480,0x0,
  0x2196,0xF8F8,0xF768,0xF7D7,
  0x2197,0xF8D9,0xF771,0xF7D6,
  0x2198,0xF8F7,0xF769,0xF7D8,
  0x2199,0xF949,0xF772,0xF7D9,
  0x21A9,0xF97E,0xF779,0x0,
  0x21AA,0x0,0xF778,0x0,
  0x231A,0xF9C4,0xF797,0x0,
  0x231B,0x0,0xF798,0x0,
  0x23E9,0x0,0xF74C,0xF7DC,
  0x23EA,0x0,0xF74B,0xF7DD,
  0x23EB,0x0,0xF761,0x0,
  0x23EC,0x0,0xF760,0x0,
  0x23F0,0xF95E,0xF7B1,0x0,
  0x23F3,0xF9C1,0xF654,0x0,
  0x24C2,0xF8BD,0x0,0x0,
  0x25AA,0x0,0xF74E,0x0,
  0x25AB,0x0,0xF74D,0x0,
  0x25B6,0x0,0xF74A,0xF7DA,
  0x25C0,0x0,0xF749,0xF7DB,
  0x25FB,0x0,0xF754,0x0,
  0x25FC,0x0,0xF755,0x0,
  0x25FD,0x0,0xF750,0x0,
  0x25FE,0x0,0xF751,0x0,
  0x2600,0xF89F,0xF660,0xF98B,
  0x2601,0xF8A0,0xF665,0xF98A,
  0x260E,0xF8E8,0xF7B3,0xF949,
  0x2611,0x0,0xF7D9,0x0,
  0x2614,0xF8A1,0xF664,0xF98C,
  0x2615,0xF8D1,0xF7B4,0xF986,
  0x261D,0x0,0xF6CF,0xF94F,
  0x263A,0x0,0xF6D4,0xFB54,
  0x2648,0xF8A7,0xF667,0xF7DF,
  0x2649,0xF8A8,0xF668,0xF7E0,
  0x264A,0xF8A9,0xF669,0xF7E1,
  0x264B,0xF8AA,0xF66A,0xF7E2,
  0x264C,0xF8AB,0xF66B,0xF7E3,
  0x264D,0xF8AC,0xF66C,0xF7E4,
  0x264E,0xF8AD,0xF66D,0xF7E5,
  0x264F,0xF8AE,0xF66E,0xF7E6,
  0x2650,0xF8AF,0xF66F,0xF7E7,
  0x2651,0xF8B0,0xF670,0xF7E8,
  0x2652,0xF8B1,0xF671,0xF7E9,
  0x2653,0xF8B2,0xF672,0xF7EA,
  0x2660,0xF8EF,0xF7BE,0xF7AE,
  0x2663,0xF8F1,0xF7C0,0xF7AF,
  0x2665,0xF8EE,0xF378,0xF7AC,
  0x2666,0xF8F0,0xF7BF,0xF7AD,
  0x2668,0xF99C,0xF695,0xF763,
  0x267B,0xF9DA,0xF47D,0x0,
  0x267F,0xF8FC,0xF657,0xF7AA,
  0x2693,0x0,0xF682,0x0,
  0x26A0,0xF9DC,0xF659,0xF7F2,
  0x26A1,0xF8A3,0xF65F,0xF77D,
  0x26AA,0x0,0xF756,0x0,
  0x26AB,0x0,0xF757,0x0,
  0x26BD,0xF8B7,0xF68F,0xF958,
  0x26BE,0xF8B4,0xF693,0xF956,
  0x26C4,0xF8A2,0xF65D,0xF989,
  0x26C5,0x0,0xF666,0x0,
  0x26CE,0x0,0xF673,0xF7EB,
  0x26D4,0x0,0xF65C,0x0,
  0x26EA,0x0,0xF7EB,0xF977,
  0x26F2,0x0,0xF342,0xF761,
  0x26F3,0xF8B5,0xF7B6,0xF954,
  0x26F5,0xF947,0xF68D,0xF95C,
  0x26FA,0x0,0xF343,0xF762,
  0x26FD,0xF8CC,0xF78E,0xF97A,
  0x2702,0xF8D6,0xF6EF,0xF9B3,
  0x2705,0x0,0xF77A,0x0,
  0x2708,0xF8C3,0xF68C,0xF95D,
  0x2709,0xF977,0xF6FA,0x0,
  0x270A,0xF8F4,0xF488,0xF950,
  0x270B,0xF8F6,0xF7C4,0xF952,
  0x270C,0xF8F5,0xF7C3,0xF951,
  0x270F,0xF9BE,0xF679,0x0,
  0x2712,0xF952,0xF7DA,0x0,
  0x2714,0x0,0xF773,0x0,
  0x2716,0x0,0xF76B,0x0,
  0x2728,0xF99F,0xF37E,0xF9CE,
  0x2733,0x0,0xF75A,0xF7A6,
  0x2734,0x0,0xF651,0xF7A5,
  0x2744,0x0,0xF662,0x0,
  0x2747,0x0,0xF644,0x0,
  0x274C,0x0,0xF76C,0xF9D3,
  0x274E,0x0,0xF76D,0x0,
  0x2753,0x0,0xF65B,0xF960,
  0x2754,0x0,0x0,0xF9D6,
  0x2755,0x0,0x0,0xF9D7,
  0x2757,0xF9A7,0xF65A,0xF961,
  0x2764,0xF991,0xF7B2,0xF962,
  0x2795,0x0,0xF758,0x0,
  0x2796,0x0,0xF759,0x0,
  0x2797,0x0,0xF770,0x0,
  0x27A1,0x0,0xF76E,0xF7D4,
  0x27B0,0xF9AF,0xF3F2,0x0,
  0x2934,0xF99A,0xF3EE,0x0,
  0x2935,0xF9A5,0xF3EF,0x0,
  0x2B05,0x0,0xF76F,0xF7D5,
  0x2B06,0x0,0xF75B,0xF7D2,
  0x2B07,0x0,0xF75C,0xF7D3,
  0x2B1B,0x0,0xF765,0x0,
  0x2B1C,0x0,0xF764,0x0,
  0x2B50,0x0,0xF663,0xF9CF,
  0x2B55,0x0,0xF381,0xF9D2,
  0x3030,0xF9AE,0x0,0x0,
  0x303D,0x0,0x0,0xF76C,
  0x3297,0x0,0xF36C,0xF9AD,
  0x3299,0xF9D9,0xF6CA,0xF9B5,
  0x1F004,0x0,0xF344,0xF76D,
  0x1F0CF,0x0,0xF473,0x0,
  0x1F170,0x0,0xF3E7,0xFBD2,
  0x1F171,0x0,0xF3E8,0xFBD3,
  0x1F17E,0x0,0xF3E9,0xFBD5,
  0x1F17F,0xF8CD,0xF67E,0xF790,
  0x1F18E,0x0,0xF3EA,0xFBD4,
  0x1F191,0xF980,0xF7C8,0x0,
  0x1F192,0x0,0xF358,0xF7B4,
  0x1F193,0xF97B,0xF795,0x0,
  0x1F194,0xF97C,0xF35B,0xF7C9,
  0x1F195,0xF982,0xF7E5,0xF7B2,
  0x1F196,0xF9D4,0x0,0x0,
  0x1F197,0xF9B0,0xF7CA,0xF7ED,
  0x1F198,0x0,0xF6C1,0x0,
  0x1F199,0x0,0xF6E8,0xF7B3,
  0x1F19A,0x0,0xF345,0xF76E,
  0xd85c,0x0,0xF3D2,0xFBB3,
  0xd85d,0x0,0xF3CF,0xFBAE,
  0xd85e,0x0,0xF348,0xFBB1,
  0xd85f,0x0,0xF3CE,0xFBAD,
  0xd860,0x0,0xF3D1,0xFBB0,
  0xd861,0x0,0xF3D0,0xFBAF,
  0xd862,0x0,0xF6A5,0xFBAB,
  0xd863,0x0,0xF3D3,0xFBB4,
  0xd864,0x0,0xF349,0xFBB2,
  0xd865,0x0,0xF790,0xFBAC,
  0x1F201,0x0,0x0,0xF7A3,
  0x1F202,0x0,0xF35A,0xF7C8,
  0x1F21A,0x0,0x0,0xF7B6,
  0x1F22F,0x0,0xF35E,0xF7CC,
  0x1F232,0xF9DD,0x0,0x0,
  0x1F233,0xF9DE,0xF35D,0xF7CB,
  0x1F234,0xF9DF,0x0,0x0,
  0x1F235,0xF9E0,0xF35C,0xF7CA,
  0x1F236,0x0,0x0,0xF7B5,
  0x1F237,0x0,0x0,0xF7B7,
  0x1F238,0x0,0x0,0xF7B8,
  0x1F239,0x0,0xF359,0xF7C7,
  0x1F23A,0x0,0xF35F,0xF7CD,
  0x1F250,0x0,0xF6D0,0xF7C6,
  0x1F251,0x0,0xF7D8,0x0,
  0x1F300,0xF8A4,0xF641,0xFB84,
  0x1F301,0xF8A5,0xF7B5,0x0,
  0x1F302,0xF8A6,0xF3BC,0xFB7C,
  0x1F303,0xF957,0xF3C5,0xFB8C,
  0x1F304,0x0,0x0,0xF98E,
  0x1F305,0x0,0xF3C8,0xFB8A,
  0x1F306,0x0,0xF34D,0xF787,
  0x1F307,0x0,0x0,0xFB8B,
  0x1F308,0x0,0xF3C6,0xFB8D,
  0x1F309,0x0,0xF698,0x0,
  0x1F30A,0xF9E4,0xF481,0xFB7E,
  0x1F30B,0x0,0xF457,0x0,
  0x1F30C,0x0,0xF463,0x0,
  0x1F30F,0x0,0xF7D0,0x0,
  0x1F311,0xF940,0xF7C5,0x0,
  0x1F313,0xF942,0xF7C7,0x0,
  0x1F314,0xF941,0xF7C6,0x0,
  0x1F315,0xF944,0x0,0x0,
  0x1F319,0xF943,0xF65E,0xF98D,
  0x1F31B,0x0,0xF661,0x0,
  0x1F31F,0x0,0x0,0xF9D5,
  0x1F320,0x0,0xF640,0x0,
  0x1F330,0x0,0xF3F9,0x0,
  0x1F331,0xF9EB,0xF482,0x0,
  0x1F334,0x0,0xF6BB,0xF9A7,
  0x1F335,0x0,0xF369,0xF9A8,
  0x1F337,0xF9E8,0xF6BD,0xF9A4,
  0x1F338,0xF9ED,0xF6A3,0xF970,
  0x1F339,0x0,0xF7EA,0xF972,
  0x1F33A,0x0,0xF367,0xF9A3,
  0x1F33B,0x0,0xF6BC,0xF9A5,
  0x1F33C,0x0,0xF44D,0x0,
  0x1F33D,0x0,0xF3F7,0x0,
  0x1F33E,0x0,0x0,0xFB85,
  0x1F33F,0x0,0xF487,0x0,
  0x1F340,0xF9E6,0xF6EC,0xF750,
  0x1F341,0xF9EC,0xF6A7,0xF758,
  0x1F342,0x0,0xF340,0xF759,
  0x1F343,0x0,0x0,0xFB88,
  0x1F344,0x0,0xF3F8,0x0,
  0x1F345,0x0,0xF38F,0xF9E9,
  0x1F346,0x0,0xF390,0xF9EA,
  0x1F347,0x0,0xF3F5,0x0,
  0x1F348,0x0,0xF3F3,0x0,
  0x1F349,0x0,0xF6A6,0xF9E8,
  0x1F34A,0x0,0xF38E,0xF9E6,
  0x1F34C,0xF9E9,0xF3F6,0x0,
  0x1F34D,0x0,0xF3F4,0x0,
  0x1F34E,0xF9EA,0xF38D,0xF9E5,
  0x1F34F,0x0,0xF45E,0x0,
  0x1F351,0x0,0xF3FA,0x0,
  0x1F352,0xF9E7,0xF6AB,0x0,
  0x1F353,0x0,0xF6AD,0xF9E7,
  0x1F354,0xF8D4,0xF6AF,0xF760,
  0x1F355,0x0,0xF3FC,0x0,
  0x1F356,0x0,0xF69D,0x0,
  0x1F357,0x0,0xF440,0x0,
  0x1F358,0x0,0xF387,0xF9DD,
  0x1F359,0xF9EE,0xF6AE,0xF9E2,
  0x1F35A,0x0,0xF388,0xF9DE,
  0x1F35B,0x0,0xF38A,0xF9E1,
  0x1F35C,0xF9F1,0xF7D1,0xF9E0,
  0x1F35D,0x0,0xF389,0xF9DF,
  0x1F35E,0xF9F2,0xF383,0xF9D9,
  0x1F35F,0x0,0xF385,0xF9DB,
  0x1F360,0x0,0xF3FB,0x0,
  0x1F361,0x0,0xF386,0xF9DC,
  0x1F362,0x0,0xF38B,0xF9E3,
  0x1F363,0x0,0xF38C,0xF9E4,
  0x1F364,0x0,0xF474,0x0,
  0x1F365,0x0,0xF6C6,0x0,
  0x1F366,0x0,0xF384,0xF9DA,
  0x1F367,0x0,0xF3BE,0xFB80,
  0x1F368,0x0,0xF44E,0x0,
  0x1F369,0x0,0xF44F,0x0,
  0x1F36A,0x0,0xF450,0x0,
  0x1F36B,0x0,0xF451,0x0,
  0x1F36C,0x0,0xF452,0x0,
  0x1F36D,0x0,0xF453,0x0,
  0x1F36E,0x0,0xF45A,0x0,
  0x1F36F,0x0,0xF45D,0x0,
  0x1F370,0xF9EF,0xF6A9,0xF987,
  0x1F371,0x0,0xF391,0xF9EC,
  0x1F372,0x0,0xF392,0xF9ED,
  0x1F373,0x0,0xF6AA,0xF788,
  0x1F374,0xF8D0,0xF685,0xF984,
  0x1F375,0xF9C3,0xF382,0xF9D8,
  0x1F376,0xF9F0,0xF36A,0xF9AB,
  0x1F377,0xF9FB,0xF69A,0x0,
  0x1F378,0xF8D2,0xF69B,0xF985,
  0x1F379,0x0,0xF442,0x0,
  0x1F37A,0xF8D3,0xF69C,0xF988,
  0x1F37B,0x0,0xF36B,0xF9AC,
  0x1F380,0xF8E5,0xF7BC,0xF9B4,
  0x1F381,0xF8E6,0xF6A8,0xF752,
  0x1F382,0xF8E7,0xF7BD,0xF9EB,
  0x1F383,0x0,0xF3C2,0xFB86,
  0x1F384,0xF948,0xF6A2,0xF973,
  0x1F385,0x0,0xF3C4,0xFB89,
  0x1F386,0x0,0xF7FC,0xF757,
  0x1F387,0x0,0xF3BF,0xFB81,
  0x1F388,0x0,0xF36E,0xF9B0,
  0x1F389,0x0,0xF36F,0xF9B2,
  0x1F38A,0x0,0xF647,0x0,
  0x1F38B,0x0,0xF441,0x0,
  0x1F38C,0x0,0xF34C,0xF784,
  0x1F38D,0x0,0xF3B7,0xFB76,
  0x1F38E,0x0,0xF3B8,0xFB78,
  0x1F38F,0x0,0xF3BB,0xFB7B,
  0x1F390,0x0,0xF3C1,0xFB83,
  0x1F391,0x0,0xF3C3,0xFB87,
  0x1F392,0x0,0xF3BA,0xFB7A,
  0x1F393,0x0,0xF3B9,0xFB79,
  0x1F3A0,0xF8DA,0x0,0x0,
  0x1F3A1,0x0,0xF645,0xF764,
  0x1F3A2,0x0,0xF3B6,0xFB73,
  0x1F3A3,0x0,0xF446,0x0,
  0x1F3A4,0xF8D7,0xF6DC,0xF97C,
  0x1F3A5,0xF8D8,0xF6F0,0xF97D,
  0x1F3A6,0x0,0x0,0xFBA7,
  0x1F3A7,0xF8DB,0xF6E1,0xF9AA,
  0x1F3A8,0xF8DC,0xF7B9,0xFBA2,
  0x1F3A9,0xF8DD,0xF3C9,0xFBA3,
  0x1F3AA,0xF8DE,0xF7BB,0x0,
  0x1F3AB,0xF8DF,0xF676,0xF765,
  0x1F3AC,0xF950,0xF697,0xF9C4,
  0x1F3AD,0x0,0xF7BA,0x0,
  0x1F3AE,0xF8EC,0xF69F,0x0,
  0x1F3AF,0x0,0xF69E,0xF770,
  0x1F3B0,0x0,0xF646,0xF773,
  0x1F3B1,0x0,0xF3B1,0xFB6C,
  0x1F3B2,0x0,0xF6A1,0x0,
  0x1F3B3,0x0,0xF447,0x0,
  0x1F3B4,0x0,0xF472,0x0,
  0x1F3B5,0xF99B,0xF7EE,0xF97E,
  0x1F3B6,0xF9A4,0xF6DE,0xF9C6,
  0x1F3B7,0x0,0x0,0xF981,
  0x1F3B8,0x0,0xF6DF,0xF982,
  0x1F3B9,0x0,0xF444,0x0,
  0x1F3BA,0x0,0xF3B0,0xF983,
  0x1F3BB,0x0,0xF6E0,0x0,
  0x1F3BC,0x0,0xF3A0,0x0,
  0x1F3BD,0xF8B3,0x0,0x0,
  0x1F3BE,0xF8B6,0xF690,0xF955,
  0x1F3BF,0xF8B8,0xF380,0xF953,
  0x1F3C0,0xF8B9,0xF7B7,0xFB6A,
  0x1F3C1,0xF8BA,0xF692,0xF772,
  0x1F3C2,0xF9B7,0xF691,0x0,
  0x1F3C3,0xF9D8,0xF643,0xF755,
  0x1F3C4,0x0,0xF445,0xF957,
  0x1F3C6,0x0,0xF346,0xF771,
  0x1F3C8,0x0,0xF694,0xFB6B,
  0x1F3CA,0x0,0xF3B2,0xFB6D,
  0x1F3E0,0xF8C4,0xF684,0xF976,
  0x1F3E1,0x0,0xF7E0,0x0,
  0x1F3E2,0xF8C5,0xF686,0xF978,
  0x1F3E3,0xF8C6,0xF351,0xF794,
  0x1F3E5,0xF8C7,0xF352,0xF796,
  0x1F3E6,0xF8C8,0xF683,0xF78E,
  0x1F3E7,0xF8C9,0xF67B,0xF795,
  0x1F3E8,0xF8CA,0xF354,0xF799,
  0x1F3E9,0x0,0xF3C7,0xFBA1,
  0x1F3EA,0xF8CB,0xF67C,0xF797,
  0x1F3EB,0xF9E3,0xF353,0xF798,
  0x1F3EC,0x0,0xF3CA,0xFBA4,
  0x1F3ED,0x0,0xF3CD,0xFBA8,
  0x1F3EE,0x0,0xF696,0x0,
  0x1F3EF,0x0,0xF3CB,0xFBA5,
  0x1F3F0,0x0,0xF3CC,0xFBA6,
  0x1F40C,0xF9F3,0xF483,0x0,
  0x1F40D,0x0,0xF3E3,0xFBCD,
  0x1F40E,0x0,0x0,0xF774,
  0x1F411,0x0,0x0,0xFBC9,
  0x1F412,0x0,0x0,0xFBC8,
  0x1F414,0x0,0xF3E4,0xFBCE,
  0x1F417,0x0,0xF3E5,0xFBCF,
  0x1F418,0x0,0xF3E0,0xFBC6,
  0x1F419,0x0,0xF7F7,0xF74A,
  0x1F41A,0x0,0xF3C0,0xFB82,
  0x1F41B,0x0,0xF3DF,0xFBC5,
  0x1F41C,0x0,0xF6B6,0x0,
  0x1F41D,0x0,0xF45B,0x0,
  0x1F41E,0x0,0xF45C,0x0,
  0x1F41F,0xF9F6,0x0,0xF959,
  0x1F420,0x0,0xF3DE,0xFBC2,
  0x1F421,0x0,0xF6AC,0x0,
  0x1F422,0x0,0xF347,0x0,
  0x1F423,0x0,0xF34E,0x0,
  0x1F424,0xF9F4,0xF6B9,0xFBC3,
  0x1F425,0x0,0xF47A,0x0,
  0x1F426,0x0,0x0,0xFBC1,
  0x1F427,0xF9F5,0xF6B5,0xF996,
  0x1F428,0x0,0xF3E1,0xFBC7,
  0x1F429,0x0,0xF6B8,0x0,
  0x1F42B,0x0,0xF3E6,0xFBD0,
  0x1F42C,0x0,0xF3DC,0xFBC0,
  0x1F42D,0x0,0xF7F2,0xF994,
  0x1F42E,0x0,0xF3E2,0xFBCB,
  0x1F42F,0x0,0xF7F0,0xF991,
  0x1F430,0x0,0xF6B0,0xFBCC,
  0x1F431,0xF946,0xF6B4,0xF990,
  0x1F432,0x0,0xF443,0x0,
  0x1F433,0x0,0xF648,0xF995,
  0x1F434,0xF9F9,0xF6B1,0xF95A,
  0x1F435,0x0,0xF6B2,0xF749,
  0x1F436,0xF945,0xF6BA,0xF993,
  0x1F437,0xF9FA,0xF6B7,0xF74B,
  0x1F438,0x0,0xF6B3,0xFBD1,
  0x1F439,0x0,0x0,0xFBC4,
  0x1F43A,0x0,0x0,0xFBCA,
  0x1F43B,0x0,0xF7F1,0xF992,
  0x1F43C,0x0,0xF44A,0x0,
  0x1F43D,0x0,0xF44C,0x0,
  0x1F43E,0x0,0xF6C7,0x0,
  0x1F440,0xF8F2,0xF7C1,0xFB59,
  0x1F442,0xF8F3,0xF7C2,0xFB5B,
  0x1F443,0x0,0xF3A4,0xFB5A,
  0x1F444,0x0,0xF3A5,0xFB5C,
  0x1F445,0x0,0xF44B,0x0,
  0x1F446,0x0,0xF360,0xF7CE,
  0x1F447,0x0,0xF361,0xF7CF,
  0x1F448,0x0,0xF6D8,0xF7D0,
  0x1F449,0x0,0xF6D9,0xF7D1,
  0x1F44A,0xF9A2,0xF6CC,0xF94D,
  0x1F44B,0x0,0xF3AA,0xFB5E,
  0x1F44C,0x0,0xF3A8,0xFB60,
  0x1F44D,0xF9CC,0xF6D2,0xF94E,
  0x1F44E,0x0,0xF3A9,0xFB61,
  0x1F44F,0x0,0xF3A7,0xFB5F,
  0x1F450,0x0,0x0,0xFB62,
  0x1F451,0xF9BF,0xF7F9,0xF74E,
  0x1F452,0x0,0xF371,0xF9B8,
  0x1F453,0xF8FB,0xF6D7,0x0,
  0x1F454,0x0,0xF366,0xF9A2,
  0x1F455,0xF9B3,0xF7E6,0xF946,
  0x1F456,0xF9B6,0xF47B,0x0,
  0x1F457,0x0,0xF46F,0xF9B9,
  0x1F458,0x0,0xF376,0xF9C1,
  0x1F459,0x0,0xF377,0xF9C2,
  0x1F45A,0x0,0xF6E6,0x0,
  0x1F45B,0xF9B4,0xF6DD,0x0,
  0x1F45C,0xF8E3,0xF674,0xF9C3,
  0x1F45D,0xF951,0x0,0x0,
  0x1F45E,0x0,0xF7E7,0x0,
  0x1F45F,0xF8FA,0xF3EC,0xF947,
  0x1F460,0xF8D5,0xF6F3,0xF77E,
  0x1F461,0x0,0x0,0xF9BA,
  0x1F462,0x0,0xF372,0xF9BB,
  0x1F463,0xF8F9,0xF3EB,0xFBD6,
  0x1F464,0xF955,0x0,0x0,
  0x1F466,0x0,0x0,0xF941,
  0x1F467,0x0,0x0,0xF942,
  0x1F468,0x0,0xF6D5,0xF944,
  0x1F469,0x0,0xF6D3,0xF945,
  0x1F46A,0x0,0xF6DA,0x0,
  0x1F46B,0x0,0x0,0xFB68,
  0x1F46E,0x0,0xF350,0xF793,
  0x1F46F,0x0,0xF3AF,0xFB69,
  0x1F470,0x0,0xF3BD,0x0,
  0x1F471,0x0,0xF3D4,0xFBB5,
  0x1F472,0x0,0xF3D5,0xFBB6,
  0x1F473,0x0,0xF3D6,0xFBB7,
  0x1F474,0x0,0xF3D7,0xFBB8,
  0x1F475,0x0,0xF3D8,0xFBB9,
  0x1F476,0x0,0xF3D9,0xFBBA,
  0x1F477,0x0,0xF3DA,0xFBBB,
  0x1F478,0x0,0xF3DB,0xFBBC,
  0x1F479,0x0,0xF448,0x0,
  0x1F47A,0x0,0xF449,0x0,
  0x1F47B,0x0,0xF6A4,0xF75B,
  0x1F47C,0x0,0xF7EF,0xF98F,
  0x1F47D,0x0,0xF6E7,0xF74C,
  0x1F47E,0x0,0xF6C5,0xF76B,
  0x1F47F,0x0,0xF6C8,0xF75A,
  0x1F480,0x0,0xF6D1,0xF75C,
  0x1F481,0x0,0x0,0xF7F3,
  0x1F482,0x0,0x0,0xFBBE,
  0x1F483,0x0,0xF3DD,0xFBBF,
  0x1F484,0xF9B5,0xF6E2,0xF9BC,
  0x1F485,0x0,0xF373,0xF9BD,
  0x1F486,0x0,0xF6E4,0xF9BE,
  0x1F487,0x0,0xF374,0xF9BF,
  0x1F488,0x0,0xF375,0xF9C0,
  0x1F489,0x0,0xF6E9,0xF77B,
  0x1F48A,0x0,0xF36D,0xF9AF,
  0x1F48B,0xF99E,0xF6C4,0xF943,
  0x1F48C,0xF9BC,0xF47C,0x0,
  0x1F48D,0xF9C0,0xF6ED,0xF974,
  0x1F48E,0x0,0x0,0xF975,
  0x1F48F,0x0,0xF7FA,0xF751,
  0x1F490,0x0,0xF368,0xF9A6,
  0x1F491,0x0,0xF3AE,0xFB65,
  0x1F492,0x0,0x0,0xFB7D,
  0x1F493,0xF992,0xF479,0xF9C7,
  0x1F494,0xF993,0xF64F,0xF963,
  0x1F495,0xF994,0xF650,0x0,
  0x1F496,0x0,0xF379,0x0,
  0x1F497,0x0,0x0,0xF9C8,
  0x1F498,0x0,0xF6C3,0xF9C9,
  0x1F499,0x0,0xF37A,0xF9CA,
  0x1F49A,0x0,0xF37B,0xF9CB,
  0x1F49B,0x0,0xF37C,0xF9CC,
  0x1F49C,0x0,0xF37D,0xF9CD,
  0x1F49D,0x0,0xF458,0xFB77,
  0x1F49E,0x0,0xF7CC,0x0,
  0x1F49F,0x0,0x0,0xF7A4,
  0x1F4A0,0xF99D,0x0,0x0,
  0x1F4A1,0xF9A0,0xF64E,0xF74F,
  0x1F4A2,0xF9A1,0xF6BE,0xF9D4,
  0x1F4A3,0xF9A3,0xF652,0xF9B1,
  0x1F4A4,0xF9A6,0xF64D,0xF77C,
  0x1F4A5,0xF9AA,0xF7CD,0x0,
  0x1F4A6,0xF9AB,0xF7CE,0xF9D1,
  0x1F4A7,0xF9AC,0xF6BF,0x0,
  0x1F4A8,0xF9AD,0xF6CD,0xF9D0,
  0x1F4A9,0x0,0xF6CE,0xF99B,
  0x1F4AA,0x0,0xF6C2,0xF78D,
  0x1F4AB,0x0,0xF460,0x0,
  0x1F4AC,0x0,0xF6D6,0x0,
  0x1F4AE,0x0,0xF6C9,0x0,
  0x1F4AF,0x0,0xF6CB,0x0,
  0x1F4B0,0xF9BA,0xF6A0,0xF76F,
  0x1F4B1,0x0,0x0,0xF78A,
  0x1F4B2,0x0,0xF796,0x0,
  0x1F4B3,0x0,0xF799,0x0,
  0x1F4B4,0xF97A,0xF79A,0x0,
  0x1F4B5,0x0,0xF7A2,0x0,
  0x1F4B8,0x0,0xF45F,0x0,
  0x1F4B9,0x0,0xF34F,0xF78B,
  0x1F4BA,0xF956,0x0,0xF75F,
  0x1F4BB,0xF9BB,0xF7E8,0xF94C,
  0x1F4BC,0x0,0xF341,0xF75E,
  0x1F4BD,0x0,0xF79F,0xF9B6,
  0x1F4BE,0x0,0xF77E,0x0,
  0x1F4BF,0xF8ED,0xF6E5,0xF766,
  0x1F4C0,0x0,0x0,0xF767,
  0x1F4C1,0x0,0xF7AC,0x0,
  0x1F4C2,0x0,0xF7AD,0x0,
  0x1F4C3,0x0,0xF77D,0x0,
  0x1F4C4,0x0,0xF786,0x0,
  0x1F4C5,0x0,0xF780,0x0,
  0x1F4C6,0x0,0xF787,0x0,
  0x1F4C7,0x0,0xF789,0x0,
  0x1F4C8,0x0,0xF792,0x0,
  0x1F4C9,0x0,0xF793,0x0,
  0x1F4CA,0x0,0xF791,0x0,
  0x1F4CB,0x0,0xF781,0x0,
  0x1F4CC,0x0,0xF78A,0x0,
  0x1F4CD,0x0,0xF77C,0x0,
  0x1F4CE,0xF9D5,0xF678,0x0,
  0x1F4CF,0x0,0xF78D,0x0,
  0x1F4D0,0x0,0xF67A,0x0,
  0x1F4D1,0x0,0xF7E2,0x0,
  0x1F4D2,0x0,0xF78B,0x0,
  0x1F4D3,0x0,0xF788,0x0,
  0x1F4D4,0x0,0xF675,0x0,
  0x1F4D5,0x0,0xF785,0x0,
  0x1F4D6,0xF8E4,0xF677,0xF789,
  0x1F4D7,0x0,0xF782,0x0,
  0x1F4D8,0x0,0xF783,0x0,
  0x1F4D9,0x0,0xF784,0x0,
  0x1F4DA,0x0,0xF78C,0x0,
  0x1F4DB,0x0,0xF6F6,0x0,
  0x1F4DC,0x0,0xF77B,0x0,
  0x1F4DD,0xF8EA,0xF365,0xF9A1,
  0x1F4DE,0x0,0xF6F7,0x0,
  0x1F4DF,0xF8BB,0xF7B8,0x0,
  0x1F4E0,0xF974,0xF6F9,0xF94B,
  0x1F4E1,0x0,0xF681,0xF78C,
  0x1F4E2,0x0,0x0,0xF783,
  0x1F4E3,0x0,0x0,0xF9B7,
  0x1F4E4,0x0,0xF7AF,0x0,
  0x1F4E5,0x0,0xF7B0,0x0,
  0x1F4E6,0x0,0xF6F8,0x0,
  0x1F4E7,0x0,0xF475,0x0,
  0x1F4E8,0x0,0xF7AE,0x0,
  0x1F4E9,0xF973,0xF466,0xF743,
  0x1F4EA,0x0,0xF6F4,0x0,
  0x1F4EB,0x0,0xF7E1,0xF741,
  0x1F4EE,0x0,0x0,0xF742,
  0x1F4F0,0x0,0xF7A8,0x0,
  0x1F4F1,0xF8E9,0xF7A5,0xF94A,
  0x1F4F2,0xF972,0xF7DF,0xF744,
  0x1F4F3,0x0,0xF363,0xF7F0,
  0x1F4F4,0x0,0xF364,0xF7F1,
  0x1F4F6,0x0,0xF357,0xF7AB,
  0x1F4F7,0xF8E2,0xF6EE,0xF948,
  0x1F4F9,0x0,0xF79B,0x0,
  0x1F4FA,0xF8EB,0xF6DB,0xF76A,
  0x1F4FB,0x0,0xF7E9,0xF768,
  0x1F4FC,0x0,0xF79D,0xF769,
  0x1F503,0x0,0xF7E4,0x0,
  0x1F50A,0x0,0xF6EA,0xF782,
  0x1F50B,0x0,0xF7A1,0x0,
  0x1F50C,0x0,0xF7A6,0x0,
  0x1F50D,0xF981,0xF6F1,0xF754,
  0x1F50E,0x0,0xF7DC,0x0,
  0x1F50F,0x0,0xF7E3,0x0,
  0x1F510,0x0,0xF7D3,0x0,
  0x1F511,0xF97D,0xF6F2,0xF980,
  0x1F512,0x0,0xF6F5,0xF785,
  0x1F513,0x0,0x0,0xF786,
  0x1F514,0xF9B8,0xF6EB,0xF9C5,
  0x1F516,0x0,0xF7DE,0x0,
  0x1F517,0x0,0xF7A7,0x0,
  0x1F518,0x0,0xF7DB,0x0,
  0x1F519,0x0,0xF7DD,0x0,
  0x1F51A,0xF95D,0x0,0x0,
  0x1F51B,0xF95C,0x0,0x0,
  0x1F51C,0xF95B,0x0,0x0,
  0x1F51D,0x0,0x0,0xF7EC,
  0x1F51E,0x0,0xF356,0xF7A7,
  0x1F51F,0x0,0xF747,0x0,
  0x1F520,0x0,0xF7D4,0x0,
  0x1F521,0x0,0xF7D5,0x0,
  0x1F522,0x0,0xF7D6,0x0,
  0x1F523,0x0,0xF7D7,0x0,
  0x1F524,0x0,0xF459,0x0,
  0x1F525,0x0,0xF653,0xF75D,
  0x1F526,0x0,0xF7A0,0x0,
  0x1F527,0xF9BD,0xF7A4,0x0,
  0x1F528,0x0,0xF7FB,0xF756,
  0x1F529,0x0,0xF79E,0x0,
  0x1F52A,0x0,0xF79C,0x0,
  0x1F52B,0x0,0xF6E3,0xF753,
  0x1F52E,0x0,0xF362,0x0,
  0x1F52F,0x0,0x0,0xF7DE,
  0x1F530,0x0,0xF658,0xF7A9,
  0x1F531,0x0,0x0,0xF971,
  0x1F532,0x0,0x0,0xF7BA,
  0x1F533,0x0,0x0,0xF7BB,
  0x1F534,0x0,0xF766,0xF7B9,
  0x1F535,0x0,0xF767,0x0,
  0x1F536,0x0,0xF762,0x0,
  0x1F537,0x0,0xF763,0x0,
  0x1F538,0x0,0xF752,0x0,
  0x1F539,0x0,0xF753,0x0,
  0x1F53A,0x0,0xF776,0x0,
  0x1F53B,0x0,0xF777,0x0,
  0x1F53C,0x0,0xF75F,0x0,
  0x1F53D,0x0,0xF75E,0x0,
  0x1F550,0x0,0x0,0xF964,
  0x1F551,0x0,0x0,0xF965,
  0x1F552,0x0,0x0,0xF966,
  0x1F553,0x0,0x0,0xF967,
  0x1F554,0x0,0x0,0xF968,
  0x1F555,0x0,0x0,0xF969,
  0x1F556,0x0,0x0,0xF96A,
  0x1F557,0x0,0x0,0xF96B,
  0x1F558,0x0,0x0,0xF96C,
  0x1F559,0x0,0x0,0xF96D,
  0x1F55A,0x0,0x0,0xF96E,
  0x1F55B,0x0,0x0,0xF96F,
  0x1F5FB,0xF9E5,0xF7ED,0xF97B,
  0x1F5FC,0x0,0xF699,0xFBA9,
  0x1F5FD,0x0,0x0,0xFBBD,
  0x1F5FE,0x0,0xF78F,0x0,
  0x1F5FF,0x0,0xF470,0x0,
  0x1F601,0xF9F8,0xF485,0xFB44,
  0x1F602,0x0,0xF468,0xFB52,
  0x1F603,0xF995,0xF649,0xF998,
  0x1F604,0x0,0x0,0xFB55,
  0x1F605,0xF9C7,0x0,0x0,
  0x1F606,0xF9CF,0x0,0x0,
  0x1F609,0xF9CE,0xF7F3,0xFB45,
  0x1F60A,0x0,0xF3A1,0xF997,
  0x1F60B,0xF9F7,0x0,0x0,
  0x1F60C,0xF9C6,0xF399,0xFB4A,
  0x1F60D,0xF9CB,0xF7F4,0xF746,
  0x1F60F,0xF9D1,0xF393,0xFB42,
  0x1F612,0xF9CA,0xF39D,0xFB4E,
  0x1F613,0xF9C8,0xF7F6,0xF748,
  0x1F614,0xF9C5,0xF394,0xFB43,
  0x1F616,0xF998,0xF397,0xFB47,
  0x1F618,0x0,0xF3A3,0xFB58,
  0x1F61A,0x0,0xF3A2,0xFB57,
  0x1F61C,0xF9CD,0xF6C0,0xF745,
  0x1F61D,0x0,0x0,0xFB49,
  0x1F61E,0xF997,0x0,0xF999,
  0x1F620,0xF996,0xF64A,0xF99A,
  0x1F621,0xF9C9,0xF461,0xFB56,
  0x1F622,0xF9D3,0xF46D,0xFB53,
  0x1F623,0xF9D0,0xF396,0xFB46,
  0x1F624,0x0,0xF395,0x0,
  0x1F625,0x0,0x0,0xFB41,
  0x1F628,0x0,0xF39A,0xFB4B,
  0x1F629,0x0,0xF46B,0x0,
  0x1F62A,0x0,0xF398,0xFB48,
  0x1F62B,0x0,0xF64C,0x0,
  0x1F62D,0xF9D2,0xF64B,0xFB51,
  0x1F630,0x0,0xF39F,0xFB4F,
  0x1F631,0xF9FC,0xF7F5,0xF747,
  0x1F632,0x0,0xF39E,0xFB50,
  0x1F633,0x0,0xF39C,0xFB4D,
  0x1F635,0xF999,0xF7CB,0x0,
  0x1F637,0x0,0xF39B,0xFB4C,
  0x1F638,0x0,0xF484,0x0,
  0x1F639,0x0,0xF467,0x0,
  0x1F63A,0x0,0xF465,0x0,
  0x1F63B,0x0,0xF469,0x0,
  0x1F63C,0x0,0xF46E,0x0,
  0x1F63D,0x0,0xF464,0x0,
  0x1F63E,0x0,0xF462,0x0,
  0x1F63F,0x0,0xF46C,0x0,
  0x1F640,0x0,0xF46A,0x0,
  0x1F645,0x0,0xF3AB,0xFB63,
  0x1F646,0x0,0xF3AC,0xFB64,
  0x1F647,0x0,0xF3AD,0xFB66,
  0x1F648,0x0,0xF454,0x0,
  0x1F649,0x0,0xF456,0x0,
  0x1F64A,0x0,0xF455,0x0,
  0x1F64B,0x0,0xF48A,0x0,
  0x1F64C,0x0,0xF48B,0xFB67,
  0x1F64D,0x0,0xF48C,0x0,
  0x1F64E,0x0,0xF48D,0x0,
  0x1F64F,0x0,0xF3A6,0xFB5D,
  0x1F680,0x0,0xF7F8,0xF74D,
  0x1F683,0xF8BC,0xF68E,0xF95E,
  0x1F684,0xF8BE,0x0,0xFB75,
  0x1F685,0x0,0xF689,0xF95F,
  0x1F687,0x0,0xF7EC,0xFB74,
  0x1F689,0x0,0xF471,0xF979,
  0x1F68C,0xF8C1,0xF688,0xF79A,
  0x1F68F,0x0,0xF680,0xF791,
  0x1F691,0x0,0xF3B4,0xFB71,
  0x1F692,0x0,0xF3B3,0xFB70,
  0x1F693,0x0,0xF3B5,0xFB72,
  0x1F695,0x0,0x0,0xF79B,
  0x1F697,0xF8BF,0xF68A,0xF95B,
  0x1F699,0xF8C0,0x0,0xFB6E,
  0x1F69A,0x0,0xF68B,0xFB6F,
  0x1F6A2,0xF8C2,0xF355,0xF7A2,
  0x1F6A4,0x0,0x0,0xF775,
  0x1F6A5,0xF8CE,0xF642,0xF78F,
  0x1F6A7,0x0,0xF34A,0xF777,
  0x1F6A8,0x0,0xF477,0x0,
  0x1F6A9,0xF983,0xF3ED,0x0,
  0x1F6AA,0xF9B9,0x0,0x0,
  0x1F6AB,0x0,0xF75D,0x0,
  0x1F6AC,0xF8E0,0xF655,0xF9AE,
  0x1F6AD,0xF8E1,0xF656,0xF7A8,
  0x1F6B2,0xF9C2,0xF687,0xF776,
  0x1F6B6,0x0,0xF476,0xF7A1,
  0x1F6B9,0x0,0x0,0xF778,
  0x1F6BA,0x0,0x0,0xF779,
  0x1F6BB,0xF8CF,0xF67D,0xF792,
  0x1F6BC,0x0,0x0,0xF77A,
  0x1F6BD,0x0,0x0,0xF781,
  0x1F6BE,0x0,0x0,0xF9A9,
  0x1F6C0,0x0,0xF34B,0xF780,
  0
};

skf_ucode n_conv_priv2emot[6400] = {
  0x000000,0x01f466,0x01f467,0x01f48b,0x01f468,0x01f469,0x01f455,0x01f45f,
  0x01f4f7,0x00260e,0x01f4f1,0x01f4e0,0x01f4bb,0x01f44a,0x01f44d,0x00261d,
  0x00270a,0x00270c,0x00270b,0x01f3bf,0x0026f3,0x01f3be,0x0026be,0x01f3c4,
  0x0026bd,0x01f41f,0x01f434,0x01f697,0x0026f5,0x002708,0x01f683,0x01f685,
  0x002753,0x002757,0x002764,0x01f494,0x01f550,0x01f551,0x01f552,0x01f553,
  0x01f554,0x01f555,0x01f556,0x01f557,0x01f558,0x01f559,0x01f55a,0x01f55b,
  0x01f338,0x01f531,0x01f339,0x01f384,0x01f48d,0x01f48e,0x01f3e0,0x0026ea,
  0x01f3e2,0x01f689,0x0026fd,0x01f5fb,0x01f3a4,0x01f3a5,0x01f3b5,0x01f511,
  0x01f3b7,0x01f3b8,0x01f3ba,0x01f374,0x01f378,0x002615,0x01f370,0x01f37a,
  0x0026c4,0x002601,0x002600,0x002614,0x01f319,0x01f304,0x01f47c,0x01f431,
  0x01f42f,0x01f43b,0x01f436,0x01f42d,0x01f433,0x01f427,0x01f60a,0x01f603,
  0x01f61e,0x01f620,0x01f4a9,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
/* e100 - */
  0x000000,0x01f4eb,0x01f4ee,0x01f4e9,0x01f4f2,0x01f61c,0x01f60d,0x01f631,
  0x01f613,0x01f435,0x01f419,0x01f437,0x01f47d,0x01f680,0x01f451,0x01f4a1,
  0x01f340,0x01f48f,0x01f381,0x01f52b,0x01f50d,0x01f3c3,0x01f528,0x01f386,
  0x01f341,0x01f342,0x01f47f,0x01f47b,0x01f480,0x01f525,0x01f4bc,0x01f4ba,
  0x01f354,0x0026f2,0x0026fa,0x002668,0x01f3a1,0x01f3ab,0x01f4bf,0x01f4c0,
  0x01f4fb,0x01f4fc,0x01f4fa,0x01f47e,0x00303d,0x01f004,0x01f19a,0x01f4b0,
  0x01f3af,0x01f3c6,0x01f3c1,0x01f3b0,0x01f40e,0x01f6a4,0x01f6b2,0x01f6a7,
  0x01f6b9,0x01f6ba,0x01f6bc,0x01f489,0x01f4a4,0x0026a1,0x01f460,0x01f6c0,
  0x01f6bd,0x01f50a,0x01f4e2,0x01f38c,0x01f512,0x01f513,0x01f306,0x01f373,
  0x01f4d6,0x01f4b1,0x01f4b9,0x01f4e1,0x01f4aa,0x01f3e6,0x01f6a5,0x01f17f,
  0x01f68f,0x01f6bb,0x01f46e,0x01f3e3,0x01f3e7,0x01f3e5,0x01f3ea,0x01f3eb,
  0x01f3e8,0x01f68c,0x01f695,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
/* e200 - */
  0x000000,0x01f6b6,0x01f6a2,0x01f201,0x01f49f,0x002734,0x002733,0x01f51e,
  0x01f6ad,0x01f530,0x00267f,0x01f4f6,0x002665,0x002666,0x002660,0x002663,
  0x00d851,0x000000,0x01f195,0x01f199,0x01f192,0x01f236,0x01f21a,0x01f237,
  0x01f238,0x01f534,0x01f532,0x01f533,0x00d853,0x00d854,0x00d855,0x00d856,
  0x00d857,0x00d858,0x00d859,0x00d85a,0x00d85b,0x00d852,0x01f250,0x01f239,
  0x01f202,0x01f194,0x01f235,0x01f233,0x01f22f,0x01f23a,0x01f446,0x01f447,
  0x01f448,0x01f449,0x002b06,0x002b07,0x0027a1,0x002b05,0x002197,0x002196,
  0x002198,0x002199,0x0025b6,0x0025c0,0x0023e9,0x0023ea,0x01f52f,0x002648,
  0x002649,0x00264a,0x00264b,0x00264c,0x00264d,0x00264e,0x00264f,0x002650,
  0x002651,0x002652,0x002653,0x0026ce,0x01f51d,0x01f197,0x0000a9,0x0000ae,
  0x01f4f3,0x01f4f4,0x0026a0,0x01f481,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
/* e300 - */
  0x000000,0x01f4dd,0x01f454,0x01f33a,0x01f337,0x01f33b,0x01f490,0x01f334,
  0x01f335,0x01f6be,0x01f3a7,0x01f376,0x01f37b,0x003297,0x01f6ac,0x01f48a,
  0x01f388,0x01f4a3,0x01f389,0x002702,0x01f380,0x003299,0x01f4bd,0x01f4e3,
  0x01f452,0x01f457,0x01f461,0x01f462,0x01f484,0x01f485,0x01f486,0x01f487,
  0x01f488,0x01f458,0x01f459,0x01f45c,0x01f3ac,0x01f514,0x01f3b6,0x01f493,
  0x01f497,0x01f498,0x01f499,0x01f49a,0x01f49b,0x01f49c,0x002728,0x002b50,
  0x01f4a8,0x01f4a6,0x002b55,0x00274c,0x01f4a2,0x01f31f,0x002754,0x002755,
  0x01f375,0x01f35e,0x01f366,0x01f35f,0x01f361,0x01f358,0x01f35a,0x01f35d,
  0x01f35c,0x01f35b,0x01f359,0x01f362,0x01f363,0x01f34e,0x01f34a,0x01f353,
  0x01f349,0x01f345,0x01f346,0x01f382,0x01f371,0x01f372,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
/* e400 - */
  0x000000,0x01f625,0x01f60f,0x01f614,0x01f601,0x01f609,0x01f623,0x01f616,
  0x01f62a,0x01f61d,0x01f60c,0x01f628,0x01f637,0x01f633,0x01f612,0x01f630,
  0x01f632,0x01f62d,0x01f602,0x01f622,0x00263a,0x01f604,0x01f621,0x01f61a,
  0x01f618,0x01f440,0x01f443,0x01f442,0x01f444,0x01f64f,0x01f44b,0x01f44f,
  0x01f44c,0x01f44e,0x01f450,0x01f645,0x01f646,0x01f491,0x01f647,0x01f64c,
  0x01f46b,0x01f46f,0x01f3c0,0x01f3c8,0x01f3b1,0x01f3ca,0x01f699,0x01f69a,
  0x01f692,0x01f691,0x01f693,0x01f3a2,0x01f687,0x01f684,0x01f38d,0x01f49d,
  0x01f38e,0x01f393,0x01f392,0x01f38f,0x01f302,0x01f492,0x01f30a,0x01f367,
  0x01f387,0x01f41a,0x01f390,0x01f300,0x01f33e,0x01f383,0x01f391,0x01f343,
  0x01f385,0x01f305,0x01f307,0x01f303,0x01f308,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
/* e500 - */
  0x000000,0x01f3e9,0x01f3a8,0x01f3a9,0x01f3ec,0x01f3ef,0x01f3f0,0x01f3a6,
  0x01f3ed,0x01f5fc,0x000000,0x00d862,0x00d865,0x00d85f,0x00d85d,0x00d861,
  0x00d860,0x00d85e,0x00d864,0x00d85c,0x00d863,0x01f471,0x01f472,0x01f473,
  0x01f474,0x01f475,0x01f476,0x01f477,0x01f478,0x01f5fd,0x01f482,0x01f483,
  0x01f42c,0x01f426,0x01f420,0x01f424,0x01f439,0x01f41b,0x01f418,0x01f428,
  0x01f412,0x01f411,0x01f43a,0x01f42e,0x01f430,0x01f40d,0x01f414,0x01f417,
  0x01f42b,0x01f438,0x01f170,0x01f171,0x01f18e,0x01f17e,0x01f463,0x002122,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
/* e600 - */
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x002600,0x002601,
  0x002614,0x0026c4,0x0026a1,0x01f300,0x01f301,0x01f302,0x002648,0x002649,
  0x00264a,0x00264b,0x00264c,0x00264d,0x00264e,0x00264f,0x002650,0x002651,
  0x002652,0x002653,0x01f3bd,0x0026be,0x0026f3,0x01f3be,0x0026bd,0x01f3bf,
  0x01f3c0,0x01f3c1,0x01f4df,0x01f683,0x0024c2,0x01f684,0x01f697,0x01f699,
  0x01f68c,0x01f6a2,0x002708,0x01f3e0,0x01f3e2,0x01f3e3,0x01f3e5,0x01f3e6,
  0x01f3e7,0x01f3e8,0x01f3ea,0x0026fd,0x01f17f,0x01f6a5,0x01f6bb,0x01f374,
  0x002615,0x01f378,0x01f37a,0x01f354,0x01f460,0x002702,0x01f3a4,0x01f3a5,
  0x002197,0x01f3a0,0x01f3a7,0x01f3a8,0x01f3a9,0x01f3aa,0x01f3ab,0x01f6ac,
  0x01f6ad,0x01f4f7,0x01f45c,0x01f4d6,0x01f380,0x01f381,0x01f382,0x00260e,
  0x01f4f1,0x01f4dd,0x01f4fa,0x01f3ae,0x01f4bf,0x002665,0x002660,0x002666,
  0x002663,0x01f440,0x01f442,0x00270a,0x00270c,0x00270b,0x002198,0x002196,
  0x01f463,0x01f45f,0x01f453,0x00267f,0x000000,0x00d851,0x000000,0x00d853,
  0x00d854,0x00d855,0x00d856,0x00d857,0x00d858,0x00d859,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x01f495,0x01f603,0x01f620,0x000000,
  0x000000,0x01f635,0x002934,0x01f3b5,0x000000,0x000000,0x000000,0x002728,
  0x01f4a1,0x01f4a2,0x01f44a,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x01f456,0x01f3c2,
  0x01f514,0x01f6aa,0x01f4b0,0x01f4bb,0x01f48c,0x01f527,0x00270f,0x01f451,
  0x01f48d,0x0023f3,0x01f6b2,0x00231a,0x01f614,0x01f60c,0x01f605,0x01f613,
  0x01f621,0x01f612,0x01f60d,0x01f44d,0x01f61c,0x01f609,0x01f606,0x01f623,
  0x01f60f,0x01f62d,0x01f622,0x01f196,0x01f4ce,0x0000a9,0x002122,0x01f3c3,
  0x003299,0x00267b,0x0000ae,0x0026a0,0x01f232,0x01f233,0x01f234,0x01f235,
  0x002194,0x002195,0x01f3eb,0x01f30a,0x01f5fb,0x01f340,0x01f352,0x01f337,
/* e700 - */
  0x01f34c,0x01f34e,0x01f331,0x01f341,0x01f338,0x01f359,0x01f370,0x01f376,
  0x01f35c,0x01f35e,0x01f40c,0x01f424,0x01f427,0x01f41f,0x01f60b,0x01f601,
  0x01f434,0x01f437,0x01f377,0x01f631,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
/* e800 - */
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
/* e900 - */
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
/* ea00 - */
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
/* eb00 - */
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
/* ec00 - */
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
/* ed00 - */
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
/* ee00 - */
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
/* ef00 - */
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
/* f000 - */
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
/* f100 - */
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
/* f200 - */
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
/* f300 - */
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
/* f400 - */
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
/* f500 - */
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
/* f600 - */
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
/* f700 - */
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
/* f800 - */
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,
  0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000,0x000000
/* f900 - */
  };
#if defined(OUTPUT_DYNAMIC_TABLE) || !defined(DYNAMIC_LOADING) || defined(SWIG_EXT)
/* --------------------------------------------------------------- */
/* GBK generation patches					   */
/* --------------------------------------------------------------- */
unsigned short gbk_compat[] = {
  0xf92c,0xf979,0xf995,0xf9e7, 0xf9f1,
  0xe40a,0xe40b, 0xe40c,0xe40d,0xe40e,0xe40f,
  0xe410,0xe411,0xe412,0xe413, 0xe414,0xe415,0xe416,0xe417,
  0xe418,0xe419,0xe41a,0xe41b, 0xe41c,0xe41d,0xe41e,0xe41f,
  0xe420,0xe421,0xe422,0xe423, 0xe424,0xe425,0xe426,0xe427,
  0xe428,0xe429,0xe42a,0xe42b, 0xe42c,0xe42d,0xe42e,0xe42f,
  0xe430,0xe431,0xe432,0xe433, 0xe434,0xe435,0xe436,0xe437,
  0xe438,0xe439,0xe43a,0xe43b, 0xe43c,0xe43d,0xe43e,0xe43f,
  0xe440,0xe441,0xe442,0xe443, 0xe444,0xe445,0xe446,0xe447,
  0xe448,0xe449,0xe44a,0xe44b, 0xe44c,0xe44d,0xe44e,0xe44f,
  0xe450,0xe451,0xe452,0xe453, 0xe454,0xe455,0xe456,0xe457,
  0xe458,0xe459,0xe45a,0xe45b, 0xe45c,0xe45d,0xe45e,0xe45f,
  0xe460,0xe461,0xe462,0xe463, 0xe464,0xe465,0xe466,0xe467,
  0xfa0c,0xfa0d,0xfa0e,0xfa0f, 0xfa11,0xfa13,0xfa14,0xfa18,
  0xfa1f,0xfa20,0xfa21,0xfa23, 0xfa24,0xfa27,0xfa28,0xfa29,
  0xe815,0xe816,0xe817,0xe818, 0xe819,0xe81a,0xe81b,0xe81c,
  0xe81d,0xe81e,0xe81f,0xe820, 0xe821,0xe822,0xe823,0xe824,
  0xe825,0xe826,0xe827,0xe828, 0xe829,0xe82a,0xe82b,0xe82c,
  0xe82d,0xe82e,0xe82f,0xe830, 0xe831,0xe832,0xe833,0xe834,
  0xe835,0xe836,0xe837,0xe838, 0xe839,0xe83a,0xe83b,0xe83c,
  0xe83d,0xe83e,0xe83f,0xe840, 0xe841,0xe842,0xe843,0xe844,
  0xe845,0xe846,0xe847,0xe848, 0xe849,0xe84a,0xe84b,0xe84c,
  0xe84d,0xe84e,0xe84f,0xe850, 0xe851,0xe852,0xe853,0xe854,
  0xe855,0xe856,0xe857,0xe858, 0xe859,0xe85a,0xe85b,0xe85c,
  0xe85d,0xe85e,0xe85f,0xe860, 0xe861,0xe862,0xe863,0xe864,
  0xe468,0xe469,0xe46a,0xe46b, 0xe46c,0xe46d,0xe46e,0xe46f,
  0xe470,0xe471,0xe472,0xe473, 0xe474,0xe475,0xe476,0xe477,
  0xe478,0xe479,0xe47a,0xe47b, 0xe47c,0xe47d,0xe47e,0xe47f,
  0xe480,0xe481,0xe482,0xe483, 0xe484,0xe485,0xe486,0xe487,
  0xe488,0xe489,0xe48a,0xe48b, 0xe48c,0xe48d,0xe48e,0xe48f,
  0xe490,0xe491,0xe492,0xe493, 0xe494,0xe495,0xe496,0xe497,
  0xe498,0xe499,0xe49a,0xe49b, 0xe49c,0xe49d,0xe49e,0xe49f,
  0xe4a0,0xe4a1,0xe4a2,0xe4a3, 0xe4a4,0xe4a5,0xe4a6,0xe4a7,
  0xe4a8,0xe4a9,0xe4aa,0xe4ab, 0xe4ac,0xe4ad,0xe4ae,0xe4af,
  0xe4b0,0xe4b1,0xe4b2,0xe4b3, 0xe4b4,0xe4b5,0xe4b6,0xe4b7,
  0xe4b8,0xe4b9,0xe4ba,0xe4bb, 0xe4bc,0xe4bd,0xe4be,0xe4bf,
  0xe4c0,0xe4c1,0xe4c2,0xe4c3, 0xe4c4,0xe4c5,
  0xffff
};

unsigned short gbk_vert_patch[] = {
  0xe78d,0xe78e,
  0xe78f,0xe790,0xe791,0xe792, 0xe793,0xfe35,0xfe36,0xfe39,
  0xfe3a,0xfe3f,0xfe40,0xfe3d, 0xfe3e,0xfe41,0xfe42,0xfe43,
  0xfe44,0xe794,0xe795,0xfe3b, 0xfe3c,0xfe37,0xfe38,0xfe31,
  0xe796,0xfe33,0xfe34,0xe797, 0xe798,0xe799,0xe79a,0xe79b,
  0xe79c,0xe79d,0xe79e,0xe79f
};

unsigned short gbk_cjk_a_patch[] = {
/* a2xx */
  0xe766,0xa2ab,
  0xe767,0xa2ac, 0xe768,0xa2ad, 0xe769,0xa2ae, 0xe76a,0xa2af,
  0xe76b,0xa2b0,
  0xe76c,0xa2e3, 0xe76d,0xa2e4, 0xe76e,0xa2ef, 0xe76f,0xa2f0,
  0xe770,0xa2fd, 0xe771,0xa2fe,
/* a4xx */
  0xe772,0xa4f4, 0xe773,0xa4f5, 0xe774,0xa4f6, 0xe775,0xa4f7,
  0xe776,0xa4f8, 0xe777,0xa4f9, 0xe778,0xa4fa, 0xe779,0xa4fb,
  0xe77a,0xa4fc, 0xe77b,0xa4fd, 0xe77c,0xa4fe,
/* a5xx */
  0xe77d,0xa5f7, 0xe77e,0xa5f8, 0xe77f,0xa5f9, 0xe780,0xa5fa,
  0xe781,0xa5fb, 0xe782,0xa5fc, 0xe783,0xa5fd, 0xe784,0xa5fe,
/* a6xx */
  0xe785,0xa6b9, 0xe786,0xa6ba, 0xe787,0xa6bb, 0xe788,0xa6bc,
  0xe789,0xa6bd, 0xe78a,0xa6be, 0xe78b,0xa6bf, 0xe78c,0xa6c0,
  0xe78d,0xa6d9, 0xe78e,0xa6da, 0xe78f,0xa6db, 0xe790,0xa6dc,
  0xe791,0xa6dd, 0xe792,0xa6de, 0xe793,0xa6df, 0xe794,0xa6ec,
  0xe795,0xa6ed, 0xe796,0xa6f3, 0xe797,0xa6f6, 0xe798,0xa6f7,
  0xe799,0xa6f8, 0xe79a,0xa6f9, 0xe79b,0xa6fa, 0xe79c,0xa6fb,
  0xe79d,0xa6fc, 0xe79e,0xa6fd, 0xe79f,0xa6fe,
/* a7xx */
  0xe7a0,0xa7c2, 0xe7a1,0xa7c3, 0xe7a2,0xa7c4, 0xe7a3,0xa7c5,
  0xe7a4,0xa7c6, 0xe7a5,0xa7c7, 0xe7a6,0xa7c8, 0xe7a7,0xa7c9,
  0xe7a8,0xa7ca, 0xe7a9,0xa7cb, 0xe7aa,0xa7cc, 0xe7ab,0xa7cd,
  0xe7ac,0xa7ce, 0xe7ad,0xa7cf, 0xe7ae,0xa7d0, 0xe7af,0xa7f2,
  0xe7b0,0xa7f3, 0xe7b1,0xa7f4, 0xe7b2,0xa7f5, 0xe7b3,0xa7f6,
  0xe7b4,0xa7f7, 0xe7b5,0xa7f8, 0xe7b6,0xa7f9, 0xe7b7,0xa7fa,
  0xe7b8,0xa7fb, 0xe7b9,0xa7fc, 0xe7ba,0xa7fd, 0xe7bb,0xa7fe,
/* a8xx */
  0x02ca,0xa840, 0x02cb,0xa841, 0x02d9,0xa842, 0x2013,0xa843,
  0x2015,0xa844, 0x2025,0xa845, 0x2035,0xa846, 0x2105,0xa847,
  0x2109,0xa848, 0x2196,0xa849, 0x2197,0xa84a, 0x2198,0xa84b,
  0x2199,0xa84c, 0x2215,0xa84d, 0x221f,0xa84e, 0x2223,0xa84f,
  0x2252,0xa850, 0x2266,0xa851, 0x2267,0xa852, 0x22bf,0xa853,
  0x2550,0xa854, 0x2551,0xa855, 0x2552,0xa856, 0x2553,0xa857,
  0x2554,0xa858, 0x2555,0xa859, 0x2556,0xa85a, 0x2557,0xa85b,
  0x2558,0xa85c, 0x2559,0xa85d, 0x255a,0xa85e, 0x255b,0xa85f,
  0x255c,0xa860, 0x255d,0xa861, 0x255e,0xa862, 0x255f,0xa863,
  0x2560,0xa864, 0x2561,0xa865, 0x2562,0xa866, 0x2563,0xa867,
  0x2564,0xa868, 0x2565,0xa869, 0x2566,0xa86a, 0x2567,0xa86b,
  0x2568,0xa86c, 0x2569,0xa86d, 0x256a,0xa86e, 0x256b,0xa86f,
  0x256c,0xa870, 0x256d,0xa871, 0x256e,0xa872, 0x256f,0xa873,
  0x2570,0xa874, 0x2571,0xa875, 0x2572,0xa876, 0x2573,0xa877,
  0x2581,0xa878, 0x2582,0xa879, 0x2583,0xa87a, 0x2584,0xa87b,
  0x2585,0xa87c, 0x2586,0xa87d, 0x2587,0xa87e,
  0x2588,0xa880, 0x2589,0xa881, 0x258a,0xa882, 0x258b,0xa883,
  0x258c,0xa884, 0x258d,0xa885, 0x258e,0xa886, 0x258f,0xa887,
  0x2593,0xa888, 0x2594,0xa889, 0x2595,0xa88a, 0x25bc,0xa88b,
  0x25bd,0xa88c, 0x25e2,0xa88d, 0x25e3,0xa88e, 0x25e4,0xa88f,
  0x25e5,0xa890, 0x2609,0xa891, 0x2295,0xa892, 0x3012,0xa893,
  0x301d,0xa894, 0x301e,0xa895, 0xe7bc,0xa896, 0xe7bd,0xa897,
  0xe7be,0xa898, 0xe7bf,0xa899, 0xe7c0,0xa89a, 0xe7c1,0xa89b,
  0xe7c2,0xa89c, 0xe7c3,0xa89d, 0xe7c4,0xa89e, 0xe7c5,0xa89f,
  0xe7c6,0xa8a0, 0xe7c7,0xa8bc, 0xe7c8,0xa8bf,
  0xe7c9,0xa8c1, 0xe7ca,0xa8c2, 0xe7cb,0xa8c3,
  0xe7cc,0xa8c4, 0xe7cd,0xa8ea, 0xe7ce,0xa8eb, 0xe7cf,0xa8ec,
  0xe7d0,0xa8ed, 0xe7d1,0xa8ee, 0xe7d2,0xa8ef, 0xe7d3,0xa8f0,
  0xe7d4,0xa8f1, 0xe7d5,0xa8f2, 0xe7d6,0xa8f3, 0xe7d7,0xa8f4,
  0xe7d8,0xa8f5, 0xe7d9,0xa8f6, 0xe7da,0xa8f7, 0xe7db,0xa8f8,
  0xe7dc,0xa8f9, 0xe7dd,0xa8fa, 0xe7de,0xa8fb, 0xe7df,0xa8fc,
  0xe7e0,0xa8fd, 0xe7e1,0xa8fe,
/* a9xx */
  0x3021,0xa940, 0x3022,0xa941, 0x3023,0xa942, 0x3024,0xa943,
  0x3025,0xa944, 0x3026,0xa945, 0x3027,0xa946, 0x3028,0xa947,
  0x3029,0xa948, 0x32a3,0xa949, 0x338e,0xa94a, 0x338f,0xa94b,
  0x339c,0xa94c, 0x339d,0xa94d, 0x339e,0xa94e, 0x33a1,0xa94f,
  0x33c4,0xa950, 0x33ce,0xa951, 0x33d1,0xa952, 0x33d2,0xa953,
  0x33d5,0xa954, 0xfe30,0xa955, 0xffe2,0xa956, 0xffe4,0xa957,
  0xe7e2,0xa958, 0x2121,0xa959, 0x3231,0xa95a, 0xe7e3,0xa95b,
  0x2010,0xa95c, 0xe7e4,0xa95d, 0xe7e5,0xa95e, 0xe7e6,0xa95f,
  0x30fc,0xa960, 0x309b,0xa961, 0x309c,0xa962, 0x30fd,0xa963,
  0x30fe,0xa964, 0x3006,0xa965, 0x309d,0xa966, 0x309e,0xa967,
  0xfe49,0xa968, 0xfe4a,0xa969, 0xfe4b,0xa96a, 0xfe4c,0xa96b,
  0xfe4d,0xa96c, 0xfe4e,0xa96d, 0xfe4f,0xa96e, 0xfe50,0xa96f,
  0xfe51,0xa970, 0xfe52,0xa971, 0xfe54,0xa972, 0xfe55,0xa973,
  0xfe56,0xa974, 0xfe57,0xa975, 0xfe59,0xa976, 0xfe5a,0xa977,
  0xfe5b,0xa978, 0xfe5c,0xa979, 0xfe5d,0xa97a, 0xfe5e,0xa97b,
  0xfe5f,0xa97c, 0xfe60,0xa97d, 0xfe61,0xa97e,
  0xfe62,0xa980, 0xfe63,0xa981, 0xfe64,0xa982, 0xfe65,0xa983,
  0xfe66,0xa984, 0xfe68,0xa985, 0xfe69,0xa986, 0xfe6a,0xa987,
  0xfe6b,0xa988, 0xe7e7,0xa989, 0xe7e8,0xa98a, 0xe7e9,0xa98b,
  0xe7ea,0xa98c, 0xe7eb,0xa98d, 0xe7ec,0xa98e, 0xe7ed,0xa98f,
  0xe7ee,0xa990, 0xe7ef,0xa991, 0xe7f0,0xa992, 0xe7f1,0xa993,
  0xe7f2,0xa994, 0xe7f3,0xa995, 0x3007,0xa996, 0xe7f4,0xa997,
  0xe7f5,0xa998, 0xe7f6,0xa999, 0xe7f7,0xa99a, 0xe7f8,0xa99b,
  0xe7f9,0xa99c, 0xe7fa,0xa99d, 0xe7fb,0xa99e, 0xe7fc,0xa99f,
  0xe7fd,0xa9a0, 0xe7fe,0xa9a1, 0xe7ff,0xa9a2, 0xe800,0xa9a3,

  0xe801,0xa9f0, 0xe802,0xa9f1, 0xe803,0xa9f2, 0xe804,0xa9f3,
  0xe805,0xa9f4, 0xe806,0xa9f5, 0xe807,0xa9f6, 0xe808,0xa9f7,
  0xe809,0xa9f8, 0xe80a,0xa9f9, 0xe80b,0xa9fa, 0xe80c,0xa9fb,
  0xe80d,0xa9fc, 0xe80e,0xa9fd, 0xe80f,0xa9fe,

#if defined(USE_CJK_A_ON_GBK) 
/* cjk_a_patch */
  0x3447,0xfe56, 0x3473,0xfe55, 0x359e,0xfe5a, 0x360e,0xfe5c,
  0x361a,0xfe5b, 0x3918,0xfe60, 0x396e,0xfe5f, 0x39cf,0xfe62,
  0x39d0,0xfe65, 0x39df,0xfe63, 0x3a73,0xfe64, 0x3b4e,0xfe68,
  0x3c6e,0xfe69, 0x3ce0,0xfe6a, 0x4056,0xfe6f, 0x415f,0xfe70,

  0x4337,0xfe72, 0x43ac,0xfe78, 0x43b1,0xfe77, 0x43dd,0xfe7a,
  0x44d6,0xfe7b, 0x464c,0xfe7d, 0x4661,0xfe7c, 0x4723,0xfe80,
  0x4729,0xfe81, 0x477c,0xfe82, 0x478d,0xfe83, 0x4947,0xfe85,
  0x497a,0xfe86, 0x497d,0xfe87, 0x4982,0xfe88, 0x4983,0xfe89,

  0x4985,0xfe8a, 0x4986,0xfe8b, 0x499b,0xfe8d, 0x499f,0xfe8c,
  0x49b6,0xfe8f, 0x49b7,0xfe8e, 0x4c77,0xfe96, 0x4c9f,0xfe93,
  0x4ca0,0xfe94, 0x4ca1,0xfe95, 0x4ca2,0xfe97, 0x4ca3,0xfe92,
  0x4d13,0xfe98, 0x4d14,0xfe99, 0x4d15,0xfe9a, 0x4d16,0xfe9b,

  0x4d17,0xfe9c, 0x4d18,0xfe9d, 0x4d19,0xfe9e, 0x4dae,0xfe9f,
#endif
  0x0000,0x0000
};

unsigned short gb2k_compat[] = {
  0xf92c,0xf979,0xf995,0xf9e7, 
  0xf9f1,0xe40a,0xe40b,0xe40c, 0xe40d,0xe40e,0xe40f,0xe410,
  0xe411,0xe412,0xe413,0xe414, 0xe415,0xe416,0xe417,0xe418,
  0xe419,0xe41a,0xe41b,0xe41c, 0xe41d,0xe41e,0xe41f,0xe420,
  0xe421,0xe422,0xe423,0xe424, 0xe425,0xe426,0xe427,0xe428,
  0xe429,0xe42a,0xe42b,0xe42c, 0xe42d,0xe42e,0xe42f,0xe430,
  0xe431,0xe432,0xe433,0xe434, 0xe435,0xe436,0xe437,0xe438,
  0xe439,0xe43a,0xe43b,0xe43c, 0xe43d,0xe43e,0xe43f,0xe440,
  0xe441,0xe442,0xe443,0xe444, 0xe445,0xe446,0xe447,0xe448,
  0xe449,0xe44a,0xe44b,0xe44c, 0xe44d,0xe44e,0xe44f,0xe450,
  0xe451,0xe452,0xe453,0xe454, 0xe455,0xe456,0xe457,0xe458,
  0xe459,0xe45a,0xe45b,0xe45c, 0xe45d,0xe45e,0xe45f,0xe460,
  0xe461,0xe462,0xe463,0xe464, 0xe465,0xe466,0xe467,
  0xfa0c,0xfa0d,0xfa0e,0xfa0f, 0xfa11,0xfa13,0xfa14,0xfa18,
  0xfa1f,0xfa20,0xfa21,0xfa23, 0xfa24,0xfa27,0xfa28,0xfa29,
  0x2e81,0xe816,0xe817,0xe818, 0x2e84,0x3473,0x3447,0x2e88,
  0x2e8b,0xe81e,0x359e,0x361a, 0x360e,0x2e8c,0x2e97,0x396e,
  0x3918,0xe826,0x39cf,0x39df, 0x3a73,0x39d0,0xe82b,0xe82c,
  0x3b4e,0x3c6e,0x3ce0,0x2ea7, 0xe831,0xe832,0x2eaa,0x4056,
  0x415f,0x2eae,0x4337,0x2eb3, 0x2eb6,0x2eb7,0xe83b,0x43b1,
  0x43ac,0x2ebb,0x43dd,0x44d6, 0x4661,0x464c,0xe843,
  0x4723,0x4729,0x477c,0x478d, 0x2eca,0x4947,0x497a,0x497d,
  0x4982,0x4983,0x4985,0x4986, 0x499f,0x499b,0x49b7,0x49b6,
  0xe854,0xe855,0x4ca3,0x4c9f, 0x4ca0,0x4ca1,0x4c77,0x4ca2,
  0x4d13,0x4d14,0x4d15,0x4d16, 0x4d17,0x4d18,0x4d19,0x4dae,
  0xe864,0xe468,0xe469,0xe46a, 0xe46b,0xe46c,0xe46d,0xe46e,
  0xe46f,0xe470,0xe471,0xe472, 0xe473,0xe474,0xe475,0xe476,
  0xe477,0xe478,0xe479,0xe47a, 0xe47b,0xe47c,0xe47d,0xe47e,
  0xe47f,0xe480,0xe481,0xe482, 0xe483,0xe484,0xe485,0xe486,
  0xe487,0xe488,0xe489,0xe48a, 0xe48b,0xe48c,0xe48d,0xe48e,
  0xe48f,0xe490,0xe491,0xe492, 0xe493,0xe494,0xe495,0xe496,
  0xe497,0xe498,0xe499,0xe49a, 0xe49b,0xe49c,0xe49d,0xe49e,
  0xe49f,0xe4a0,0xe4a1,0xe4a2, 0xe4a3,0xe4a4,0xe4a5,0xe4a6,
  0xe4a7,0xe4a8,0xe4a9,0xe4aa, 0xe4ab,0xe4ac,0xe4ad,0xe4ae,
  0xe4af,0xe4b0,0xe4b1,0xe4b2, 0xe4b3,0xe4b4,0xe4b5,0xe4b6,
  0xe4b7,0xe4b8,0xe4b9,0xe4ba, 0xe4bb,0xe4bc,0xe4bd,0xe4be,
  0xe4bf,0xe4c0,0xe4c1,0xe4c2, 0xe4c3,0xe4c4,0xe4c5,
  0xffff
};

unsigned short gb2k_cjk_a_patch[] = {
  0x20ac,0xa2e3,
  0x01f9,0xa8bf, 
  0x303e,0xa989, 0x2ff0,0xa98a, 0x2ff1,0xa98b,
  0x2ff2,0xa98c, 0x2ff3,0xa98d, 0x2ff4,0xa98e, 0x2ff5,0xa98f,
  0x2ff6,0xa990, 0x2ff7,0xa991, 0x2ff8,0xa992, 0x2ff9,0xa993,
  0x2ffa,0xa994, 0x2ffb,0xa995,
  0x0000,0x0000
};

unsigned short cp932w_latin_patch[] = { /* 0xa0 - 0xff */
  0x0000,0x0021,0x2171,0x2172, 0x0000,0x005c,0x007c,0x0000,
  0x0000,0x0063,0x0061,0x2263, 0x224c,0x002d,0x0052,0x2131,
  0x0000,0x0000,0x0032,0x0033, 0x0000,0x264c,0x0000,0x2126,
  0x2124,0x0031,0x006f,0x2264, 0x0000,0x0000,0x0000,0x0000,

  0x0041,0x0041,0x0041,0x0041, 0x0041,0x0041,0x0041,0x0043,
  0x0045,0x0045,0x0045,0x0045, 0x0049,0x0049,0x0049,0x0049,
  0x0044,0x004e,0x004f,0x004f, 0x004f,0x004f,0x004f,0x0000,
  0x004f,0x0055,0x0055,0x0055, 0x0055,0x0059,0x0054,0x0073,

  0x0061,0x0061,0x0061,0x0061, 0x0061,0x0061,0x0061,0x0063,
  0x0065,0x0065,0x0065,0x0065, 0x0069,0x0069,0x0069,0x0069,
  0x0064,0x006e,0x006f,0x006f, 0x006f,0x006f,0x006f,0x0000,
  0x006f,0x0075,0x0075,0x0075, 0x0075,0x0079,0x0074,0x0079
};

#endif

#ifdef KEIS_EXTRA_SUPPORT
skf_ucode o_KEIS_9F[56] = { 
    	   0x4f03,0x4f0b,0x5215, 0x5271,0x5786,0x57c7,0x57de,
    0x37e2,0x5d6d,0x625a,0x677b, 0x67c0,0x67f5,0x6935,0x6980,
    0x6992,0x6a73,0x6a9e,0x6ae4, 0x6c97,0x6e57,0x6ebf,0x6f8d,
    0x6f97,0x710f,0x72be,0x73ca, 0x757e,0x7682,0x7823,0x784e,
    0x7a5d,0x7ca0,0x7cd9,0x81fa, 0x828e,0x8330,0x845a,0x85ad,
    0x880b,0x8983,0x92d3,0x93ba, 0x958d,0x9733,0x973b,0x974f,
    0x9b2e,0x9b66,0x9b75,0x9c00, 0x9c63,0x9d96,0x9d1e,0x9d62,
    0x9d70
};

unsigned short o_KEIS_AF[36] = { /* afa1 - afc4		*/
	   0x250c,0x250d,0x250f, 0x2510,0x2511,0x2513,0x2514,
    0x2515,0x2517,0x2518,0x2519, 0x251b,0x251c,0x251d,0x2523,
    0x2524,0x2525,0x252b,0x252c, 0x252d,0x2533,0x2534,0x2535,
    0x253b,0x253c,0x253f,0x254b, 0x2500,0x2500,0x2501,0x2502,
    0x2502,0x2503,0x254e,0x254f, 0x2236
};
#else
#define o_KEIS_9F	NULL
#define o_KEIS_AF	NULL
#endif

unsigned short cp932932_uni_byte[CP932932_PATCH_LEN] = {
	   0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,
	   0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,
	   0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,
	   0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000, 0x0000,0x0000,0x0000
};

#if defined(OUTPUT_DYNAMIC_TABLE) || !defined(DYNAMIC_LOADING) || defined(SWIG_EXT)
/* ---------------------------------------------------- */
/* Macintosh Kanjitalk-7 gaiji conversion table		*/
/* ---------------------------------------------------- */
unsigned short uni_t_mac_abbrev_29[940] = {
	0x2460,	0x2461,	0x2462,	0x2463,	0x2464,	0x2465,	0x2466,
0x2467,	0x2468,	0x2469,	0x246a,	0x246b,	0x246c,	0x246d, 0x246e,
0x246f,	0x2470,	0x2471,	0x2472,	0x2473,	0,	0,	0,
0,	0,	0,	0,	0,	0,	0,	0x2474,
0x2475,	0x2476,	0x2477,	0x2478,	0x2479,	0x247a,	0x247b,	0x247c,
0x247d,	0x247e,	0x247f,	0x2480,	0x2481,	0x2482,	0x2483,	0x2484,
0x2485,	0x2486,	0x2487,	0,	0,	0,	0,	0,
0,	0,	0,	0,	0,	0x2776,	0x2777,	0x2778,
0x2779,	0x277a,	0x277b,	0x277c,	0x277d,	0x277e,	0,	0,
0,	0,	0,	0,	0,	0,	0,	0,
0,	0,	0x2488,	0x2489,	0x248a,	0x248b,	0x248c,	0x248d,
0x248e,	0x248f,	0x2490,	0,	0,	0,	0,
	0x2160,	0x2161,	0x2162,	0x2163,	0x2164,	0x2165,	0x2166,
0x2167,	0x2168,	0x2169,	0x216a,	0x216b,	0,	0,	0,
0,	0,	0,	0,	0,	0,	0x2170,	0x2171,
0x2172,	0x2173,	0x2174,	0x2175,	0x2176,	0x2177,	0x2178,	0x2179,
0x217a,	0x217b,	0,	0,	0,	0,	0,	0,
0,	0,	0,	0,	0,	0,	0,	0,
0,	0,	0,	0,	0,	0,	0,	0,
0,	0,	0,	0,	0,	0,	0x249c,	0x249d,
0x249e,	0x249f,	0x24a0,	0x24a1,	0x24a2,	0x24a3,	0x24a4,	0x24a5,
0x24a6,	0x24a7,	0x24a8,	0x24a9,	0x24aa,	0x24ab,	0x24ac,	0x24ad,
0x24ae,	0x24af,	0x24b0,	0x24b1,	0x24b2,	0x24b3,	0x24b4,	0x24b5,
0,	0,	0,	0,	0,	0,	0,
	0x339c,	0x339f,	0x339d,	0x33a0,	0x33a4,	0xff4d,	0x33a1,
0x33a5,	0x339e,	0x33a2,	0x338e,	0xff47,	0x338f,	0x33c4,	0x3396,
0x3397,	0x006c,	0x3398,	0x33b3,	0x33b2,	0x33b1,	0x33b0,	0x2109,
0x33d4,	0x33cb,	0x3390,	0x3385,	0x3386,	0x3387,	0,	0,
0,	0,	0,	0,	0,	0,	0,	0,
0,	0,	0,	0,	0,	0,	0,	0,
0,	0,	0,	0,	0,	0,	0,	0,
0,	0,	0,	0,	0,	0,	0,	0,
0,	0,	0,	0,	0,	0,	0,	0,
0,	0,	0,	0,	0,	0,	0,	0,
0,	0,	0,	0,	0,	0,	0,	0,
0,	0,	0,	0x2116,	0x33cd,	0x2121,	0,
	0x2664,	0x2667,	0x2661,	0x2662,	0x2660,	0x2663,	0x2665,
0x2666,	0,	0,	0,	0,	0,	0,	0,
0,	0,	0,	0,	0,	0x3020,	0x260e,	0x3004,
0,	0,	0,	0,	0,	0,	0,	0,
0,	0,	0,	0,	0,	0,	0,	0,
0,	0x261e,	0x261c,	0x261d,	0x261f,	0x21c6,	0x21c4,	0x21c5,
0x21f5,	0x21e8,	0x21e6,	0x21e7,	0x21e9,	0x21c0,	0x21bc,	0x21be,
0x21c2,	0,	0,	0,	0,	0,	0,	0,
0,	0,	0,	0,	0,	0,	0,	0,
0,	0,	0,	0,	0,	0,	0,	0,
0,	0,	0,	0,	0,	0,	0,	0,
0,	0,	0,	0,	0,	0,	0,
	0x3230,	0x322a,	0x322b,	0x322c,	0x322d,	0x322e,	0x322f,
0x3240,	0x3237,	0x3242,	0x3243,	0x3239,	0x323a,	0x3231,	0x323e,
0x3234,	0x3232,	0x323b,	0x3236,	0x3233,	0x3235,	0x323c,	0x323d,
0x323f,	0x3238,	0,	0,	0,	0,	0,	0,
0,	0,	0,	0,	0,	0,	0,	0,
0,	0,	0,	0,	0,	0,	0,	0,
0,	0,	0,	0,	0,	0,	0,	0,
0,	0,	0,	0,	0,	0,	0,	0,
0,	0,	0,	0,	0,	0,	0,	0,
0,	0,	0,	0,	0,	0,	0,	0,
0,	0,	0,	0x32a4,	0x32a5,	0x32a6,	0x32a7,	0x32a8,
0x32a9,	0x3296,	0x329d,	0x3298,	0x329e,	0x63a7,	0x3299,
	0x3349,	0x3322,	0x334d,	0x3314,	0x3316,	0x3305,	0x3333,
0x334e,	0x3303,	0x3336,	0x3318,	0x3315,	0x3327,	0x3351,	0x334a,
0x3339,	0x3357,	0x330d,	0x3342,	0x3323,	0x3326,	0x333b,	0x332b,
0,	0,	0,	0,	0,	0,	0,	0x3300,
0x331e,	0x332a,	0x3331,	0x3347,	0,	0,	0,	0,
0,	0,	0,	0,	0,	0,	0,	0,
0,	0,	0,	0,	0,	0,	0,	0,
0,	0,	0,	0,	0,	0,	0,	0,
0,	0,	0,	0,	0,	0,	0,	0x337e,
0x337d,	0x337c,	0x337b,	0,	0,	0,	0,	0,
0,	0,	0,	0,	0,	0,	0,	0,
0,	0,	0,	0,	0x337f,	0x3292,	0x3296,
	0x222e,	0x221f,	0x22bf,	0,	0,	0,	0,
0,	0,	0,	0,	0,	0,	0,	0,
0,	0,	0,	0,	0,	0x301f,	0x301d,	0,
0,	0,	0,	0,	0,	0,	0,	0,
0,	0,	0,	0,	0,	0,	0,	0,
0,	0x3094,	0,	0x30f7,	0x30f8,	0x30f9,	0x30fa,	0,
0,	0,	0,	0,	0,	0,	0,	0,
0,	0,	0,	0,	0,	0,	0,	0,
0,	0,	0,	0,	0,	0,	0,	0,
0,	0,	0,	0,	0,	0,	0,	0,
0,	0,	0,	0,	0,	0,	0,	0,
0,	0,	0,	0,	0,	0,	0,
	0,	0x3001,	0x3002,	0,	0,	0,	0,
0,	0,	0,	0,	0,	0,	0,	0,
0,	0x2595,	0xfe33,	0,	0,	0,	0,	0,
0,	0,	0,	0,	0xfe32,	0xfe31,	0xfe32,	0,
0,	0,	0x2017,	0x2015,	0x22ee,	0xfe30,	0,	0,
0,	0,	0xfe35,	0xfe36,	0xfe39,	0xfe3a,	0xfe39,	0xfe3a,
0xfe37,	0xfe38,	0xfe3f,	0xfe40,	0xfe3d,	0xfe3e,	0xfe41,	0xfe42,
0xfe43,	0xfe44,	0xfe3b,	0xfe3c,	0,	0,	0,	0,
0,	0x2225,	0,	0,	0,	0,	0,	0,
0,	0,	0,	0,	0,	0,	0,	0,
0,	0,	0,	0,	0,	0,	0,	0,
0,	0,	0,	0,	0,	0,	0,
	0x3041,	0,	0x3043,	0,	0x3045,	0, 	0x3047,
0,	0x3049,	0,	0,	0,	0,	0,	0,
0,	0,	0,	0,	0,	0,	0,	0,
0,	0,	0,	0,	0,	0,	0,	0,
0,	0,	0,	0x3063,	0,	0,	0,	0,
0,	0,	0,	0,	0,	0,	0,	0,
0,	0,	0,	0,	0,	0,	0,	0,
0,	0,	0,	0,	0,	0,	0,	0,
0,	0,	0,	0x3083,	0,	0x3085,	0,	0x3087,
0,	0,	0,	0,	0,	0,	0x308e,	0,
0,	0,	0,	0,	0,	0,	0,	0,
0,	0,	0,	0,	0,	0,	0,
	0x30a1,	0,	0x30a3,	0,	0x30a5,	0, 	0x30a7,
0,	0x30a9,	0,	0,	0,	0,	0,	0,
0,	0,	0,	0,	0,	0,	0,	0,
0,	0,	0,	0,	0,	0,	0,	0,
0,	0,	0,	0x30c3,	0,	0,	0,	0,
0,	0,	0,	0,	0,	0,	0,	0,
0,	0,	0,	0,	0,	0,	0,	0,
0,	0,	0,	0,	0,	0,	0,	0,
0,	0,	0,	0x30e3,	0,	0x30e5,	0,	0x30e7,
0,	0,	0,	0,	0,	0,	0x30ee,	0,
0,	0,	0,	0,	0,	0x30f5,	0x30f6,	0,
0,	0,	0,	0,	0,	0,	0
};

#endif

#if defined(OUTPUT_DYNAMIC_TABLE) 
/* --------------------------------------------------------------- */
/* input side table for kana region and kanji region		   */
/* --------------------------------------------------------------- */
skf_ucode x0208_long_table[ISOMB_CODE_END];
unsigned short cp932_table[ISOMB_CODE_END];
unsigned short cp932w_table[ISOMB_CODE_END];
unsigned short cp943_table[ISOMB_CODE_END];
unsigned short big5h_uni_byte[BIG5_TBL_LEN]; /* BIG5 HKU	   */
unsigned short big5a_uni_byte[BIG5P_TBL_LEN];   /* BIG5 UAO	   */
unsigned short big52_uni_byte[BIG5P_TBL_LEN];   /* BIG5 2003	   */
skf_ucode x213_1n_uni_byte[ISOMB_CODE_END];    /* JIS X 0213(2004) */
unsigned short gbk_gen_map[0x5200];	    /* 4e00 - 9fff	   */
unsigned short gbk_uni_byte[GBK_TBL_LEN];   /* GBK		   */
unsigned short gb2k_uni_byte[GBK_TBL_LEN];  /* GB18030		   */
skf_ucode big5p_uni_byte[BIG5P_TBL_LEN];    /* BIG5 PLUS	   */
skf_ucode keish_uni_byte[ISOMB_CODE_END];   /* KEIS 0xa1a1 -	   */
skf_ucode ebckeis_uni_byte[256];	    /* KEIS EBCDIK part -  */
skf_ucode x0208_nj_uni_byte[ISOMB_CODE_END]; /* JYOUYOU KANJI	   */

skf_ucode n_emoji_a_uni_byte[EMOJI_TBL_LEN]; /* DoCoMo emoji	   */
skf_ucode a_emoji_a_uni_byte[EMOJI_TBL_LEN]; /* KDDI-AU emoji	   */
skf_ucode s_emoji_a_uni_byte[EMOJI_TBL_LEN]; /* Softbank emoji	   */
skf_ucode n_emoji_j_uni_byte[ISOMB_CODE_END]; /* DoCoMo emoji	   */
skf_ucode a_emoji_j_uni_byte[ISOMB_CODE_END]; /* KDDI-AU emoji	   */
skf_ucode s_emoji_j_uni_byte[ISOMB_CODE_END]; /* Softbank emoji	   */

struct iso_byte_defs iso_unibyte_defs[] = {
  {'m',1,128,x9010_a_uni_byte,FALSE,NULL,1,NULL,NULL,"x9010_a"},
				/* JIS X9010 OCR-A */
  {'o',1,128,x9010_ba_uni_byte,FALSE,NULL,1,NULL,NULL,"x9010_ba"},
				/* JIS X9010 OCR-B add*/
  {'s',1,128,x9010_e13_uni_byte,FALSE,NULL,1,NULL,NULL,"x9010_e13"},
				/* JIS X9010 OCR-e13b*/
  {'D',1,128,nats_add_uni_byte,FALSE,NULL,1,NULL,NULL,"nats_add"},
				/* NATS additional */
  {'F',1,128,nats_add_den_uni_byte,FALSE,NULL,1,NULL,NULL,"nats_add_den"},
				/* NATS additional for Denmark*/
  {'L',1,128,iso646_po_o_uni_byte,FALSE,NULL,1,NULL,NULL,"iso646_po_o"},
				/* Olivetti portugul*/
  {'M',1,128,din31625_uni_byte,FALSE,NULL,1,NULL,NULL,"din31625"},
				/* DIN 31625 for African lang.	*/
  {'N',1,128,iso5427_uni_byte,FALSE,NULL,1,NULL,NULL,"iso5427"},
				/* ISO5427(BasicCyrillic)*/
  {'O',1,128,din31624_uni_byte,FALSE,NULL,1,NULL,NULL,"din31624"},
  {'P',1,128,iso5426_80_uni_byte,FALSE,NULL,1,NULL,NULL,"iso5426_80"},
				/* ISO 5426 (Bibilo graph Extension) */
  {'Q',1,128,iso5427_s_uni_byte,FALSE,NULL,1,NULL,NULL,"iso5427_s"},
				/* ISO 5427 (Cyrillic Extension)  */
  {'S',1,128,iso5428_1_uni_byte,FALSE,NULL,1,NULL,NULL,"iso5428_1"},
				/* ISO 5428 (biblio greek set)     */
  {'T',1,128,NULL,FALSE,NULL,1,NULL,NULL,NULL},
				/* GB1988 (Chinese set)- set below */
  {'U',1,128,ecma114_gr_uni_byte,FALSE,NULL,1,NULL,NULL,"ecma114_gr"},
				/* Latin-Greek ECMA (Honeywell-Bull) */
  {'V',1,128,uk_tele_uni_byte,FALSE,NULL,1,NULL,NULL,"uk_tele"}, 
				/* Teletext(UK)*/
  {'W',1,128,iso646_inis_s_uni_byte,FALSE,NULL,1,NULL,NULL,"iso646_inis_s"},
				/* INIS subset  */
  {'X',1,128,NULL,FALSE,NULL,1,NULL,NULL,NULL},
				/* ISO 5428-1980(biblio greek set)*/
  {'Y',1,128,iso646_it_o_uni_byte,FALSE,NULL,1,NULL,NULL,"iso646_it_o"},
				/* ISO-646 Itarian(Olivetti)	*/
  {'[',1,128,ecma114_gr2_uni_byte,FALSE,NULL,1,NULL,NULL,"ecma114_gr2"},
				/* ECMA 114 Greek(left plain)   */
  {0x5c,1,128,oli_greek_uni_byte,FALSE,NULL,1,NULL,NULL,"oli_greek"},
				/* latin-greek (Olivetti)	   */
  {']',1,128,inis_ns_uni_byte,FALSE,NULL,1,NULL,NULL,"inis_ns"},
				/* INIS non-standard(left)*/
  {'^',1,128,inis_cyl_uni_byte,FALSE,NULL,1,NULL,NULL,"inis_cyl"},
				/* INIS cyrillic(left) */
  {'_',1,128,codar_u_uni_byte,FALSE,NULL,1,NULL,NULL,"codar_u"},
				/* Arabes Codar-U */
  {0x60,1,128,iso646_ns4551_uni_byte,FALSE,NULL,1,NULL,NULL,"iso646_ns4551"},
				/* NS 4551 (Norwegian)	   */
  {'b',1,128,videotex_sp1_uni_byte,FALSE,NULL,1,NULL,NULL,"videotex_sp1"},
				/* Supplementary videotex	   */
  {'c',1,128,NULL,FALSE,NULL,1,NULL,NULL,NULL},
				/* 2nd Supplementary videotex   */
  {'d',1,128,NULL,FALSE,NULL,1,NULL,NULL,NULL},
				/* 3rd Supplementary videotex   */
  {'e',1,128,apl_uni_byte,FALSE,NULL,1,NULL,NULL,"apl"},
				/* APL Canada(left plain)   */
  {'g',1,128,iso646_po_i_uni_byte,FALSE,NULL,1,NULL,NULL,"iso646_po_i"},
				/* ISO646(Portuguese)*/
  {'h',1,128,iso646_sp_i_uni_byte,FALSE,NULL,1,NULL,NULL,"iso646_sp_i"},
				/* ISO646(Spanish/IBM)*/
  {'i',1,128,msz7795_uni_byte,FALSE,NULL,1,NULL,NULL,"msz7795"},
				/* ISO646(Hungarian/IBM)*/
  {'k',1,128,iso9036_uni_byte,FALSE,NULL,1,NULL,NULL,"iso9036"},
				/* ISO 9036 (Arabic/ASMO449)   */
  {'l',1,128,iso6937_sp2_uni_byte,FALSE,NULL,1,NULL,NULL,"iso6937_sp2"},
				/* ISO 6937 Supplementary 2    */
  {'p',1,128,x9010_h_uni_byte,FALSE,NULL,1,NULL,NULL,"x9010_h"},
				/* JIS X9010-1984 OCR handwriting  */
  {'q',1,128,x9010_oa_uni_byte,FALSE,NULL,1,NULL,NULL,"x9010_oa"},
				/* JIS X9010-1984 OCR additional   */
  {'u',1,128,t61_1_uni_byte,FALSE,NULL,1,NULL,NULL,"t61_1"},
				/* CCITT Rec.T61 Teletex 1st*/
  {'v',1,128,t61_2_uni_byte,FALSE,NULL,1,NULL,NULL,"t61_2"},
				/* CCITT Rec.T61 Teletex 2nd*/
  {'w',1,128,csa_z243_1_uni_byte,FALSE,NULL,1,NULL,NULL,"csa_z243_1"},
				/* Z243.4-1985 1st Graphic set  */
  {'x',1,128,csa_z243_2_uni_byte,FALSE,NULL,1,NULL,NULL,"csa_z243_2"},
				/* Z243.4-1985 2nd Graphic set  */
  {'y',1,128,NULL,FALSE,NULL,1,NULL,NULL,NULL},
				/* CCITT Rec. T101 Mosaic set   */
  {'z',1,128,serb_slov_uni_byte,FALSE,NULL,1,NULL,NULL,"serb_slov"},
				/* Serbocroatian and Slovenian set */
  {'{',1,128,serb_uni_byte,FALSE,NULL,1,NULL,NULL,"serb"},
				/* Serbocroatian Cyrillic set   */
  {'|',1,128,ccitt_mt101_2_uni_byte,FALSE,NULL,1,NULL,NULL,"ccitt_mt101_2"},
				/* CCITT Rec. T101 Mosaic 2nd set  */
  {'}',1,128,macd_uni_byte,FALSE,NULL,1,NULL,NULL,"macd"},
				/* Macedonian Cyrillic set */
  {0x61,1,128,iso646_ns4551_2_uni_byte,FALSE,NULL,1,NULL,NULL,
	"iso646_ns4551_2"}, /* NS 4551 (Norwegian) version 2	   */
  {0x00,0,0,NULL,FALSE,NULL,0,NULL,NULL,NULL}	/* is last entry	   */
};

/* --------------------------------------------------------------- */
/* ESC-'-'-? : iso-2022 96 character set			   */
/* --------------------------------------------------------------- */
struct iso_byte_defs iso_iso8859_defs[] = {
  {'E',1,128,csa_z243_uni_byte,COD_SET96,NULL,1,NULL,NULL,"csa_z243"},
					/* Canadian CSA Z243.5 */
  {'I',1,128,csn369103_uni_byte,COD_SET96,NULL,1,NULL,NULL,"csn369103"}, 
					/* CSN 369103 Czechoslovak */
  {'J',1,128,iso6937_a1_uni_byte,COD_SET96,NULL,1,NULL,NULL,"iso6937_a1"},
					/* ISO6937+a1 */
  {'K',1,128,tech_uni_byte,COD_SET96,NULL,1,NULL,NULL,"tech"},
					/* Technical set */
  {'N',1,128,iso6937_2_uni_byte,COD_SET96,NULL,1,NULL,NULL,"iso6937_2"},
					/* ISO 6937-2 */
  {'O',1,128,gost19768_uni_byte,COD_SET96,NULL,1,NULL,NULL,"gost19768"},
					/* Basic Cyrillic for 8bit code */
  {'P',1,128,iso8859_sp_uni_byte,COD_SET96,NULL,1,NULL,NULL,"iso8859_sp"},
					/* iso-8859-suppl */
  {'Q',1,128,box_uni_byte,COD_SET96,NULL,1,NULL,NULL,"box"}, /* Box drawing */
  {'R',1,128,iso6937_sp_uni_byte,COD_SET96,NULL,1,NULL,NULL,"iso6937_sp"},
					/* ISO 6937 Supplementary */
  {'S',1,128,ir164_uni_byte,COD_SET96,NULL,1,NULL,NULL,"ir164"},
					/* CCITT Heblew*/
  {'U',1,128,ir167_uni_byte,COD_SET96,NULL,1,NULL,NULL,"ir167"},
					/* Arabic/French/German*/
  {'X',1,128,iso4873_sami_uni_byte,COD_SET96,NULL,1,NULL,NULL,"iso4873_sami"},
					/* Sami(lappish) supplement */
  {'[',1,128,iec1289_uni_byte,COD_SET96,NULL,1,NULL,NULL,"iec1289"},
					/* IEC1289 tech set */
  {0x5c,1,128,iso8859_1w_uni_byte,COD_SET96,NULL,1,NULL,NULL,"iso8859_1w"},
					/* Welsh 8859-1 */
  {']',1,128,sami_sp1_uni_byte,COD_SET96,NULL,1,NULL,NULL,"sami_sp1"},
				/* Sami(Norwegian-lappish) supplement */
  {'^',1,128,ir197_uni_byte,COD_SET96,NULL,1,NULL,NULL,"ir197"},
					/* latin/hebrew */
  {0x60,1,128,uralic_uni_byte,COD_SET96,NULL,1,NULL,NULL,"uralic"},
					/* Uralic supplement */
  {'a',1,128,volg_uni_byte,COD_SET96,NULL,1,NULL,NULL,"volg"},
					/* Volgaic supplement */
  {'c',1,128,iso8859_1e_uni_byte,COD_SET96,NULL,1,NULL,NULL,"iso8859_1e"},
					/* iso8859-1+euro */
  {'d',1,128,iso8859_4e_uni_byte,COD_SET96,NULL,1,NULL,NULL,"iso8859_4e"},
					/* iso8859-4+euro */
  {'e',1,128,iso8859_13e_uni_byte,COD_SET96,NULL,1,NULL,NULL,"iso8859_13e"},
					/*iso8859-13+euro*/
  {'g',1,128,is434_uni_byte,COD_SET96,NULL,1,NULL,NULL,"is434"}, /* Ogham */
  {'h',1,128,sami_sp2_uni_byte,COD_SET96,NULL,1,NULL,NULL,"sami_sp2"},
				/* sami(Finnish) supplement set 2 */
  {'i',1,128,rh_greek_uni_byte,COD_SET96,NULL,L_EL,NULL,NULL,"rh_greek"}, 
				/* righthand latin/greek */
  {'j',1,128,si1311_uni_byte,COD_SET96,NULL,L_HE,NULL,NULL,"si1311"}, 
					/* Latin/Heblew for 8-bit */
  {'}',1,128,NULL,COD_SET96,NULL,1,NULL,NULL,NULL},
					/* CCITT Mosaic Rec.101 set III */
  {0x00,0,0,NULL,COD_SET96,NULL,0,NULL,NULL,NULL}	/* is last entry   */
};

/* --------------------------------------------------------------- */
/* Regional code without iso-2022 calling sequences		   */
/* --------------------------------------------------------------- */
struct iso_byte_defs misc_byte_defs[] = {
  {0x28,1,128,NULL,COD_NISO,NULL,1,NULL,NULL,NULL},/* KOI-8 R		 */
  {0x29,1,128,NULL,COD_NISO,NULL,1,NULL,NULL,NULL},/* KOI-8 U		 */
  {0x2a,1,128,NULL,COD_NISO,NULL,1,NULL,NULL,NULL},/* MAC-roman		 */
  {0x2b,1,128,NULL,COD_NISO,NULL,1,NULL,NULL,NULL},/* Microsoft cp437(US)*/
  {0x2c,1,128,NULL,COD_NISO,NULL,1,NULL,NULL,NULL},/* Microsoft cp1251 	 */
  {0x2d,1,128,NULL,COD_NISO,NULL,1,NULL,NULL,NULL},/* KS_X_1003		 */
/* dynamic loading area */
/* 1.93-1.94 added charsets					   */
  {0x74,1,128,NULL,COD_NISO,NULL,1,NULL,NULL,NULL}, /* VNI */
  {0x75,1,128,cp1258_uni_byte,COD_NISO,NULL,1,NULL,NULL,"cp1258"},
			/* MS cp1258	*/
  {0x76,1,128,viscii_uni_byte,COD_NISO,NULL,1,NULL,NULL,"viscii"},
			/* VISCII left	*/
  {0x77,1,128,visciir_uni_byte,COD_NISO,NULL,1,NULL,NULL,"visciir"},
			/* VISCII right	*/
  {0x78,1,146,visciiq_uni_byte,COD_NISO,NULL,1,NULL,NULL,"visciiq"},
			/* VISCII viqr	*/
  {0x79,1,128,cp737_uni_byte,COD_NISO,NULL,L_EL,NULL,NULL,"cp737"},
  {0x7a,1,128,cp775_uni_byte,COD_NISO,NULL,L_NU,NULL,NULL,"cp775"},
  {0x7b,1,128,cp853_uni_byte,COD_NISO,NULL,L_NU,NULL,NULL,"cp853"},
  {0x7c,1,128,cp895_uni_byte,COD_NISO,NULL,L_NU,NULL,NULL,"cp895"},
  {0x56,1,128,cp850_uni_byte,COD_NISO,NULL,L_NU,NULL,NULL,"cp850"},
  {0x74,1,128,cp852_uni_byte,COD_NISO,NULL,L_NU,NULL,NULL,"cp852"},
  {0x73,1,128,cp855_uni_byte,COD_NISO,NULL,L_RU,NULL,NULL,"cp855"},
  {0x72,1,128,cp857_uni_byte,COD_NISO,NULL,L_TR,NULL,NULL,"cp857"},
  {0x71,1,128,cp860_uni_byte,COD_NISO,NULL,L_PT,NULL,NULL,"cp860"},
  {0x70,1,128,cp861_uni_byte,COD_NISO,NULL,L_IS,NULL,NULL,"cp861"},
  {0x6f,1,128,cp862_uni_byte,COD_NISO,NULL,L_HE,NULL,NULL,"cp862"},
  {0x6e,1,128,cp863_uni_byte,COD_NISO,NULL,L_FR,NULL,NULL,"cp863"},
  {0x6d,1,128,cp864_uni_byte,COD_NISO,NULL,L_AR,NULL,NULL,"cp864"},
  {0x6c,1,128,cp865_uni_byte,COD_NISO,NULL,L_NU,NULL,NULL,"cp865"},
  {0x6b,1,128,cp866_uni_byte,COD_NISO,NULL,L_NU,NULL,NULL,"cp866"},
  {0x69,1,128,cp869_uni_byte,COD_NISO,NULL,L_ID,NULL,NULL,"cp869"},
  {0x68,1,128,cp874_uni_byte,COD_NISO,NULL,L_TH,NULL,NULL,"cp874"},
  {0x66,1,128,cp1250_uni_byte,COD_NISO,NULL,L_NU,NULL,NULL,"cp1250"},
  {0x57,1,128,cp1252_uni_byte,COD_NISO,NULL,L_NU,NULL,NULL,"cp1252"},
  {0x58,1,128,cp1253_uni_byte,COD_NISO,NULL,L_NU,NULL,NULL,"cp1253"},
  {0x59,1,128,cp1254_uni_byte,COD_NISO,NULL,L_NU,NULL,NULL,"cp1254"},
  {0x5a,1,128,cp1255_uni_byte,COD_NISO,NULL,L_NU,NULL,NULL,"cp1255"},
  {0x52,1,128,vpsl_uni_byte,COD_NISO,NULL,L_VI,NULL,NULL,"vpsl"},
  {0x53,1,128,armiscii_uni_byte,COD_NISO,NULL,L_HY,NULL,NULL,"armiscii"},
  {0x54,1,128,geostd8_uni_byte,COD_NISO,NULL,L_KA,NULL,NULL,"geostd8"},
  {0x55,1,128,vpsr_uni_byte,COD_NISO,NULL,L_VI,NULL,NULL,"vpsr"},
  {0x64,1,256,iso11548_uni_byte,COD_NISO,NULL,L_NU,NULL,NULL,
  	"iso11548"},
  {0x65,1,128,brf_uni_byte,COD_NISO,NULL,L_NU,NULL,NULL,"brf"},
  {0x67,1,128,tscii_uni_byte,COD_NISO,NULL,L_TA,NULL,NULL,"tscii"},
  {0x6a,1,192,vni_uni_byte,COD_NISO,NULL,M_VI,NULL,NULL,"vni"},
  {0x7d,1,128,gsm0338_uni_byte,COD_NISO,NULL,L_NU,NULL,NULL,"gsm0338"},
  {0x00,0,0,NULL,COD_NISO,NULL,0,NULL,NULL,NULL}	/* is last entry   */
};

struct iso_byte_defs miscmul_byte_defs[] = {
  {0x41,2,BIG5_TBL_LEN,big5_uni_byte,COD_NISO|COD_MB,NULL,
	M_ZH,NULL,NULL,"cp950"}, /* Big5 cp950 */
  {0x42,2,BIG5_TBL_LEN,big5_uni_byte,COD_NISO|COD_MB,NULL,
	M_ZH,NULL,NULL,"big5"}, /* Big5 ETEN */
  {0x44,2,IBMDBCSL_TBL_LEN,uni_t_ibm937,COD_NISO|COD_MB,NULL,
  	M_ZH,NULL,NULL,"ibm937"},
  {0x45,2,IBMDBCS_TBL_LEN,uni_t_ibm935,COD_NISO|COD_MB,NULL,
  	M_ZH,NULL,NULL,"ibm935"},
  {0x46,2,IBMDBCSL_TBL_LEN,uni_t_ibm933,COD_NISO|COD_MB,NULL,
  	M_KO,NULL,NULL,"ibm933"},
  {0x47,2,BIG5_TBL_LEN,big5h_uni_byte,COD_NISO|COD_MB,NULL,1,
	hku_table_gen,NULL,"big5h"},	/* Big5 HKU	   */
  {0x48,2,GB12345_TBL_LEN,gb12345_uni_byte,COD_NISO|COD_MB,NULL,M_ZH,
	NULL,NULL,"gb12345"}, 		/* GB/T 12345 */
  {0x4a,2,IBMDBCS_TBL_LEN,uni_t_ibm930,COD_NISO|COD_MB,NULL,M_JP,
	NULL,NULL,"ibm930"},
  {0x4b,4,BIG5P_TBL_LEN,NULL,COD_NISO|COD_MB,big5p_uni_byte,M_ZH,
	big5p_table_gen,NULL,"big5p"},	/* BIG5+HKSCS	   */
  {0x4c,2,GBK_TBL_LEN,gb2k_uni_byte,COD_NISO|COD_MB,NULL,M_ZH,
	gb2k_table_gen, NULL,"gb2k"}, 	/* GB 18030_Base */
  {0x4e,2,GBK_TBL_LEN,gbk_uni_byte,COD_NISO|COD_MB,NULL,
	M_ZH,gbk_table_gen,NULL,"gbk"}, /* GBK */
  {0x4f,2,JOHAB_TBL_LEN,johab_uni_byte,COD_NISO|COD_MB,NULL,
	M_KO,NULL,NULL,"johab"}, /* JOHAB */
  {0x50,2,BIG5P_TBL_LEN,big52_uni_byte,COD_NISO|COD_MB,NULL,
	M_ZH,big52_table_gen,NULL,"big52"},
  {0x51,2,BIG5P_TBL_LEN,big5a_uni_byte,COD_NISO|COD_MB,NULL,
	M_ZH,big5a_table_gen,NULL,"big5a"},
/* Currently, I don't have following codeset documents		   */
  {0x60,4,96800,NULL,COD_NISO|COD_MB,NULL,1,NULL,NULL,NULL},
				/* GT-shotai table(B/Right)*/
  {0x61,4,57236,NULL,COD_NISO|COD_MB,NULL,1,NULL,NULL,NULL},
				/* Daikanwa table(B/Right) */
  {0x62,2,57236,NULL,COD_NISO|COD_MB,NULL,1,NULL,NULL,NULL},
				/* Symbol table(B/Right)   */
  {0x63,1,256,braille6_kana_uni_byte,COD_NISO|COD_MB,NULL,1,
  	NULL,NULL,"Braille6"}, /* 6-braille table */
  {0x64,1,256,NULL,COD_NISO|COD_MB,NULL,1,
  	NULL,NULL,"Braille8"}, /* 8-braille table */
  {0x65,2,1410,NULL,COD_NISO|COD_MB,NULL,1,NULL,NULL,NULL},
  				/* Tompa table */
  {0x66,4,ISOMB_CODE_END,NULL,	/* X-0208 with new jyouyou kanji   */
	(COD_NISO | COD_MB),
	x0208_nj_uni_byte,M_JP,x0208nj_table_gen,
	"New-Jyouyo-Kanji(X0208based)","x0208_nj"},
  {0x67,2,BIG5P_TBL_LEN,cp949_uni_byte,COD_NISO|COD_MB,NULL,
	M_KO,NULL,NULL,"cp949"},
  {0x6a,4,21000,NULL,COD_NISO|COD_MB,NULL,1,NULL,NULL,NULL},
			/* JuminKihonDaicho touitsu code - not yet */
  {0x00,0,0,NULL,COD_NISO|COD_MB,NULL,0,NULL,NULL,NULL}/* is last entry   */
};

/* --------------------------------------------------------------- */
/* 94 character with second intermediate byte			   */
/* --------------------------------------------------------------- */
struct iso_byte_defs iso_im2byte_defs[] = {
/* dynamic loading area */
  {0x40,1,128,ccitt_gr_uni_byte,COD_ISOALT,NULL,1,NULL,NULL,"ccitt_gr"},
				/* Greek Graphic for Videotex  */
  {0x41,1,128,cuban_uni_byte,COD_ISOALT,NULL,1,NULL,NULL,"cuban"},
				/* Cuban character set */
  {0x42,1,128,iso646_inv_uni_byte,COD_ISOALT,NULL,1,NULL,NULL,"iso646_inv"},
				/* IEC646 invariant character set */
  {0x43,1,128,ir_gl_uni_byte,COD_ISOALT,NULL,1,NULL,NULL,"ir_gl"},
				/* Variants for Irish Gaelic   */
  {0x44,1,128,iso_turk_uni_byte,COD_ISOALT,NULL,1,NULL,NULL,"iso_turk"},
				/* Turkmen Alphabets		  */
  {0x45,1,128,ansel_uni_byte,COD_ISOALT,NULL,1,NULL,NULL,"ansel"},
				/* ANSI Extend latin (ANSEL)   */
  {0x46,1,128,tds616_uni_byte,COD_ISOALT,NULL,1,NULL,NULL,"tds616"},
				/* Turkmen TDS 565		 */
  {0x00,0,0,NULL,COD_ISOALT,NULL,0,NULL,NULL,NULL}	/* is last entry   */
};

/* --------------------------------------------------------------- */
/* ESC-$-? : shorten multibyte sequence				   */
/* --------------------------------------------------------------- */
struct iso_byte_defs iso_3_dblbyte_defs[] = {
  {'@',2,KANJI_TBL_END,uni_t_x0208_78,COD_MB | COD_X0208 ,NULL,1,
	NULL,NULL,"x208_78"},	/* JIS X-0208(1978)	   */
/* dynamic loading area */
  {'A',2,ISOMB_CODE_END,uni_t_gb2312,COD_MB,NULL,1,
	NULL,NULL,NULL},	/* GB 2312-80 */
  {'G',1,128,vodafone_p1_uni_byte,COD_MB,NULL,1,NULL,NULL,"vodafone_p1"},
  {'E',1,128,vodafone_p2_uni_byte,COD_MB,NULL,1,NULL,NULL,"vodafone_p2"},
  {'F',1,128,vodafone_p3_uni_byte,COD_MB,NULL,1,NULL,NULL,"vodafone_p3"},
  {'O',1,128,vodafone_p4_uni_byte,COD_MB,NULL,1,NULL,NULL,"vodafone_p4"},
  {'P',1,128,vodafone_p5_uni_byte,COD_MB,NULL,1,NULL,NULL,"vodafone_p5"},
  {'Q',1,128,vodafone_p6_uni_byte,COD_MB,NULL,1,NULL,NULL,"vodafone_p6"},
  {'b',2,ISOMB_CODE_END,cp932_table,COD_MB,NULL,1,
	cp932_table_gen,NULL,"cp932"},
  {'i',2,ISOMB_CODE_END,cp943_table,COD_MB,NULL,1,
	cp943_table_gen,NULL,"cp943"},
  {'j',2,ISOMB_CODE_END,cp932w_table,COD_MB,NULL,1,
	cp932_table_gen,NULL,"cp932w"},
  {0x00,0,0,NULL,COD_MB,NULL,0,NULL,NULL,NULL}	/* is last entry	   */
};

/* --------------------------------------------------------------- */
/* ESC-$-(-? : long sequence for CJK				   */
/* --------------------------------------------------------------- */
struct iso_byte_defs iso_4_dblbyte_defs[] = {
  {'B',2,KANJI_TBL_END,NULL,COD_MB | COD_MB_4,NULL,0,NULL,NULL,NULL},
  {'@',2,KANJI_TBL_END,uni_t_x0208_78,COD_MB | COD_MB_4 ,NULL,0,NULL,NULL,NULL},
  {'A',2,ISOMB_CODE_END,uni_t_gb2312, 	/* GB 2312-80		   */
	COD_MB | COD_MB_4,NULL,0,NULL,NULL,"gb2312"},
  {'D',2,X0212_TBL_END,			/* JIS X-0212(1990) 	   */
	NULL,COD_MB | COD_MB_4,NULL,0,NULL,NULL,NULL},
  {'O',4,ISOMB_CODE_END,NULL,		/* JIS X-0213(1st plane)  */
	(COD_99 | COD_MB | COD_MB_4 | COD_MANUAL | COD_X213_1),
	uni_t_x213_1,0,NULL,NULL,"x213_1"},
  {'P',4,ISOMB_CODE_END,NULL, 		/* JIS X-0213(2nd plane)  */
	(COD_99 | COD_MB | COD_MB_4 | COD_MANUAL | COD_X213_2),
	uni_t_0213_abbrev_q_21,0,NULL,NULL,"x213_2"}, 
  {'C',2,ISOMB_CODE_END, 		/* KS-X1001-1987	  */
	uni_t_x1001,COD_MB | COD_MB_4,NULL,0,NULL,NULL,"ksx1001"},
/* dynamic loading area */
  {'E',2,ISOMB_CODE_END,NULL,COD_MB | COD_MB_4,NULL,0,NULL,NULL,NULL}, 
					/* CCITT Chinese	*/
  {'F',2,ISOMB_CODE_END,NULL,COD_MB | COD_MB_4,NULL,0,NULL,NULL,NULL},
					/* Blissymbol */
  {'G',2,ISOMB_CODE_END,uni_t_cns11643_1,COD_MB | COD_MB_4,NULL,0,
		NULL,NULL,"cns11643_1"},	/* CNS-11643-1992 Set 1  */
  {'H',2,ISOMB_CODE_END,uni_t_cns11643_2,COD_MB | COD_MB_4,NULL,0,
		NULL,NULL,"cns11643_2"},	/* CNS-11643-1992 Set 2  */
  {'I',2,ISOMB_CODE_END,uni_t_cns11643_3,COD_MB | COD_MB_4,NULL,0,
		NULL,NULL,"cns11643_3"},	/* CNS-11643-1992 Set 3 */
  {'J',2,ISOMB_CODE_END,NULL,COD_MB|COD_MB_4,NULL,0,NULL,NULL,"cns11643_4"},
					/* CNS-11643-1992 Set 4 */
  {'K',2,ISOMB_CODE_END,NULL,COD_MB|COD_MB_4,NULL,0,NULL,NULL,"cns11643_5"},
					/* CNS-11643-1992 Set 5 */
  {'L',2,ISOMB_CODE_END,NULL,COD_MB|COD_MB_4,NULL,0,NULL,NULL,"cns11643_6"},
					/* CNS-11643-1992 Set 6 */
  {'M',2,ISOMB_CODE_END,NULL,COD_MB|COD_MB_4,NULL,0,NULL,NULL,"cns11643_7"},
					/* CNS-11643-1992 Set 7 */
  {'N',2,ISOMB_CODE_END,NULL,COD_MB|COD_MB_4,NULL,0,NULL,NULL,"dprk_nkr"},
					/* DPRK Korian	   */
  {'Q',4,ISOMB_CODE_END,NULL,
	(COD_99 | COD_MB | COD_MB_4 | COD_MANUAL | COD_X213_1),
	x213_1n_uni_byte,0,x213n_table_gen,NULL,"x213_1n"}, 
					/* JIS X-0213-2004 (1st plane)  */
  {0x00,0,0,NULL,COD_MB|COD_MB_4,NULL,0,NULL,NULL,NULL} /* is last entry */
};

/* --------------------------------------------------------------- */
/* codepage tables						   */
/* --------------------------------------------------------------- */
struct iso_byte_defs cp_byte_defs[] = { /* codepage tables	   */
{0x40,1,128,macczech_uni_byte,COD_NISO|COD_SET96,NULL,L_CS,NULL,NULL,"macczech"},
{0x41,1,128,machebrew_uni_byte,COD_NISO|COD_SET96,
	NULL,L_HE,NULL,NULL,"machebrew"},
{0x42,1,128,macfarsi_uni_byte,COD_NISO|COD_SET96,NULL,L_FA,NULL,NULL,"macfarsi"},
{0x43,1,128,macdevanaga_uni_byte,COD_NISO|COD_SET96,
	NULL,L_HI,NULL,NULL,"macdevanaga"},
{0x44,1,128,maccyril_uni_byte,COD_NISO|COD_SET96,NULL,L_RU,NULL,NULL,"maccyril"},
{0x45,1,128,macturki_uni_byte,COD_NISO|COD_SET96,NULL,L_TR,NULL,NULL,"macturki"},
{0x46,1,128,macgreek_uni_byte,COD_NISO|COD_SET96,NULL,L_EL,NULL,NULL,"macgreek"},
{0x47,1,128,macarabic_uni_byte,COD_NISO|COD_SET96,
	NULL,L_AR,NULL,NULL,"macarabic"},
{0x48,1,128,macicelan_uni_byte,COD_NISO|COD_SET96,
	NULL,L_IS,NULL,NULL,"macicelan"},
{0x49,1,128,macgujarati_uni_byte,COD_NISO|COD_SET96,
	NULL,L_GU,NULL,NULL,"macgujarati"},
{0x4a,1,128,macgurmukhi_uni_byte,COD_NISO|COD_SET96,
	NULL,L_PA,NULL,NULL,"macgurmukhi"},
{0x4b,1,128,maccroat_uni_byte,COD_NISO|COD_SET96,NULL,L_HR,NULL,NULL,"maccroat"},
{0x4c,1,128,macromanian_uni_byte,COD_NISO|COD_SET96,
	NULL,L_RO,NULL,NULL,"macromanian"},
{0x4d,1,128,macburgarian_uni_byte,COD_NISO|COD_SET96,NULL,L_RO,NULL,
	"Mac Burgarian","macburg"},
{0x4f,1,128,cp1256_uni_byte,COD_NISO|COD_SET96,NULL,L_CS,NULL,NULL,"cp1256"},
{0x50,1,128,cp1257_uni_byte,COD_NISO|COD_SET96,NULL,L_CS,NULL,NULL,"cp1257"},
{0x51,1,128,ds2089_uni_byte,COD_NISO|COD_SET96,NULL,L_DK,NULL,NULL,"ds2089"},
{0x52,1,128,kz1048_uni_byte,COD_NISO|COD_SET96,NULL,L_KK,NULL,NULL,
	"kz1048"},
{0x55,1,128,hproman8_uni_byte,COD_NISO|COD_SET96,NULL,L_NU,NULL,NULL,
	"hproman8"},
{0x56,1,128,koi8ru_uni_byte,COD_NISO|COD_SET96,NULL,L_NU,NULL,NULL,
	"koi8ru"},
{0x57,1,128,koi8t_uni_byte,COD_NISO|COD_SET96,NULL,L_NU,NULL,NULL,
	"koi8t"},
{0x58,1,128,cp922_uni_byte,COD_NISO|COD_SET96,NULL,L_NU,NULL,NULL,
	"cp922"},
{0x59,1,128,NULL,COD_NISO|COD_SET96,NULL,L_NU,NULL,NULL,
	"cp720"},
{0x5b,1,128,mule_lao_uni_byte,COD_NISO|COD_SET96,NULL,L_LO,NULL,NULL,
	"mule_lao"},
{0x5c,1,128,cp1133_uni_byte,COD_NISO|COD_SET96,NULL,L_LO,NULL,NULL,
	"cp1133"},
{0x5d,1,128,pt154_uni_byte,COD_NISO|COD_SET96,NULL,L_KK,NULL,NULL,
	"pt154"},
{0x5e,1,128,cp858_uni_byte,COD_NISO|COD_SET96,NULL,L_DA,NULL,NULL,
	"cp858"},
{0x5f,1,128,cp1125_uni_byte,COD_NISO|COD_SET96,NULL,L_UK,NULL,NULL,
	"cp1125"},
{0x60,1,128,cp851_uni_byte,COD_NISO|COD_SET96,NULL,L_CS,NULL,NULL,
	"cp851"},
{0x70,1,128,iscii_as_uni_byte,COD_NISO|COD_SET96,NULL,L_NU,NULL,NULL,"iscii_as"},
{0x71,1,128,iscii_be_uni_byte,COD_NISO|COD_SET96,NULL,L_NU,NULL,NULL,"iscii_be"},
{0x72,1,128,iscii_de_uni_byte,COD_NISO|COD_SET96,NULL,L_NU,NULL,NULL,"iscii_de"},
{0x73,1,128,iscii_gu_uni_byte,COD_NISO|COD_SET96,NULL,L_NU,NULL,NULL,"iscii_gu"},
{0x74,1,128,iscii_ka_uni_byte,COD_NISO|COD_SET96,NULL,L_NU,NULL,NULL,"iscii_ka"},
{0x75,1,128,iscii_ma_uni_byte,COD_NISO|COD_SET96,NULL,L_NU,NULL,NULL,"iscii_ma"},
{0x76,1,128,iscii_or_uni_byte,COD_NISO|COD_SET96,NULL,L_NU,NULL,NULL,"iscii_or"},
{0x77,1,128,iscii_pa_uni_byte,COD_NISO|COD_SET96,NULL,L_NU,NULL,NULL,"iscii_pa"},
{0x78,1,128,iscii_ta_uni_byte,COD_NISO|COD_SET96,NULL,L_NU,NULL,NULL,"iscii_ta"},
{0x79,1,128,iscii_te_uni_byte,COD_NISO|COD_SET96,NULL,L_NU,NULL,NULL,"iscii_te"},
{0x7a,1,128,winsami2_uni_byte,COD_NISO|COD_SET96,NULL,L_NU,NULL,NULL,"winsami2"},
  {0x00,0,0,NULL,COD_NISO | COD_SET96,NULL,0,NULL,NULL,NULL}
};
/* --------------------------------------------------------------- */
/* overlay tables						   */
/* --------------------------------------------------------------- */
struct iso_byte_defs ovlay_byte_defs[] = { /* overlay tables	   */
  {0x41,2,512,i_ntt_tbl,COD_NISO | COD_MB_4,
	NULL,L_JP,ntt_table_setup,NULL,"i_ntt"}, /*NTT SJIS*/
  {0x48,2,36,o_KEIS_AF,COD_NISO | COD_MB_4,NULL,M_JP,keish_table_gen,
	NULL,"keisaf"},  /* KEIS addendum 0xafa1 - 	   */
  {0x49,4,56,NULL,COD_NISO | COD_MB_4,o_KEIS_9F,1,NULL,NULL,"keis9f"},
				/* KEIS 0x9fa1 addendum		   */
  {0x4a,2,JEF_TBL_LEN,uni_t_jef43,COD_NISO | COD_MB_4,NULL,1,NULL,NULL,"jef43"},
				/* JEF-Lowside */
  {0x4b,4,KEIS_TBL_LEN,NULL,COD_NISO | COD_MB_4,uni_t_keis59,1,
	NULL,NULL,"keis59"},	/* KEIS83 ext3  */
  {0x4c,2,GB2K_A_LEN,gb2k_a_tbl,COD_NISO|COD_MB_4,NULL,L_ZH,
	NULL,NULL,"gb2k_a"},	/* GB18030 */
  {0x4d,2,940,uni_t_mac_abbrev_29,COD_NISO | COD_MB_4,NULL,M_JP,
	NULL,NULL,"mac_abbrev_29"},	/* Kanjitalk 7 Overlay */
  {0x4e,4,HKSCS_PATCH_LEN,NULL,COD_NISO|COD_MB_4,hkscs_fa_uni_byte,L_ZH,
	NULL,NULL,"hkscs_fa"},	/* BIG5+HKSCS */
  {0x50,2,CP932932_PATCH_LEN,cp932932_uni_byte,COD_NISO|COD_MB_4,NULL,
  	L_JP,NULL,NULL,"cp932inv_patch"},	/* nkf-compatibility */
  {0x60,4,96800,NULL,COD_NISO | COD_MB_4,NULL,L_JP,NULL,NULL,NULL},
				/* GT Shotai */
  {0x61,4,57236,NULL,COD_NISO | COD_MB_4,NULL,L_JP,NULL,NULL,NULL},
				/* Daikanwa */
  {0x62,2,57236,NULL,COD_NISO | COD_MB_4,NULL,L_JP,NULL,NULL,NULL},
				/* Symbols */
  {0x63,1,64,NULL,COD_NISO | COD_MB_4,NULL,L_JP,NULL,NULL,NULL},
				/* 6-Braille */
  {0x64,1,256,NULL,COD_NISO | COD_MB_4,NULL,L_JP,NULL,NULL,NULL},
				/* 8-Braille */
  {0x65,2,1410,NULL,COD_NISO | COD_MB_4,NULL,L_JP,NULL,NULL,NULL}, /* Tompa */
  {0x68,4,PRV_TABLE_LEN,NULL,COD_NISO|COD_MB_4,n_conv_priv2emot,L_NU,
  	NULL,NULL,"conv_priv2emot"},
  {0x6a,1,238,vni_expat_uni_byte,COD_NISO|COD_MB_4,NULL,M_VI,
  	NULL,NULL,"vnie"},
  {0x6b,1,256,uni_lig_tscii,COD_NISO|COD_MB_4,NULL,L_TA,
  	NULL,NULL,"tscii_i"},
  {0x6c,1,128,gsm0338_alt_uni_byte,COD_NISO|COD_MB_4,NULL,L_NU,
  	NULL,NULL,"gsm0338a"},
  {0x6d,4,EMOJI_TBL_LEN,NULL,COD_NISO|COD_MB_4,n_emoji_a_uni_byte,L_NU,
  	emoticon_table_gen,NULL,"n_emoji"},
  {0x6e,4,EMOJI_TBL_LEN,NULL,COD_NISO|COD_MB_4,a_emoji_a_uni_byte,L_NU,
  	emoticon_table_gen,NULL,"a_emoji"},
  {0x6f,4,EMOJI_TBL_LEN,NULL,COD_NISO|COD_MB_4,s_emoji_a_uni_byte,L_NU,
  	emoticon_table_gen,NULL,"s_emoji"},
  {0x00,0,0,NULL,COD_NISO | COD_MB_4,NULL,L_NU,NULL,NULL,NULL}
				/* is last entry */
};

/* --------------------------------------------------------------- */
/* ebcdic tables						   */
/* --------------------------------------------------------------- */
struct iso_byte_defs ebcdic_byte_defs[] = { /* ebcdic tables	   */
  {0x00,0,0,NULL,COD_NISO | COD_25,NULL,L_NU,NULL,NULL,NULL}
				/* is last entry */
};

static struct iso_byte_defs_entry iso_bytedef_table[] = {
  {iso_unibyte_defs,0,0,NULL}, 
  {iso_iso8859_defs,0,0,NULL}, 
  {iso_im2byte_defs,0,0,NULL}, 
  {iso_3_dblbyte_defs,0,0,NULL},
  {iso_4_dblbyte_defs,0,0,NULL}, 
  {misc_byte_defs,0,0,NULL},
  {cp_byte_defs,0,0,NULL},
  {ovlay_byte_defs,0,0,NULL},
  {miscmul_byte_defs,0,0,NULL},
  {ebcdic_byte_defs,0,0,NULL},
  {NULL,0,0,NULL}
};
#endif

/* --------------------------------------------------------------- */
/* output side table for kana region and kanji region		   */
/* --------------------------------------------------------------- */

#define  is_OTBL_X213(x) ((x & (OTBL_JIS | OTBL_X213)) == (OTBL_JIS | OTBL_X213))
#define  is_OTBL_X213C(x) ((x & (OTBL_JIS | OTBL_X213C)) == (OTBL_JIS | OTBL_X213C))
#define  is_OTBL_JISK(x) ((x & (OTBL_JIS | OTBL_JISK)) == (OTBL_JIS | OTBL_JISK))

#if defined(OUTPUT_DYNAMIC_TABLE) 
unsigned short	o_ascii_tbl[ASCII_TABLE_LEN];
unsigned short	o_kana_tbl[KANA_TABLE_LEN];
unsigned short	o_cjk_tbl[CJK_TABLE_LEN];
unsigned short	o_glyph_tbl[GLYPH_TABLE_LEN];
unsigned short	o_latin_tbl[LATIN_TABLE_LEN];
unsigned short	o_cjk_a_tbl[CJK_A_TABLE_LEN];
unsigned short	o_cjk_b_tbl[CJK_B_TABLE_LEN];
unsigned short	o_cjk_cc_tbl[CJK_C_TABLE_LEN];
unsigned short	o_cjk_y_tbl[Y_TABLE_LEN];
unsigned short	o_cjk_hngl_tbl[HNGL_TABLE_LEN];
unsigned short	o_cpt_tbl[CPT_TABLE_LEN];
unsigned short	o_prv_tbl[PRV_TABLE_LEN];
unsigned short	o_hist_tbl[HIST_TABLE_LEN];
unsigned short	o_note_tbl[NOTE_TABLE_LEN];
unsigned short	o_upmisc_tbl[UPMISC_TABLE_LEN];
unsigned short	o_upkana_tbl[UPKANA_TABLE_LEN];

extern unsigned short  ascii_uni_byte[];
extern unsigned short  koi8_uni_byte[];
extern unsigned short  iso8859_1_uni_byte[];
extern unsigned short  iso8859_2_uni_byte[];
extern unsigned short  iso8859_3_uni_byte[];
extern unsigned short  iso8859_4_uni_byte[];
extern unsigned short  iso8859_5_uni_byte[];
extern unsigned short  iso8859_6_uni_byte[];
extern unsigned short  iso8859_7_uni_byte[];
extern unsigned short  iso8859_8_uni_byte[];
extern unsigned short  iso8859_9_uni_byte[];
extern unsigned short  iso8859_10_uni_byte[];
extern unsigned short  iso8859_13_uni_byte[];
extern unsigned short  iso8859_14_uni_byte[];
extern unsigned short  iso8859_15_uni_byte[];
extern unsigned short  iso8859_16_uni_byte[];
extern unsigned short  tis620_2533_uni_byte[];
extern unsigned short  cp1251_u_uni_byte[];
extern unsigned short  gb198880_uni_byte[];

extern long	uni_fix_table[];	
#endif

#if defined(OUTPUT_DYNAMIC_TABLE) || !defined(DYNAMIC_LOADING) || defined(SWIG_EXT)
static long	x0213_0003_table[] = {
  /* multimap part */
    0x00e6, 0x295c,
    0x0254, 0x2b38,
    0x0259, 0x2b30,
    0x025a, 0x2b43,
    0x028c, 0x2b37,
    0xff02, 0x2230,
    0xff07, 0x222f,
    0xff0d, 0x2231,
    0xff5e, 0x2232,
    0xffe0, 0x2171,
    0xffe1, 0x2172,
    0xffe2, 0x224c,
    0xffe3, 0x2131,
    0xffe4, 0x2925,
    0xffe5, 0x216f,
    0x3016, 0x225a,
    0x3017, 0x225b,
    0x3018, 0x2258,
    0x3019, 0x2259,
    0x301a, 0x225a,
    0x301b, 0x225b,
    0x301d, 0x2d60,
 /* 2000-2003 change */
    0x9004, 0x3029,
    0x9b1d, 0xfd37,
    0x8fc2, 0x312a,
    0xf992, 0x6f23,
    -1
};

/* Added 10 glyphs in JIS X 0213(2004) */
static long	x0213_0003s_table[] = {
    0x4ff1, 0x2e21,
    0x525d, 0x2f7e,
    0x541e, 0x4f7e,
    0x5653, 0x7427,
    0x59f8, 0x7e7a,
    0x5c5b, 0x7e7b,
    0x5e77, 0x7e7c,
    0x7626, 0x7e7d,
    0x7e6b, 0x7e7e,
    0x20b9f, 0x4f54,
    -1
};
#endif

#if defined(OUTPUT_DYNAMIC_TABLE) 
struct out_region_defs {
    char	defschar;
    int		len;
    unsigned short	*tbl;
} otbl_reg_defs[] = {
    {'N',KANA_TABLE_LEN,o_kana_tbl}, {'K',CJK_TABLE_LEN,o_cjk_tbl},
    {'C',CPT_TABLE_LEN,o_cpt_tbl}, {'L',LATIN_TABLE_LEN,o_latin_tbl},
    {'G',GLYPH_TABLE_LEN,o_glyph_tbl}, {'H',HNGL_TABLE_LEN,o_cjk_hngl_tbl},
    {'A',CJK_A_TABLE_LEN,o_cjk_a_tbl}, {'B',CJK_B_TABLE_LEN,o_cjk_b_tbl},
    {'Y',Y_TABLE_LEN,o_cjk_y_tbl}, {'X',CJK_C_TABLE_LEN,o_cjk_cc_tbl},
    {'P',PRV_TABLE_LEN,o_prv_tbl}, {'S',128,o_ascii_tbl}, 
    {'I',HIST_TABLE_LEN,o_hist_tbl}, {'O',NOTE_TABLE_LEN,o_note_tbl},
    {'U',UPKANA_TABLE_LEN,o_upkana_tbl},
    {'M',UPMISC_TABLE_LEN,o_upmisc_tbl},
    {'-',0,NULL}, {'-',0,NULL}
};
char otbl_reg_symbol[] = 
    {'N','K','C','L','G','H','A','B','Y','X','P','S','I','O','U','M',
     '-','-'};

struct iso_byte_defs uo_iso_kana_defs[] = {
  {'B',0,KANA_TABLE_LEN,NULL,COD_MB,NULL,0,NULL}, /* JIS X-0208/0212 */
/* JIS X-0213 and its variants */
  {'O',0,KANA_TABLE_LEN,NULL,COD_MB | COD_MB_4,NULL,0,NULL},
  {'P',0,KANA_TABLE_LEN,NULL,COD_MB | COD_MB_4,NULL,0,NULL},
/* GB's */
  {'A',0,KANA_TABLE_LEN,NULL,COD_MB | COD_MB_4,NULL,0,NULL},
/* Hangle's */
  {'C',0,KANA_TABLE_LEN,NULL,COD_MB | COD_MB_4,NULL,0,NULL},
  {0x00,0,0,NULL,FALSE,NULL,0,NULL}
};

struct iso_byte_defs uo_iso_kanji_defs[] = {
  {'B',0,CJK_TABLE_LEN,NULL,COD_MB,NULL,0,NULL},/* JIS X-0208/0212 */
/* JIS X-0213 and its variants */
  {'O',0,CJK_TABLE_LEN,NULL,COD_MB | COD_MB_4,NULL,0,NULL},
  {'P',0,CJK_TABLE_LEN,NULL,COD_MB | COD_MB_4,NULL,0,NULL},
  {'A',0,CJK_TABLE_LEN,NULL,COD_MB | COD_MB_4,NULL,0,NULL},
  {'C',0,CJK_TABLE_LEN,NULL,COD_MB | COD_MB_4,NULL,0,NULL},
  {0x00,0,0,NULL,FALSE,NULL,0,NULL}
};

struct iso_byte_defs uo_iso_compat_defs[] = {
  {'B',0,CPT_TABLE_LEN,NULL,COD_MB,NULL,0,NULL},/* JIS X-0208/0212 */
  {'O',0,CPT_TABLE_LEN,NULL,COD_MB | COD_MB_4,NULL,0,NULL},
  {'P',0,CPT_TABLE_LEN,NULL,COD_MB | COD_MB_4,NULL,0,NULL},
  {'A',0,CPT_TABLE_LEN,NULL,COD_MB | COD_MB_4,NULL,0,NULL},
  {'C',0,CPT_TABLE_LEN,NULL,COD_MB | COD_MB_4,NULL,0,NULL},
  {0x00,0,0,NULL,FALSE,NULL,0,NULL}
};

#define ocs_gb2312_index	2
#define ocs_iso2022cnc_index	15
#define ocs_iso2022cng_index	16
#define ocs_gb18030_index	37

/* must be synchonize to output table defs in out_code_table.c */
/* do not insert entry into table below. See MAINTAIN ORDER.	*/
struct out_codeset_defs {
	char	defschar[4];
	short	char_width;
	int	table_len[4];
	unsigned short *g1unitbl;
	unsigned short *g2unitbl;
	unsigned short *g3unitbl;
	unsigned short *g4unitbl;
	skf_ucode *g1uniltbl;
	skf_ucode *g2uniltbl;
	skf_ucode *g3uniltbl;
	skf_ucode *g4uniltbl;
	char	*desc;
	void	(*otablegen)();
	unsigned long 	valtbl;
} dyn_out_codeset[] = {
  {{'B','O','P',0},4, 		/* Nr.1 JIS X-0213 (compat)	   */
   {ISOMB_CODE_END,ISOMB_CODE_END,ISOMB_CODE_END,0},NULL,NULL,NULL,NULL,
   uni_t_x213_1,x0208_long_table,uni_t_0213_abbrev_q_21,NULL,
   "iso2022_jp_2000c",NULL,
   OTBL_KANJI | OTBL_KANA | OTBL_COMPAT | OTBL_GLYPHS | OTBL_LATIN
  | OTBL_JIS | OTBL_X213C | OTBL_CJK_A | OTBL_CJK_B | OTBL_CJK_CC
  | OTBL_X213 | OTBL_JISK},
  {{'O','P',0,0},4, 		/* Nr.2 JIS X-0213 (2000,full)	   */
   {ISOMB_CODE_END,ISOMB_CODE_END,0,0},NULL,NULL,NULL,NULL,uni_t_x213_1,
   uni_t_0213_abbrev_q_21,NULL,NULL,"iso2022_jp_2000",NULL,
   OTBL_JIS | OTBL_KANJI | OTBL_KANA | OTBL_COMPAT | OTBL_GLYPHS 
  | OTBL_LATIN | OTBL_CJK_A | OTBL_CJK_B | OTBL_CJK_CC | OTBL_X213
  | OTBL_JISK},
  {{'A',0x00,0,0},2,		/* Nr.3 GB2312			   */
   {ISOMB_CODE_END,0,0,0},uni_t_gb2312,NULL,NULL,NULL,NULL,NULL,
   NULL,NULL,"gb2312",gb2312_otbl_fix,
   OTBL_KANJI | OTBL_KANA | OTBL_COMPAT | OTBL_GLYPHS | OTBL_LATIN
   |OTBL_ABSUP},
  {{'C',0x00,0,0},2,		/* Nr.4 KS X 1001		   */
   {ISOMB_CODE_END,0,0,0},uni_t_x1001,NULL,NULL,NULL,NULL,NULL,
   NULL,NULL,"ksx1001",NULL,
   OTBL_KANJI | OTBL_KANA | OTBL_COMPAT | OTBL_GLYPHS | OTBL_HNGL 
   | OTBL_LATIN},
  {{0x42,0x00,0,0},2,{BIG5_TBL_LEN,0,0,0}, /* Nr.5 BIG5-ETEN	   */
   big5_uni_byte,NULL,NULL,NULL,NULL,NULL,NULL,NULL,"big5_eten",NULL,
   OTBL_KANJI | OTBL_KANA | OTBL_COMPAT | OTBL_GLYPHS | OTBL_LATIN
   | OTBL_BIG5 | OTBL_NC},
  {{0x47,0x00,0,0},2,{BIG5_TBL_LEN,0,0,0}, /* Nr.6 BIG5-HKU	   */
   big5h_uni_byte,NULL,NULL,NULL,NULL,NULL,NULL,NULL,"big5_hku",NULL,
   OTBL_KANJI | OTBL_KANA | OTBL_COMPAT | OTBL_GLYPHS | OTBL_LATIN
   | OTBL_BIG5 | OTBL_HKU | OTBL_NC},
  {{'^',0x00,0,0},2,{BIG5_TBL_LEN,0,0,0},  /* Nr.7 BIG5-cp950	   */
   big5_uni_byte,NULL,NULL,NULL,NULL,NULL,NULL,NULL,"big5_cp950",NULL,
   OTBL_KANJI | OTBL_KANA | OTBL_COMPAT | OTBL_GLYPHS | OTBL_LATIN
   | OTBL_BIG5 | OTBL_CP950 | OTBL_NC},
  {{'H',0x00,0,0},2,{ISOMB_CODE_END,0,0,0},gb12345_uni_byte,NULL,
   NULL,NULL,NULL,NULL,NULL,NULL,"gb12345",NULL,
   OTBL_KANJI | OTBL_KANA | OTBL_COMPAT | OTBL_GLYPHS | OTBL_LATIN
   | OTBL_NC}, /* Nr.8 GB12345 */
  {{0x4f,'C',0,0},2,{JOHAB_TBL_LEN,ISOMB_CODE_END,0,0},
   johab_uni_byte, uni_t_x1001, NULL,NULL,NULL,NULL,NULL,NULL,
   "ks_johab",NULL,
   OTBL_KANJI | OTBL_KANA | OTBL_COMPAT | OTBL_GLYPHS | OTBL_LATIN
   | OTBL_HNGL | OTBL_NC | OTBL_JOHAB}, /* Nr.9 johab */
  {{'G','H',0,0},2,{ISOMB_CODE_END,ISOMB_CODE_END,0,0},
   uni_t_cns11643_1,uni_t_cns11643_2,NULL,NULL,NULL,NULL,NULL,NULL,
   "cns11643",NULL,
   OTBL_KANJI | OTBL_KANA | OTBL_COMPAT | OTBL_GLYPHS | OTBL_LATIN
  | OTBL_CJK_A},	/* Nr.10 CNS 11643 */
  {{'@',0x00,0,0},2,{ISOMB_CODE_END,0,0,0},uni_t_x0208_78,NULL,
   NULL,NULL,NULL,NULL,NULL,NULL,"oldjis",NULL,
   OTBL_JIS | OTBL_KANJI | OTBL_KANA | OTBL_COMPAT | OTBL_GLYPHS
   | OTBL_LATIN | OTBL_JISK},
	/* Nr.11 JIS X-0208 (1978: i.e. JIS C6226) */
  {{0x51,0,'A',0},2,{ISOSB_CODE_END,0,ISOSB_CODE_END,0},
   NULL,NULL, NULL, NULL,NULL,NULL,NULL,NULL, "koi_8",NULL,
   OTBL_LATIN | OTBL_GLYPHS | OTBL_JIS | OTBL_MONO}, /* Nr.12 KOI-8 */
  {{0x55,'A',0,0},2,{ISOSB_CODE_END,ISOSB_CODE_END,0,0},
   NULL,NULL, NULL, NULL,NULL,NULL,NULL,NULL, "cp1251",NULL,
   OTBL_LATIN | OTBL_GLYPHS | OTBL_JIS | OTBL_MONO}, /* Nr.13 cp1251 */
  {{'A','A',0,0},2,{ISOSB_CODE_END,ISOSB_CODE_END,0,0},
   NULL,NULL,NULL,NULL,NULL,NULL, NULL, NULL, "iso8859_1",NULL,
   OTBL_LATIN | OTBL_GLYPHS | OTBL_MONO}, /* Nr.14 iso8859-1 */
  {{'F','A',0,0},2,{ISOSB_CODE_END,ISOSB_CODE_END,0,0},
   NULL,NULL, NULL, NULL,NULL,NULL,NULL,NULL, "iso8859_7",NULL,
   OTBL_LATIN | OTBL_GLYPHS | OTBL_MONO}, /* Nr.15 iso8859-7 */
  {{'J','G','A',0},2,{ISOMB_CODE_END,ISOMB_CODE_END,ISOMB_CODE_END,0},
   uni_t_cns11643_1,uni_t_cns11643_2,uni_t_gb2312,NULL,NULL,NULL,
   NULL,NULL,"iso2022_cnc",NULL,
   OTBL_KANJI | OTBL_KANA | OTBL_COMPAT | OTBL_GLYPHS | OTBL_LATIN
  | OTBL_CJK_A},	/* Nr.16 iso-2022-cn(CNS 11643 based) */
  {{'I','G','A',0},2,{ISOMB_CODE_END,ISOMB_CODE_END,ISOMB_CODE_END,0},
   uni_t_gb2312,uni_t_cns11643_2,uni_t_cns11643_1,NULL,
   NULL,NULL,NULL,NULL,"iso2022_cng",NULL,
   OTBL_KANJI | OTBL_KANA | OTBL_COMPAT | OTBL_GLYPHS | OTBL_LATIN
  | OTBL_CJK_A},	/* Nr.17 iso-2022-cn(GB2312 based) */
  {{'b',0x00,0,0},2,{ISOMB_CODE_END,0,0,0}, cp932_table,NULL,
   NULL,NULL,NULL,NULL,NULL,NULL,"cp932",cp932_fix_tbl, OTBL_JIS |
   OTBL_JISK | OTBL_KANJI | OTBL_KANA | OTBL_COMPAT | OTBL_GLYPHS
   | OTBL_PRV | OTBL_LATIN},/* Nr.18 JIS X-0208 (cp932)		  */
  {{'i',0x00,0,0},2,{ISOMB_CODE_END,0,0,0}, cp943_table,NULL,
   NULL,NULL,NULL,NULL,NULL,NULL,"cp943",cp943_fix_tbl, OTBL_JIS |
   OTBL_KANJI | OTBL_KANA | OTBL_COMPAT | OTBL_GLYPHS | OTBL_PRV |
   OTBL_LATIN | OTBL_JISK},  /* Nr.19 JIS X-0208 (cp943:IBM OS/2) */
  {{'Q','P',0,0},4,{ISOMB_CODE_END,ISOMB_CODE_END,0,0},
   NULL,NULL,NULL,NULL,x213_1n_uni_byte,
   uni_t_0213_abbrev_q_21,NULL,NULL, "iso2022_jp_2004",o_x213_1nfix,
   OTBL_JIS | OTBL_KANJI | OTBL_CJK_B | OTBL_X213 | OTBL_JISK},
	/* Nr.20 JIS X-0213 (2004) - Kanji & CJK-B differs */
  {{0x37,0,0,0},2,{ISOMB_CODE_END,0,0,0},
   cp932_table,NULL,NULL,NULL,NULL,NULL,NULL,NULL,
   "sjis_cel",sjis_cell_fix_tbl, OTBL_JIS | OTBL_PRV | OTBL_JISK},
   	/* Nr.21 SJIS Cellular		   */
  {{0x76,0,0,'A'},2,{ISOSB_CODE_END,0,0,ISOSB_CODE_END},
   viscii_uni_byte,NULL,NULL,visciir_uni_byte,NULL,NULL,NULL,NULL,
   "viscii",NULL,
   OTBL_LATIN | OTBL_GLYPHS | OTBL_NC | OTBL_MONO}, /* Nr.22 VISCII */
  {{0x4e,0,0,0},2,{GBK_TBL_LEN,0,0,0},gbk_uni_byte,
   NULL,NULL,NULL,NULL,NULL,
   NULL, NULL,"gbk",gbk_otbl_fix,
   OTBL_KANJI | OTBL_KANA | OTBL_COMPAT | OTBL_GLYPHS | OTBL_LATIN
   | OTBL_CJK_A | OTBL_PRV | OTBL_GBK | OTBL_NC}, /* Nr.23 GBK */
  {{'B','A',0,0},2,{ISOSB_CODE_END,ISOSB_CODE_END,0,0},
   NULL,NULL,NULL,NULL,NULL,NULL, NULL, NULL, "iso8859_2",NULL,
   OTBL_LATIN | OTBL_GLYPHS | OTBL_MONO}, /* Nr.24 iso8859-2 */
  {{'C','A',0,0},2,{ISOSB_CODE_END,ISOSB_CODE_END,0,0},
   NULL,NULL,NULL,NULL,NULL,NULL, NULL, NULL, "iso8859_3",NULL,
   OTBL_LATIN | OTBL_GLYPHS | OTBL_MONO}, /* Nr.25 iso8859-3 */
  {{'D','A',0,0},2,{ISOSB_CODE_END,ISOSB_CODE_END,0,0},
   NULL,NULL,NULL,NULL,NULL,NULL, NULL, NULL, "iso8859_4",NULL,
   OTBL_LATIN | OTBL_GLYPHS | OTBL_MONO}, /* Nr.26 iso8859-4 */
  {{'L','A',0,0},2,{ISOSB_CODE_END,ISOSB_CODE_END,0,0},
   NULL,NULL,NULL,NULL,NULL,NULL, NULL, NULL, "iso8859_5",NULL,
   OTBL_LATIN | OTBL_GLYPHS | OTBL_MONO}, /* Nr.27 iso8859-5 */
  {{'G','A',0,0},2,{ISOSB_CODE_END,ISOSB_CODE_END,0,0},
   NULL,NULL,NULL,NULL,NULL,NULL, NULL, NULL, "iso8859_6",NULL,
   OTBL_LATIN | OTBL_GLYPHS | OTBL_MONO}, /* Nr.28 iso8859-6 */
  {{'H','A',0,0},2,{ISOSB_CODE_END,ISOSB_CODE_END,0,0},
   NULL,NULL,NULL,NULL,NULL,NULL, NULL, NULL, "iso8859_8",NULL,
   OTBL_LATIN | OTBL_GLYPHS | OTBL_MONO}, /* Nr.29 iso8859-8 */
  {{'M','A',0,0},2,{ISOSB_CODE_END,ISOSB_CODE_END,0,0},
   NULL,NULL,NULL,NULL,NULL,NULL, NULL, NULL, "iso8859_9",NULL,
   OTBL_LATIN | OTBL_GLYPHS | OTBL_MONO}, /* Nr.30 iso8859-9 */
  {{'V','A',0,0},2,{ISOSB_CODE_END,ISOSB_CODE_END,0,0},
   NULL,NULL,NULL,NULL,NULL,NULL, NULL, NULL, "iso8859_10",NULL,
   OTBL_LATIN | OTBL_GLYPHS | OTBL_MONO}, /* Nr.31 iso8859-10 */
  {{'T','A',0,0},2,{ISOSB_CODE_END,ISOSB_CODE_END,0,0},
   NULL,NULL,NULL,NULL,NULL,NULL, NULL, NULL, "iso8859_11",NULL,
   OTBL_LATIN | OTBL_GLYPHS | OTBL_MONO}, /* Nr.32 iso8859-11 */
  {{'Y','A',0,0},2,{ISOSB_CODE_END,ISOSB_CODE_END,0,0},
   NULL,NULL,NULL,NULL,NULL,NULL, NULL, NULL, "iso8859_13",NULL,
   OTBL_LATIN | OTBL_GLYPHS | OTBL_MONO}, /* Nr.33 iso8859-13 */
  {{'_','A',0,0},2,{ISOSB_CODE_END,ISOSB_CODE_END,0,0},
   NULL,NULL,NULL,NULL,NULL,NULL, NULL, NULL, "iso8859_14",NULL,
   OTBL_LATIN | OTBL_GLYPHS | OTBL_MONO}, /* Nr.34 iso8859-14 */
  {{'b','A',0,0},2,{ISOSB_CODE_END,ISOSB_CODE_END,0,0},NULL,NULL,
   NULL,NULL,NULL,NULL, NULL, NULL, "iso8859_15",NULL,
   OTBL_LATIN | OTBL_GLYPHS | OTBL_MONO}, /* Nr.35 iso8859-15 */
  {{'f','A',0,0},2,{ISOSB_CODE_END,ISOSB_CODE_END,0,0},NULL,NULL,
   NULL,NULL,NULL,NULL, NULL, NULL, "iso8859_16",NULL,
   OTBL_LATIN | OTBL_GLYPHS | OTBL_MONO}, /* Nr.36 iso8859-16 */
  {{0x4b,0x00,0,0},4,
   {BIG5P_TBL_LEN,0,0,0},NULL,NULL,NULL,NULL,
   big5p_uni_byte,NULL,NULL,NULL,"big5_plus",big5p_otbl_fix, 
     OTBL_KANJI | OTBL_KANA | OTBL_COMPAT | OTBL_GLYPHS
   | OTBL_LATIN | OTBL_PRV | OTBL_CJK_A | OTBL_CJK_B | OTBL_CJK_CC
   | OTBL_BIG5 | OTBL_NC}, 		/* Nr.37 BIG5-PLUS    */
  {{0x4c,0x4c,0,0},2,{GBK_TBL_LEN,GB2K_A_LEN,0,0},gb2k_uni_byte, 
   gb2k_a_tbl,NULL,NULL,NULL,NULL,NULL,NULL,"gb2k",gb2k_otbl_gen,
   (OTBL_GBK | OTBL_NC | OTBL_KANJI | OTBL_KANA | OTBL_COMPAT
   | OTBL_GLYPHS | OTBL_LATIN | OTBL_CJK_B | OTBL_HNGL | OTBL_Y 
   | OTBL_CJK_A | OTBL_PRV)}, 	/* Nr.38 GB18030 		 */
  {{0x4a,0x4a,0,0},2, 	/* Nr.39 EBCDIC IBM DBCS Japanese	 */
   {11970,256,0,0}, uni_t_ibm930,NULL,NULL,NULL,NULL,NULL,NULL,NULL,
   "ibm930",NULL, OTBL_NC | OTBL_EBC | OTBL_KANJI | OTBL_KANA
   | OTBL_COMPAT | OTBL_GLYPHS | OTBL_LATIN | OTBL_PRV | OTBL_ASCII},
  {{0x46,0x46,0,0},2, 	/* Nr.40 EBCDIC IBM DBCS Korian		 */
   {30970,256,0,0}, uni_t_ibm933,NULL,NULL,NULL,NULL,NULL,NULL,NULL,
   "ibm933",NULL,
   OTBL_NC | OTBL_EBC | OTBL_KANJI | OTBL_KANA | OTBL_COMPAT |
    OTBL_GLYPHS | OTBL_LATIN | OTBL_HNGL | OTBL_PRV | OTBL_ASCII},
  {{0x45,0x45,0,0},2,{11970,256,0,0}, uni_t_ibm935,NULL,NULL,NULL,
  NULL,NULL,NULL,NULL,
   "ibm935",NULL, OTBL_NC | OTBL_EBC | OTBL_KANJI | OTBL_KANA
   | OTBL_COMPAT | OTBL_GLYPHS | OTBL_LATIN | OTBL_PRV | OTBL_ASCII},
	/* Nr.41 EBCDIC IBM DBCS Simplified Chinese */
  {{0x44,0x44,0,0},2,{30970,256,0,0}, uni_t_ibm937,NULL,NULL,NULL,
  NULL,NULL,NULL,NULL,
   "ibm937",NULL, OTBL_NC | OTBL_EBC | OTBL_KANJI | OTBL_KANA 
   | OTBL_COMPAT | OTBL_GLYPHS | OTBL_LATIN | OTBL_PRV | OTBL_ASCII},
	/* Nr.42 EBCDIC IBM DBCS Traditional Chinese */
  {{0x50,0x00,0,0},2, 		/* Nr.43 BIG5-2003	      */
   {BIG5P_TBL_LEN,0,0,0},big52_uni_byte,NULL,NULL,NULL,NULL,
   NULL,NULL,NULL,"big5_2003",NULL, 
     OTBL_KANJI | OTBL_KANA | OTBL_COMPAT | OTBL_GLYPHS
   | OTBL_LATIN | OTBL_PRV 
   | OTBL_BIG5 | OTBL_NC},
  {{0x51,0x00,0,0},2, 		/* Nr.44 BIG5-UAO	      */
   {BIG5P_TBL_LEN,0,0,0},big5a_uni_byte,NULL,NULL,NULL,NULL,
   NULL,NULL,NULL,"big5_uao",big5a_otbl_fix, 
     OTBL_KANJI | OTBL_KANA | OTBL_COMPAT | OTBL_GLYPHS
   | OTBL_LATIN | OTBL_PRV | OTBL_CJK_A 
   | OTBL_BIG5 | OTBL_NC},
  {{'j',0x00,0,0},2,{ISOMB_CODE_END,0,0,0}, /* Nr.45 cp932w   */
   cp932w_table,NULL,NULL,NULL,NULL,NULL,NULL,NULL,
   "cp932w",cp932w_fix_tbl,
   OTBL_JIS | OTBL_KANJI | OTBL_KANA | OTBL_COMPAT | OTBL_GLYPHS
   | OTBL_PRV | OTBL_LATIN | OTBL_JISK}, 
  {{0x67,0x00,0,0},2,{BIG5P_TBL_LEN,0,0,0},cp949_uni_byte,
   NULL,NULL,NULL,NULL,NULL,NULL,NULL,"cp949",uhc_otbl_fix, 
     OTBL_KANJI | OTBL_KANA | OTBL_COMPAT | OTBL_GLYPHS
   | OTBL_LATIN | OTBL_PRV | OTBL_HNGL
   | OTBL_GBK | OTBL_NC}, 		/* Nr.46 cp949 (UHC)     */
  {{0x4d,0x4d,0,0},2, 		/* Nr.47 EBCDIC IBM DBCS ibm931  */
   {11970,256,0,0}, uni_t_ibm930,NULL,NULL,NULL,NULL,NULL,NULL,NULL,
   "ibm931",NULL,
   OTBL_NC | OTBL_EBC 
   | OTBL_COMPAT | OTBL_GLYPHS | OTBL_LATIN | OTBL_ASCII},
#if defined(KEIS_EXTRA_SUPPORT) && defined(POST_195)
  {{0x65,0x65,0x65,0x65},4, 	/* Nr.48 KEIS			 */
   {KEIS_TBL_LEN,256,56,ISOMB_CODE_END},NULL,NULL,NULL,NULL,
   uni_t_keis59,ebckeis_uni_byte,
   o_KEIS_9F,keish_uni_byte,"keis",NULL, OTBL_NC | OTBL_EBC 
   | OTBL_COMPAT | OTBL_GLYPHS | OTBL_LATIN | OTBL_ASCII},
#endif
  {{0x63,0,0,0},4,	/* Nr.49 JIS X-0208(newjyouyoukanji)	   */
   {ISOMB_CODE_END,0,0,0},NULL,NULL,NULL,NULL,x0208_nj_uni_byte,
   NULL,NULL,NULL,"iso2022_jpnj",NULL,
   OTBL_JIS | OTBL_KANJI | OTBL_KANA | OTBL_COMPAT | OTBL_GLYPHS |
   OTBL_LATIN | OTBL_CJK_B | OTBL_JISK},
  {{0x6a,0,0,0},4,	/* Nr.50 SJIS_NTT Doc*mo		   */
   {EMOJI_TBL_LEN,0,0,0},NULL,NULL,NULL,NULL,n_emoji_a_uni_byte,
   NULL,NULL,NULL,"sjis_docomo_phone",emoti_ntt_otbl_gen,
   OTBL_JIS | OTBL_KANJI | OTBL_KANA | OTBL_COMPAT | OTBL_PRV
   | OTBL_GLYPHS | OTBL_LATIN | OTBL_NOTE | OTBL_JISK},
  {{0x6b,0,0,0},4,	/* Nr.51 SJIS_KDD* AU			   */
   {EMOJI_TBL_LEN,0,0,0},NULL,NULL,NULL,NULL,a_emoji_a_uni_byte,
   NULL,NULL,NULL,"sjis_au_phone",emoti_au_otbl_gen,
   OTBL_JIS | OTBL_KANJI | OTBL_KANA | OTBL_COMPAT | OTBL_PRV
   | OTBL_GLYPHS | OTBL_LATIN | OTBL_NOTE | OTBL_JISK},
  {{0x6c,0,0,0},4,	/* Nr.52 SJIS_S*ftBank			   */
   {EMOJI_TBL_LEN,0,0,0},NULL,NULL,NULL,NULL,s_emoji_a_uni_byte,
   NULL,NULL,NULL,"sjis_sbnk_phone",emoti_sb_otbl_gen,
   OTBL_JIS | OTBL_KANJI | OTBL_KANA | OTBL_COMPAT | OTBL_PRV
   | OTBL_GLYPHS | OTBL_LATIN | OTBL_NOTE | OTBL_JISK},
#if 0
  {{'N',0x00,0,0},2,{ISOMB_CODE_END,0,0,0},uni_t_x1001,NULL,NULL,NULL,
  NULL,NULL,NULL,NULL,"DPR Korian",NULL,
   OTBL_KANJI | OTBL_KANA | OTBL_COMPAT | OTBL_GLYPHS | OTBL_HNGL 
   | OTBL_LATIN}, /* Nr.xx DPR Korian */
#endif
  {{0x00,0x00,0,0},0,{0,0,0,0},NULL,NULL,NULL,NULL,NULL,FALSE}
};

/* --------------------------------------------------------------- */

short	out_x0208_2 = 0;	/* X-0208 2nd plane	  */
#if	!defined(SWIG_EXT) || defined(OUTPUT_DYNAMIC_TABLE)
short		debug_opt = 0;
#endif

int gen_tables(entry,f,header,output_format)
struct iso_byte_defs	*entry;
FILE	*f;
FILE	*header;
int	output_format;
{
    int i,j;
    skf_ucode *dumpedtbl;
    unsigned short *utable;
    unsigned short uc;
    skf_ucode luc;
    unsigned long kana;
#if defined(DYNAMIC_LOADING) && !defined(SWIG_EXT)
    int	mb_cur_max,mb_cur_min;
    char *uconv_class;
#endif

    if (((entry->unitbl) == NULL) && ((entry->uniltbl) == NULL)) return(0);
    if ((entry->cname) == NULL) return(0);
    kana = entry->is_kana;
    if (entry->char_width <= 2) {	/* UCS2	*/
	utable = entry->unitbl;
#if !defined(DYNAMIC_LOADING) || defined(SWIG_EXT)
	/* header generation */
#if 0
	fprintf(stderr,"\n generating %s",entry->cname);
	(void)fflush(stderr);
#endif
	fprintf(header,"\nunsigned short %s_uni_byte[%d] = {\n",
		entry->cname,entry->table_len);
#else
	if (output_format == FORMAT_SKF) {
	    fprintf(header,"\n#define %s_uni_byte\tNULL",entry->cname);
	    fprintf(f,"skf_ctable20");
	} else if (output_format == FORMAT_ICU) {
	    if (entry->char_width > 1) {
		mb_cur_max = 2;
		mb_cur_min = 2;
		uconv_class = "MBCS";
	    } else {
		mb_cur_max = 1;
		mb_cur_min = 1;
		uconv_class = "SBCS";
	    };
	    fprintf(header,"<code_set_name>\t\"%s\"\n",entry->cname);
	    fprintf(header,"<char_name_mask>\t\"AXXXX\"\n");
	    fprintf(header,"<mb_cur_max>\t%01d\n",mb_cur_max);
	    fprintf(header,"<mb_cur_min>\t%01d\n",mb_cur_min);
	    fprintf(header,"<uconv_class>\t\"%s\"\n",uconv_class);
	    fprintf(header,"<subchar>\t\\x3F\n");
	    fprintf(header,"#\nCHARMAP\n#\n#\n#10646  %s\n#------ -----\n",
		entry->cname);
	} else if (output_format == FORMAT_CITRUS) {
	    fprintf(stderr,"Sorry, CITRUS format is not yet supported.");
	    return(0);
	} else if (output_format == FORMAT_GNU) {
	    fprintf(stderr,"Sorry, GNU LIBC format is not yet supported.");
	    return(0);
	} else if (output_format == FORMAT_MOZ) {
	    fprintf(stderr,"Sorry, MOZILLA format is not yet supported.");
	    return(0);
	} else;
#endif
	for (i=0;i<entry->table_len;i++) {
	    if (!is_tbl_iso(kana)) {
		j = i;
		uc = utable[j];
		if (entry->defschar == 'i') {  /* cp943 */
		    switch (j) {
			case 0x1c: uc = 0x2014; break;
			case 0x50: uc = 0xffe0; break;
			case 0x51: uc = 0xffe1; break;
			case 0x89: uc = 0xffe2; break;
			default: break;
		    };
		} else if (entry->defschar == 'b') { /* cp932 */
		    ;	/* do nothing */
		};
	    } else {
		uc = utable[i];
	    };
#if !defined(DYNAMIC_LOADING) || defined(SWIG_EXT)
	    fprintf(header,"0x%04x",uc);
	    if (i < (entry->table_len - 1)) {
		putc(',',header);
	    } else {
		fprintf(header,"\n};\n\n");
	    };
	    if ((i & 0x07) == 0x07) putc('\n',header);
#else
	if (output_format == FORMAT_SKF) {
	    putc((uc >> 8) & 0xff,f);
	    putc(uc & 0xff,f);
	} else if (output_format == FORMAT_ICU) {
	    fprintf(header,"<U%04x> ",uc);

	} else if (output_format == FORMAT_CITRUS) {
	} else ;
#endif
	};
    } else if (entry->char_width == 4) {  /* UTF-32 and !UCS2 */
	dumpedtbl = entry->uniltbl;
#if !defined(DYNAMIC_LOADING) || defined(SWIG_EXT)
	/* header generation */
	fprintf(stderr,"\n generating %s",entry->cname); (void)fflush(stderr);
	fprintf(header,"\nskf_ucode %s_uni_byte[%d] = {\n",
		entry->cname,entry->table_len);
#else
	if (entry->cname != NULL) {
	    fprintf(header,"\n#define %s_uni_byte\tNULL",entry->cname);
	} else;
	fprintf(f,"skf_ctable40");
#endif
	for (i=0;i<entry->table_len;i++) {
	    luc = dumpedtbl[i];
#if !defined(DYNAMIC_LOADING) || defined(SWIG_EXT)
	    fprintf(header,"0x%08x",luc);
	    if (i < (entry->table_len - 1)) {
		putc(',',header);
	    } else {
		fprintf(header,"\n};\n\n");
	    };
	    if ((i & 0x07) == 0x07) putc('\n',header);
#else
	    putc((luc >> 24) & 0xffU,f);
	    putc((luc >> 16) & 0xffU,f);
	    putc((luc >> 8) & 0xffU,f);
	    putc(luc & 0xffU,f);
#endif
	};
    };
    if (output_format == FORMAT_ICU) {
	fprintf(header,"#\nEND CHARMAP\n#\n#\n");
    } else if (output_format == FORMAT_ICU) {
	;
    } else {
	fprintf(header,"\n");
    };
    return(0);
}

#endif /* OUTPUT_DYNAMIC_TABLE */

#if defined(OUTPUT_DYNAMIC_TABLE) || !defined(DYNAMIC_LOADING) || defined(SWIG_EXT)
/* --------------------------------------------------------------- */
void set_out_table(uc,icc)
long uc,icc;
{
    unsigned short ic = (unsigned short) icc;

    if ((uc >= 0x0000) && (uc < 0x0080)) {
	o_ascii_tbl[uc] = ic;
    } else if ((uc >= 0x0080) && (uc < LATIN_TBL_START)) {
	; /* various latin: just discard	*/
    } else if ((uc >= LATIN_TBL_START) && (uc < GLYPH_TBL_START)) {
	o_latin_tbl[uc - LATIN_TBL_START] = ic;
    } else if ((uc >= GLYPH_TBL_START) && (uc < KANA_TBL_START)) {
	o_glyph_tbl[uc - GLYPH_TBL_START] = ic;
    } else if ((uc >= KANA_TBL_START) && (uc < CJK_A_TBL_START)) {
	o_kana_tbl[uc - KANA_TBL_START] = ic;
    } else if ((uc >= CJK_A_TBL_START) && (uc < CJK_TBL_START)) {
	o_cjk_a_tbl[uc - CJK_A_TBL_START] = ic;
    } else if ((uc >= CJK_TBL_START) && (uc < Y_TBL_START)) {
	o_cjk_tbl[uc - CJK_TBL_START] = ic;
    } else if ((uc >= Y_TBL_START) && (uc < HNGL_TBL_START)) {
	o_cjk_y_tbl[uc - Y_TBL_START] = ic;
    } else if ((uc >= HNGL_TBL_START) && (uc <= HNGL_TBL_END)) {
	o_cjk_hngl_tbl[uc - HNGL_TBL_START] = ic;
    } else if ((uc > HNGL_TBL_END) && (uc < PRV_TBL_START)) {
	;	/* internal patch table */
    } else if ((uc >= PRV_TBL_START) && (uc < CPT_TBL_START)) {
	o_prv_tbl[uc - PRV_TBL_START] = ic;
    } else if ((uc >= CPT_TBL_START) && (uc < CPT_TBL_END)) {
	o_cpt_tbl[uc - CPT_TBL_START] = ic;
    } else if ((uc >= HIST_TBL_START) && (uc <= HIST_TBL_END)) {
	o_hist_tbl[uc - HIST_TBL_START] = ic;
    } else if ((uc >= UPMISC_TBL_START) && (uc <= UPMISC_TBL_END)) {
	o_upmisc_tbl[uc - UPMISC_TBL_START] = ic;
    } else if ((uc >= UPKANA_TBL_START) && (uc <= UPKANA_TBL_END)) {
	o_upkana_tbl[uc - UPKANA_TBL_START] = ic;
    } else if ((uc >= NOTE_TBL_START) && (uc <= NOTE_TBL_END)) {
	o_note_tbl[uc - NOTE_TBL_START] = ic;
    } else if ((uc >= CJK_B_TBL_START) && (uc <= CJK_B_TBL_END)) {
	o_cjk_b_tbl[uc - CJK_B_TBL_START] = ic;
    } else if ((uc >= CJK_C_TBL_START) && (uc <= CJK_C_TBL_END)) {
	o_cjk_cc_tbl[uc - CJK_C_TBL_START] = ic;
    } else if (uc == 0) {
	;
    } else if (uc == 0xffff) {	/* Maybe this should not discard. */
    	;
    } else {
	fprintf(stderr,"\n out of patch table: %lx - %lx\n",
		uc,icc); /* out of patchable table. do nothing  */
    };	/* else: discard				   */
    return;
}

/* --------------------------------------------------------------- */
void read_fix_table(fixt)
long	*fixt;
{
    long	fixb;
    unsigned short fixu;

    while (*fixt > 0) {
	fixb = *(fixt++); fixu = (unsigned short) (*(fixt++));
	set_out_table(fixb,fixu);
    };
}
#endif

#if defined(OUTPUT_DYNAMIC_TABLE) || !defined(DYNAMIC_LOADING) || defined(SWIG_EXT)
/* --------------------------------------------------------------- */
void ntt_table_setup()
{
    long i = 0;

/* Vodafone table setup */
/* NTT docomo table setup */
    for (i=0; i<512;i++) i_ntt_tbl[i] = 0;
    for (i=0x3e;i < 0x158; i++) {
	if (uni_f_nttglyph[i-0x3e] < 0xf800) continue;
	i_ntt_tbl[(uni_f_nttglyph[i-0x3e]-0xf800)] = 
		(unsigned short)(i + 0xe600);
    };
}

/* --------------------------------------------------------------- */
void hku_table_gen()
{
    long j,iup,idn,ic;
#ifdef	SKFDEBUG
    if (debug_opt > 8) fprintf(stderr," hku_table_gen ");
#endif
/* BIG5 HKU */
    for (j=0; j < BIG5_TBL_LEN; j++) {
	iup = (j / 190); idn = (j % 190);
	if (iup >= (0xc9 - 0xa1)) {
	    ic = ((iup - 3) * 190) +
		  (((idn >= 0x60) && (idn <= 0x7d)) ?
			(idn - 0x61 + 0xa0) : 0) +
		  (((idn >= 0x00) && (idn <= 0x3e)) ?
			(idn + 0x60) : 0) +
		  (((idn >= 0x7e) && (idn <= 0xbd)) ? 
 			(idn - 0x61 + 0xa0) : 0); 
	    if (ic >= BIG5_TBL_LEN) ic = 0;
	} else ic = j;
	if (((idn >= 0x00) && (idn <= 0x3e)) ||
		((idn >= 0x60) && (idn <= 0xbd))) {
	    big5h_uni_byte[ic]= big5_uni_byte[j];
	};
    };
}
/* --------------------------------------------------------------- */
void big5p_table_gen()
{
    long j,k;
#ifdef	SKFDEBUG
    if (debug_opt > 8) fprintf(stderr," big5p_table_gen ");
#endif
/* generate big5-plus(big5 + hkscs) */
    for (j=0;j< BIG5_TBL_LEN;j++) { /* skip 0x8140-0xa0fe */
    	big5p_uni_byte[BIG5_OFFSET+j] = big5_uni_byte[j];
    };
    /* fill up 0x8140 - 0x84fe */
    for (j=0;j<4; j++) {
	for (k=0;k<190;k++) {
	    if (k == 0x3f) { k = 0x5f; continue; };
	    big5p_uni_byte[(j * 190) + k] =
		(skf_ucode) (0xeeb8 + (j * (190 - 33)) + k
				- ((k >= 0x60) ? 33 : 0));
	};
    };
    /* fill up 0x8540 - 0x87fe: by 0 */
    for (j=4;j<7; j++) {
	for (k=0;k<190;k++) {
	    if (k == 0x3f) { k = 0x5f; continue; };
	    big5p_uni_byte[(j * 190) + k] = 0;
	};
    };
    for (j=0;j<HKSCS_88_LEN;j++) {  /* 8840 - */
    	big5p_uni_byte[j+1330] = hkscs_88_uni_byte[j];
    };
    for (j=0;j<HKSCS_FA_LEN;j++) {  /* fa40 - */
    	if (hkscs_fa_uni_byte[j] != 0) 
	    big5p_uni_byte[21470+j+1330] = hkscs_fa_uni_byte[j];
    };
    for (j=0;j<HKSCS_C6_LEN;j++) {  /* c640 - */
    	if (hkscs_c6_uni_byte[j] != 0) 
	    big5p_uni_byte[11780+j+1330] = hkscs_c6_uni_byte[j];
    };
}
/* --------------------------------------------------------------- */
void big52_table_gen()
{
    long j,k;
#ifdef	SKFDEBUG
    if (debug_opt > 8) fprintf(stderr," big5_2003_table_gen ");
#endif
/* generate big5-plus(big5 + hkscs) */
    for (j=0;j< BIG5_TBL_LEN;j++) { /* skip 0x8140-0xa0fe */
    	big52_uni_byte[BIG5_OFFSET+j] = big5_uni_byte[j]; 
    };
    /* fill up 0x8140 - 0x8dfe */
    for (j=0;j<13; j++) {
	for (k=0;k<190;k++) {
	    if (k == 0x3f) { k = 0x5f; continue; };
	    big52_uni_byte[(j * 190) + k] =
		(skf_ucode) (0xeeb8 + (j * (190 - 33)) + k
				- ((k >= 0x60) ? 33 : 0));
	};
    };
    /* fill up 0x8e40 - 0xa0fe */
    for (j=13;j<32; j++) {
	for (k=0;k<190;k++) {
	    if (k == 0x3f) { k = 0x5f; continue; };
	    big52_uni_byte[(j * 190) + k] =
		(skf_ucode) (0xe311 + ((j - 13) * (190 - 33)) + k
				- ((k >= 0x60) ? 33 : 0));
	};
    };
    /* fill up 0xfa40 - 0xfefe */
    for (j=0;j<5; j++) {
	for (k=0;k<190;k++) {
	    if (k == 0x3f) { k = 0x5f; continue; };
	    big52_uni_byte[(j*190)+k+BIG5_TBL_LEN+BIG5_OFFSET-950] =
		(skf_ucode) (0xe000 + (j * (190 - 33)) + k
				- ((k >= 0x60) ? 33 : 0));
	};
    };
    big52_uni_byte[6085] = 0x2027; big52_uni_byte[6094] = 0xfe51;
    big52_uni_byte[6102] = 0x2015; big52_uni_byte[6106] = 0x2574;

    big52_uni_byte[6242] = 0xff5e; big52_uni_byte[6257] = 0x2295;
    big52_uni_byte[6258] = 0x2299; big52_uni_byte[6269] = 0xff0f;
    big52_uni_byte[6270] = 0xff3c; big52_uni_byte[6271] = 0x2215;
    big52_uni_byte[6272] = 0xfe68; big52_uni_byte[6369] = 0x2501;
    big52_uni_byte[6370] = 0x251d; big52_uni_byte[6371] = 0x253f;
    big52_uni_byte[6372] = 0x2525;
    big52_uni_byte[6410] = 0x3039;

    big52_uni_byte[13238] = 0x2f05; big52_uni_byte[13262] = 0xff3e;

    big52_uni_byte[22985] = 0x2554; big52_uni_byte[22986] = 0x2557;
    big52_uni_byte[22987] = 0x255a; big52_uni_byte[22988] = 0x255d;
}
/* --------------------------------------------------------------- */
void big5a_table_gen()
{
    long j;
#ifdef	SKFDEBUG
    if (debug_opt > 8) fprintf(stderr," big5_uao_table_gen ");
#endif
/* generate big5-plus(big5 + hkscs) */
    for (j=0;j< BIG5_TBL_LEN;j++) { /* skip 0x8140-0xa0fe */
    	big5a_uni_byte[BIG5_OFFSET+j] = big5_uni_byte[j];
    };
    for (j=0;j<BIG5_OFFSET;j++) {  /* 8140 - a0fe */
    	big5a_uni_byte[j] = big5uao_81_uni_byte[j];
    };
    for (j=0;j<BIG5UAO_FA_LEN;j++) {  /* fa40 - fefe*/
	big5a_uni_byte[BIG5P_TBL_LEN+j-BIG5UAO_FA_LEN] = big5uao_fa_uni_byte[j];
    };
    for (j=0;j<HKSCS_C6_LEN;j++) {  /* c640 - */
	big5a_uni_byte[11780+j+1330] = big5uao_c6_uni_byte[j];
    };
    for (j=0;j<29;j++) { 	 /* a3e2 - a3fe */
	big5a_uni_byte[6621+j] = big5uao_a3_uni_byte[j];
    };
    big5a_uni_byte[6085] = 0x2027;
    big5a_uni_byte[6094] = 0xfe51;
    big5a_uni_byte[6106] = 0x2574;
    big5a_uni_byte[6209] = 0x00af;

    big5a_uni_byte[6242] = 0xff5e;
    big5a_uni_byte[6257] = 0x2295; big5a_uni_byte[6258] = 0x2299;
    big5a_uni_byte[6269] = 0xff0f; big5a_uni_byte[6270] = 0xff3c;
    big5a_uni_byte[6271] = 0x2215; big5a_uni_byte[6272] = 0xfe68;

    big5a_uni_byte[6409] = 0x5341; big5a_uni_byte[6411] = 0x5345;

    big5a_uni_byte[12371] = 0x5f5d;
}

/* --------------------------------------------------------------- */
void gbk_table_gen()
{
    long j;
    unsigned int ic;
    long		iup,idn;
    long		dc;

#ifdef	SKFDEBUG
    if (debug_opt > 8) fprintf(stderr," gbk_table_gen ");
#endif
/* gbk table generation */
    for (j=0;j<GBK_TBL_LEN;j++) {
	gbk_uni_byte[j] = 0;	/* cleanup			   */
    };
/* gbk unuse map generation */
    for (j=0;j<0x5200;j++) {
	gbk_gen_map[j] = 0;
    };

    for (j=0;j<ISOMB_CODE_END;j++) {
	iup = (j / 94); idn = (j % 94);
	ic = (unsigned int)
		(((iup - 0x81 + 0xa1) * 190) + (idn + 0xa1 - 0x41));
	gbk_uni_byte[ic] = uni_t_gb2312[j];
	if ((uni_t_gb2312[j] >= 0x4e00) && (uni_t_gb2312[j]<0xa000)) {
	    gbk_gen_map[uni_t_gb2312[j] - 0x4e00] = 1;
	};
    };
    ic = 0; iup = 0xaa; idn = 0;
    for (j=0x4e00;j<=0x9fa5;j++) {
	if (ic < GBK_3_LEN) {	/* area GBK/3			   */
	    if (gbk_gen_map[j - 0x4e00] == 0) {
		gbk_uni_byte[ic++] = (unsigned short)j;
	    };
	} else {
	    dc = ((iup - 0x81) * 190) + idn + 0x00;
	    if (gbk_gen_map[j - 0x4e00] == 0) {
		gbk_uni_byte[dc] = (unsigned short)j; idn++;
	    };
	    if (idn >= 0x60) {
		idn = 0; iup++;
	    };
	};
    };
    /* --- fill private area --- */
    ic = 0xe000;
    for (iup = 0xaa;iup<0xb0;iup++) {
	for (idn = (0xa1 - 1); idn < 0xfe; idn++,ic++) {
	    dc = ((iup - 0x81)*190) + (idn - 0x40);
	    gbk_uni_byte[dc] = (unsigned short)ic;
	};
    };
    ic = 0xe4c6;
    for (iup = 0xa1;iup<=0xa7;iup++) {
	for (idn = 0x40; idn < 0xa1; idn++) {
	    if (idn == 0x7f) continue;
	    dc = ((iup - 0x81)*190) + (idn - 0x40) 
			- ((idn > 0x7f) ? 1 : 0);
	    gbk_uni_byte[dc] = (unsigned short)(ic++);
	};
    };
    ic = 0xe234;
    for (iup = 0xf8;iup<0xfe;iup++) {
	for (idn = (0xa1 - 1); idn < 0xfe; idn++,ic++) {
	    dc = ((iup - 0x81)*190) + (idn - 0x40);
	    gbk_uni_byte[dc] = (unsigned short)ic;
	};
    };
    ic = 0xe810;
    for (idn = (0xfa - 1); idn < 0xfe; idn++,ic++) {
	dc = ((0xd7 - 0x81)*190) + (idn - 0x40);
	gbk_uni_byte[dc] = (unsigned short)ic;
    };
    /* --- compat fill --- */
    gbk_uni_byte[6179] = 0x00b7;
    iup = 0xfd; idn = 0x9c - 1;
    for (j=0;;j++) {
    	if (gbk_compat[j] == 0xffff) break;
	dc = ((iup - 0x81)*190) + (idn - 0x40);
	gbk_uni_byte[dc] = gbk_compat[j]; 
	idn ++; if (idn == 0xfe) { iup++; idn = 0x40;};
    };
    iup = 0xa6; idn = 56;
    for (j=0;j<0x26;j++) {	/* vertical character patch */
	dc = ((iup - 0x81) * 190) + idn + 0xa1 - 0x40 - 1 + j;
	gbk_uni_byte[dc] = gbk_vert_patch[j];
    };
    iup = 0xa2; idn = 0;
    for (j=0;j<12;j++) {	/* latin patch */
	dc = ((iup - 0x81) * 190) + idn + 0xa1 - 0x40 - 1 + j;
	gbk_uni_byte[dc] = (unsigned short)(0x2170 + j);
    };
    for (j=0;;j+=2) {	/* read patch table */
    	if (gbk_cjk_a_patch[j] == 0) break;
    	iup = (gbk_cjk_a_patch[j+1] >> 8) & 0xff;
    	idn = gbk_cjk_a_patch[j+1] & 0xff;
	dc = ((iup - 0x81) * 190) + idn - 0x40 - ((idn > 0x7e) ? 1:0);
	gbk_uni_byte[dc] = gbk_cjk_a_patch[j];
    };

}

/* --------------------------------------------------------------- */
void gb2k_table_gen()
{
    long j;
    long		iup,idn;
    long		dc;

#ifdef	SKFDEBUG
    if (debug_opt > 8) fprintf(stderr," gb2k_table_gen ");
#endif
    gbk_table_gen();
/* gbk table generation */
    for (j=0;j<GBK_TBL_LEN;j++) {
	gb2k_uni_byte[j] = gbk_uni_byte[j];
    };
    iup = 0xfd; idn = 0x9c - 1;
    for (j=0;;j++) {
	dc = ((iup - 0x81)*190) + (idn - 0x40);
	gb2k_uni_byte[dc] = gb2k_compat[j]; 
	idn ++; if (idn == 0xfe) { iup++; idn = 0x40;};
	if (gb2k_compat[j] == 0xffffU) break;
    };
    for (j=0;;j+=2) {	/* read patch table */
    	if (gb2k_cjk_a_patch[j] == 0) break;
    	iup = (gb2k_cjk_a_patch[j+1] >> 8) & 0xff;
    	idn = gb2k_cjk_a_patch[j+1] & 0xff;
	dc = ((iup - 0x81) * 190) + idn - 0x40 - ((idn > 0x7e) ? 1:0);
	gb2k_uni_byte[dc] = gb2k_cjk_a_patch[j];
    };
}
/* --------------------------------------------------------------- */
void gb2k_otbl_gen()
{
    int i,j;
    long ic;
    long uc;

    gb2k_table_gen();

    for (i=0;i<GB2K_A_LEN;i++) {	/* FIXME */
	uc = gb2k_a_tbl[i];
	ic = i | 0x8000U;
	if (uc != 0xffff) set_out_table(uc,ic);
    };
    for (j=0x9fcb;j<0xa000;j++) {
	o_cjk_tbl[j-0x4e00] = (unsigned short)((j - 0x5543) | 0x8000U);
    };

    o_prv_tbl[0x7c7] = 0x28bc;
    o_latin_tbl[0x159] = 0x28bf; o_prv_tbl[0x7c8] = 0x28bf;
#if !defined(STRICT_MS_COMPAT)
    o_kana_tbl[0xfb] = 0x21a4;
    o_prv_tbl[0x819] = 0x7e54; o_prv_tbl[0x81a] = 0x7e55;
    o_prv_tbl[0x81b] = 0x7e56; o_prv_tbl[0x81c] = 0x7e57;
    o_prv_tbl[0x81d] = 0x7e58;
    o_prv_tbl[0x81f] = 0x7e5a; o_prv_tbl[0x820] = 0x7e5b;
    o_prv_tbl[0x821] = 0x7e5c; o_prv_tbl[0x822] = 0x7e5d;
    o_prv_tbl[0x823] = 0x7e5e; o_prv_tbl[0x824] = 0x7e5f;
    o_prv_tbl[0x825] = 0x7e60;
    o_prv_tbl[0x827] = 0x7e62; o_prv_tbl[0x828] = 0x7e63;
    o_prv_tbl[0x829] = 0x7e64; o_prv_tbl[0x82a] = 0x7e65;
    o_prv_tbl[0x82d] = 0x7e68; o_prv_tbl[0x82e] = 0x7e69;
    o_prv_tbl[0x82f] = 0x7e6a; o_prv_tbl[0x830] = 0x7e6b;
    o_prv_tbl[0x833] = 0x7e6e; o_prv_tbl[0x834] = 0x7e6f;
    o_prv_tbl[0x835] = 0x7e70; o_prv_tbl[0x836] = 0x7e71;
    o_prv_tbl[0x837] = 0x7e72; o_prv_tbl[0x838] = 0x7e73;
    o_prv_tbl[0x839] = 0x7e74; o_prv_tbl[0x83a] = 0x7e75;
    o_prv_tbl[0x83b] = 0x7e76; o_prv_tbl[0x83c] = 0x7e77;
    o_prv_tbl[0x83d] = 0x7e78; o_prv_tbl[0x83e] = 0x7e79;
    o_prv_tbl[0x83f] = 0x7e7a; o_prv_tbl[0x840] = 0x7e7b;
    o_prv_tbl[0x841] = 0x7e7c; o_prv_tbl[0x842] = 0x7e7d;
    o_prv_tbl[0x844] = 0x7e80; o_prv_tbl[0x845] = 0x7e81;
    o_prv_tbl[0x846] = 0x7e82; o_prv_tbl[0x847] = 0x7e83;
    o_prv_tbl[0x848] = 0x7e84; o_prv_tbl[0x849] = 0x7e85;
    o_prv_tbl[0x84a] = 0x7e86; o_prv_tbl[0x84b] = 0x7e87;
    o_prv_tbl[0x84c] = 0x7e88; o_prv_tbl[0x84d] = 0x7e89;
    o_prv_tbl[0x84e] = 0x7e8a; o_prv_tbl[0x84f] = 0x7e8b;
    o_prv_tbl[0x850] = 0x7e8c; o_prv_tbl[0x851] = 0x7e8d;
    o_prv_tbl[0x852] = 0x7e8e; o_prv_tbl[0x853] = 0x7e8f;
    o_prv_tbl[0x856] = 0x7e92; o_prv_tbl[0x857] = 0x7e93;
    o_prv_tbl[0x858] = 0x7e94; o_prv_tbl[0x859] = 0x7e95;
    o_prv_tbl[0x85a] = 0x7e96; o_prv_tbl[0x85b] = 0x7e97;
    o_prv_tbl[0x85c] = 0x7e98; o_prv_tbl[0x85d] = 0x7e99;
    o_prv_tbl[0x85e] = 0x7e9a; o_prv_tbl[0x85f] = 0x7e9b;
    o_prv_tbl[0x860] = 0x7e9c; o_prv_tbl[0x861] = 0x7e9d;
    o_prv_tbl[0x862] = 0x7e9e; o_prv_tbl[0x863] = 0x7e9f;
#endif
#if defined(UNICODE_4)
    o_latin_tbl[0x1d9f] = 0x28bc;
#endif

    /* should not need, but some code broke these stuff	*/
    o_cjk_tbl[0x2150] = 0x1d89;

}
/* --------------------------------------------------------------- */
#if 0
static char *emot_tbl_gen_err[3] ={
    "*NTT_EMOJI ERROR2: %x,%x,%x(%x,%x)\n",
    "*AU_EMOJI ERROR2: %x,%x,%x(%x,%x)\n",
    "*SB_EMOJI ERROR2: %x,%x,%x(%x,%x)\n"
};
void emoticon_tlb_gen_part(ch,tbl,ntbl,mod)
skf_ucode ch;
skf_ucode tbl;
skf_ucode ntbl;
int mod;
{
    int low,up,clow,cup;
    int n;
    
    if (uni_map_emoticon[i+mod] != 0) {
	up = (uni_map_emoticon[i+mod] & 0xff00UL) >> 8;
	low = (uni_map_emoticon[i+mod] & 0x00ffUL);
	cup = up + up -((up <= 0x9f) ? 0x102 : 0x182);
	if (low < 0x9f) {
	    clow = low - ((low > A_DEL) ? 0x41 : 0x40);
	} else {
	    clow = low - 0x9f; cup++;
	};
	if (up < 0xf0) {	/* within x-0208 area		*/
	    fprintf(stderr,emot_tbl_gen_err[mod],
			    ch,cup,clow,up,low);
	    a_emoji_j_uni_byte[cup * 94 + clow] = ch;
	} else {
	    cup -= 94;
	    n = cup * 94 + clow;
	    if ((n_e >= EMOJI_TBL_LEN) || (up > 0xfc) || (cup < 0)) {
		fprintf(stderr,emot_tbl_gen_err[mod],
			    ch,cup,clow,up,low);
	    } else {
		a_emoji_a_uni_byte[n] = ch;
	    };
	};
    } else;
}
#endif

void emoticon_table_gen()
{
    int	i,j;
    skf_ucode	ch;
    int		up,low;
    int		cup,clow;
    int		n_e;

    for (j=0;j<ISOMB_CODE_END;j++) {
    	n_emoji_j_uni_byte[j] = 0;
    	a_emoji_j_uni_byte[j] = 0;
    	s_emoji_j_uni_byte[j] = 0;
    };

    for (i=0;uni_map_emoticon[i] != 0;) {
    	ch = uni_map_emoticon[i];
	if (uni_map_emoticon[i+1] != 0) {
	    up = (uni_map_emoticon[i+1] & 0xff00) >> 8;
	    low = (uni_map_emoticon[i+1] & 0x00ff);
	    cup = up + up -((up <= 0x9f) ? 0x102 : 0x182);
	    if (low < 0x9f) {
		clow = low - ((low > A_DEL) ? 0x41 : 0x40);
	    } else {
		clow = low - 0x9f; cup++;
	    };
	    if (up < 0xf0) {	/* within x-0208 area		*/
		fprintf(stderr,"*NTT_EMOJI ERROR2: %x,%x,%x(%x,%x)\n",
		    		ch,cup,clow,up,low);
		n_emoji_j_uni_byte[cup * 94 + clow] = ch;
	    } else {
		cup -= 94;
		n_e = cup * 94 + clow;
		if ((n_e >= EMOJI_TBL_LEN) || (up > 0xfc) || (cup < 0)) {
		    fprintf(stderr,"*NTT_EMOJI ERROR: %x,%x,%x(%x,%x)\n",
		    		ch,cup,clow,up,low);
		} else {
		    n_emoji_a_uni_byte[n_e] = ch;
		};
	    };
	} else;

	if (uni_map_emoticon[i+2] != 0) {
	    up = (uni_map_emoticon[i+2] & 0xff00UL) >> 8;
	    low = (uni_map_emoticon[i+2] & 0x00ffUL);
	    cup = up + up -((up <= 0x9f) ? 0x102 : 0x182);
	    if (low < 0x9f) {
		clow = low - ((low > A_DEL) ? 0x41 : 0x40);
	    } else {
		clow = low - 0x9f; cup++;
	    };
	    if (up < 0xf0) {	/* within x-0208 area		*/
		fprintf(stderr,"*AU_EMOJI ERROR2: %x,%x,%x(%x,%x)\n",
		    		ch,cup,clow,up,low);
		a_emoji_j_uni_byte[cup * 94 + clow] = ch;
	    } else {
		cup -= 94;
		n_e = cup * 94 + clow;
		if ((n_e >= EMOJI_TBL_LEN) || (up > 0xfc) || (cup < 0)) {
		    fprintf(stderr,"*AU ERROR: %x,%x,%x(%x,%x)\n",
		    		ch,cup,clow,up,low);
		} else {
		    a_emoji_a_uni_byte[n_e] = ch;
		};
	    };
	} else;

	if (uni_map_emoticon[i+3] != 0) {
	    up = (uni_map_emoticon[i+3] & 0xff00) >> 8;
	    low = (uni_map_emoticon[i+3] & 0x00ff);
	    cup = up + up -((up <= 0x9f) ? 0x102 : 0x182);
	    if (low < 0x9f) {
		clow = low - ((low > A_DEL) ? 0x41 : 0x40);
	    } else {
		clow = low - 0x9f; cup++;
	    };
	    if (up < 0xf0) {	/* within x-0208 area		*/
		s_emoji_j_uni_byte[cup * 94 + clow] = ch;
	    } else {
		cup -= 94;
		n_e = cup * 94 + clow;
		if ((n_e >= EMOJI_TBL_LEN) || (up > 0xfc) || (cup < 0)) {
		    fprintf(stderr,"*SB ERROR: %x,%x,%x(%x,%x)\n",
		    		ch,cup,clow,up,low);
		} else {
		    s_emoji_a_uni_byte[n_e] = ch;
		};
	    };
	} else;
	i += 4;
    };
}

/* --------------------------------------------------------------- */
void emoti_ntt_otbl_gen()
{
    emoticon_otbl_gen(1);
}

void emoti_sb_otbl_gen()
{
    emoticon_otbl_gen(3);
}

void emoti_au_otbl_gen()
{
    emoticon_otbl_gen(2);
}

void emoticon_otbl_gen(m)
int m;
{
    int i;
    skf_ucode ch;
    int cup,clow,c3;
    skf_ucode uch;
    int up,low;

    for (i=0;i<NOTE_TABLE_LEN;i++) {
    	o_note_tbl[i] = 0;
    };

    emoticon_table_gen();

    for (i=0; uni_map_emoticon[i] != 0;i += 4) {
	ch = uni_map_emoticon[i+m];
	if (ch == 0) continue;
	if (ch >= 0xf000) {
	    low = ch & 0xffU; up = (ch >> 8) & 0xffU;
	    cup = (up - 0xf0) * 2;
	    if (low < 0x9f) {
		clow = low - ((low > A_DEL) ? 0x41 : 0x40);
	    } else {
		clow = low - 0x9f; cup++;
	    };
	    c3 = (cup << 8) + clow + 0xa121;
	} else {	/* SJIS code is < 0xf000	   */
	    low = ch & 0xffU; up = (ch >> 8) & 0xffU;
	    cup = up + up -((up <= 0x9f) ? 0x102 : 0x182);
	    if (low < 0x9f) {
		clow = low - ((low > A_DEL) ? 0x41 : 0x40);
	    } else {
		clow = low - 0x9f; cup++;
	    };
	    c3 = (cup << 8) + clow + 0x2121;
	};
	uch = uni_map_emoticon[i];
	set_out_table(uch,c3);
    };
}

/* **** FIX TABLES *********************************************** */
/* --------------------------------------------------------------- */
void gb2312_otbl_fix()
{
    o_glyph_tbl[0x17] = 0x2124;
    o_kana_tbl[0xfb] = 0x2124;
}
/* --------------------------------------------------------------- */
void gbk_otbl_fix()
{
    gbk_table_gen();

    o_glyph_tbl[0xac] = 0x80; o_prv_tbl[0x18f5] = 0xff;
    o_kana_tbl[0xfb] = 0x21a4;
    o_latin_tbl[0x1d9f] = 0xa8bc;
    o_latin_tbl[0x159] = 0xa8bf;

    /* should not need, but some code broke these stuff	*/
    o_cjk_tbl[0x3dd4] = 0xdab3; o_prv_tbl[0x6cd] = 0xa667;
}
/* --------------------------------------------------------------- */
void big5p_otbl_fix()
{
    int	i,ic,uc;

    hku_table_gen();

    /* sustain old private area mapping */
#ifdef	SKFDEBUG
    if (debug_opt > 8) fprintf(stderr," big5p_table_gen ");
#endif

    for (i=0;hkscs_priv_patch[i] != 0;i += 2) {
	ic = hkscs_priv_patch[i];
	uc = hkscs_priv_patch[i+1];
	set_out_table(uc,ic);
    };
};
/* --------------------------------------------------------------- */
void big5a_otbl_fix()
{
    int	i,ic,uc;

    /* sustain old private area mapping */
#ifdef SKFDEBUG
    if (debug_opt > 8) fprintf(stderr," big5a_table_gen ");
#endif

    big5a_table_gen();

    for (i=0;big5_uao_otbl_patch[i] != 0;i += 2) {
	ic = big5_uao_otbl_patch[i];
	if (ic >= 0x8000) {
	    ic = (ic & 0x7fffU) + 0x2000;
	} else if (ic >= 0x100) {
	    ic = (ic & 0x7fffU) | 0x8000U;
	};
	uc = big5_uao_otbl_patch[i+1];
	set_out_table(uc,ic);
    };
}
/* --------------------------------------------------------------- */
void	x213n_table_gen()
{
    long j;
    skf_ucode	uc;
    long		iup,idn;
    long		dc;
#ifdef SKFDEBUG
    if (debug_opt > 8) fprintf(stderr," x213n_table_gen ");
#endif
    for (j=0; j< ISOMB_CODE_END;j++) {
	x213_1n_uni_byte[j] = uni_t_x213_1[j];
    };

/* JIS X 0213(2004) */
    for (j=0; x0213_0003s_table[j] >= 0; j += 2) {
	dc = x0213_0003s_table[j];
	iup = ((x0213_0003s_table[j+1] >> 8) - 0x21) & 0x7f;
	idn = (x0213_0003s_table[j+1] - 0x21) & 0x7f;
	uc = (skf_ucode)((iup * 94) + idn);
	x213_1n_uni_byte[uc] = (skf_ucode)dc;
    };

}
/* --------------------------------------------------------------- */
void	cp932_table_gen()
{
    int j;
#ifdef SKFDEBUG
    if (debug_opt > 8) fprintf(stderr," cp932_table_gen ");
#endif
    for (j=0; j< ISOMB_CODE_END;j++) {
	cp932_table[j] = uni_t_x208[j];
	cp932w_table[j] = uni_t_x208[j];
    };
}
/* --------------------------------------------------------------- */
void	o_x213_1nfix()
{
#ifdef SKFDEBUG
    if (debug_opt > 8) fprintf(stderr," x0213_1sfix ");
#endif
    x213n_table_gen();
}
/* --------------------------------------------------------------- */
void cp932_fix_tbl()
{
    int i;
    cp932_table_gen();

    o_glyph_tbl[0x225] = 0x2142; o_cpt_tbl[0x60d] = 0x215d;
    o_cpt_tbl[0x65e] = 0x2141; o_cpt_tbl[0x6e2] = 0x224c;
    o_cpt_tbl[0x6e4] = 0x7c7c;
    o_glyph_tbl[0x211] = 0x2d74; o_glyph_tbl[0x780] = 0x2d21;
    o_glyph_tbl[0x781] = 0x2d22; o_glyph_tbl[0x782] = 0x2d23;
    o_glyph_tbl[0x783] = 0x2d24; o_glyph_tbl[0x784] = 0x2d25;
    o_glyph_tbl[0x785] = 0x2d26; o_glyph_tbl[0x786] = 0x2d27;
    o_glyph_tbl[0x787] = 0x2d28; o_glyph_tbl[0x788] = 0x2d29;
    o_glyph_tbl[0x789] = 0x2d2a; o_kana_tbl[0x1d] = 0x2d60;
    o_latin_tbl[0x06] = 0x7c7c;
    
    for (i=0;i<(20*94);i++) o_prv_tbl[i] = 0xa121 + i;
}
/* --------------------------------------------------------------- */
void cp932w_fix_tbl()
{
    int i;

    cp932_table_gen();

    o_glyph_tbl[0x225] = 0x2142; o_cpt_tbl[0x60d] = 0x215d;
    o_cpt_tbl[0x65e] = 0x2141; o_cpt_tbl[0x6e2] = 0x224c;
    o_cpt_tbl[0x6e4] = 0x7c7c;
    o_glyph_tbl[0x211] = 0x2d74; o_glyph_tbl[0x780] = 0x2d21;
    o_glyph_tbl[0x781] = 0x2d22; o_glyph_tbl[0x782] = 0x2d23;
    o_glyph_tbl[0x783] = 0x2d24; o_glyph_tbl[0x784] = 0x2d25;
    o_glyph_tbl[0x785] = 0x2d26; o_glyph_tbl[0x786] = 0x2d27;
    o_glyph_tbl[0x787] = 0x2d28; o_glyph_tbl[0x788] = 0x2d29;
    o_glyph_tbl[0x789] = 0x2d2a; o_kana_tbl[0x1d] = 0x2d60;

    for (i=0xa0; i < 0x100; i++) {
	o_latin_tbl[i - 0xa0] = cp932w_latin_patch[i - 0xa0];
    };
    for (i=0;i<(20*94);i++) o_prv_tbl[i] = 0xa121 + i;
}
/* --------------------------------------------------------------- */
void	cp943_table_gen()
{
    int j;
    for (j=0; j< ISOMB_CODE_END;j++) {
	cp943_table[j] = uni_t_x208[j];
    };
    cp943_table[0x001c] = 0x2014;		/* em dash	   */
    cp943_table[0x0050] = 0xffe0;		/* Cent		   */
    cp943_table[0x0051] = 0xffe1;		/* Pound	   */
    cp943_table[0x0089] = 0xffe2;		/* fullwidth not   */
}
/* --------------------------------------------------------------- */
void cp943_fix_tbl()
{
    cp943_table_gen();

    o_latin_tbl[0x06] = 0x224c;
    o_glyph_tbl[0x14] = 0x213d; o_glyph_tbl[0x15] = 0x213d;
    o_glyph_tbl[0x211] = 0x2d74; o_glyph_tbl[0x225] = 0x2142;
    o_cpt_tbl[0x60d] = 0x215d; o_cpt_tbl[0x65e] = 0x2141;
    o_cpt_tbl[0x6e0] = 0x2171; o_cpt_tbl[0x6e1] = 0x2172;
    o_cpt_tbl[0x6e2] = 0x7c7b; o_cpt_tbl[0x6e4] = 0x7c7c;
}
/* --------------------------------------------------------------- */
void	sjis_cell_fix_tbl()
{
    int j;
    ntt_table_setup();
    for (j=0; j< (0x158 - 0x3e); j++) {
	o_prv_tbl[0x63e + j] = uni_f_nttglyph[j];
    };
}
/* --------------------------------------------------------------- */
void uhc_otbl_fix()
{
    o_latin_tbl[0x0e] = 0xa2e7;
}
/* --------------------------------------------------------------- */
void x0208nj_table_gen()
{
    int i;

    for (i=0;i<ISOMB_CODE_END;i++) {
	x0208_nj_uni_byte[i] = uni_t_x208[i];
    };
    x0208_nj_uni_byte[(0x3cU - 0x21) * 94 + 0x38U - 0x21] = 0x20b9fUL;
    x0208_nj_uni_byte[(0x45U - 0x21) * 94 + 0x36U - 0x21] = 0x5861UL;
    x0208_nj_uni_byte[(0x47U - 0x21) * 94 + 0x6dU - 0x21] = 0x525dUL;
    x0208_nj_uni_byte[(0x4bU - 0x21) * 94 + 0x4bU - 0x21] = 0x9830UL;
}
/* --------------------------------------------------------------- */
void keish_table_gen()
{
    int j;
#ifdef KEIS_EXTRA_SUPPORT
    for (j=0; j< ISOMB_CODE_END;j++) {
	keish_uni_byte[j] = uni_t_x208[j];
    };
    for (j=0; j<36; j++) {
	keish_uni_byte[j+(8*94)] = o_KEIS_AF[j];
    };
#endif
    for (j=0;j<256;j++) {
	ebckeis_uni_byte[j] = ebcdik40[j];
    };
}
/* --------------------------------------------------------------- */
#endif
/* --------------------------------------------------------------- */
void output_various_charmap_assist(uc,ic,num,of,format)
long uc;
int ic,num;
FILE *of;
int format;
{
   if (ic == 0) return;		/* skip undefined codepoint	   */
   if (format == FORMAT_ICU) {
       fprintf(of,"<U%04lX> ",uc);
       if (ic >= 0x100) {
	    fprintf(of,"\\x%02X",((ic >> 8) & 0x0ffU));
	    fprintf(of,"\\x%02X",(ic & 0x0ffU));
       } else {
	    fprintf(of,"\\x%02X",(ic & 0x0ffU));
       };
       fprintf(of, " #|%01d\n",num);
    } else;
}

/* --------------------------------------------------------------- */

#if defined(OUTPUT_DYNAMIC_TABLE) 
/* --------------------------------------------------------------- */
/* dyn_table main:						   */
/*  DYNAMIC_LOADING - generate external table and NULL'd header	   */
/* !DYNAMIC_LOADING - generate header include table definitions	   */
/* --------------------------------------------------------------- */
int main(argc,argv)
int	argc;
char  **argv;
{
    long i = 0,j,k;

    skf_ucode	uc;
    unsigned int ic;
    long		iup,idn;
    long		dc;
    unsigned long	mask;
    union 	psu_tbl_d {unsigned short *s; skf_ucode *l; } psu_tbl;
    int		dfch;
#if defined(DYNAMIC_LOADING) && !defined(SWIG_EXT)
    char	*filename = NULL;
    FILE	*f = NULL;
#endif
    long	typ;
    struct iso_byte_defs *itable,jtable;
    FILE	*iof;		/* in_table_defs.h	*/
    FILE	*of = NULL;	/* out_table_defs.h	*/
/*
 *  output format - specifies table type
 */
    int		out_fmt = FORMAT_SKF;
    char	*opt;
    int		opt_pos;
/*
 *  for other format support
 */
#if defined(DYNAMIC_LOADING) && !defined(SWIG_EXT)
    char	*nametail = "stb";
    int	mb_cur_max,mb_cur_min;
    char *uconv_class;
#endif

#if defined(DYNAMIC_LOADING) && !defined(SWIG_EXT)
    out_fmt = FORMAT_SKF;		/* DYNAMIC_LOADING	*/
#else
    out_fmt = FORMAT_SKFL;	/* !DYNAMIC_LOADING	*/
#endif

    if (argc > 1) {
    	opt_pos = 1;
	for (; (opt_pos < argc) && (*argv[opt_pos] == '-'); opt_pos++) {
	    opt = argv[opt_pos]; opt++;
	    switch (*opt) {
	    	case 'i': out_fmt = FORMAT_ICU; break;
	    	case 'c': out_fmt = FORMAT_CITRUS; break;
	    	case 'g': out_fmt = FORMAT_GNU; break;
	    	case 'm': out_fmt = FORMAT_MOZ; break;
		default:  out_fmt = FORMAT_SKF;
	    };
	};
    };

/* output side table generation */
    for (j=0; j< ISOMB_CODE_END;j++) {
	k = (j / 94);
	if ((j <= X0208_KANJI_END) && (k != 12)) {
	    x0208_long_table[j] = uni_t_x208[j]; /* */
	} else x0208_long_table[j] = 0;
    };
/* MAINTAIN ORDER */
/* set tables defined in in_code_table.c			   */
    iso_unibyte_defs[12].unitbl = (unsigned short *)gb198880_uni_byte;
    /* --- Nr.12: KOI-8 ---------- */
    dyn_out_codeset[11].g1unitbl = (unsigned short *)ascii_uni_byte;
    dyn_out_codeset[11].g3unitbl = (unsigned short *)koi8_uni_byte;
    /* --- Nr.13: cp1251 ---------- */
    dyn_out_codeset[12].g1unitbl = (unsigned short *)ascii_uni_byte;
    dyn_out_codeset[12].g2unitbl = (unsigned short *)cp1251_u_uni_byte;
    /* --- Nr.14,5: iso8859-1,7 ---------- */
    dyn_out_codeset[13].g1unitbl = (unsigned short *)ascii_uni_byte;
    dyn_out_codeset[13].g2unitbl = (unsigned short *)iso8859_1_uni_byte;
    dyn_out_codeset[14].g1unitbl = (unsigned short *)ascii_uni_byte;
    dyn_out_codeset[14].g2unitbl = (unsigned short *)iso8859_7_uni_byte;

    /* --- Nr.23: GBK ---------- */
    /* --- Nr.24-36: iso8859-* ---------- */
    dyn_out_codeset[23].g1unitbl = (unsigned short *)ascii_uni_byte;
    dyn_out_codeset[24].g1unitbl = (unsigned short *)ascii_uni_byte;
    dyn_out_codeset[25].g1unitbl = (unsigned short *)ascii_uni_byte;
    dyn_out_codeset[26].g1unitbl = (unsigned short *)ascii_uni_byte;
    dyn_out_codeset[27].g1unitbl = (unsigned short *)ascii_uni_byte;
    dyn_out_codeset[28].g1unitbl = (unsigned short *)ascii_uni_byte;
    dyn_out_codeset[29].g1unitbl = (unsigned short *)ascii_uni_byte;
    dyn_out_codeset[30].g1unitbl = (unsigned short *)ascii_uni_byte;
    dyn_out_codeset[31].g1unitbl = (unsigned short *)ascii_uni_byte;
    dyn_out_codeset[32].g1unitbl = (unsigned short *)ascii_uni_byte;
    dyn_out_codeset[33].g1unitbl = (unsigned short *)ascii_uni_byte;
    dyn_out_codeset[34].g1unitbl = (unsigned short *)ascii_uni_byte;
    dyn_out_codeset[35].g1unitbl = (unsigned short *)ascii_uni_byte;

    dyn_out_codeset[23].g2unitbl = (unsigned short *)iso8859_2_uni_byte;
    dyn_out_codeset[24].g2unitbl = (unsigned short *)iso8859_3_uni_byte;
    dyn_out_codeset[25].g2unitbl = (unsigned short *)iso8859_4_uni_byte;
    dyn_out_codeset[26].g2unitbl = (unsigned short *)iso8859_5_uni_byte;
    dyn_out_codeset[27].g2unitbl = (unsigned short *)iso8859_6_uni_byte;
    dyn_out_codeset[28].g2unitbl = (unsigned short *)iso8859_8_uni_byte;
    dyn_out_codeset[29].g2unitbl = (unsigned short *)iso8859_9_uni_byte;
    dyn_out_codeset[30].g2unitbl = (unsigned short *)iso8859_10_uni_byte;
    dyn_out_codeset[31].g2unitbl = (unsigned short *)tis620_2533_uni_byte;
    dyn_out_codeset[32].g2unitbl = (unsigned short *)iso8859_13_uni_byte;
    dyn_out_codeset[33].g2unitbl = (unsigned short *)iso8859_14_uni_byte;
    dyn_out_codeset[34].g2unitbl = (unsigned short *)iso8859_15_uni_byte;
    dyn_out_codeset[35].g2unitbl = (unsigned short *)iso8859_16_uni_byte;
    /* --- Nr.36: BIG5-plus ---- */
    /* --- Nr.37: GB18030 ------ */
    dyn_out_codeset[38].g2unitbl = (unsigned short *)ebcdic40;
    dyn_out_codeset[39].g2unitbl = (unsigned short *)ebcdic41;
    dyn_out_codeset[40].g2unitbl = (unsigned short *)ebcdic42;
    dyn_out_codeset[41].g2unitbl = (unsigned short *)ebcdic43;
    dyn_out_codeset[46].g2unitbl = (unsigned short *)ebcdic44;

/* input side table generation */
    i = 0;
    if ((out_fmt == FORMAT_SKF) ||
    	(out_fmt == FORMAT_SKFL)) {
	fprintf(stderr,"\n** generating input side tables: ");
    } else {
	fprintf(stderr,"\n** generating alternate tables: ");
	if (out_fmt == FORMAT_ICU) fprintf(stderr,"ICU ");
	if (out_fmt == FORMAT_CITRUS) fprintf(stderr,"CITRUS ");
	if (out_fmt == FORMAT_MOZ) fprintf(stderr,"MOZILLA ");
	if (out_fmt == FORMAT_GNU) fprintf(stderr,"GNU ");
    };

/* output side table preparation */
    if ((out_fmt == FORMAT_SKF) ||
    	(out_fmt == FORMAT_SKFL)) {
	if ((iof = fopen(SKF_IN_CODE_FILE,SKF_OUTMODE)) == NULL) {
	    fprintf(stderr,"skf_dyn_table: input table open failed %s\n",
			SKF_IN_CODE_FILE);
			exit(0);
	};
	if ((of = fopen(SKF_OUT_CODE_FILE,SKF_OUTMODE)) == NULL) {
	    fprintf(stderr,"skf_dyn_table: output table open failed %s\n",
			SKF_OUT_CODE_FILE);
			exit(0);
	};
    } else {
	if ((iof = fopen(SKF_IN_CODE_FILE,SKF_OUTMODE)) == NULL) {
	    fprintf(stderr,"skf_dyn_table: input table open failed %s\n",
			SKF_IN_CODE_FILE);
			exit(0);
	};
	if ((of = fopen(SKF_ALT_TABLE_FILE,SKF_OUTMODE)) == NULL) {
	    fprintf(stderr,"skf_dyn_table: output table open failed %s\n",
			SKF_ALT_TABLE_FILE);
			exit(0);
	};
    };
#if defined(DYNAMIC_LOADING) && !defined(SWIG_EXT)
    filename = (char *)calloc(SKF_TABLE_PATH,sizeof(char));
#endif
    while ((itable = iso_bytedef_table[i].ientry) != NULL) {
	j = 0; 
	i++;
	while (itable[j].defschar != 0) {
	    typ = itable[j].is_kana;
	    jtable = itable[j++];
	    if (jtable.cname == NULL) continue; 
	    fprintf(stderr,"\n%s - ",jtable.cname); (void)fflush(stderr);
	    if (typ & COD_NISO) {	/* non-iso	*/
		typ |= ((jtable.table_len > 256) ? COD_MB : 0);
	    };
	    if (jtable.hook != NULL) {
		(*jtable.hook)();
	    };
	    if ((jtable.unitbl != NULL) 
		|| (jtable.uniltbl != NULL)) {
#if defined(DYNAMIC_LOADING) && !defined(SWIG_EXT)
		dc = jtable.defschar & 0x7f;
		if ((dc >= 0x40) && (dc < 0x7f)) {
		    dc = charname_conv[dc-0x40];
		};
		if (snprintf(filename,SKF_TABLE_PATH-2,
    		    "table/i%c%c%c%c%c.stb",
		    (typ & COD_NISO) ? ((typ & COD_MB_4) ? 'O' : 'N') : 'I',
		    (typ & COD_MB) ? 'M' : 'S',
		    (typ & COD_MB_4) ? '4' : '3',
    /* call letter capitalize, for windows are case insensitive	   */
		    (((dc >= 'a') && (dc <= 'z')) ?
		    ((typ & COD_SET96) ? '7' : '5') :
		    ((typ & COD_SET96) ? '6' : '4')), 
		    (int)(SKFtoupper(dc))) < 0) {
		    fprintf(stderr,"dyn_table: internal error\n");
		    exit(0);
		};
		fprintf(stderr,"%s ",filename);
		if ((f = fopen(filename,SKF_OUTMODE)) == NULL) {
    fprintf(stderr,"skf_dyn_table: output table open failed %s\n",
		    filename);
		    exit(0);
		};
		(void)fflush(iof);
		gen_tables(&(jtable),f,iof,out_fmt);
		fclose(f);
#else
		(void)fflush(iof);
		gen_tables(&(jtable),NULL,iof,out_fmt);
#endif
	    } else {
		continue;
	    }; 
	};
    };

    fprintf(stderr,"\n** generating output side tables: ");
/* output side table generation */
    for (i=0; dyn_out_codeset[i].char_width != 0; i++) {
	fprintf(stderr,"\n generating %s ..",dyn_out_codeset[i].desc);
	(void)fflush(stdout);
/* clear allocate buffer table */
	for (j=0; j<ASCII_TABLE_LEN; j++) o_ascii_tbl[j] = 0;
	for (j=0; j<KANA_TABLE_LEN; j++) o_kana_tbl[j] = 0;
	for (j=0; j<CJK_TABLE_LEN; j++) o_cjk_tbl[j] = 0;
	for (j=0; j<GLYPH_TABLE_LEN; j++) o_glyph_tbl[j] = 0;
	for (j=0; j<LATIN_TABLE_LEN; j++) o_latin_tbl[j] = 0;
	for (j=0; j<CJK_A_TABLE_LEN; j++) o_cjk_a_tbl[j] = 0;
	for (j=0; j<CJK_B_TABLE_LEN; j++) o_cjk_b_tbl[j] = 0;
	for (j=0; j<CJK_C_TABLE_LEN; j++) o_cjk_cc_tbl[j] = 0;
	for (j=0; j<CPT_TABLE_LEN; j++) o_cpt_tbl[j] = 0;
	for (j=0; j<Y_TABLE_LEN; j++) o_cjk_y_tbl[j] = 0;
	for (j=0; j<HNGL_TABLE_LEN; j++) o_cjk_hngl_tbl[j] = 0;
	for (j=0; j<PRV_TABLE_LEN; j++) o_prv_tbl[j] = 0;
	for (j=0; j<HIST_TABLE_LEN; j++) o_hist_tbl[j] = 0;
	for (j=0; j<NOTE_TABLE_LEN; j++) o_note_tbl[j] = 0;
	for (j=0; j<UPKANA_TABLE_LEN; j++) o_upkana_tbl[j] = 0;
	for (j=0; j<UPMISC_TABLE_LEN; j++) o_upmisc_tbl[j] = 0;

/* fill table */
	mask = (dyn_out_codeset[i].valtbl & 0xffffUL);
	/* fill compat area beforehand */
	if (dyn_out_codeset[i].valtbl & OTBL_JIS) {
	      for (j=0; j< CPT_TABLE_LEN; j++) {
		o_cpt_tbl[j] = uni_f_compat[j];
		}; };
	for (k=0; k<4; k++) {
	  if (dyn_out_codeset[i].defschar[k] == 0) continue;
	  if (k == 0) {
		/* just dirty hacks. recast table to skf_ucode */
	    if (dyn_out_codeset[i].char_width == 4)
		psu_tbl.l = (skf_ucode *)(dyn_out_codeset[i].g1uniltbl);
	    else 
		psu_tbl.s = dyn_out_codeset[i].g1unitbl;
	  } else if (k == 1) {
	    if (dyn_out_codeset[i].char_width == 4)
		psu_tbl.l = (skf_ucode *)(dyn_out_codeset[i].g2uniltbl);
	    else 
		psu_tbl.s = dyn_out_codeset[i].g2unitbl;
	  } else if (k == 2) {
	    if (dyn_out_codeset[i].char_width == 4)
		psu_tbl.l = (skf_ucode *)(dyn_out_codeset[i].g3uniltbl);
	    else 
		psu_tbl.s = dyn_out_codeset[i].g3unitbl;
	  } else {
	    if (dyn_out_codeset[i].char_width == 4)
		psu_tbl.l = (skf_ucode *)(dyn_out_codeset[i].g4uniltbl);
	    else 
		psu_tbl.s = dyn_out_codeset[i].g4unitbl;
	  };
	  if (((dyn_out_codeset[i].char_width == 4) && psu_tbl.l == NULL)
    || ((dyn_out_codeset[i].char_width != 4) && psu_tbl.s == NULL)) {
	    fprintf(stderr,"\n fault: table is empty - %s(k: %ld)\n",
			dyn_out_codeset[i].desc,k);
	    exit(0);
	  };
	  for (j=0; j<dyn_out_codeset[i].table_len[k]; j++) {
	    if ((dyn_out_codeset[i].valtbl & OTBL_JOHAB)
		&& (k == 1) && (j == (12 * 94))) {
			/* use only HANZI part of KS X 1001	   */
		j = (JOHAB_KOFFSET * 94) - 1;
		continue; 	/* should fix			   */
	    };
	  /* --- UC generation --- */
	    if (dyn_out_codeset[i].char_width == 4)
		uc = psu_tbl.l[j];
	    else 
		uc = psu_tbl.s[j];
	  /* --- IC generation --- */
	    if (otbl_isotype(dyn_out_codeset[i].valtbl)) {	
		iup = (j / 94); idn = (j % 94);
		ic = ((iup + 0x21) << 8) + (idn + 0x21);
	    } else if (dyn_out_codeset[i].valtbl & OTBL_BIG5) {
		iup = (j / 190); idn = (j % 190);
		ic = (((iup + 0x21) << 8) + (idn + 0x40)
			+ ((idn >= 0x5e) ? 1 : 0)) & 0xffffUL;
		if (dyn_out_codeset[i].valtbl & OTBL_CP950) {
				/* MS variant(cp950) BIG5	   */
		    if ((ic >= 0x46a1) && (ic < 0xc900)) {
			ic = 0;		/* not defined in cp950	   */
		    };
		} else ;		/* normal BIG5		   */
	    } else if (dyn_out_codeset[i].valtbl & OTBL_JOHAB) {
		if (k == 0) {	/* HANGLE JOHAB code		   */
		    iup = (j / 188); idn = (j % 188);
		    ic = (((iup + 0x84) << 8) + (idn + 0x41)
			+ ((idn >= 0x3d) ? 2 : 0)) & 0xffffUL;
		} else {
		  iup = (j / 94); idn = (j % 94);
		  if (j > (12*94)) {
		    ic = (((((iup - JOHAB_KOFFSET) >> 1) + JOHAB_HANJA1) << 8)
			+ ((iup & 0x1) ? ((idn >= 0x4e) ? 0x12 : 0): 0x70)
			+ (idn + 0x31)) & 0xffffUL;
		  } else {
		    ic = ((((iup >> 1) + JOHAB_HANJA0) << 8)
			+ ((iup & 0x1) ? 0x70 : ((idn >= 0x4e) ? 0x12 : 0))
			+ (idn + 0x31)) & 0xffffUL;
		  };
		};
	    } else if (dyn_out_codeset[i].valtbl & OTBL_GBK) {
		iup = (j / 190); idn = (j % 190);
		ic = (((iup + 0x81) << 8) + (idn + 0x40)
			+ ((idn > 0x3e) ? 1 : 0)) & 0xffffUL;
		if (i == ocs_gb18030_index) {
		    ic = ic & 0x7fffUL; if (k == 1) ic = j;
		};
	    } else if (dyn_out_codeset[i].valtbl & OTBL_MONO) {
		if (j < 128) ic = j;
		else ic = 0;
	    } else if (dyn_out_codeset[i].valtbl & OTBL_EBC) {
		if (i == 47) {	/* keis				*/
		    if (k == 3) {
			iup = (j / 94); idn = (j % 94);
			ic = ((iup + 0xa1) << 8) + (idn + 0xa1);
		    } else if (k == 0) {
			iup = (j / 94); idn = (j % 94);
			ic = ((iup + 0x59) << 8) + (idn + 0xa1);
		    } else if (k == 2) {
			ic = 0x9f00 + (j + 0xa1);
		    } else ic = j;	/* k == 1 */
		} else if (k == 0) {
		    iup = (j / 190); idn = (j % 190);
		    ic = ((iup + 0x41) << 8) + (idn + 0x41);
		} else ic = j;
	    } else {
		ic = 0x2121;
	    };
/* --- dimensions --- */
	    if (k == 3) {
		ic |= 0x0080;
	    } else if (k == 2) {
		ic |= 0x8080;
	    } else if (is_OTBL_X213C(dyn_out_codeset[i].valtbl)) {
		if (k == 0) ic |= 0x8000UL;
	    } else if (k == 1) {
		if (((dyn_out_codeset[i].valtbl & OTBL_JOHAB) == 0) &&
			((dyn_out_codeset[i].valtbl & OTBL_EBC) == 0)) 
		    ic |= 0x8000UL;
	    };

	  /* --- Fill up tables --- */
	    if ((uc >= 0x00a0) && (uc < 0x2000)) {
		if (!(dyn_out_codeset[i].valtbl & OTBL_ABSUP) 
			|| (ic < 0x2a20) || (ic > 0x2b7f)) {
		    o_latin_tbl[uc - 0x00a0] = ic;
		};
	    } else if ((uc >= 0x2000) && (uc < 0x3000)) {
		if (dyn_out_codeset[i].valtbl & OTBL_BIG5) {
		    if ((ic < 0x7900) || 
			(uc < 0x2500) || (uc >= 0x2580)) {
			if (o_glyph_tbl[uc - 0x2000] == 0) {
			    o_glyph_tbl[uc - 0x2000] = ic;
			};
		    } else {
			if (o_glyph_tbl[uc - 0x2000] == 0) {
			    o_glyph_tbl[uc - 0x2000] = ic;
			};
		    };
		} else if (dyn_out_codeset[i].valtbl & OTBL_JIS) {
		    if ((i == 18) || (i == 17)) { /* cp932 or 943  */
			if (o_glyph_tbl[uc - 0x2000] == 0) {
			    o_glyph_tbl[uc - 0x2000] = ic;
			};
		    } else {
			o_glyph_tbl[uc - 0x2000] = ic;
		    };
		} else {
		    o_glyph_tbl[uc - 0x2000] = ic;
		};
	    } else if ((uc >= 0x4e00) && (uc < 0xa000)) {
		if (((i != ocs_iso2022cnc_index) && 
		    (i != ocs_iso2022cng_index)) ||
			o_cjk_tbl[uc - 0x4e00] == 0) {
		    o_cjk_tbl[uc - 0x4e00] = ic;
		};
	    } else {
		set_out_table(uc,ic);
	    };
	  };
	};
/* added fix. iso-2022-jp-3 & 3-strict kana table smudge fix */
	if (dyn_out_codeset[i].valtbl & OTBL_JIS) {
	    for (j=0;j<KANA_TABLE_LEN;j++) {
		if ((uni_f_kana[j] != 0) && (uni_f_kana[j]<0x8000))
			o_kana_tbl[j] = uni_f_kana[j];
	    };
/* several overwrite fix */
	    if (is_OTBL_X213C(dyn_out_codeset[i].valtbl)) {
		o_cpt_tbl[0x602] = 0xa230;
		o_cpt_tbl[0x60d] = 0xa231;
		o_cpt_tbl[0x6e4] = 0xa925;
		o_kana_tbl[0x18] = 0xa258; o_kana_tbl[0x19] = 0xa259;
		o_kana_tbl[0x1a] = 0xa25a; o_kana_tbl[0x1b] = 0xa25b;
		o_kana_tbl[0x16] = 0xa25a; o_kana_tbl[0x17] = 0xa25b;
		o_kana_tbl[0x1d] = 0xad60;
		o_latin_tbl[0x46] = 0xa95c;
		o_latin_tbl[0x1b4] = 0xab38;
		o_latin_tbl[0x1b9] = 0xab30;
		o_latin_tbl[0x1ba] = 0xab43;
		o_latin_tbl[0x1ec] = 0xab37;
	    } else if (is_OTBL_X213(dyn_out_codeset[i].valtbl)){
		read_fix_table(x0213_0003_table);
	    } else if (is_OTBL_JISK(dyn_out_codeset[i].valtbl)){
	    	/* JIS but not X-0213			   */
		read_fix_table(uni_fix_table);
		o_glyph_tbl[0x14] = 0x2141; o_glyph_tbl[0x212] = 0x215d;
	    } else;	/* does not apply any kanji related patch */
	};
/* --- codeset specific fixes --- */
	if (dyn_out_codeset[i].otablegen != NULL) {
	    (dyn_out_codeset[i].otablegen)();
	};
/* --- codeset specific fixes --- */
/* --- output begins here ------- */
#if defined(DYNAMIC_LOADING) && !defined(SWIG_EXT)
	if (out_fmt == FORMAT_SKF) {
	  for (j=0;(mask & 0xffffUL) != 0; mask = (mask << 1), j++) {
	    if ((mask & 0x4000UL) != 0) {
		dc = (int)(dyn_out_codeset[i].defschar[0] & 0x7f);
		if ((dc >= 0x40) && (dc < 0x7f) &&
			!(dyn_out_codeset[i].valtbl & OTBL_NC)) {
		    dc = charname_conv[dc-0x40];
		};
		dfch = otbl_reg_defs[j].defschar;
		if (out_fmt == FORMAT_ICU) {
		    nametail = "ucm";
		} else if (out_fmt == FORMAT_CITRUS) {
		    nametail = "src";
		} else;
		if (snprintf(filename,SKF_TABLE_PATH-2,
    		    "table/o%cM%c%c%c.%s",
		    (dyn_out_codeset[i].valtbl & OTBL_NC) ? 'N' : 'I',
		    (((dc >= 'a') && (dc <= 'z')) ?
		    ((dyn_out_codeset[i].table_len[0] > 256) ? 'N' : 'T'):
		    ((dyn_out_codeset[i].table_len[0] > 256) ? 'M' : 'S')),
		    ((is_OTBL_X213C(dyn_out_codeset[i].valtbl)) ?
		     'P' : (int)(SKFtoupper(dc))), dfch, nametail) < 0) {
		    fprintf(stderr,"dyn_table: internal error\n");
		    exit(0);
		};
		fprintf(stderr,"%s ",filename);
		(void)fflush(stderr);
		if ((f = fopen(filename,SKF_OUTMODE)) == NULL) {
	fprintf(stderr,"skf_dyn_table: output table open failed %s\n",
		    filename);
		    exit(0);
		};
		fprintf(f,"skf_ctable20");
		for (k=0; k < otbl_reg_defs[j].len; k++) {
		    putc((otbl_reg_defs[j].tbl[k] >> 8) & 0xff,f);
		    putc(otbl_reg_defs[j].tbl[k] & 0xff,f);
		};
		fclose(f);
		fprintf(of,"\n#define ot_%s%c\tNULL",
			dyn_out_codeset[i].desc,dfch);
	    };
	  };
	} else if (out_fmt == FORMAT_ICU) {
	    if (dyn_out_codeset[i].char_width > 1) {
		mb_cur_max = 2;
		mb_cur_min = 2;
		uconv_class = "MBCS";
	    } else {
		mb_cur_max = 1;
		mb_cur_min = 1;
		uconv_class = "SBCS";
	    };
	    fprintf(of,"<code_set_name>\t\"%s\"\n",
		dyn_out_codeset[i].desc);
	    fprintf(of,"<char_name_mask>\t\"AXXXX\"\n");
	    fprintf(of,"<mb_cur_max>\t%01d\n",mb_cur_max);
	    fprintf(of,"<mb_cur_min>\t%01d\n",mb_cur_min);
	    fprintf(of,"<uconv_class>\t\"%s\"\n",uconv_class);
	    fprintf(of,"<subchar>\t\\x3F\n");
	    fprintf(of,
		"#\nCHARMAP\n#\n#\n#10646  %s\n#------ -----\n",
		dyn_out_codeset[i].desc);
	    for (j=0; (j<ASCII_TABLE_LEN) && (mask & OTBL_ASCII); j++) 
	output_various_charmap_assist(j,o_ascii_tbl[j],0,of,out_fmt);
	    for (j=0; (j<LATIN_TABLE_LEN) && (mask & OTBL_LATIN); j++) 
	output_various_charmap_assist(j+0xa0,o_latin_tbl[j],0,of,out_fmt);
	    for (j=0; (j<GLYPH_TABLE_LEN) && (mask & OTBL_GLYPHS); j++) 
	output_various_charmap_assist(j+0x2000,o_glyph_tbl[j],0,of,out_fmt);
	    for (j=0; (j<KANA_TABLE_LEN) && (mask & OTBL_KANA); j++) 
	output_various_charmap_assist(j+0x3000,o_kana_tbl[j],0,of,out_fmt);
	    for (j=0; (j<CJK_A_TABLE_LEN) && (mask & OTBL_CJK_A); j++) 
	output_various_charmap_assist(j+0x3400,o_cjk_a_tbl[j],0,of,out_fmt);
	    for (j=0; (j<CJK_TABLE_LEN) && (mask & OTBL_KANJI); j++) 
	output_various_charmap_assist(j+0x4e00,o_cjk_tbl[j],0,of,out_fmt);
	    for (j=0; (j<Y_TABLE_LEN) && (mask & OTBL_Y); j++)
	output_various_charmap_assist(j+Y_TBL_START,o_cjk_y_tbl[j],
		0,of,out_fmt);
	    for (j=0; (j<HNGL_TABLE_LEN) && (mask & OTBL_HNGL); j++) 
	output_various_charmap_assist(j+HNGL_TBL_START,o_cjk_hngl_tbl[j],
      		0,of,out_fmt);
	    for (j=0; (j<PRV_TABLE_LEN) && (mask & OTBL_PRV); j++)
	output_various_charmap_assist(j+0xe000,o_prv_tbl[j],0,of,out_fmt);
	    for (j=0; (j<CPT_TABLE_LEN) && (mask & OTBL_COMPAT); j++) 
	output_various_charmap_assist(j+0xf900,o_cpt_tbl[j],0,of,out_fmt);
	    for (j=0; (j<HIST_TABLE_LEN) && (mask & OTBL_HIST); j++) 
	output_various_charmap_assist(j+HIST_TBL_START,o_hist_tbl[j],
		0,of,out_fmt);
	    for (j=0; (j<UPKANA_TABLE_LEN) && (mask & OTBL_UPKANA); j++)
	output_various_charmap_assist(j+UPKANA_TBL_START,o_upkana_tbl[j],
		0,of,out_fmt);
	    for (j=0; (j<UPMISC_TABLE_LEN) && (mask & OTBL_UPMISC); j++)
	output_various_charmap_assist(j+UPMISC_TBL_START,o_upmisc_tbl[j],
		0,of,out_fmt);
	    for (j=0; (j<NOTE_TABLE_LEN) && (mask & OTBL_NOTE); j++)
	output_various_charmap_assist(j+NOTE_TBL_START,o_note_tbl[j],
		0,of,out_fmt);
	    for (j=0; (j<CJK_B_TABLE_LEN) && (mask & OTBL_CJK_B); j++)
	output_various_charmap_assist(j+CJK_B_TBL_START,o_cjk_b_tbl[j],
		0,of,out_fmt);
	    for (j=0; (j<CJK_C_TABLE_LEN) && (mask & OTBL_CJK_CC); j++)
	output_various_charmap_assist(j+CJK_C_TBL_START,o_cjk_cc_tbl[j],
		0,of,out_fmt);
	} else if (out_fmt == FORMAT_CITRUS) {
	    fprintf(stderr,"Sorry, CITRUS format is not yet supported.");
	} else;
#else
	for (j=0;(mask & 0xffffUL) != 0; mask = (mask << 1), j++) {
	    if ((mask & 0x4000UL) != 0) {
		dc = (int)(dyn_out_codeset[i].defschar[0] & 0x7f);
		if ((dc >= 0x40) && (dc < 0x7f) &&
			!(dyn_out_codeset[i].valtbl & OTBL_NC)) {
		    dc = charname_conv[dc-0x40];
		};
		dfch = otbl_reg_defs[j].defschar;
		fprintf(of,"\nunsigned short ot_%s%c[%d] = {\n",
			dyn_out_codeset[i].desc,
			dfch,otbl_reg_defs[j].len);
		for (k=0; k < otbl_reg_defs[j].len; k++) {
		    fprintf(of,"0x%04x",otbl_reg_defs[j].tbl[k]);
		    if (k < (otbl_reg_defs[j].len - 1)) {
			putc(',',of);
		    } else {
			fprintf(of,"\n};\n\n");
		    };
		    if ((k & 0x07) == 0x07) putc('\n',of);
		};
	    };
	};
#endif
    };
    fprintf(stderr,"\n");
    fprintf(of,"\n");
#if defined(DYNAMIC_LOADING) && !defined(SWIG_EXT)
    if ((out_fmt == FORMAT_ICU) || (out_fmt == FORMAT_CITRUS) 
    	|| (out_fmt == FORMAT_MOZ) || (out_fmt == FORMAT_GNU)) {
	fprintf(of,"\n");
    };
#endif
    fclose(of);
    fclose(iof);
    exit(0) ;
}
#endif	/* OUTPUT_DYNAMIC_TABLE	*/
